export type Maybe<T> = T | null
export type InputMaybe<T> = Maybe<T>
export type Exact<T extends { [key: string]: unknown }> = {
  [K in keyof T]: T[K]
}
export type MakeOptional<T, K extends keyof T> = Omit<T, K> & {
  [SubKey in K]?: Maybe<T[SubKey]>
}
export type MakeMaybe<T, K extends keyof T> = Omit<T, K> & {
  [SubKey in K]: Maybe<T[SubKey]>
}
/** All built-in and custom scalars, mapped to their actual values */
export type Scalars = {
  ID: string
  String: string
  Boolean: boolean
  Int: number
  Float: number
  /**
   * An Amazon Web Services Amazon Resource Name (ARN), including the Region and account ID.
   * For more information, refer to [Amazon Resource Names](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html).
   */
  ARN: any
  /**
   * Represents an [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601)-encoded date string.
   * For example, September 7, 2019 is represented as `"2019-07-16"`.
   *
   */
  Date: any
  /**
   * Represents an [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601)-encoded date and time string.
   * For example, 3:30 pm on September 7, 2019 in the time zone of UTC (Coordinated Universal Time) is
   * represented as `"2019-09-07T15:50:00Z`".
   *
   */
  DateTime: any
  /**
   * A signed decimal number, which supports arbitrary precision and is serialized as a string.
   *
   * Example values: `"29.99"`, `"29.999"`.
   *
   */
  Decimal: any
  /**
   * A string containing a strict subset of HTML code. Non-allowed tags will be stripped out.
   * Allowed tags:
   * * `a` (allowed attributes: `href`)
   * * `b`
   * * `br`
   * * `em`
   * * `i`
   * * `strong`
   * * `u`
   * Use [HTML](https://shopify.dev/api/admin-graphql/latest/scalars/HTML) instead if you need to
   * include other HTML tags.
   *
   * Example value: `"Your current domain is <strong>johns-apparel.myshopify.com</strong>."`
   *
   */
  FormattedString: any
  /**
   * A string containing HTML code. Refer to the [HTML spec](https://html.spec.whatwg.org/#elements-3) for a
   * complete list of HTML elements.
   *
   * Example value: `"<p>Grey cotton knit sweater.</p>"`.
   *
   */
  HTML: any
  /**
   * A [JSON](https://www.json.org/json-en.html) object.
   *
   * Example value:
   * `{
   *   "product": {
   *     "id": "gid://shopify/Product/1346443542550",
   *     "title": "White T-shirt",
   *     "options": [{
   *       "name": "Size",
   *       "values": ["M", "L"]
   *     }]
   *   }
   * }`
   *
   */
  JSON: any
  /** A monetary value string without a currency symbol or code. Example value: `"100.57"`. */
  Money: any
  /**
   * Represents a unique identifier in the Storefront API. A `StorefrontID` value can be used wherever an ID is expected in the Storefront API.
   *
   * Example value: `"Z2lkOi8vc2hvcGlmeS9Qcm9kdWN0LzEwMDc5Nzg1MTAw"`.
   *
   */
  StorefrontID: any
  /**
   * Represents an [RFC 3986](https://datatracker.ietf.org/doc/html/rfc3986) and
   * [RFC 3987](https://datatracker.ietf.org/doc/html/rfc3987)-compliant URI string.
   *
   * For example, `"https://johns-apparel.myshopify.com"` is a valid URL. It includes a scheme (`https`) and a host
   * (`johns-apparel.myshopify.com`).
   *
   */
  URL: any
  /**
   * An unsigned 64-bit integer. Represents whole numeric values between 0 and 2^64 - 1 encoded as a string of base-10 digits.
   *
   * Example value: `"50"`.
   *
   */
  UnsignedInt64: any
  /**
   * Time between UTC time and a location's observed time, in the format `"+HH:MM"` or `"-HH:MM"`.
   *
   * Example value: `"-07:00"`.
   *
   */
  UtcOffset: any
}

/**
 * Represents the permission required to access a Shopify Admin API or Storefront API resource for a shop. Access scopes are granted by merchants to requesting applications.
 *
 */
export type AccessScope = {
  __typename?: 'AccessScope'
  /** Description of the resource access provided by the access scope when granted to an application. */
  description: Scalars['String']
  /**
   * Represents the access scope as a readable string. Typically follows the format `{action}_{resource}`: a `read` or `write` action, followed by the resource on which the action is allowed to be performed on, separated by an underscore. For example, `read_orders`; `write_products`.
   *
   */
  handle: Scalars['String']
}

/** A sale associated with an order price adjustment. */
export type AdjustmentSale = Sale & {
  __typename?: 'AdjustmentSale'
  /** The type of order action that the sale represents. */
  actionType: SaleActionType
  /** The unique identifier for the sale. */
  id: Scalars['ID']
  /** The line type assocated with the sale. */
  lineType: SaleLineType
  /** The number of units either ordered or intended to be returned. */
  quantity?: Maybe<Scalars['Int']>
  /** All individual taxes associated with the sale. */
  taxes: Array<SaleTax>
  /** The total sale amount after taxes and discounts. */
  totalAmount: MoneyBag
  /** The total discounts allocated to the sale after taxes. */
  totalDiscountAmountAfterTaxes: MoneyBag
  /** The total discounts allocated to the sale before taxes. */
  totalDiscountAmountBeforeTaxes: MoneyBag
  /** The total amount of taxes for the sale. */
  totalTaxAmount: MoneyBag
}

/** Whether all items in the cart are entitled to the discount. */
export type AllDiscountItems = {
  __typename?: 'AllDiscountItems'
  /** Whether all items are selected. The value is hardcoded to `true`. */
  allItems: Scalars['Boolean']
}

/**
 * A version of the API, as defined by [Shopify API versioning](https://shopify.dev/api/usage/versioning).
 * Versions are commonly referred to by their handle (for example, `2021-10`).
 *
 */
export type ApiVersion = {
  __typename?: 'ApiVersion'
  /** The human-readable name of the version. */
  displayName: Scalars['String']
  /** The unique identifier of an ApiVersion. All supported API versions have a date-based (YYYY-MM) or `unstable` handle. */
  handle: Scalars['String']
  /** Whether the version is actively supported by Shopify. Supported API versions are guaranteed to be stable. Unsupported API versions include unstable, release candidate, and end-of-life versions that are marked as unsupported. For more information, refer to [Versioning](https://shopify.dev/api/usage/versioning). */
  supported: Scalars['Boolean']
}

/** A Shopify application. */
export type App = Node & {
  __typename?: 'App'
  /** A unique application API identifier. */
  apiKey: Scalars['String']
  /** App store page URL of the app. */
  appStoreAppUrl?: Maybe<Scalars['URL']>
  /** App store page URL of the developer who created the app. */
  appStoreDeveloperUrl?: Maybe<Scalars['URL']>
  /** Banner image for the app. */
  banner: Image
  /** Description of the app. */
  description?: Maybe<Scalars['String']>
  /** The name of the app developer. */
  developerName?: Maybe<Scalars['String']>
  /**
   * Website of the developer who created the app.
   * @deprecated Use `appStoreDeveloperUrl` instead
   */
  developerUrl: Scalars['URL']
  /** Whether the app uses the Embedded App SDK. */
  embedded: Scalars['Boolean']
  /** Requirements that must be met before the app can be installed. */
  failedRequirements: Array<FailedRequirement>
  /** A list of app features that are shown in the Shopify App Store listing. */
  features: Array<Scalars['String']>
  /** Feedback from this app about the store. */
  feedback?: Maybe<AppFeedback>
  /** Handle of the app. */
  handle?: Maybe<Scalars['String']>
  /** Icon that represents the app. */
  icon: Image
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** Webpage where you can install the app. */
  installUrl?: Maybe<Scalars['URL']>
  /**
   * Corresponding AppInstallation for this shop and App.
   * Returns null if the App is not installed.
   *
   */
  installation?: Maybe<AppInstallation>
  /**
   * Whether the app is the [post purchase](https://shopify.dev/apps/checkout/post-purchase) app in use.
   *
   */
  isPostPurchaseAppInUse: Scalars['Boolean']
  /**
   * Webpage that the app starts in.
   * @deprecated Use AppInstallation.launchUrl instead
   */
  launchUrl: Scalars['URL']
  /**
   * Menu items for the app, which also appear as submenu items in left navigation sidebar in the Shopify admin.
   *
   * @deprecated Use AppInstallation.navigationItems instead
   */
  navigationItems: Array<NavigationItem>
  /** Detailed information about the app pricing. */
  pricingDetails?: Maybe<Scalars['String']>
  /** Summary of the app pricing details. */
  pricingDetailsSummary: Scalars['String']
  /** Link to app privacy policy. */
  privacyPolicyUrl?: Maybe<Scalars['URL']>
  /** Whether the app is published to the Shopify App Store. */
  published: Scalars['Boolean']
  /** Screenshots of the app. */
  screenshots: Array<Image>
  /** Whether the app was developed by Shopify. */
  shopifyDeveloped: Scalars['Boolean']
  /** Name of the app. */
  title: Scalars['String']
  /**
   * Message that appears when the app is uninstalled. For example:
   * By removing this app, you will no longer be able to publish products to MySocialSite or view this app in your Shopify admin. You can re-enable this channel at any time.
   *
   */
  uninstallMessage: Scalars['String']
  /**
   * Webpage where you can uninstall the app.
   * @deprecated Use AppInstallation.uninstallUrl instead
   */
  uninstallUrl?: Maybe<Scalars['URL']>
}

/**
 * An auto-generated type for paginating through multiple Apps.
 *
 */
export type AppConnection = {
  __typename?: 'AppConnection'
  /** A list of edges. */
  edges: Array<AppEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** App credits can be applied by the merchant towards future app purchases, subscriptions, or usage records in Shopify. */
export type AppCredit = Node & {
  __typename?: 'AppCredit'
  /** The amount that can be used towards future app purchases in Shopify. */
  amount: MoneyV2
  /** The date and time when the app credit was created. */
  createdAt: Scalars['DateTime']
  /** The description of the app credit. */
  description: Scalars['String']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** Whether the app credit is a test transaction. */
  test: Scalars['Boolean']
}

/**
 * An auto-generated type for paginating through multiple AppCredits.
 *
 */
export type AppCreditConnection = {
  __typename?: 'AppCreditConnection'
  /** A list of edges. */
  edges: Array<AppCreditEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `appCreditCreate` mutation. */
export type AppCreditCreatePayload = {
  __typename?: 'AppCreditCreatePayload'
  /** The newly created app credit. */
  appCredit?: Maybe<AppCredit>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one AppCredit and a cursor during pagination.
 *
 */
export type AppCreditEdge = {
  __typename?: 'AppCreditEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of AppCreditEdge. */
  node: AppCredit
}

/**
 * An auto-generated type which holds one App and a cursor during pagination.
 *
 */
export type AppEdge = {
  __typename?: 'AppEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of AppEdge. */
  node: App
}

/**
 * Reports the status of shops and their resources and displays this information
 * within Shopify admin. AppFeedback is used to notify merchants about steps they need to take
 * to set up an app on their store.
 *
 */
export type AppFeedback = {
  __typename?: 'AppFeedback'
  /** The application associated to the feedback. */
  app: App
  /** A link to where merchants can resolve errors. */
  link?: Maybe<Link>
  /** The feedback message presented to the merchant. */
  messages: Array<UserError>
}

/** Represents an installed application on a shop. */
export type AppInstallation = Node & {
  __typename?: 'AppInstallation'
  /** The access scopes granted to the application by a merchant during installation. */
  accessScopes: Array<AccessScope>
  /** The active application subscriptions billed to the shop on a recurring basis. */
  activeSubscriptions: Array<AppSubscription>
  /** All subscriptions created for a shop. */
  allSubscriptions: AppSubscriptionConnection
  /** Application which is installed. */
  app: App
  /**
   * Channel associated with the installed application.
   * @deprecated Use `publication` instead
   */
  channel?: Maybe<Channel>
  /** Credits that can be used towards future app purchases. */
  credits: AppCreditConnection
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The URL to launch the application. */
  launchUrl: Scalars['URL']
  /** One-time purchases to a shop. */
  oneTimePurchases: AppPurchaseOneTimeConnection
  /** The publication associated with the installed application. */
  publication?: Maybe<Publication>
  /** The records that track the externally-captured revenue for the app. The records are used for revenue attribution purposes. */
  revenueAttributionRecords: AppRevenueAttributionRecordConnection
  /**
   * Subscriptions charge to a shop on a recurring basis.
   * @deprecated Use `activeSubscriptions` instead
   */
  subscriptions: Array<AppSubscription>
  /** The URL to uninstall the application. */
  uninstallUrl?: Maybe<Scalars['URL']>
}

/** Represents an installed application on a shop. */
export type AppInstallationAllSubscriptionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<AppSubscriptionSortKeys>
}

/** Represents an installed application on a shop. */
export type AppInstallationCreditsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<AppTransactionSortKeys>
}

/** Represents an installed application on a shop. */
export type AppInstallationOneTimePurchasesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<AppTransactionSortKeys>
}

/** Represents an installed application on a shop. */
export type AppInstallationRevenueAttributionRecordsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<AppRevenueAttributionRecordSortKeys>
}

/**
 * The possible categories of an app installation, based on their purpose
 * or the environment they can run in.
 *
 */
export enum AppInstallationCategory {
  /** Apps that serve as channels through which sales are made, such as the online store. */
  Channel = 'CHANNEL',
  /** Apps that can be used in the POS mobile client. */
  PosEmbedded = 'POS_EMBEDDED',
}

/**
 * An auto-generated type for paginating through multiple AppInstallations.
 *
 */
export type AppInstallationConnection = {
  __typename?: 'AppInstallationConnection'
  /** A list of edges. */
  edges: Array<AppInstallationEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one AppInstallation and a cursor during pagination.
 *
 */
export type AppInstallationEdge = {
  __typename?: 'AppInstallationEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of AppInstallationEdge. */
  node: AppInstallation
}

/** The levels of privacy of an app installation. */
export enum AppInstallationPrivacy {
  Private = 'PRIVATE',
  Public = 'PUBLIC',
}

/** The set of valid sort keys for the AppInstallation query. */
export enum AppInstallationSortKeys {
  /** Sort by the `app_title` value. */
  AppTitle = 'APP_TITLE',
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `installed_at` value. */
  InstalledAt = 'INSTALLED_AT',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/**
 * The pricing model for the app subscription.
 * The pricing model input can be either `appRecurringPricingDetails` or `appUsagePricingDetails`.
 *
 */
export type AppPlanInput = {
  /** The pricing details for recurring billing. */
  appRecurringPricingDetails?: InputMaybe<AppRecurringPricingInput>
  /** The pricing details for usage-based billing. */
  appUsagePricingDetails?: InputMaybe<AppUsagePricingInput>
}

/** The app plan that the merchant is subscribed to. */
export type AppPlanV2 = {
  __typename?: 'AppPlanV2'
  /** The plan billed to a shop on a recurring basis. */
  pricingDetails: AppPricingDetails
}

/**
 * The information about the price that's charged to a shop every plan period.
 * The concrete type can be `AppRecurringPricing` for recurring billing or `AppUsagePricing` for usage-based billing.
 *
 */
export type AppPricingDetails = AppRecurringPricing | AppUsagePricing

/** The frequency at which the shop is billed for an app subscription. */
export enum AppPricingInterval {
  /** The app subscription bills the shop annually. */
  Annual = 'ANNUAL',
  /** The app subscription bills the shop every 30 days. */
  Every_30Days = 'EVERY_30_DAYS',
}

/** Services and features purchased once by the store. */
export type AppPurchase = {
  /** The date and time when the app purchase occurred. */
  createdAt: Scalars['DateTime']
  /** The name of the app purchase. */
  name: Scalars['String']
  /** The amount to be charged to the store for the app purchase. */
  price: MoneyV2
  /** The status of the app purchase. */
  status: AppPurchaseStatus
  /** Whether the app purchase is a test transaction. */
  test: Scalars['Boolean']
}

/** Services and features purchased once by a store. */
export type AppPurchaseOneTime = AppPurchase &
  Node & {
    __typename?: 'AppPurchaseOneTime'
    /** The date and time when the app purchase occurred. */
    createdAt: Scalars['DateTime']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The name of the app purchase. */
    name: Scalars['String']
    /** The amount to be charged to the store for the app purchase. */
    price: MoneyV2
    /** The status of the app purchase. */
    status: AppPurchaseStatus
    /** Whether the app purchase is a test transaction. */
    test: Scalars['Boolean']
  }

/**
 * An auto-generated type for paginating through multiple AppPurchaseOneTimes.
 *
 */
export type AppPurchaseOneTimeConnection = {
  __typename?: 'AppPurchaseOneTimeConnection'
  /** A list of edges. */
  edges: Array<AppPurchaseOneTimeEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `appPurchaseOneTimeCreate` mutation. */
export type AppPurchaseOneTimeCreatePayload = {
  __typename?: 'AppPurchaseOneTimeCreatePayload'
  /** The newly created app one-time purchase. */
  appPurchaseOneTime?: Maybe<AppPurchaseOneTime>
  /**
   * The URL that the merchant can access to approve or decline the newly created app one-time purchase.
   *
   * If the merchant declines, then the merchant is redirected to the app and receives a notification message stating that the charge was declined.
   * If the merchant approves and they're successfully invoiced, then the state of the charge changes from `pending` to `active`.
   *
   * You get paid after the charge is activated.
   *
   */
  confirmationUrl?: Maybe<Scalars['URL']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one AppPurchaseOneTime and a cursor during pagination.
 *
 */
export type AppPurchaseOneTimeEdge = {
  __typename?: 'AppPurchaseOneTimeEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of AppPurchaseOneTimeEdge. */
  node: AppPurchaseOneTime
}

/**
 * The approval status of the app purchase.
 *
 * The merchant is charged for the purchase immediately after approval, and the status changes to `active`.
 * If the payment fails, then the app purchase remains `pending`.
 *
 * Purchases start as `pending` and can change to: `active`, `declined`, `expired`. After a purchase changes, it
 * remains in that final state.
 *
 */
export enum AppPurchaseStatus {
  /** The app purchase has been approved by the merchant and is ready to be activated by the app. App purchases created through the GraphQL Admin API are activated upon approval. */
  Accepted = 'ACCEPTED',
  /** The app purchase was approved by the merchant and has been activated by the app. Active app purchases are charged to the merchant and are paid out to the partner. */
  Active = 'ACTIVE',
  /** The app purchase was declined by the merchant. */
  Declined = 'DECLINED',
  /** The app purchase was not accepted within two days of being created. */
  Expired = 'EXPIRED',
  /** The app purchase is pending approval by the merchant. */
  Pending = 'PENDING',
}

/**
 * The pricing information about a subscription app.
 * The object contains an interval (the frequency at which the shop is billed for an app subscription) and
 * a price (the amount to be charged to the subscribing shop at each interval).
 *
 */
export type AppRecurringPricing = {
  __typename?: 'AppRecurringPricing'
  /** The frequency at which the subscribing shop is billed for an app subscription. */
  interval: AppPricingInterval
  /** The amount and currency to be charged to the subscribing shop every billing interval. */
  price: MoneyV2
}

/** Instructs the app subscription to generate a fixed charge on a recurring basis. The frequency is specified by the billing interval. */
export type AppRecurringPricingInput = {
  /** How often the app subscription generates a charge. */
  interval?: InputMaybe<AppPricingInterval>
  /** The amount to be charged to the store every billing interval. The only permitted currency code is USD. */
  price: MoneyInput
}

/** Represents app revenue that was captured externally by the partner. */
export type AppRevenueAttributionRecord = Node & {
  __typename?: 'AppRevenueAttributionRecord'
  /** The financial amount captured in this attribution. */
  amount: MoneyV2
  /** The timestamp when the financial amount was captured. */
  capturedAt: Scalars['DateTime']
  /** The timestamp at which this revenue attribution was issued. */
  createdAt: Scalars['DateTime']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /**
   * The unique value submitted during the creation of the app revenue attribution record.
   * For more information, refer to
   * [Idempotent requests](https://shopify.dev/api/usage/idempotent-requests).
   *
   */
  idempotencyKey: Scalars['String']
  /** Indicates whether this is a test submission. */
  test: Scalars['Boolean']
  /** The type of revenue attribution. */
  type: AppRevenueAttributionType
}

/**
 * An auto-generated type for paginating through multiple AppRevenueAttributionRecords.
 *
 */
export type AppRevenueAttributionRecordConnection = {
  __typename?: 'AppRevenueAttributionRecordConnection'
  /** A list of edges. */
  edges: Array<AppRevenueAttributionRecordEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `appRevenueAttributionRecordCreate` mutation. */
export type AppRevenueAttributionRecordCreatePayload = {
  __typename?: 'AppRevenueAttributionRecordCreatePayload'
  /** The created app revenue attribution record. */
  appRevenueAttributionRecord?: Maybe<AppRevenueAttributionRecord>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<AppRevenueAttributionRecordCreateUserError>
}

/** An error that occurs during the execution of `AppRevenueAttributionRecordCreate`. */
export type AppRevenueAttributionRecordCreateUserError = DisplayableError & {
  __typename?: 'AppRevenueAttributionRecordCreateUserError'
  /** The error code. */
  code?: Maybe<AppRevenueAttributionRecordCreateUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `AppRevenueAttributionRecordCreateUserError`. */
export enum AppRevenueAttributionRecordCreateUserErrorCode {
  /** The input value is invalid. */
  Invalid = 'INVALID',
  /** The input value is already taken. */
  Taken = 'TAKEN',
}

/** Return type for `appRevenueAttributionRecordDelete` mutation. */
export type AppRevenueAttributionRecordDeletePayload = {
  __typename?: 'AppRevenueAttributionRecordDeletePayload'
  /** The ID of the revenue attribution that was deleted, if one was. */
  deletedId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<AppRevenueAttributionRecordDeleteUserError>
}

/** An error that occurs during the execution of `AppRevenueAttributionRecordDelete`. */
export type AppRevenueAttributionRecordDeleteUserError = DisplayableError & {
  __typename?: 'AppRevenueAttributionRecordDeleteUserError'
  /** The error code. */
  code?: Maybe<AppRevenueAttributionRecordDeleteUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `AppRevenueAttributionRecordDeleteUserError`. */
export enum AppRevenueAttributionRecordDeleteUserErrorCode {
  /** The input value is invalid. */
  Invalid = 'INVALID',
}

/**
 * An auto-generated type which holds one AppRevenueAttributionRecord and a cursor during pagination.
 *
 */
export type AppRevenueAttributionRecordEdge = {
  __typename?: 'AppRevenueAttributionRecordEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of AppRevenueAttributionRecordEdge. */
  node: AppRevenueAttributionRecord
}

/** Allows to supply an app revenue attribution record. */
export type AppRevenueAttributionRecordInput = {
  /** The financial amount captured in this attribution. */
  amount: MoneyInput
  /** The timestamp when the financial amount was captured. */
  capturedAt: Scalars['DateTime']
  /**
   * The unique value submitted during creation.
   * For more information, refer to
   * [Idempotent requests](https://shopify.dev/api/usage/idempotent-requests).
   *
   */
  idempotencyKey: Scalars['String']
  /** Indicates whether this is a test submission. */
  test: Scalars['Boolean']
  /** The type of revenue attribution. */
  type: AppRevenueAttributionType
}

/** The set of valid sort keys for the AppRevenueAttributionRecord query. */
export enum AppRevenueAttributionRecordSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/** Represents the billing types of revenue attribution. */
export enum AppRevenueAttributionType {
  /** App purchase related revenue collection. */
  ApplicationPurchase = 'APPLICATION_PURCHASE',
  /** App subscription revenue collection. */
  ApplicationSubscription = 'APPLICATION_SUBSCRIPTION',
  /** App usage-based revenue collection. */
  ApplicationUsage = 'APPLICATION_USAGE',
  /** Other app revenue collection type. */
  Other = 'OTHER',
}

/** Provides users access to services and/or features for a duration of time. */
export type AppSubscription = Node & {
  __typename?: 'AppSubscription'
  /** The date and time when the app subscription was created. */
  createdAt: Scalars['DateTime']
  /** The date and time when the current app subscription period ends. */
  currentPeriodEnd?: Maybe<Scalars['DateTime']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The plans attached to the app subscription. */
  lineItems: Array<AppSubscriptionLineItem>
  /** The name of the app subscription. */
  name: Scalars['String']
  /** The URL that the merchant is redirected to after approving the app subscription. */
  returnUrl: Scalars['URL']
  /** The status of the app subscription. */
  status: AppSubscriptionStatus
  /** Specifies whether the app subscription is a test transaction. */
  test: Scalars['Boolean']
  /** The number of free trial days, starting at the subscription's creation date, by which billing is delayed. */
  trialDays: Scalars['Int']
}

/** Return type for `appSubscriptionCancel` mutation. */
export type AppSubscriptionCancelPayload = {
  __typename?: 'AppSubscriptionCancelPayload'
  /** The cancelled app subscription. */
  appSubscription?: Maybe<AppSubscription>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type for paginating through multiple AppSubscriptions.
 *
 */
export type AppSubscriptionConnection = {
  __typename?: 'AppSubscriptionConnection'
  /** A list of edges. */
  edges: Array<AppSubscriptionEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `appSubscriptionCreate` mutation. */
export type AppSubscriptionCreatePayload = {
  __typename?: 'AppSubscriptionCreatePayload'
  /** The newly-created app subscription. */
  appSubscription?: Maybe<AppSubscription>
  /** The URL pointing to the page where the merchant approves or declines the charges for an app subscription. */
  confirmationUrl?: Maybe<Scalars['URL']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one AppSubscription and a cursor during pagination.
 *
 */
export type AppSubscriptionEdge = {
  __typename?: 'AppSubscriptionEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of AppSubscriptionEdge. */
  node: AppSubscription
}

/** The plan attached to an app subscription. */
export type AppSubscriptionLineItem = {
  __typename?: 'AppSubscriptionLineItem'
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The pricing model for the app subscription. */
  plan: AppPlanV2
  /** A list of the store's usage records for a usage pricing plan. */
  usageRecords: AppUsageRecordConnection
}

/** The plan attached to an app subscription. */
export type AppSubscriptionLineItemUsageRecordsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<AppUsageRecordSortKeys>
}

/** Allows an app to add more than one pricing plan to an app subscription. */
export type AppSubscriptionLineItemInput = {
  /** The pricing model for the app subscription. */
  plan: AppPlanInput
}

/** Return type for `appSubscriptionLineItemUpdate` mutation. */
export type AppSubscriptionLineItemUpdatePayload = {
  __typename?: 'AppSubscriptionLineItemUpdatePayload'
  /** The updated app subscription. */
  appSubscription?: Maybe<AppSubscription>
  /** The URL where the merchant approves or declines the updated app subscription line item. */
  confirmationUrl?: Maybe<Scalars['URL']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** The set of valid sort keys for the AppSubscription query. */
export enum AppSubscriptionSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/** The status of the app subscription. */
export enum AppSubscriptionStatus {
  /** The app subscription has been approved by the merchant and is ready to be activated by the app. */
  Accepted = 'ACCEPTED',
  /** The app subscription has been approved by the merchant. Active app subscriptions are billed to the shop. After payment, partners receive payouts. */
  Active = 'ACTIVE',
  /** The app subscription was cancelled by the app. This could be caused by the app being uninstalled, a new app subscription being activated, or a direct cancellation by the app. This is a terminal state. */
  Cancelled = 'CANCELLED',
  /** The app subscription was declined by the merchant. This is a terminal state. */
  Declined = 'DECLINED',
  /** The app subscription wasn't accepted within two days of being created. This is a terminal state. */
  Expired = 'EXPIRED',
  /** The app subscription is on hold due to non-payment. The subscription re-activates after payments resume. */
  Frozen = 'FROZEN',
  /** The app subscription is pending approval by the merchant. */
  Pending = 'PENDING',
}

/** The set of valid sort keys for the AppTransaction query. */
export enum AppTransactionSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/**
 * Defines a usage pricing model for the app subscription.
 * These charges are variable based on how much the merchant uses the app.
 *
 */
export type AppUsagePricing = {
  __typename?: 'AppUsagePricing'
  /** The total usage records for interval. */
  balanceUsed: MoneyV2
  /**
   * The capped amount prevents the merchant from being charged for any usage over that amount during a billing period.
   * This prevents billing from exceeding a maximum threshold over the duration of the billing period.
   * For the merchant to continue using the app after exceeding a capped amount, they would need to agree to a new usage charge.
   *
   */
  cappedAmount: MoneyV2
  /** The frequency with which the app usage records are billed. */
  interval: AppPricingInterval
  /**
   * The terms and conditions for app usage pricing.
   * Must be present in order to create usage charges.
   * The terms are presented to the merchant when they approve an app's usage charges.
   *
   */
  terms: Scalars['String']
}

/** Allows an app to issue arbitrary charges for app usage associated with a subscription. */
export type AppUsagePricingInput = {
  /** The maximum amount of usage charges that can be incurred within a subscription billing interval. */
  cappedAmount: MoneyInput
  /** The terms and conditions for app usage. These terms stipulate the pricing model for the charges that an app creates. */
  terms: Scalars['String']
}

/** Store usage for app subscriptions with usage pricing. */
export type AppUsageRecord = Node & {
  __typename?: 'AppUsageRecord'
  /** The date and time when the usage record was created. */
  createdAt: Scalars['DateTime']
  /** The description of the app usage record. */
  description: Scalars['String']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The price of the usage record. The only permitted currency code is USD. */
  price: MoneyV2
  /** Defines the usage pricing plan the merchant is subscribed to. */
  subscriptionLineItem: AppSubscriptionLineItem
}

/**
 * An auto-generated type for paginating through multiple AppUsageRecords.
 *
 */
export type AppUsageRecordConnection = {
  __typename?: 'AppUsageRecordConnection'
  /** A list of edges. */
  edges: Array<AppUsageRecordEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `appUsageRecordCreate` mutation. */
export type AppUsageRecordCreatePayload = {
  __typename?: 'AppUsageRecordCreatePayload'
  /** The newly created app usage record. */
  appUsageRecord?: Maybe<AppUsageRecord>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one AppUsageRecord and a cursor during pagination.
 *
 */
export type AppUsageRecordEdge = {
  __typename?: 'AppUsageRecordEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of AppUsageRecordEdge. */
  node: AppUsageRecord
}

/** The set of valid sort keys for the AppUsageRecord query. */
export enum AppUsageRecordSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/** Represents a generic custom attribute. */
export type Attribute = {
  __typename?: 'Attribute'
  /** Key or name of the attribute. */
  key: Scalars['String']
  /** Value of the attribute. */
  value?: Maybe<Scalars['String']>
}

/** Specifies the input fields required for an attribute. */
export type AttributeInput = {
  /** Key or name of the attribute. */
  key: Scalars['String']
  /** Value of the attribute. */
  value: Scalars['String']
}

/**
 * Automatic discount applications capture the intentions of a discount that was automatically applied.
 *
 */
export type AutomaticDiscountApplication = DiscountApplication & {
  __typename?: 'AutomaticDiscountApplication'
  /** The method by which the discount's value is allocated to its entitled items. */
  allocationMethod: DiscountApplicationAllocationMethod
  /**
   * An ordered index that can be used to identify the discount application and indicate the precedence
   * of the discount application for calculations.
   *
   */
  index: Scalars['Int']
  /** How the discount amount is distributed on the discounted lines. */
  targetSelection: DiscountApplicationTargetSelection
  /** Whether the discount is applied on line items or shipping lines. */
  targetType: DiscountApplicationTargetType
  /** The title of the discount application. */
  title: Scalars['String']
  /** The value of the discount application. */
  value: PricingValue
}

/** The set of valid sort keys for the AutomaticDiscount query. */
export enum AutomaticDiscountSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/**
 * Basic events chronicle resource activities such as the creation of an article, the fulfillment of an order, or
 * the addition of a product.
 *
 */
export type BasicEvent = Event &
  Node & {
    __typename?: 'BasicEvent'
    /** The name of the app that created the event. */
    appTitle?: Maybe<Scalars['String']>
    /** Whether the event was created by an app. */
    attributeToApp: Scalars['Boolean']
    /** Whether the event was caused by an admin user. */
    attributeToUser: Scalars['Boolean']
    /** The date and time when the event was created. */
    createdAt: Scalars['DateTime']
    /** Whether the event is critical. */
    criticalAlert: Scalars['Boolean']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** Human readable text that describes the event. */
    message: Scalars['FormattedString']
  }

/** Represents an error that happens during the execution of a billing attempt mutation. */
export type BillingAttemptUserError = DisplayableError & {
  __typename?: 'BillingAttemptUserError'
  /** The error code. */
  code?: Maybe<BillingAttemptUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `BillingAttemptUserError`. */
export enum BillingAttemptUserErrorCode {
  /** The input value is blank. */
  Blank = 'BLANK',
  /** Subscription contract does not exist. */
  ContractNotFound = 'CONTRACT_NOT_FOUND',
  /** The input value is invalid. */
  Invalid = 'INVALID',
}

/** Possible error codes that can be returned by `BulkMutationUserError`. */
export enum BulkMutationErrorCode {
  /** There was a problem reading the JSONL file. This error might be intermittent, so you can try performing the same query again. */
  InternalFileServerError = 'INTERNAL_FILE_SERVER_ERROR',
  /** The operation did not run because the mutation is invalid. Check your mutation syntax and try again. */
  InvalidMutation = 'INVALID_MUTATION',
  /** The JSONL file submitted via the `stagedUploadsCreate` mutation is invalid. Update the file and try again. */
  InvalidStagedUploadFile = 'INVALID_STAGED_UPLOAD_FILE',
  /** The JSONL file could not be found. Try [uploading the file](https://shopify.dev/api/usage/bulk-operations/imports#generate-the-uploaded-url-and-parameters) again, and check that you've entered the URL correctly for the `bulkOperationRunMutationUploadPath` mutation argument. */
  NoSuchFile = 'NO_SUCH_FILE',
  /** The operation did not run because another bulk mutation is already running. [Wait for the operation to finish](https://shopify.dev/api/usage/bulk-operations/imports#wait-for-the-operation-to-finish) before retrying this operation. */
  OperationInProgress = 'OPERATION_IN_PROGRESS',
}

/** Represents an error that happens during execution of a bulk mutation. */
export type BulkMutationUserError = DisplayableError & {
  __typename?: 'BulkMutationUserError'
  /** The error code. */
  code?: Maybe<BulkMutationErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/**
 * An asynchronous long-running operation to fetch data in bulk or to bulk import data.
 *
 * Bulk operations are created using the `bulkOperationRunQuery` or `bulkOperationRunMutation` mutation. After
 * they are created, clients should poll the `status` field for updates. When `COMPLETED`, the `url` field contains
 * a link to the data in [JSONL](http://jsonlines.org/) format.
 *
 * Refer to the [bulk operations guide](https://shopify.dev/api/usage/bulk-operations/imports) for more details.
 *
 */
export type BulkOperation = Node & {
  __typename?: 'BulkOperation'
  /** When the bulk operation was successfully completed. */
  completedAt?: Maybe<Scalars['DateTime']>
  /** When the bulk operation was created. */
  createdAt: Scalars['DateTime']
  /** Error code for failed operations. */
  errorCode?: Maybe<BulkOperationErrorCode>
  /** File size in bytes of the file in the `url` field. */
  fileSize?: Maybe<Scalars['UnsignedInt64']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /**
   * A running count of all the objects processed.
   * For example, when fetching all the products and their variants, this field counts both products and variants.
   * This field can be used to track operation progress.
   *
   */
  objectCount: Scalars['UnsignedInt64']
  /**
   * The URL that points to the partial or incomplete response data (in [JSONL](http://jsonlines.org/) format) that was returned by a failed operation.
   * The URL expires 7 days after the operation fails. Returns `null` when there's no data available.
   *
   */
  partialDataUrl?: Maybe<Scalars['URL']>
  /** GraphQL query document specified in `bulkOperationRunQuery`. */
  query: Scalars['String']
  /**
   * A running count of all the objects that are processed at the root of the query.
   * For example, when fetching all the products and their variants, this field only counts products.
   * This field can be used to track operation progress.
   *
   */
  rootObjectCount: Scalars['UnsignedInt64']
  /** Status of the bulk operation. */
  status: BulkOperationStatus
  /** The bulk operation's type. */
  type: BulkOperationType
  /**
   * The URL that points to the response data in [JSONL](http://jsonlines.org/) format.
   * The URL expires 7 days after the operation completes.
   *
   */
  url?: Maybe<Scalars['URL']>
}

/** Return type for `bulkOperationCancel` mutation. */
export type BulkOperationCancelPayload = {
  __typename?: 'BulkOperationCancelPayload'
  /** The bulk operation to be canceled. */
  bulkOperation?: Maybe<BulkOperation>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Error codes for failed bulk operations. */
export enum BulkOperationErrorCode {
  /**
   * The provided operation `query` returned access denied due to missing
   * [access scopes](https://shopify.dev/api/usage/access-scopes).
   * Review the requested object permissions and execute the query as a normal non-bulk GraphQL request to see more details.
   *
   */
  AccessDenied = 'ACCESS_DENIED',
  /**
   * The operation resulted in partial or incomplete data due to internal server errors during execution.
   * These errors might be intermittent, so you can try performing the same query again.
   *
   */
  InternalServerError = 'INTERNAL_SERVER_ERROR',
  /**
   * The operation resulted in partial or incomplete data due to query timeouts during execution.
   * In some cases, timeouts can be avoided by modifying your `query` to select fewer fields.
   *
   */
  Timeout = 'TIMEOUT',
}

/** Return type for `bulkOperationRunMutation` mutation. */
export type BulkOperationRunMutationPayload = {
  __typename?: 'BulkOperationRunMutationPayload'
  /** The newly created bulk operation. */
  bulkOperation?: Maybe<BulkOperation>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<BulkMutationUserError>
}

/** Return type for `bulkOperationRunQuery` mutation. */
export type BulkOperationRunQueryPayload = {
  __typename?: 'BulkOperationRunQueryPayload'
  /** The newly created bulk operation. */
  bulkOperation?: Maybe<BulkOperation>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** The valid values for the status of a bulk operation. */
export enum BulkOperationStatus {
  /** The bulk operation has been canceled. */
  Canceled = 'CANCELED',
  /**
   * Cancelation has been initiated on the bulk operation. There may be a short delay from when a cancelation
   * starts until the operation is actually canceled.
   *
   */
  Canceling = 'CANCELING',
  /** The bulk operation has successfully completed. */
  Completed = 'COMPLETED',
  /** The bulk operation has been created. */
  Created = 'CREATED',
  /** The bulk operation URL has expired. */
  Expired = 'EXPIRED',
  /**
   * The bulk operation has failed. For information on why the operation failed, use
   * [BulkOperation.errorCode](https://shopify.dev/api/admin-graphql/latest/enums/bulkoperationerrorcode).
   *
   */
  Failed = 'FAILED',
  /** The bulk operation is runnning. */
  Running = 'RUNNING',
}

/** The valid values for the bulk operation's type. */
export enum BulkOperationType {
  /** The bulk operation is a mutation. */
  Mutation = 'MUTATION',
  /** The bulk operation is a query. */
  Query = 'QUERY',
}

/** Return type for `bulkProductResourceFeedbackCreate` mutation. */
export type BulkProductResourceFeedbackCreatePayload = {
  __typename?: 'BulkProductResourceFeedbackCreatePayload'
  /** The feedback that is created. */
  feedback?: Maybe<Array<ProductResourceFeedback>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<BulkProductResourceFeedbackCreateUserError>
}

/** An error that occurs during the execution of `BulkProductResourceFeedbackCreate`. */
export type BulkProductResourceFeedbackCreateUserError = DisplayableError & {
  __typename?: 'BulkProductResourceFeedbackCreateUserError'
  /** The error code. */
  code?: Maybe<BulkProductResourceFeedbackCreateUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `BulkProductResourceFeedbackCreateUserError`. */
export enum BulkProductResourceFeedbackCreateUserErrorCode {
  /** The input value is blank. */
  Blank = 'BLANK',
  /** The input value is invalid. */
  Invalid = 'INVALID',
  /** The input value should be less than or equal to the maximum value allowed. */
  LessThanOrEqualTo = 'LESS_THAN_OR_EQUAL_TO',
  /** The operation was attempted on too many feedback objects. The maximum number of feedback objects that you can operate on is 50. */
  MaximumFeedbackLimitExceeded = 'MAXIMUM_FEEDBACK_LIMIT_EXCEEDED',
  /** The feedback for a later version of this resource was already accepted. */
  OutdatedFeedback = 'OUTDATED_FEEDBACK',
  /** The input value needs to be blank. */
  Present = 'PRESENT',
  /** The product wasn't found or isn't available to the channel. */
  ProductNotFound = 'PRODUCT_NOT_FOUND',
}

/**
 * A discount that is automatically applied to an order that is being edited.
 *
 */
export type CalculatedAutomaticDiscountApplication =
  CalculatedDiscountApplication & {
    __typename?: 'CalculatedAutomaticDiscountApplication'
    /** The method by which the discount's value is allocated to its entitled items. */
    allocationMethod: DiscountApplicationAllocationMethod
    /** The level at which the discount was applied. */
    appliedTo: DiscountApplicationLevel
    /** The description of discount application. Indicates the reason why the discount was applied. */
    description?: Maybe<Scalars['String']>
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** How the discount amount is distributed on the discounted lines. */
    targetSelection: DiscountApplicationTargetSelection
    /** Whether the discount is applied on line items or shipping lines. */
    targetType: DiscountApplicationTargetType
    /** The value of the discount application. */
    value: PricingValue
  }

/**
 * An amount discounting the line that has been allocated by an associated discount application.
 *
 */
export type CalculatedDiscountAllocation = {
  __typename?: 'CalculatedDiscountAllocation'
  /** The money amount allocated by the discount application in shop and presentment currencies. */
  allocatedAmountSet: MoneyBag
  /** The discount that the allocated amount originated from. */
  discountApplication: CalculatedDiscountApplication
}

/**
 * A [discount application](https://shopify.dev/api/admin-graphql/latest/interfaces/discountapplication) involved in order editing that might be newly added or have new changes applied.
 *
 */
export type CalculatedDiscountApplication = {
  /** The method by which the discount's value is allocated to its entitled items. */
  allocationMethod: DiscountApplicationAllocationMethod
  /** The level at which the discount was applied. */
  appliedTo: DiscountApplicationLevel
  /** The description of discount application. Indicates the reason why the discount was applied. */
  description?: Maybe<Scalars['String']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** How the discount amount is distributed on the discounted lines. */
  targetSelection: DiscountApplicationTargetSelection
  /** Whether the discount is applied on line items or shipping lines. */
  targetType: DiscountApplicationTargetType
  /** The value of the discount application. */
  value: PricingValue
}

/**
 * An auto-generated type for paginating through multiple CalculatedDiscountApplications.
 *
 */
export type CalculatedDiscountApplicationConnection = {
  __typename?: 'CalculatedDiscountApplicationConnection'
  /** A list of edges. */
  edges: Array<CalculatedDiscountApplicationEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one CalculatedDiscountApplication and a cursor during pagination.
 *
 */
export type CalculatedDiscountApplicationEdge = {
  __typename?: 'CalculatedDiscountApplicationEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of CalculatedDiscountApplicationEdge. */
  node: CalculatedDiscountApplication
}

/**
 * A discount code that is applied to an order that is being edited.
 *
 */
export type CalculatedDiscountCodeApplication =
  CalculatedDiscountApplication & {
    __typename?: 'CalculatedDiscountCodeApplication'
    /** The method by which the discount's value is allocated to its entitled items. */
    allocationMethod: DiscountApplicationAllocationMethod
    /** The level at which the discount was applied. */
    appliedTo: DiscountApplicationLevel
    /** The string identifying the discount code that was used at the time of application. */
    code: Scalars['String']
    /** The description of discount application. Indicates the reason why the discount was applied. */
    description?: Maybe<Scalars['String']>
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** How the discount amount is distributed on the discounted lines. */
    targetSelection: DiscountApplicationTargetSelection
    /** Whether the discount is applied on line items or shipping lines. */
    targetType: DiscountApplicationTargetType
    /** The value of the discount application. */
    value: PricingValue
  }

/** The computed properties for a draft order. */
export type CalculatedDraftOrder = {
  __typename?: 'CalculatedDraftOrder'
  /** Order-level discount applied to the draft order. */
  appliedDiscount?: Maybe<DraftOrderAppliedDiscount>
  /** The available shipping rates for the draft order. Requires a customer with a valid shipping address and at least one line item. */
  availableShippingRates: Array<ShippingRate>
  /** Customer who will be sent an invoice for the draft order, if there is one. */
  customer?: Maybe<Customer>
  /** Line items in the draft order with their computed properties. */
  lineItems: Array<CalculatedDraftOrderLineItem>
  /** Line item that contains the shipping costs. */
  shippingLine?: Maybe<ShippingLine>
  /**
   * Subtotal of the line items and their discounts (does not contain shipping charges or shipping discounts, or taxes).
   *
   */
  subtotalPrice: Scalars['Money']
  /** Total amount of taxes charged for each line item and shipping line. */
  taxLines: Array<TaxLine>
  /** Total amount of the draft order (includes taxes, shipping charges, and discounts). */
  totalPrice: Scalars['Money']
  /** Total shipping charge for the draft order. */
  totalShippingPrice: Scalars['Money']
  /** Total amount of taxes for the draft order. */
  totalTax: Scalars['Money']
}

/** The computed line items for a draft order. */
export type CalculatedDraftOrderLineItem = {
  __typename?: 'CalculatedDraftOrderLineItem'
  /** Discount applied to the line item. */
  appliedDiscount?: Maybe<DraftOrderAppliedDiscount>
  /** Indicates if this is a product variant line item, or a custom line item. */
  custom: Scalars['Boolean']
  /** List of additional information about the line item. */
  customAttributes: Array<Attribute>
  /** Total price with discounts applied. */
  discountedTotal: MoneyV2
  /** Unit price with discounts applied. */
  discountedUnitPrice: MoneyV2
  /**
   * Name of the service provider who fulfilled the order.
   *
   * Valid values are either **manual** or the name of the provider.
   * For example, **amazon**, **shipwire**.
   *
   * Deleted fulfillment services will return null.
   *
   */
  fulfillmentService?: Maybe<FulfillmentService>
  /** Image associated with the draft order line item. */
  image?: Maybe<Image>
  /** Indicates whether the line item represents the puchase of a gift card. */
  isGiftCard: Scalars['Boolean']
  /** Name of the product. */
  name: Scalars['String']
  /**
   * Total price (without discounts) of the line item, based on the original unit price of the variant x quantity.
   *
   */
  originalTotal: MoneyV2
  /** Variant price without any discounts applied. */
  originalUnitPrice: MoneyV2
  /** Product associated with the draft order line item. */
  product?: Maybe<Product>
  /** Number of variant items requested in the draft order. */
  quantity: Scalars['Int']
  /** Whether physical shipping is required for the variant. */
  requiresShipping: Scalars['Boolean']
  /** Variant SKU number. */
  sku?: Maybe<Scalars['String']>
  /** Whether the variant is taxable. */
  taxable: Scalars['Boolean']
  /** Title of the product or variant (this field only applies to custom line items). */
  title: Scalars['String']
  /** Total value of the discount. */
  totalDiscount: MoneyV2
  /** Variant associated with the draft order line item. */
  variant?: Maybe<ProductVariant>
  /** Name of the variant. */
  variantTitle?: Maybe<Scalars['String']>
  /** Name of the vendor who made the variant. */
  vendor?: Maybe<Scalars['String']>
  /** Weight unit and value for a draft order line item. */
  weight?: Maybe<Weight>
}

/**
 * A line item involved in order editing that may be newly added or have new changes applied.
 *
 */
export type CalculatedLineItem = {
  __typename?: 'CalculatedLineItem'
  /** The discounts that have been allocated onto the line item by discount applications. */
  calculatedDiscountAllocations: Array<CalculatedDiscountAllocation>
  /** The list of additional information about the line item. */
  customAttributes: Array<Attribute>
  /**
   * The discounts that have been allocated onto the line item by discount applications.
   * @deprecated Use `calculatedDiscountAllocations` instead
   */
  discountAllocations: Array<DiscountAllocation>
  /** The price of a single quantity of the line item with line item discounts applied, in shop and presentment currencies. Discounts applied to the entire order aren't included in this price. */
  discountedUnitPriceSet: MoneyBag
  /** The total number of items that can be edited. */
  editableQuantity: Scalars['Int']
  /** The editable quantity prior to any changes made in the current edit. */
  editableQuantityBeforeChanges: Scalars['Int']
  /** The total price of editable lines in shop and presentment currencies. */
  editableSubtotalSet: MoneyBag
  /** Whether the calculated line item has a staged discount. */
  hasStagedLineItemDiscount: Scalars['Boolean']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The image object associated to the line item's variant. */
  image?: Maybe<Image>
  /** The variant unit price in shop and presentment currencies, without any discounts applied. */
  originalUnitPriceSet: MoneyBag
  /** The total number of items. */
  quantity: Scalars['Int']
  /** Whether the line item can be restocked or not. */
  restockable: Scalars['Boolean']
  /** Whether the changes on the line item will result in a restock. */
  restocking: Scalars['Boolean']
  /** The variant SKU number. */
  sku?: Maybe<Scalars['String']>
  /** A list of changes that affect this line item. */
  stagedChanges: Array<OrderStagedChange>
  /** The title of the product. */
  title: Scalars['String']
  /** The total price of uneditable lines in shop and presentment currencies. */
  uneditableSubtotalSet: MoneyBag
  /**
   * The product variant associated with this line item. The value is null for custom line items and items where
   * the variant has been deleted.
   *
   */
  variant?: Maybe<ProductVariant>
  /** The title of the variant. */
  variantTitle?: Maybe<Scalars['String']>
}

/**
 * An auto-generated type for paginating through multiple CalculatedLineItems.
 *
 */
export type CalculatedLineItemConnection = {
  __typename?: 'CalculatedLineItemConnection'
  /** A list of edges. */
  edges: Array<CalculatedLineItemEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one CalculatedLineItem and a cursor during pagination.
 *
 */
export type CalculatedLineItemEdge = {
  __typename?: 'CalculatedLineItemEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of CalculatedLineItemEdge. */
  node: CalculatedLineItem
}

/**
 * Represents a discount that was manually created for an order that is being edited.
 *
 */
export type CalculatedManualDiscountApplication =
  CalculatedDiscountApplication & {
    __typename?: 'CalculatedManualDiscountApplication'
    /** The method by which the discount's value is allocated to its entitled items. */
    allocationMethod: DiscountApplicationAllocationMethod
    /** The level at which the discount was applied. */
    appliedTo: DiscountApplicationLevel
    /** The description of discount application. Indicates the reason why the discount was applied. */
    description?: Maybe<Scalars['String']>
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** How the discount amount is distributed on the discounted lines. */
    targetSelection: DiscountApplicationTargetSelection
    /** Whether the discount is applied on line items or shipping lines. */
    targetType: DiscountApplicationTargetType
    /** The value of the discount application. */
    value: PricingValue
  }

/**
 * An order with edits applied but not saved.
 *
 */
export type CalculatedOrder = Node & {
  __typename?: 'CalculatedOrder'
  /**
   * Returns only the new discount applications being added to the order in the current edit.
   *
   */
  addedDiscountApplications: CalculatedDiscountApplicationConnection
  /**
   * Returns only the new line items being added to the order during the current edit.
   *
   */
  addedLineItems: CalculatedLineItemConnection
  /** Amount of the order-level discount (does not contain any line item discounts) in shop and presentment currencies. */
  cartDiscountAmountSet?: Maybe<MoneyBag>
  /** Whether the changes have been applied and saved to the order. */
  committed: Scalars['Boolean']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /**
   * Returns all items on the order that existed before starting the edit.
   * Will include any changes that have been made.
   * Will not include line items added during the current edit.
   *
   */
  lineItems: CalculatedLineItemConnection
  /** The HTML of the customer notification for the order edit. */
  notificationPreviewHtml?: Maybe<Scalars['HTML']>
  /** The customer notification title. */
  notificationPreviewTitle: Scalars['String']
  /**
   * The order without any changes applied.
   * @deprecated Use `originalOrder` instead
   */
  order: Order
  /**
   * The order without any changes applied.
   *
   */
  originalOrder: Order
  /**
   * List of changes made to the order during the current edit.
   *
   */
  stagedChanges: OrderStagedChangeConnection
  /** The sum of the quantities for the line items that contribute to the order's subtotal. */
  subtotalLineItemsQuantity: Scalars['Int']
  /** The subtotal of the line items, in shop and presentment currencies, after all the discounts are applied.  The subtotal does not include shipping.  The subtotal includes taxes for taxes-included orders and excludes taxes for taxes-excluded orders. */
  subtotalPriceSet?: Maybe<MoneyBag>
  /** Taxes charged for the line item. */
  taxLines: Array<TaxLine>
  /** Total price of the order less the total amount received from the customer in shop and presentment currencies. */
  totalOutstandingSet: MoneyBag
  /** Total amount of the order (includes taxes and discounts) in shop and presentment currencies. */
  totalPriceSet: MoneyBag
}

/**
 * An order with edits applied but not saved.
 *
 */
export type CalculatedOrderAddedDiscountApplicationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An order with edits applied but not saved.
 *
 */
export type CalculatedOrderAddedLineItemsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An order with edits applied but not saved.
 *
 */
export type CalculatedOrderLineItemsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An order with edits applied but not saved.
 *
 */
export type CalculatedOrderStagedChangesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * A discount created by a Shopify script for an order that is being edited.
 *
 */
export type CalculatedScriptDiscountApplication =
  CalculatedDiscountApplication & {
    __typename?: 'CalculatedScriptDiscountApplication'
    /** The method by which the discount's value is allocated to its entitled items. */
    allocationMethod: DiscountApplicationAllocationMethod
    /** The level at which the discount was applied. */
    appliedTo: DiscountApplicationLevel
    /** The description of discount application. Indicates the reason why the discount was applied. */
    description?: Maybe<Scalars['String']>
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** How the discount amount is distributed on the discounted lines. */
    targetSelection: DiscountApplicationTargetSelection
    /** Whether the discount is applied on line items or shipping lines. */
    targetType: DiscountApplicationTargetType
    /** The value of the discount application. */
    value: PricingValue
  }

/**
 * A channel represents an app where you sell a group of products and collections.
 * A channel can be a platform or marketplace such as Facebook or Pinterest, an online store, or POS.
 *
 */
export type Channel = Node & {
  __typename?: 'Channel'
  /** Underlying app used by the channel. */
  app: App
  /** The collection publications for the list of collections published to the channel. */
  collectionPublicationsV3: ResourcePublicationConnection
  /** The list of collections published to the channel. */
  collections: CollectionConnection
  /**
   * Unique identifier for the channel.
   * @deprecated Use `id` instead
   */
  handle: Scalars['String']
  /** Whether the collection is available to the channel. */
  hasCollection: Scalars['Boolean']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** Name of the channel. */
  name: Scalars['String']
  /**
   * Menu items for the channel, which also appear as submenu items in left navigation sidebar in the Shopify admin.
   *
   * @deprecated Use App.navigationItems instead
   */
  navigationItems: Array<NavigationItem>
  /**
   * Home page for the channel.
   * @deprecated Use App.launchUrl instead
   */
  overviewPath?: Maybe<Scalars['URL']>
  /**
   * The product publications for the products published to the channel.
   * @deprecated Use `productPublicationsV3` instead
   */
  productPublications: ProductPublicationConnection
  /** The product publications for the list of products published to the channel. */
  productPublicationsV3: ResourcePublicationConnection
  /** The list of products published to the channel. */
  products: ProductConnection
  /** Whether or not this channel supports future publishing. */
  supportsFuturePublishing: Scalars['Boolean']
}

/**
 * A channel represents an app where you sell a group of products and collections.
 * A channel can be a platform or marketplace such as Facebook or Pinterest, an online store, or POS.
 *
 */
export type ChannelCollectionPublicationsV3Args = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * A channel represents an app where you sell a group of products and collections.
 * A channel can be a platform or marketplace such as Facebook or Pinterest, an online store, or POS.
 *
 */
export type ChannelCollectionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * A channel represents an app where you sell a group of products and collections.
 * A channel can be a platform or marketplace such as Facebook or Pinterest, an online store, or POS.
 *
 */
export type ChannelHasCollectionArgs = {
  id: Scalars['ID']
}

/**
 * A channel represents an app where you sell a group of products and collections.
 * A channel can be a platform or marketplace such as Facebook or Pinterest, an online store, or POS.
 *
 */
export type ChannelProductPublicationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * A channel represents an app where you sell a group of products and collections.
 * A channel can be a platform or marketplace such as Facebook or Pinterest, an online store, or POS.
 *
 */
export type ChannelProductPublicationsV3Args = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * A channel represents an app where you sell a group of products and collections.
 * A channel can be a platform or marketplace such as Facebook or Pinterest, an online store, or POS.
 *
 */
export type ChannelProductsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An auto-generated type for paginating through multiple Channels.
 *
 */
export type ChannelConnection = {
  __typename?: 'ChannelConnection'
  /** A list of edges. */
  edges: Array<ChannelEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one Channel and a cursor during pagination.
 *
 */
export type ChannelEdge = {
  __typename?: 'ChannelEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of ChannelEdge. */
  node: Channel
}

/** The set of valid sort keys for the CodeDiscount query. */
export enum CodeDiscountSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `ends_at` value. */
  EndsAt = 'ENDS_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
  /** Sort by the `starts_at` value. */
  StartsAt = 'STARTS_AT',
  /** Sort by the `title` value. */
  Title = 'TITLE',
  /** Sort by the `updated_at` value. */
  UpdatedAt = 'UPDATED_AT',
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type Collection = HasMetafieldDefinitions &
  HasMetafields &
  HasPublishedTranslations &
  Node &
  Publishable & {
    __typename?: 'Collection'
    /** The number of publications a resource is published to without feedback errors. */
    availablePublicationCount: Scalars['Int']
    /**
     * A single-line, text-only description of the collection, stripped of any HTML tags and formatting that were included in the description.
     *
     */
    description: Scalars['String']
    /**
     * The description of the collection, including any HTML tags and formatting. This content is typically displayed to customers, such as on an online store, depending on the theme.
     *
     */
    descriptionHtml: Scalars['HTML']
    /** Information about the collection that's provided through resource feedback. */
    feedback?: Maybe<ResourceFeedback>
    /**
     * A unique string that identifies the collection. If a handle isn't specified when a collection is created, it's automatically generated from the collection's original title, and typically includes words from the title separated by hyphens. For example, a collection that was created with the title `Summer Catalog 2022` might have the handle `summer-catalog-2022`.
     *
     * If the title is changed, the handle doesn't automatically change.
     *
     * The handle can be used in themes by the Liquid templating language to refer to the collection, but using the ID is preferred because it never changes.
     *
     */
    handle: Scalars['String']
    /** Whether the collection includes the specified product. */
    hasProduct: Scalars['Boolean']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The image associated with the collection. */
    image?: Maybe<Image>
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** Returns a metafield by namespace and key that belongs to the resource. */
    metafield?: Maybe<Metafield>
    /** List of metafield definitions. */
    metafieldDefinitions: MetafieldDefinitionConnection
    /** List of metafields that belong to the resource. */
    metafields: MetafieldConnection
    /** Returns a private metafield by namespace and key that belongs to the resource. */
    privateMetafield?: Maybe<PrivateMetafield>
    /** List of private metafields that belong to the resource. */
    privateMetafields: PrivateMetafieldConnection
    /** The products that are included in the collection. */
    products: ProductConnection
    /** The number of products in the collection. */
    productsCount: Scalars['Int']
    /** The number of publications a resource is published on. */
    publicationCount: Scalars['Int']
    /**
     * The channels where the collection is published.
     * @deprecated Use `resourcePublications` instead
     */
    publications: CollectionPublicationConnection
    /**
     * Check to see whether the resource is published to a given channel.
     * @deprecated Use `publishedOnPublication` instead
     */
    publishedOnChannel: Scalars['Boolean']
    /**
     * Check to see whether the resource is published to the calling app's channel.
     * @deprecated Use `publishedOnCurrentPublication` instead
     */
    publishedOnCurrentChannel: Scalars['Boolean']
    /** Check to see whether the resource is published to the calling app's publication. */
    publishedOnCurrentPublication: Scalars['Boolean']
    /** Check to see whether the resource is published to a given publication. */
    publishedOnPublication: Scalars['Boolean']
    /** The list of resources that are published to a publication. */
    resourcePublications: ResourcePublicationConnection
    /** The list of resources that are either published or staged to be published to a publication. */
    resourcePublicationsV2: ResourcePublicationV2Connection
    /**
     * For a smart (automated) collection, specifies the rules that determine whether a product is included.
     *
     */
    ruleSet?: Maybe<CollectionRuleSet>
    /**
     * If the default SEO fields for page title and description have been modified, contains the modified information.
     *
     */
    seo: Seo
    /**
     * The order in which the products in the collection are displayed by default in the Shopify admin and in sales channels, such as an online store.
     *
     */
    sortOrder: CollectionSortOrder
    /**
     * The Storefront GraphQL API ID of the `Collection`.
     *
     * As of the `2022-04` version release, the Storefront GraphQL API will no longer return Base64 encoded IDs to match the behavior of the Admin GraphQL API. Therefore, you can safely use the `id` field's value instead.
     *
     * @deprecated Use `id` instead
     */
    storefrontId: Scalars['StorefrontID']
    /**
     * The suffix of the Liquid template being used to show the collection in an online store. For example, if the value is `custom`, then the collection is using the `collection.custom.liquid` template. If the value is `null`, then the collection is using the default `collection.liquid` template.
     *
     */
    templateSuffix?: Maybe<Scalars['String']>
    /**
     * The name of the collection. It's displayed in the Shopify admin and is typically displayed in sales channels, such as an online store.
     *
     */
    title: Scalars['String']
    /** The translations associated with the resource. */
    translations: Array<PublishedTranslation>
    /**
     * The list of channels that the resource is not published to.
     * @deprecated Use `unpublishedPublications` instead
     */
    unpublishedChannels: ChannelConnection
    /** The list of publications that the resource is not published to. */
    unpublishedPublications: PublicationConnection
    /**
     * The date and time ([ISO 8601 format](http://en.wikipedia.org/wiki/ISO_8601)) when the collection was last modified.
     *
     */
    updatedAt: Scalars['DateTime']
  }

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionDescriptionArgs = {
  truncateAt?: InputMaybe<Scalars['Int']>
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionHasProductArgs = {
  id: Scalars['ID']
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionImageArgs = {
  crop?: InputMaybe<CropRegion>
  maxHeight?: InputMaybe<Scalars['Int']>
  maxWidth?: InputMaybe<Scalars['Int']>
  scale?: InputMaybe<Scalars['Int']>
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionMetafieldDefinitionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  pinnedStatus?: InputMaybe<MetafieldDefinitionPinnedStatus>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<MetafieldDefinitionSortKeys>
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionPrivateMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionPrivateMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionProductsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<ProductCollectionSortKeys>
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionPublicationCountArgs = {
  onlyPublished?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionPublicationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  onlyPublished?: InputMaybe<Scalars['Boolean']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionPublishedOnChannelArgs = {
  channelId: Scalars['ID']
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionPublishedOnPublicationArgs = {
  publicationId: Scalars['ID']
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionResourcePublicationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  onlyPublished?: InputMaybe<Scalars['Boolean']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionResourcePublicationsV2Args = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  onlyPublished?: InputMaybe<Scalars['Boolean']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionTranslationsArgs = {
  locale: Scalars['String']
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionUnpublishedChannelsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a group of products that can be displayed in online stores and other sales channels in categories, which makes it easy for customers to find them. For example, an athletics store might create different collections for running attire, shoes, and accessories.
 *
 * Collections can be defined by conditions, such as whether they match certain product tags. These are called smart or automated collections.
 *
 * Collections can also be created for a custom group of products. These are called custom or manual collections.
 *
 */
export type CollectionUnpublishedPublicationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Return type for `collectionAddProducts` mutation. */
export type CollectionAddProductsPayload = {
  __typename?: 'CollectionAddProductsPayload'
  /** The updated collection. */
  collection?: Maybe<Collection>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type for paginating through multiple Collections.
 *
 */
export type CollectionConnection = {
  __typename?: 'CollectionConnection'
  /** A list of edges. */
  edges: Array<CollectionEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `collectionCreate` mutation. */
export type CollectionCreatePayload = {
  __typename?: 'CollectionCreatePayload'
  /** The collection that has been created. */
  collection?: Maybe<Collection>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Specifies the collection to delete. */
export type CollectionDeleteInput = {
  /** The ID of the collection to be deleted. */
  id: Scalars['ID']
}

/** Return type for `collectionDelete` mutation. */
export type CollectionDeletePayload = {
  __typename?: 'CollectionDeletePayload'
  /** The ID of the collection that was deleted. */
  deletedCollectionId?: Maybe<Scalars['ID']>
  /** The shop associated with the collection. */
  shop: Shop
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one Collection and a cursor during pagination.
 *
 */
export type CollectionEdge = {
  __typename?: 'CollectionEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of CollectionEdge. */
  node: Collection
}

/** Specifies the input fields required to create a collection. */
export type CollectionInput = {
  /** The description of the collection, in HTML format. */
  descriptionHtml?: InputMaybe<Scalars['String']>
  /**
   * A unique human-friendly string for the collection. Automatically generated from the collection's title.
   *
   */
  handle?: InputMaybe<Scalars['String']>
  /** Specifies the collection to update or create a new collection if absent. */
  id?: InputMaybe<Scalars['ID']>
  /** The image associated with the collection. */
  image?: InputMaybe<ImageInput>
  /** The metafields to associate with this collection. */
  metafields?: InputMaybe<Array<MetafieldInput>>
  /** The private metafields to associated with this product. */
  privateMetafields?: InputMaybe<Array<PrivateMetafieldInput>>
  /** Initial list of collection products. Only valid with `productCreate` and without rules. */
  products?: InputMaybe<Array<Scalars['ID']>>
  /** Initial list of collection publications. Only valid with `productCreate`. This argument is deprecated: Use PublishablePublish instead. */
  publications?: InputMaybe<Array<CollectionPublicationInput>>
  /**
   * Indicates whether a redirect is required after a new handle has been provided.
   * If true, then the old handle is redirected to the new one automatically.
   *
   */
  redirectNewHandle?: InputMaybe<Scalars['Boolean']>
  /**
   * The rules used to assign products to the collection.
   *
   */
  ruleSet?: InputMaybe<CollectionRuleSetInput>
  /** SEO information for the collection. */
  seo?: InputMaybe<SeoInput>
  /** The order in which the collection's products are sorted. */
  sortOrder?: InputMaybe<CollectionSortOrder>
  /** The theme template used when viewing the collection in a store. */
  templateSuffix?: InputMaybe<Scalars['String']>
  /** Required for creating a new collection. */
  title?: InputMaybe<Scalars['String']>
}

/** Represents the publications where a collection is published. */
export type CollectionPublication = {
  __typename?: 'CollectionPublication'
  /**
   * The channel where the collection will be published.
   * @deprecated Use `publication` instead
   */
  channel: Channel
  /** The collection to be published on the publication. */
  collection: Collection
  /** Whether the publication is published or not. */
  isPublished: Scalars['Boolean']
  /** The publication where the collection will be published. */
  publication: Publication
  /** The date that the publication was or is going to be published. */
  publishDate: Scalars['DateTime']
}

/**
 * An auto-generated type for paginating through multiple CollectionPublications.
 *
 */
export type CollectionPublicationConnection = {
  __typename?: 'CollectionPublicationConnection'
  /** A list of edges. */
  edges: Array<CollectionPublicationEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one CollectionPublication and a cursor during pagination.
 *
 */
export type CollectionPublicationEdge = {
  __typename?: 'CollectionPublicationEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of CollectionPublicationEdge. */
  node: CollectionPublication
}

/** Specifies the publications to which a collection will be published. */
export type CollectionPublicationInput = {
  /** This argument is deprecated: Use publicationId instead. */
  channelHandle?: InputMaybe<Scalars['String']>
  /** The ID of the channel. This argument is deprecated: Use publicationId instead. */
  channelId?: InputMaybe<Scalars['ID']>
  /** The ID of the publication. */
  publicationId?: InputMaybe<Scalars['ID']>
}

/** Specifies a collection to publish and the sales channels to publish it to. */
export type CollectionPublishInput = {
  /** The channels where the collection will be published. */
  collectionPublications: Array<CollectionPublicationInput>
  /** The collection to create or update publications for. */
  id: Scalars['ID']
}

/** Return type for `collectionPublish` mutation. */
export type CollectionPublishPayload = {
  __typename?: 'CollectionPublishPayload'
  /** The published collection. */
  collection?: Maybe<Collection>
  /** The channels where the collection has been published. */
  collectionPublications?: Maybe<Array<CollectionPublication>>
  /** The shop associated with the collection. */
  shop: Shop
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `collectionRemoveProducts` mutation. */
export type CollectionRemoveProductsPayload = {
  __typename?: 'CollectionRemoveProductsPayload'
  /** The asynchronous job removing the products. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `collectionReorderProducts` mutation. */
export type CollectionReorderProductsPayload = {
  __typename?: 'CollectionReorderProductsPayload'
  /** The asynchronous job reordering the products. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Represents at rule that's used to assign products to a collection. */
export type CollectionRule = {
  __typename?: 'CollectionRule'
  /** The attribute that the rule focuses on (for example, `title` or `product_type`). */
  column: CollectionRuleColumn
  /** The value that the operator is applied to (for example, `Hats`). */
  condition: Scalars['String']
  /**
   * The type of operator that the rule is based on (for example, `equals`, `contains`, or `not_equals`).
   *
   */
  relation: CollectionRuleRelation
}

/** Specifies the property of a product being used to populate the smart collection. */
export enum CollectionRuleColumn {
  /** The `is_price_reduced` attribute, which is a Boolean type evaluated as `true` if a product has a `compare_at_price` set on any of its variants. */
  IsPriceReduced = 'IS_PRICE_REDUCED',
  /** The `tag` attribute. */
  Tag = 'TAG',
  /** The `title` attribute. */
  Title = 'TITLE',
  /** The `type` attribute. */
  Type = 'TYPE',
  /** The `variant_compare_at_price` attribute. */
  VariantCompareAtPrice = 'VARIANT_COMPARE_AT_PRICE',
  /** The `variant_inventory` attribute. */
  VariantInventory = 'VARIANT_INVENTORY',
  /** The `variant_price` attribute. */
  VariantPrice = 'VARIANT_PRICE',
  /** The `variant_title` attribute. */
  VariantTitle = 'VARIANT_TITLE',
  /** The `variant_weight` attribute. */
  VariantWeight = 'VARIANT_WEIGHT',
  /** The `vendor` attribute. */
  Vendor = 'VENDOR',
}

/** Collections may use rules to automatically include the matching products. This defines restrictions for a type of rule. */
export type CollectionRuleConditions = {
  __typename?: 'CollectionRuleConditions'
  /** Allowed relations of the rule. */
  allowedRelations: Array<CollectionRuleRelation>
  /** Most commonly used relation for this rule. */
  defaultRelation: CollectionRuleRelation
  /** Type of the rule. */
  ruleType: CollectionRuleColumn
}

/** Specifies a rule to associate with a collection. */
export type CollectionRuleInput = {
  /** The attribute that the rule focuses on (for example, `title` or `product_type`). */
  column: CollectionRuleColumn
  /** The value that the operator is applied to (for example, `Hats`). */
  condition: Scalars['String']
  /**
   * The type of operator that the rule is based on (for example, `equals`, `contains`, or `not_equals`).
   *
   */
  relation: CollectionRuleRelation
}

/** Specifies the relationship between the `column` and the condition. */
export enum CollectionRuleRelation {
  /** The attribute contains the condition. */
  Contains = 'CONTAINS',
  /** The attribute ends with the condition. */
  EndsWith = 'ENDS_WITH',
  /** The attribute is equal to the condition. */
  Equals = 'EQUALS',
  /** The attribute is greater than the condition. */
  GreaterThan = 'GREATER_THAN',
  /** The attribute is not set. */
  IsNotSet = 'IS_NOT_SET',
  /** The attribute is set. */
  IsSet = 'IS_SET',
  /** The attribute is less than the condition. */
  LessThan = 'LESS_THAN',
  /** The attribute does not contain the condition. */
  NotContains = 'NOT_CONTAINS',
  /** The attribute does not equal the condition. */
  NotEquals = 'NOT_EQUALS',
  /** The attribute starts with the condition. */
  StartsWith = 'STARTS_WITH',
}

/** The set of rules that are used to determine which products are included in the collection. */
export type CollectionRuleSet = {
  __typename?: 'CollectionRuleSet'
  /**
   * Whether products must match any or all of the rules to be included in the collection.
   * If true, then products must match one or more of the rules to be included in the collection.
   * If false, then products must match all of the rules to be included in the collection.
   *
   */
  appliedDisjunctively: Scalars['Boolean']
  /** The rules used to assign products to the collection. */
  rules: Array<CollectionRule>
}

/** Specifies a rule set for the collection. */
export type CollectionRuleSetInput = {
  /**
   * Whether products must match any or all of the rules to be included in the collection.
   * If true, then products must match one or more of the rules to be included in the collection.
   * If false, then products must match all of the rules to be included in the collection.
   *
   */
  appliedDisjunctively: Scalars['Boolean']
  /** The rules used to assign products to the collection. */
  rules?: InputMaybe<Array<CollectionRuleInput>>
}

/** The set of valid sort keys for the Collection query. */
export enum CollectionSortKeys {
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
  /** Sort by the `title` value. */
  Title = 'TITLE',
  /** Sort by the `updated_at` value. */
  UpdatedAt = 'UPDATED_AT',
}

/** Specifies the sort order for the products in the collection. */
export enum CollectionSortOrder {
  /** Alphabetically, in ascending order (A - Z). */
  AlphaAsc = 'ALPHA_ASC',
  /** Alphabetically, in descending order (Z - A). */
  AlphaDesc = 'ALPHA_DESC',
  /** By best-selling products. */
  BestSelling = 'BEST_SELLING',
  /** By date created, in ascending order (oldest - newest). */
  Created = 'CREATED',
  /** By date created, in descending order (newest - oldest). */
  CreatedDesc = 'CREATED_DESC',
  /** In the order set manually by the merchant. */
  Manual = 'MANUAL',
  /** By price, in ascending order (lowest - highest). */
  PriceAsc = 'PRICE_ASC',
  /** By price, in descending order (highest - lowest). */
  PriceDesc = 'PRICE_DESC',
}

/** Specifies the collection to unpublish and the sales channels to remove it from. */
export type CollectionUnpublishInput = {
  /** The channels where the collection is published. */
  collectionPublications: Array<CollectionPublicationInput>
  /** The collection to create or update publications for. */
  id: Scalars['ID']
}

/** Return type for `collectionUnpublish` mutation. */
export type CollectionUnpublishPayload = {
  __typename?: 'CollectionUnpublishPayload'
  /** The collection that has been unpublished. */
  collection?: Maybe<Collection>
  /** The shop associated with the collection. */
  shop: Shop
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `collectionUpdate` mutation. */
export type CollectionUpdatePayload = {
  __typename?: 'CollectionUpdatePayload'
  /** The updated collection. */
  collection?: Maybe<Collection>
  /** The asynchronous job updating the products based on the new rule set. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * Comment events are generated by staff members of a shop.
 * They are created when a staff member adds a comment to the timeline of an order, draft order, customer, or transfer.
 *
 */
export type CommentEvent = Event &
  Node & {
    __typename?: 'CommentEvent'
    /** The name of the app that created the event. */
    appTitle?: Maybe<Scalars['String']>
    /** The attachments associated with the comment event. */
    attachments: Array<CommentEventAttachment>
    /** Whether the event was created by an app. */
    attributeToApp: Scalars['Boolean']
    /** Whether the event was caused by an admin user. */
    attributeToUser: Scalars['Boolean']
    /** Whether the comment event can be deleted. If true, then the comment event can be deleted. */
    canDelete: Scalars['Boolean']
    /** Whether the comment event can be edited. If true, then the comment event can be edited. */
    canEdit: Scalars['Boolean']
    /** The date and time when the event was created. */
    createdAt: Scalars['DateTime']
    /** Whether the event is critical. */
    criticalAlert: Scalars['Boolean']
    /** Whether the comment event has been edited. If true, then the comment event has been edited. */
    edited: Scalars['Boolean']
    /** The object reference associated with the comment event. For example, a product or discount). */
    embed?: Maybe<CommentEventEmbed>
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** Human readable text that describes the event. */
    message: Scalars['FormattedString']
    /** The raw body of the comment event. */
    rawMessage: Scalars['String']
    /** The parent subject to which the comment event belongs. */
    subject: CommentEventSubject
  }

/** A file attachment associated to a comment event. */
export type CommentEventAttachment = {
  __typename?: 'CommentEventAttachment'
  /** The file extension of the comment event attachment, indicating the file format. */
  fileExtension?: Maybe<Scalars['String']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The image attached to the comment event. */
  image?: Maybe<Image>
  /** The filename of the comment event attachment. */
  name: Scalars['String']
  /** The size of the attachment. */
  size: Scalars['Int']
  /** The URL of the attachment. */
  url: Scalars['URL']
}

/** A file attachment associated to a comment event. */
export type CommentEventAttachmentImageArgs = {
  crop?: InputMaybe<CropRegion>
  maxHeight?: InputMaybe<Scalars['Int']>
  maxWidth?: InputMaybe<Scalars['Int']>
  scale?: InputMaybe<Scalars['Int']>
}

/** The main embed of a comment event. */
export type CommentEventEmbed =
  | Customer
  | DraftOrder
  | Order
  | Product
  | ProductVariant

/** The subject line of a comment event. */
export type CommentEventSubject = {
  /** Whether the timeline subject has a timeline comment. If true, then a timeline comment exists. */
  hasTimelineComment: Scalars['Boolean']
  /** A globally-unique identifier. */
  id: Scalars['ID']
}

/** The context data that determines the pricing of a variant. */
export type ContextualPricingContext = {
  /** The country code used to fetch country-specific prices. */
  country?: InputMaybe<CountryCode>
}

/** The list of all the countries from the combined shipping zones for the shop. */
export type CountriesInShippingZones = {
  __typename?: 'CountriesInShippingZones'
  /** The list of all the countries from all the combined shipping zones. */
  countryCodes: Array<CountryCode>
  /** Whether 'Rest of World' has been defined in any of the shipping zones. */
  includeRestOfWorld: Scalars['Boolean']
}

/** ISO 3166-1 alpha-2 country codes with some differences. */
export enum CountryCode {
  /** Ascension Island. */
  Ac = 'AC',
  /** Andorra. */
  Ad = 'AD',
  /** United Arab Emirates. */
  Ae = 'AE',
  /** Afghanistan. */
  Af = 'AF',
  /** Antigua & Barbuda. */
  Ag = 'AG',
  /** Anguilla. */
  Ai = 'AI',
  /** Albania. */
  Al = 'AL',
  /** Armenia. */
  Am = 'AM',
  /** Netherlands Antilles. */
  An = 'AN',
  /** Angola. */
  Ao = 'AO',
  /** Argentina. */
  Ar = 'AR',
  /** Austria. */
  At = 'AT',
  /** Australia. */
  Au = 'AU',
  /** Aruba. */
  Aw = 'AW',
  /** Åland Islands. */
  Ax = 'AX',
  /** Azerbaijan. */
  Az = 'AZ',
  /** Bosnia & Herzegovina. */
  Ba = 'BA',
  /** Barbados. */
  Bb = 'BB',
  /** Bangladesh. */
  Bd = 'BD',
  /** Belgium. */
  Be = 'BE',
  /** Burkina Faso. */
  Bf = 'BF',
  /** Bulgaria. */
  Bg = 'BG',
  /** Bahrain. */
  Bh = 'BH',
  /** Burundi. */
  Bi = 'BI',
  /** Benin. */
  Bj = 'BJ',
  /** St. Barthélemy. */
  Bl = 'BL',
  /** Bermuda. */
  Bm = 'BM',
  /** Brunei. */
  Bn = 'BN',
  /** Bolivia. */
  Bo = 'BO',
  /** Caribbean Netherlands. */
  Bq = 'BQ',
  /** Brazil. */
  Br = 'BR',
  /** Bahamas. */
  Bs = 'BS',
  /** Bhutan. */
  Bt = 'BT',
  /** Bouvet Island. */
  Bv = 'BV',
  /** Botswana. */
  Bw = 'BW',
  /** Belarus. */
  By = 'BY',
  /** Belize. */
  Bz = 'BZ',
  /** Canada. */
  Ca = 'CA',
  /** Cocos (Keeling) Islands. */
  Cc = 'CC',
  /** Congo - Kinshasa. */
  Cd = 'CD',
  /** Central African Republic. */
  Cf = 'CF',
  /** Congo - Brazzaville. */
  Cg = 'CG',
  /** Switzerland. */
  Ch = 'CH',
  /** Côte d’Ivoire. */
  Ci = 'CI',
  /** Cook Islands. */
  Ck = 'CK',
  /** Chile. */
  Cl = 'CL',
  /** Cameroon. */
  Cm = 'CM',
  /** China. */
  Cn = 'CN',
  /** Colombia. */
  Co = 'CO',
  /** Costa Rica. */
  Cr = 'CR',
  /** Cuba. */
  Cu = 'CU',
  /** Cape Verde. */
  Cv = 'CV',
  /** Curaçao. */
  Cw = 'CW',
  /** Christmas Island. */
  Cx = 'CX',
  /** Cyprus. */
  Cy = 'CY',
  /** Czechia. */
  Cz = 'CZ',
  /** Germany. */
  De = 'DE',
  /** Djibouti. */
  Dj = 'DJ',
  /** Denmark. */
  Dk = 'DK',
  /** Dominica. */
  Dm = 'DM',
  /** Dominican Republic. */
  Do = 'DO',
  /** Algeria. */
  Dz = 'DZ',
  /** Ecuador. */
  Ec = 'EC',
  /** Estonia. */
  Ee = 'EE',
  /** Egypt. */
  Eg = 'EG',
  /** Western Sahara. */
  Eh = 'EH',
  /** Eritrea. */
  Er = 'ER',
  /** Spain. */
  Es = 'ES',
  /** Ethiopia. */
  Et = 'ET',
  /** Finland. */
  Fi = 'FI',
  /** Fiji. */
  Fj = 'FJ',
  /** Falkland Islands. */
  Fk = 'FK',
  /** Faroe Islands. */
  Fo = 'FO',
  /** France. */
  Fr = 'FR',
  /** Gabon. */
  Ga = 'GA',
  /** United Kingdom. */
  Gb = 'GB',
  /** Grenada. */
  Gd = 'GD',
  /** Georgia. */
  Ge = 'GE',
  /** French Guiana. */
  Gf = 'GF',
  /** Guernsey. */
  Gg = 'GG',
  /** Ghana. */
  Gh = 'GH',
  /** Gibraltar. */
  Gi = 'GI',
  /** Greenland. */
  Gl = 'GL',
  /** Gambia. */
  Gm = 'GM',
  /** Guinea. */
  Gn = 'GN',
  /** Guadeloupe. */
  Gp = 'GP',
  /** Equatorial Guinea. */
  Gq = 'GQ',
  /** Greece. */
  Gr = 'GR',
  /** South Georgia & South Sandwich Islands. */
  Gs = 'GS',
  /** Guatemala. */
  Gt = 'GT',
  /** Guinea-Bissau. */
  Gw = 'GW',
  /** Guyana. */
  Gy = 'GY',
  /** Hong Kong SAR. */
  Hk = 'HK',
  /** Heard & McDonald Islands. */
  Hm = 'HM',
  /** Honduras. */
  Hn = 'HN',
  /** Croatia. */
  Hr = 'HR',
  /** Haiti. */
  Ht = 'HT',
  /** Hungary. */
  Hu = 'HU',
  /** Indonesia. */
  Id = 'ID',
  /** Ireland. */
  Ie = 'IE',
  /** Israel. */
  Il = 'IL',
  /** Isle of Man. */
  Im = 'IM',
  /** India. */
  In = 'IN',
  /** British Indian Ocean Territory. */
  Io = 'IO',
  /** Iraq. */
  Iq = 'IQ',
  /** Iran. */
  Ir = 'IR',
  /** Iceland. */
  Is = 'IS',
  /** Italy. */
  It = 'IT',
  /** Jersey. */
  Je = 'JE',
  /** Jamaica. */
  Jm = 'JM',
  /** Jordan. */
  Jo = 'JO',
  /** Japan. */
  Jp = 'JP',
  /** Kenya. */
  Ke = 'KE',
  /** Kyrgyzstan. */
  Kg = 'KG',
  /** Cambodia. */
  Kh = 'KH',
  /** Kiribati. */
  Ki = 'KI',
  /** Comoros. */
  Km = 'KM',
  /** St. Kitts & Nevis. */
  Kn = 'KN',
  /** North Korea. */
  Kp = 'KP',
  /** South Korea. */
  Kr = 'KR',
  /** Kuwait. */
  Kw = 'KW',
  /** Cayman Islands. */
  Ky = 'KY',
  /** Kazakhstan. */
  Kz = 'KZ',
  /** Laos. */
  La = 'LA',
  /** Lebanon. */
  Lb = 'LB',
  /** St. Lucia. */
  Lc = 'LC',
  /** Liechtenstein. */
  Li = 'LI',
  /** Sri Lanka. */
  Lk = 'LK',
  /** Liberia. */
  Lr = 'LR',
  /** Lesotho. */
  Ls = 'LS',
  /** Lithuania. */
  Lt = 'LT',
  /** Luxembourg. */
  Lu = 'LU',
  /** Latvia. */
  Lv = 'LV',
  /** Libya. */
  Ly = 'LY',
  /** Morocco. */
  Ma = 'MA',
  /** Monaco. */
  Mc = 'MC',
  /** Moldova. */
  Md = 'MD',
  /** Montenegro. */
  Me = 'ME',
  /** St. Martin. */
  Mf = 'MF',
  /** Madagascar. */
  Mg = 'MG',
  /** North Macedonia. */
  Mk = 'MK',
  /** Mali. */
  Ml = 'ML',
  /** Myanmar (Burma). */
  Mm = 'MM',
  /** Mongolia. */
  Mn = 'MN',
  /** Macao SAR. */
  Mo = 'MO',
  /** Martinique. */
  Mq = 'MQ',
  /** Mauritania. */
  Mr = 'MR',
  /** Montserrat. */
  Ms = 'MS',
  /** Malta. */
  Mt = 'MT',
  /** Mauritius. */
  Mu = 'MU',
  /** Maldives. */
  Mv = 'MV',
  /** Malawi. */
  Mw = 'MW',
  /** Mexico. */
  Mx = 'MX',
  /** Malaysia. */
  My = 'MY',
  /** Mozambique. */
  Mz = 'MZ',
  /** Namibia. */
  Na = 'NA',
  /** New Caledonia. */
  Nc = 'NC',
  /** Niger. */
  Ne = 'NE',
  /** Norfolk Island. */
  Nf = 'NF',
  /** Nigeria. */
  Ng = 'NG',
  /** Nicaragua. */
  Ni = 'NI',
  /** Netherlands. */
  Nl = 'NL',
  /** Norway. */
  No = 'NO',
  /** Nepal. */
  Np = 'NP',
  /** Nauru. */
  Nr = 'NR',
  /** Niue. */
  Nu = 'NU',
  /** New Zealand. */
  Nz = 'NZ',
  /** Oman. */
  Om = 'OM',
  /** Panama. */
  Pa = 'PA',
  /** Peru. */
  Pe = 'PE',
  /** French Polynesia. */
  Pf = 'PF',
  /** Papua New Guinea. */
  Pg = 'PG',
  /** Philippines. */
  Ph = 'PH',
  /** Pakistan. */
  Pk = 'PK',
  /** Poland. */
  Pl = 'PL',
  /** St. Pierre & Miquelon. */
  Pm = 'PM',
  /** Pitcairn Islands. */
  Pn = 'PN',
  /** Palestinian Territories. */
  Ps = 'PS',
  /** Portugal. */
  Pt = 'PT',
  /** Paraguay. */
  Py = 'PY',
  /** Qatar. */
  Qa = 'QA',
  /** Réunion. */
  Re = 'RE',
  /** Romania. */
  Ro = 'RO',
  /** Serbia. */
  Rs = 'RS',
  /** Russia. */
  Ru = 'RU',
  /** Rwanda. */
  Rw = 'RW',
  /** Saudi Arabia. */
  Sa = 'SA',
  /** Solomon Islands. */
  Sb = 'SB',
  /** Seychelles. */
  Sc = 'SC',
  /** Sudan. */
  Sd = 'SD',
  /** Sweden. */
  Se = 'SE',
  /** Singapore. */
  Sg = 'SG',
  /** St. Helena. */
  Sh = 'SH',
  /** Slovenia. */
  Si = 'SI',
  /** Svalbard & Jan Mayen. */
  Sj = 'SJ',
  /** Slovakia. */
  Sk = 'SK',
  /** Sierra Leone. */
  Sl = 'SL',
  /** San Marino. */
  Sm = 'SM',
  /** Senegal. */
  Sn = 'SN',
  /** Somalia. */
  So = 'SO',
  /** Suriname. */
  Sr = 'SR',
  /** South Sudan. */
  Ss = 'SS',
  /** São Tomé & Príncipe. */
  St = 'ST',
  /** El Salvador. */
  Sv = 'SV',
  /** Sint Maarten. */
  Sx = 'SX',
  /** Syria. */
  Sy = 'SY',
  /** Eswatini. */
  Sz = 'SZ',
  /** Tristan da Cunha. */
  Ta = 'TA',
  /** Turks & Caicos Islands. */
  Tc = 'TC',
  /** Chad. */
  Td = 'TD',
  /** French Southern Territories. */
  Tf = 'TF',
  /** Togo. */
  Tg = 'TG',
  /** Thailand. */
  Th = 'TH',
  /** Tajikistan. */
  Tj = 'TJ',
  /** Tokelau. */
  Tk = 'TK',
  /** Timor-Leste. */
  Tl = 'TL',
  /** Turkmenistan. */
  Tm = 'TM',
  /** Tunisia. */
  Tn = 'TN',
  /** Tonga. */
  To = 'TO',
  /** Turkey. */
  Tr = 'TR',
  /** Trinidad & Tobago. */
  Tt = 'TT',
  /** Tuvalu. */
  Tv = 'TV',
  /** Taiwan. */
  Tw = 'TW',
  /** Tanzania. */
  Tz = 'TZ',
  /** Ukraine. */
  Ua = 'UA',
  /** Uganda. */
  Ug = 'UG',
  /** U.S. Outlying Islands. */
  Um = 'UM',
  /** United States. */
  Us = 'US',
  /** Uruguay. */
  Uy = 'UY',
  /** Uzbekistan. */
  Uz = 'UZ',
  /** Vatican City. */
  Va = 'VA',
  /** St. Vincent & Grenadines. */
  Vc = 'VC',
  /** Venezuela. */
  Ve = 'VE',
  /** British Virgin Islands. */
  Vg = 'VG',
  /** Vietnam. */
  Vn = 'VN',
  /** Vanuatu. */
  Vu = 'VU',
  /** Wallis & Futuna. */
  Wf = 'WF',
  /** Samoa. */
  Ws = 'WS',
  /** Kosovo. */
  Xk = 'XK',
  /** Yemen. */
  Ye = 'YE',
  /** Mayotte. */
  Yt = 'YT',
  /** South Africa. */
  Za = 'ZA',
  /** Zambia. */
  Zm = 'ZM',
  /** Zimbabwe. */
  Zw = 'ZW',
  /** Unknown Region. */
  Zz = 'ZZ',
}

/**
 * The country-specific harmonized system code and ISO country code for an inventory item.
 *
 */
export type CountryHarmonizedSystemCode = {
  __typename?: 'CountryHarmonizedSystemCode'
  /** The ISO 3166-1 alpha-2 country code for the country that issued the specified harmonized system code. */
  countryCode: CountryCode
  /** The country-specific harmonized system code. These are usually longer than 6 digits. */
  harmonizedSystemCode: Scalars['String']
}

/**
 * An auto-generated type for paginating through multiple CountryHarmonizedSystemCodes.
 *
 */
export type CountryHarmonizedSystemCodeConnection = {
  __typename?: 'CountryHarmonizedSystemCodeConnection'
  /** A list of edges. */
  edges: Array<CountryHarmonizedSystemCodeEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one CountryHarmonizedSystemCode and a cursor during pagination.
 *
 */
export type CountryHarmonizedSystemCodeEdge = {
  __typename?: 'CountryHarmonizedSystemCodeEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of CountryHarmonizedSystemCodeEdge. */
  node: CountryHarmonizedSystemCode
}

/**
 * The fields required to specify a harmonized system code.
 *
 */
export type CountryHarmonizedSystemCodeInput = {
  /** The ISO 3166-1 alpha-2 country code for the country that issued the specified harmonized system code. */
  countryCode: CountryCode
  /** Country specific harmonized system code. */
  harmonizedSystemCode: Scalars['String']
}

/** Specifies the input fields required to create a media object. */
export type CreateMediaInput = {
  /** The alt text associated to the media. */
  alt?: InputMaybe<Scalars['String']>
  /** The media content type. */
  mediaContentType: MediaContentType
  /** The original source of the media object. May be an external URL or signed upload URL. */
  originalSource: Scalars['String']
}

/** The part of the image that should remain after cropping. */
export enum CropRegion {
  /** Keep the bottom of the image. */
  Bottom = 'BOTTOM',
  /** Keep the center of the image. */
  Center = 'CENTER',
  /** Keep the left of the image. */
  Left = 'LEFT',
  /** Keep the right of the image. */
  Right = 'RIGHT',
  /** Keep the top of the image. */
  Top = 'TOP',
}

/**
 * The three-letter currency codes that represent the world currencies used in stores. These include standard ISO 4217 codes, legacy codes,
 * and non-standard codes.
 *
 */
export enum CurrencyCode {
  /** United Arab Emirates Dirham (AED). */
  Aed = 'AED',
  /** Afghan Afghani (AFN). */
  Afn = 'AFN',
  /** Albanian Lek (ALL). */
  All = 'ALL',
  /** Armenian Dram (AMD). */
  Amd = 'AMD',
  /** Netherlands Antillean Guilder. */
  Ang = 'ANG',
  /** Angolan Kwanza (AOA). */
  Aoa = 'AOA',
  /** Argentine Pesos (ARS). */
  Ars = 'ARS',
  /** Australian Dollars (AUD). */
  Aud = 'AUD',
  /** Aruban Florin (AWG). */
  Awg = 'AWG',
  /** Azerbaijani Manat (AZN). */
  Azn = 'AZN',
  /** Bosnia and Herzegovina Convertible Mark (BAM). */
  Bam = 'BAM',
  /** Barbadian Dollar (BBD). */
  Bbd = 'BBD',
  /** Bangladesh Taka (BDT). */
  Bdt = 'BDT',
  /** Bulgarian Lev (BGN). */
  Bgn = 'BGN',
  /** Bahraini Dinar (BHD). */
  Bhd = 'BHD',
  /** Burundian Franc (BIF). */
  Bif = 'BIF',
  /** Bermudian Dollar (BMD). */
  Bmd = 'BMD',
  /** Brunei Dollar (BND). */
  Bnd = 'BND',
  /** Bolivian Boliviano (BOB). */
  Bob = 'BOB',
  /** Brazilian Real (BRL). */
  Brl = 'BRL',
  /** Bahamian Dollar (BSD). */
  Bsd = 'BSD',
  /** Bhutanese Ngultrum (BTN). */
  Btn = 'BTN',
  /** Botswana Pula (BWP). */
  Bwp = 'BWP',
  /** Belarusian Ruble (BYN). */
  Byn = 'BYN',
  /** Belarusian Ruble (BYR). */
  Byr = 'BYR',
  /** Belize Dollar (BZD). */
  Bzd = 'BZD',
  /** Canadian Dollars (CAD). */
  Cad = 'CAD',
  /** Congolese franc (CDF). */
  Cdf = 'CDF',
  /** Swiss Francs (CHF). */
  Chf = 'CHF',
  /** Chilean Peso (CLP). */
  Clp = 'CLP',
  /** Chinese Yuan Renminbi (CNY). */
  Cny = 'CNY',
  /** Colombian Peso (COP). */
  Cop = 'COP',
  /** Costa Rican Colones (CRC). */
  Crc = 'CRC',
  /** Cape Verdean escudo (CVE). */
  Cve = 'CVE',
  /** Czech Koruny (CZK). */
  Czk = 'CZK',
  /** Djiboutian Franc (DJF). */
  Djf = 'DJF',
  /** Danish Kroner (DKK). */
  Dkk = 'DKK',
  /** Dominican Peso (DOP). */
  Dop = 'DOP',
  /** Algerian Dinar (DZD). */
  Dzd = 'DZD',
  /** Egyptian Pound (EGP). */
  Egp = 'EGP',
  /** Eritrean Nakfa (ERN). */
  Ern = 'ERN',
  /** Ethiopian Birr (ETB). */
  Etb = 'ETB',
  /** Euro (EUR). */
  Eur = 'EUR',
  /** Fijian Dollars (FJD). */
  Fjd = 'FJD',
  /** Falkland Islands Pounds (FKP). */
  Fkp = 'FKP',
  /** United Kingdom Pounds (GBP). */
  Gbp = 'GBP',
  /** Georgian Lari (GEL). */
  Gel = 'GEL',
  /** Ghanaian Cedi (GHS). */
  Ghs = 'GHS',
  /** Gibraltar Pounds (GIP). */
  Gip = 'GIP',
  /** Gambian Dalasi (GMD). */
  Gmd = 'GMD',
  /** Guinean Franc (GNF). */
  Gnf = 'GNF',
  /** Guatemalan Quetzal (GTQ). */
  Gtq = 'GTQ',
  /** Guyanese Dollar (GYD). */
  Gyd = 'GYD',
  /** Hong Kong Dollars (HKD). */
  Hkd = 'HKD',
  /** Honduran Lempira (HNL). */
  Hnl = 'HNL',
  /** Croatian Kuna (HRK). */
  Hrk = 'HRK',
  /** Haitian Gourde (HTG). */
  Htg = 'HTG',
  /** Hungarian Forint (HUF). */
  Huf = 'HUF',
  /** Indonesian Rupiah (IDR). */
  Idr = 'IDR',
  /** Israeli New Shekel (NIS). */
  Ils = 'ILS',
  /** Indian Rupees (INR). */
  Inr = 'INR',
  /** Iraqi Dinar (IQD). */
  Iqd = 'IQD',
  /** Iranian Rial (IRR). */
  Irr = 'IRR',
  /** Icelandic Kronur (ISK). */
  Isk = 'ISK',
  /** Jersey Pound. */
  Jep = 'JEP',
  /** Jamaican Dollars (JMD). */
  Jmd = 'JMD',
  /** Jordanian Dinar (JOD). */
  Jod = 'JOD',
  /** Japanese Yen (JPY). */
  Jpy = 'JPY',
  /** Kenyan Shilling (KES). */
  Kes = 'KES',
  /** Kyrgyzstani Som (KGS). */
  Kgs = 'KGS',
  /** Cambodian Riel. */
  Khr = 'KHR',
  /** Kiribati Dollar (KID). */
  Kid = 'KID',
  /** Comorian Franc (KMF). */
  Kmf = 'KMF',
  /** South Korean Won (KRW). */
  Krw = 'KRW',
  /** Kuwaiti Dinar (KWD). */
  Kwd = 'KWD',
  /** Cayman Dollars (KYD). */
  Kyd = 'KYD',
  /** Kazakhstani Tenge (KZT). */
  Kzt = 'KZT',
  /** Laotian Kip (LAK). */
  Lak = 'LAK',
  /** Lebanese Pounds (LBP). */
  Lbp = 'LBP',
  /** Sri Lankan Rupees (LKR). */
  Lkr = 'LKR',
  /** Liberian Dollar (LRD). */
  Lrd = 'LRD',
  /** Lesotho Loti (LSL). */
  Lsl = 'LSL',
  /** Lithuanian Litai (LTL). */
  Ltl = 'LTL',
  /** Latvian Lati (LVL). */
  Lvl = 'LVL',
  /** Libyan Dinar (LYD). */
  Lyd = 'LYD',
  /** Moroccan Dirham. */
  Mad = 'MAD',
  /** Moldovan Leu (MDL). */
  Mdl = 'MDL',
  /** Malagasy Ariary (MGA). */
  Mga = 'MGA',
  /** Macedonia Denar (MKD). */
  Mkd = 'MKD',
  /** Burmese Kyat (MMK). */
  Mmk = 'MMK',
  /** Mongolian Tugrik. */
  Mnt = 'MNT',
  /** Macanese Pataca (MOP). */
  Mop = 'MOP',
  /** Mauritanian Ouguiya (MRU). */
  Mru = 'MRU',
  /** Mauritian Rupee (MUR). */
  Mur = 'MUR',
  /** Maldivian Rufiyaa (MVR). */
  Mvr = 'MVR',
  /** Malawian Kwacha (MWK). */
  Mwk = 'MWK',
  /** Mexican Pesos (MXN). */
  Mxn = 'MXN',
  /** Malaysian Ringgits (MYR). */
  Myr = 'MYR',
  /** Mozambican Metical. */
  Mzn = 'MZN',
  /** Namibian Dollar. */
  Nad = 'NAD',
  /** Nigerian Naira (NGN). */
  Ngn = 'NGN',
  /** Nicaraguan Córdoba (NIO). */
  Nio = 'NIO',
  /** Norwegian Kroner (NOK). */
  Nok = 'NOK',
  /** Nepalese Rupee (NPR). */
  Npr = 'NPR',
  /** New Zealand Dollars (NZD). */
  Nzd = 'NZD',
  /** Omani Rial (OMR). */
  Omr = 'OMR',
  /** Panamian Balboa (PAB). */
  Pab = 'PAB',
  /** Peruvian Nuevo Sol (PEN). */
  Pen = 'PEN',
  /** Papua New Guinean Kina (PGK). */
  Pgk = 'PGK',
  /** Philippine Peso (PHP). */
  Php = 'PHP',
  /** Pakistani Rupee (PKR). */
  Pkr = 'PKR',
  /** Polish Zlotych (PLN). */
  Pln = 'PLN',
  /** Paraguayan Guarani (PYG). */
  Pyg = 'PYG',
  /** Qatari Rial (QAR). */
  Qar = 'QAR',
  /** Romanian Lei (RON). */
  Ron = 'RON',
  /** Serbian dinar (RSD). */
  Rsd = 'RSD',
  /** Russian Rubles (RUB). */
  Rub = 'RUB',
  /** Rwandan Franc (RWF). */
  Rwf = 'RWF',
  /** Saudi Riyal (SAR). */
  Sar = 'SAR',
  /** Solomon Islands Dollar (SBD). */
  Sbd = 'SBD',
  /** Seychellois Rupee (SCR). */
  Scr = 'SCR',
  /** Sudanese Pound (SDG). */
  Sdg = 'SDG',
  /** Swedish Kronor (SEK). */
  Sek = 'SEK',
  /** Singapore Dollars (SGD). */
  Sgd = 'SGD',
  /** Saint Helena Pounds (SHP). */
  Shp = 'SHP',
  /** Sierra Leonean Leone (SLL). */
  Sll = 'SLL',
  /** Somali Shilling (SOS). */
  Sos = 'SOS',
  /** Surinamese Dollar (SRD). */
  Srd = 'SRD',
  /** South Sudanese Pound (SSP). */
  Ssp = 'SSP',
  /** Sao Tome And Principe Dobra (STD). */
  Std = 'STD',
  /** Syrian Pound (SYP). */
  Syp = 'SYP',
  /** Swazi Lilangeni (SZL). */
  Szl = 'SZL',
  /** Thai baht (THB). */
  Thb = 'THB',
  /** Tajikistani Somoni (TJS). */
  Tjs = 'TJS',
  /** Turkmenistani Manat (TMT). */
  Tmt = 'TMT',
  /** Tunisian Dinar (TND). */
  Tnd = 'TND',
  /** Tongan Pa'anga (TOP). */
  Top = 'TOP',
  /** Turkish Lira (TRY). */
  Try = 'TRY',
  /** Trinidad and Tobago Dollars (TTD). */
  Ttd = 'TTD',
  /** Taiwan Dollars (TWD). */
  Twd = 'TWD',
  /** Tanzanian Shilling (TZS). */
  Tzs = 'TZS',
  /** Ukrainian Hryvnia (UAH). */
  Uah = 'UAH',
  /** Ugandan Shilling (UGX). */
  Ugx = 'UGX',
  /** United States Dollars (USD). */
  Usd = 'USD',
  /** Uruguayan Pesos (UYU). */
  Uyu = 'UYU',
  /** Uzbekistan som (UZS). */
  Uzs = 'UZS',
  /** Venezuelan Bolivares (VEF). */
  Vef = 'VEF',
  /** Venezuelan Bolivares (VES). */
  Ves = 'VES',
  /** Vietnamese đồng (VND). */
  Vnd = 'VND',
  /** Vanuatu Vatu (VUV). */
  Vuv = 'VUV',
  /** Samoan Tala (WST). */
  Wst = 'WST',
  /** Central African CFA Franc (XAF). */
  Xaf = 'XAF',
  /** East Caribbean Dollar (XCD). */
  Xcd = 'XCD',
  /** West African CFA franc (XOF). */
  Xof = 'XOF',
  /** CFP Franc (XPF). */
  Xpf = 'XPF',
  /** Unrecognized currency. */
  Xxx = 'XXX',
  /** Yemeni Rial (YER). */
  Yer = 'YER',
  /** South African Rand (ZAR). */
  Zar = 'ZAR',
  /** Zambian Kwacha (ZMW). */
  Zmw = 'ZMW',
}

/** Currency formats configured for the merchant. These formats are available to use within Liquid. */
export type CurrencyFormats = {
  __typename?: 'CurrencyFormats'
  /** Money without currency in HTML. */
  moneyFormat: Scalars['FormattedString']
  /** Money without currency in emails. */
  moneyInEmailsFormat: Scalars['String']
  /** Money with currency in HTML. */
  moneyWithCurrencyFormat: Scalars['FormattedString']
  /** Money with currency in emails. */
  moneyWithCurrencyInEmailsFormat: Scalars['String']
}

/** A setting for a presentment currency. */
export type CurrencySetting = {
  __typename?: 'CurrencySetting'
  /** The currency's ISO code. */
  currencyCode: CurrencyCode
  /** The full name of the currency. */
  currencyName: Scalars['String']
  /** Whether the currency is enabled or not. An enabled currency setting is visible to buyers and allows orders to be generated with that currency as presentment. */
  enabled: Scalars['Boolean']
  /** The date and time when the active exchange rate for the currency was last modified. It can be the automatic rate's creation date, or the manual rate's last updated at date if active. */
  rateUpdatedAt?: Maybe<Scalars['DateTime']>
}

/**
 * An auto-generated type for paginating through multiple CurrencySettings.
 *
 */
export type CurrencySettingConnection = {
  __typename?: 'CurrencySettingConnection'
  /** A list of edges. */
  edges: Array<CurrencySettingEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one CurrencySetting and a cursor during pagination.
 *
 */
export type CurrencySettingEdge = {
  __typename?: 'CurrencySettingEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of CurrencySettingEdge. */
  node: CurrencySetting
}

/**
 * Represents information about a customer of the shop, such as the customer's contact details, their order
 * history, and whether they've agreed to receive marketing material by email.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type Customer = CommentEventSubject &
  HasEvents &
  HasMetafieldDefinitions &
  HasMetafields &
  LegacyInteroperability &
  Node & {
    __typename?: 'Customer'
    /**
     * Whether the customer has agreed to receive marketing material.
     * @deprecated Use `emailMarketingConsent` instead
     */
    acceptsMarketing: Scalars['Boolean']
    /**
     * The date and time when the customer consented or objected to receiving marketing material by email.
     *
     * @deprecated Use `emailMarketingConsent` instead
     */
    acceptsMarketingUpdatedAt: Scalars['DateTime']
    /** A list of addresses associated with the customer. */
    addresses: Array<MailingAddress>
    /**
     * The average amount that the customer spent per order.
     * @deprecated Use `averageOrderAmountV2` instead
     */
    averageOrderAmount?: Maybe<Scalars['Money']>
    /** The average amount that the customer spent per order. */
    averageOrderAmountV2?: Maybe<MoneyV2>
    /**
     * Whether the merchant can delete the customer from their store.
     *
     * A customer can be deleted from a store only if they have not yet made an order. After a customer makes an
     * order, they can't be deleted from a store.
     *
     */
    canDelete: Scalars['Boolean']
    /** The date and time when the customer was added to the store. */
    createdAt: Scalars['DateTime']
    /** The default address associated with the customer. */
    defaultAddress?: Maybe<MailingAddress>
    /**
     * The full name of the customer, based on the values for first_name and last_name. If the first_name and
     * last_name are not available, then this falls back to the customer's email address, and if that is not available, the customer's phone number.
     *
     */
    displayName: Scalars['String']
    /** The customer's email address. */
    email?: Maybe<Scalars['String']>
    /** A list of events associated with the customer. */
    events: EventConnection
    /** The customer's first name. */
    firstName?: Maybe<Scalars['String']>
    /**
     * Whether the customer has a note associated with them.
     * @deprecated Check for a value in the note field directly instead.
     */
    hasNote: Scalars['Boolean']
    /**
     * Whether the merchant has added timeline comments about the customer on the customer's page.
     * @deprecated To query for comments on the timeline, use the events connection and a `query` argument containing `verb:comment`, or look for a `CommentEvent` in the `__typename` of events.
     */
    hasTimelineComment: Scalars['Boolean']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The image associated with the customer. */
    image: Image
    /** The customer's last name. */
    lastName?: Maybe<Scalars['String']>
    /** The customer's last order. */
    lastOrder?: Maybe<Order>
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /**
     * The amount of time since the customer was first added to the store.
     *
     * Example: 'about 12 years'.
     *
     */
    lifetimeDuration: Scalars['String']
    /** The customer's locale. */
    locale: Scalars['String']
    /**
     * The marketing subscription opt-in level, as described by the M3AAWG best practices guidelines, that the
     * customer gave when they consented to receive marketing material by email.
     *
     * If the customer does not accept email marketing, then this property is `null`.
     *
     * @deprecated Use `emailMarketingConsent` instead
     */
    marketingOptInLevel?: Maybe<CustomerMarketingOptInLevel>
    /** Returns a metafield by namespace and key that belongs to the resource. */
    metafield?: Maybe<Metafield>
    /** List of metafield definitions. */
    metafieldDefinitions: MetafieldDefinitionConnection
    /** List of metafields that belong to the resource. */
    metafields: MetafieldConnection
    /** A unique identifier for the customer that's used with Multipass login. */
    multipassIdentifier?: Maybe<Scalars['String']>
    /** A note about the customer. */
    note?: Maybe<Scalars['String']>
    /** A list of the customer's orders. */
    orders: OrderConnection
    /**
     * The number of orders that the customer has made at the store in their lifetime.
     * @deprecated Use `numberOfOrders` instead
     */
    ordersCount: Scalars['UnsignedInt64']
    /** A list of the customer's payment methods. */
    paymentMethods: CustomerPaymentMethodConnection
    /** The customer's phone number. */
    phone?: Maybe<Scalars['String']>
    /** Returns a private metafield by namespace and key that belongs to the resource. */
    privateMetafield?: Maybe<PrivateMetafield>
    /** List of private metafields that belong to the resource. */
    privateMetafields: PrivateMetafieldConnection
    /** Possible subscriber states of a customer defined by their subscription contracts. */
    productSubscriberStatus: CustomerProductSubscriberStatus
    /**
     * The current SMS marketing state for the customer's phone number.
     *
     * If the customer does not have a phone number, then this property is `null`.
     *
     */
    smsMarketingConsent?: Maybe<CustomerSmsMarketingConsentState>
    /** The state of the customer's account with the shop. */
    state: CustomerState
    /** A list of the customer's subscription contracts. */
    subscriptionContracts: SubscriptionContractConnection
    /** A comma separated list of tags that have been added to the customer. */
    tags: Array<Scalars['String']>
    /** Whether the customer is exempt from being charged taxes on their orders. */
    taxExempt: Scalars['Boolean']
    /** The list of tax exemptions applied to the customer. */
    taxExemptions: Array<TaxExemption>
    /**
     * The total amount that the customer has spent on orders in their lifetime.
     * @deprecated Use `amountSpent` instead
     */
    totalSpent: Scalars['Money']
    /**
     * The total amount that the customer has spent on orders in their lifetime.
     * @deprecated Use `amountSpent` instead
     */
    totalSpentV2: MoneyV2
    /** The date and time when the customer was last updated. */
    updatedAt: Scalars['DateTime']
    /**
     * Whether the email address is formatted correctly. This does not
     * guarantee that the email address actually exists.
     *
     */
    validEmailAddress: Scalars['Boolean']
    /** Whether the customer has verified their email address. Defaults to `true` if the customer is created through the Shopify admin or API. */
    verifiedEmail: Scalars['Boolean']
  }

/**
 * Represents information about a customer of the shop, such as the customer's contact details, their order
 * history, and whether they've agreed to receive marketing material by email.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type CustomerAddressesArgs = {
  first?: InputMaybe<Scalars['Int']>
}

/**
 * Represents information about a customer of the shop, such as the customer's contact details, their order
 * history, and whether they've agreed to receive marketing material by email.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type CustomerEventsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<EventSortKeys>
}

/**
 * Represents information about a customer of the shop, such as the customer's contact details, their order
 * history, and whether they've agreed to receive marketing material by email.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type CustomerImageArgs = {
  size?: InputMaybe<Scalars['Int']>
}

/**
 * Represents information about a customer of the shop, such as the customer's contact details, their order
 * history, and whether they've agreed to receive marketing material by email.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type CustomerMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/**
 * Represents information about a customer of the shop, such as the customer's contact details, their order
 * history, and whether they've agreed to receive marketing material by email.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type CustomerMetafieldDefinitionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  pinnedStatus?: InputMaybe<MetafieldDefinitionPinnedStatus>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<MetafieldDefinitionSortKeys>
}

/**
 * Represents information about a customer of the shop, such as the customer's contact details, their order
 * history, and whether they've agreed to receive marketing material by email.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type CustomerMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents information about a customer of the shop, such as the customer's contact details, their order
 * history, and whether they've agreed to receive marketing material by email.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type CustomerOrdersArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<OrderSortKeys>
}

/**
 * Represents information about a customer of the shop, such as the customer's contact details, their order
 * history, and whether they've agreed to receive marketing material by email.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type CustomerPaymentMethodsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  showRevoked?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents information about a customer of the shop, such as the customer's contact details, their order
 * history, and whether they've agreed to receive marketing material by email.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type CustomerPrivateMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/**
 * Represents information about a customer of the shop, such as the customer's contact details, their order
 * history, and whether they've agreed to receive marketing material by email.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type CustomerPrivateMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents information about a customer of the shop, such as the customer's contact details, their order
 * history, and whether they've agreed to receive marketing material by email.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type CustomerSubscriptionContractsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Return type for `customerAddTaxExemptions` mutation. */
export type CustomerAddTaxExemptionsPayload = {
  __typename?: 'CustomerAddTaxExemptionsPayload'
  /** The updated customer. */
  customer?: Maybe<Customer>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type for paginating through multiple Customers.
 *
 */
export type CustomerConnection = {
  __typename?: 'CustomerConnection'
  /** A list of edges. */
  edges: Array<CustomerEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * The source that collected the customer's consent to receive marketing materials.
 *
 */
export enum CustomerConsentCollectedFrom {
  /**
   * The customer consent was collected outside of Shopify.
   *
   */
  Other = 'OTHER',
  /**
   * The customer consent was collected by Shopify.
   *
   */
  Shopify = 'SHOPIFY',
}

/** Return type for `customerCreate` mutation. */
export type CustomerCreatePayload = {
  __typename?: 'CustomerCreatePayload'
  /** The created customer. */
  customer?: Maybe<Customer>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Represents a card instrument for customer payment method. */
export type CustomerCreditCard = {
  __typename?: 'CustomerCreditCard'
  /** The billing address of the card. */
  billingAddress?: Maybe<CustomerCreditCardBillingAddress>
  /** The brand of the card. */
  brand: Scalars['String']
  /** Whether the card is about to expire. */
  expiresSoon: Scalars['Boolean']
  /** The expiry month of the card. */
  expiryMonth: Scalars['Int']
  /** The expiry year of the card. */
  expiryYear: Scalars['Int']
  /** The card's BIN number. */
  firstDigits?: Maybe<Scalars['String']>
  /** The payment method can be revoked if there are no active subscription contracts. */
  isRevocable: Scalars['Boolean']
  /** The last 4 digits of the card. */
  lastDigits: Scalars['String']
  /** The masked card number with only the last 4 digits displayed. */
  maskedNumber: Scalars['String']
  /** The name of the card holder. */
  name: Scalars['String']
  /** The source of the card if coming from a wallet such as Apple Pay. */
  source?: Maybe<Scalars['String']>
  /** The last 4 digits of the Device Account Number. */
  virtualLastDigits?: Maybe<Scalars['String']>
}

/** The billing address of a credit card payment instrument. */
export type CustomerCreditCardBillingAddress = {
  __typename?: 'CustomerCreditCardBillingAddress'
  /** The first line of the address. Typically the street address or PO Box number. */
  address1?: Maybe<Scalars['String']>
  /** The name of the city, district, village, or town. */
  city?: Maybe<Scalars['String']>
  /** The name of the country. */
  country?: Maybe<Scalars['String']>
  /**
   * The two-letter code for the country of the address.
   * For example, US.
   *
   */
  countryCode?: Maybe<CountryCode>
  /** The region of the address, such as the province, state, or district. */
  province?: Maybe<Scalars['String']>
  /**
   * The two-letter code for the region.
   * For example, ON.
   *
   */
  provinceCode?: Maybe<Scalars['String']>
  /** The zip or postal code of the address. */
  zip?: Maybe<Scalars['String']>
}

/** Specifies the customer to delete. */
export type CustomerDeleteInput = {
  /** The ID of the customer to delete. */
  id: Scalars['ID']
}

/** Return type for `customerDelete` mutation. */
export type CustomerDeletePayload = {
  __typename?: 'CustomerDeletePayload'
  /** The ID of the deleted customer. */
  deletedCustomerId?: Maybe<Scalars['ID']>
  /** The shop of the deleted customer. */
  shop: Shop
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one Customer and a cursor during pagination.
 *
 */
export type CustomerEdge = {
  __typename?: 'CustomerEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of CustomerEdge. */
  node: Customer
}

/** Return type for `customerGenerateAccountActivationUrl` mutation. */
export type CustomerGenerateAccountActivationUrlPayload = {
  __typename?: 'CustomerGenerateAccountActivationUrlPayload'
  /** The generated account activation URL. */
  accountActivationUrl?: Maybe<Scalars['URL']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Provides the fields and values to use when creating or updating a customer. */
export type CustomerInput = {
  /** Whether the customer has consented to receive marketing material by email. This argument is deprecated: Use `emailMarketingConsent` instead in API versions 2022-04 and higher. */
  acceptsMarketing?: InputMaybe<Scalars['Boolean']>
  /**
   * The date and time when the customer consented or objected to receiving marketing
   * material by email.
   *  This argument is deprecated: Use `emailMarketingConsent` instead in API versions 2022-04 and higher.
   */
  acceptsMarketingUpdatedAt?: InputMaybe<Scalars['DateTime']>
  /** The addresses for a customer. */
  addresses?: InputMaybe<Array<MailingAddressInput>>
  /** The unique email address of the customer. */
  email?: InputMaybe<Scalars['String']>
  /** The customer's first name. */
  firstName?: InputMaybe<Scalars['String']>
  /** The ID of the customer to update. */
  id?: InputMaybe<Scalars['ID']>
  /** The customer's last name. */
  lastName?: InputMaybe<Scalars['String']>
  /** The customer's locale. */
  locale?: InputMaybe<Scalars['String']>
  /**
   * The marketing subscription opt-in level used when the customer consented to receiving
   * marketing material by email.
   *  This argument is deprecated: Use `emailMarketingConsent` instead in API versions 2022-04 and higher.
   */
  marketingOptInLevel?: InputMaybe<CustomerMarketingOptInLevel>
  /** Additional metafields to associate to the customer. */
  metafields?: InputMaybe<Array<MetafieldInput>>
  /** A note about the customer. */
  note?: InputMaybe<Scalars['String']>
  /** The unique phone number for the customer. */
  phone?: InputMaybe<Scalars['String']>
  /** The private metafields to associate with the customer. */
  privateMetafields?: InputMaybe<Array<PrivateMetafieldInput>>
  /**
   * The marketing consent information when the customer consented to receiving marketing
   *         material by SMS. The `phone` field is required when creating a customer with SMS
   *         marketing consent information.
   */
  smsMarketingConsent?: InputMaybe<CustomerSmsMarketingConsentInput>
  /**
   * A list of tags to associate with the customer. Can be an array or a comma-separated list. Example values: `["tag1", "tag2", "tag3"]`, `"tag1, tag2, tag3"`
   *
   * Updating `tags` overwrites any existing tags that were previously added to the customer. To add new tags without overwriting
   * existing tags, use the [tagsAdd](https://shopify.dev/api/admin-graphql/latest/mutations/tagsadd)
   * mutation.
   *
   */
  tags?: InputMaybe<Array<Scalars['String']>>
  /** Whether the customer is exempt from paying taxes on their order. */
  taxExempt?: InputMaybe<Scalars['Boolean']>
  /** The list of tax exemptions to apply to the customer. */
  taxExemptions?: InputMaybe<Array<TaxExemption>>
}

/** Represents a customer's visiting activities on a shop's online store. */
export type CustomerJourney = {
  __typename?: 'CustomerJourney'
  /** The position of the current order within the customer's order history. */
  customerOrderIndex: Scalars['Int']
  /** The amount of days between first session and order creation date. First session represents first session since the last order, or first session within the 30 day attribution window, if more than 30 days has passed since the last order. */
  daysToConversion: Scalars['Int']
  /** The customer's first session going into the shop. */
  firstVisit: CustomerVisit
  /** The last session before an order is made. */
  lastVisit?: Maybe<CustomerVisit>
  /** Events preceding a customer order, such as shop sessions. */
  moments: Array<CustomerMoment>
}

/** Represents a customer's visiting activities on a shop's online store. */
export type CustomerJourneySummary = {
  __typename?: 'CustomerJourneySummary'
  /** The position of the current order within the customer's order history. Test orders aren't included. */
  customerOrderIndex?: Maybe<Scalars['Int']>
  /** The number of days between the first session and the order creation date. The first session represents the first session since the last order, or the first session within the 30 day attribution window, if more than 30 days have passed since the last order. */
  daysToConversion?: Maybe<Scalars['Int']>
  /** The customer's first session going into the shop. */
  firstVisit?: Maybe<CustomerVisit>
  /** The last session before an order is made. */
  lastVisit?: Maybe<CustomerVisit>
  /** The events preceding a customer's order, such as shop sessions. */
  moments?: Maybe<CustomerMomentConnection>
  /** The total number of customer moments associated with this order. Returns null if the order is still in the process of being attributed. */
  momentsCount?: Maybe<Scalars['Int']>
  /** Whether or not the attributed sessions for the order have been created yet. */
  ready: Scalars['Boolean']
}

/** Represents a customer's visiting activities on a shop's online store. */
export type CustomerJourneySummaryMomentsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * The possible values for the marketing subscription opt in level enabled at the time the customer consented to receive marketing information.
 *
 * The levels are defined by [the M3AAWG best practices guideline
 *   document](https://www.m3aawg.org/sites/maawg/files/news/M3AAWG_Senders_BCP_Ver3-2015-02.pdf).
 *
 */
export enum CustomerMarketingOptInLevel {
  /**
   * After providing their information, the customer receives a confirmation and is required to
   * perform a intermediate step before receiving marketing information.
   *
   */
  ConfirmedOptIn = 'CONFIRMED_OPT_IN',
  /**
   * After providing their information, the customer receives marketing information without any
   * intermediate steps.
   *
   */
  SingleOptIn = 'SINGLE_OPT_IN',
  /**
   * The customer receives marketing information but how they were opted in is unknown.
   *
   */
  Unknown = 'UNKNOWN',
}

/** Represents a session preceding an order, often used for building a timeline of events leading to an order. */
export type CustomerMoment = {
  /** The date and time when the customer's session occurred. */
  occurredAt: Scalars['DateTime']
}

/**
 * An auto-generated type for paginating through multiple CustomerMoments.
 *
 */
export type CustomerMomentConnection = {
  __typename?: 'CustomerMomentConnection'
  /** A list of edges. */
  edges: Array<CustomerMomentEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one CustomerMoment and a cursor during pagination.
 *
 */
export type CustomerMomentEdge = {
  __typename?: 'CustomerMomentEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of CustomerMomentEdge. */
  node: CustomerMoment
}

/** All possible instruments for CustomerPaymentMethods. */
export type CustomerPaymentInstrument =
  | CustomerCreditCard
  | CustomerPaypalBillingAgreement
  | CustomerShopPayAgreement

/** The billing address of a payment instrument. */
export type CustomerPaymentInstrumentBillingAddress = {
  __typename?: 'CustomerPaymentInstrumentBillingAddress'
  /** The first line of the address. Typically the street address or PO Box number. */
  address1?: Maybe<Scalars['String']>
  /** The name of the city, district, village, or town. */
  city?: Maybe<Scalars['String']>
  /** The name of the country. */
  country?: Maybe<Scalars['String']>
  /**
   * The two-letter code for the country of the address.
   * For example, US.
   *
   */
  countryCode?: Maybe<CountryCode>
  /** The name of the buyer of the address. */
  name?: Maybe<Scalars['String']>
  /** The region of the address, such as the province, state, or district. */
  province?: Maybe<Scalars['String']>
  /**
   * The two-letter code for the region.
   * For example, ON.
   *
   */
  provinceCode?: Maybe<Scalars['String']>
  /** The zip or postal code of the address. */
  zip?: Maybe<Scalars['String']>
}

/** A customer's payment method. */
export type CustomerPaymentMethod = Node & {
  __typename?: 'CustomerPaymentMethod'
  /** The customer to whom the payment method belongs. */
  customer?: Maybe<Customer>
  /** The ID of this payment method. */
  id: Scalars['ID']
  /** The instrument for this payment method. */
  instrument?: Maybe<CustomerPaymentInstrument>
  /** The time that the payment method was revoked. */
  revokedAt?: Maybe<Scalars['DateTime']>
  /** The revocation reason for this payment method. */
  revokedReason?: Maybe<CustomerPaymentMethodRevocationReason>
  /** List Subscription Contracts. */
  subscriptionContracts: SubscriptionContractConnection
}

/** A customer's payment method. */
export type CustomerPaymentMethodSubscriptionContractsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An auto-generated type for paginating through multiple CustomerPaymentMethods.
 *
 */
export type CustomerPaymentMethodConnection = {
  __typename?: 'CustomerPaymentMethodConnection'
  /** A list of edges. */
  edges: Array<CustomerPaymentMethodEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `customerPaymentMethodCreditCardCreate` mutation. */
export type CustomerPaymentMethodCreditCardCreatePayload = {
  __typename?: 'CustomerPaymentMethodCreditCardCreatePayload'
  /** The customer payment method. */
  customerPaymentMethod?: Maybe<CustomerPaymentMethod>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `customerPaymentMethodCreditCardUpdate` mutation. */
export type CustomerPaymentMethodCreditCardUpdatePayload = {
  __typename?: 'CustomerPaymentMethodCreditCardUpdatePayload'
  /** The customer payment method. */
  customerPaymentMethod?: Maybe<CustomerPaymentMethod>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one CustomerPaymentMethod and a cursor during pagination.
 *
 */
export type CustomerPaymentMethodEdge = {
  __typename?: 'CustomerPaymentMethodEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of CustomerPaymentMethodEdge. */
  node: CustomerPaymentMethod
}

/** Return type for `customerPaymentMethodGetUpdateUrl` mutation. */
export type CustomerPaymentMethodGetUpdateUrlPayload = {
  __typename?: 'CustomerPaymentMethodGetUpdateUrlPayload'
  /** The URL to redirect the customer to update the payment method. */
  updatePaymentMethodUrl?: Maybe<Scalars['URL']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<CustomerPaymentMethodGetUpdateUrlUserError>
}

/** An error that occurs during the execution of `CustomerPaymentMethodGetUpdateUrl`. */
export type CustomerPaymentMethodGetUpdateUrlUserError = DisplayableError & {
  __typename?: 'CustomerPaymentMethodGetUpdateUrlUserError'
  /** The error code. */
  code?: Maybe<CustomerPaymentMethodGetUpdateUrlUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `CustomerPaymentMethodGetUpdateUrlUserError`. */
export enum CustomerPaymentMethodGetUpdateUrlUserErrorCode {
  /** Customer doesn't exist. */
  CustomerDoesNotExist = 'CUSTOMER_DOES_NOT_EXIST',
  /** Invalid payment instrument. */
  InvalidInstrument = 'INVALID_INSTRUMENT',
  /** Payment method doesn't exist. */
  PaymentMethodDoesNotExist = 'PAYMENT_METHOD_DOES_NOT_EXIST',
  /** Too many requests. */
  TooManyRequests = 'TOO_MANY_REQUESTS',
}

/** Return type for `customerPaymentMethodPaypalBillingAgreementCreate` mutation. */
export type CustomerPaymentMethodPaypalBillingAgreementCreatePayload = {
  __typename?: 'CustomerPaymentMethodPaypalBillingAgreementCreatePayload'
  /** The customer payment method. */
  customerPaymentMethod?: Maybe<CustomerPaymentMethod>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<CustomerPaymentMethodUserError>
}

/** Return type for `customerPaymentMethodPaypalBillingAgreementUpdate` mutation. */
export type CustomerPaymentMethodPaypalBillingAgreementUpdatePayload = {
  __typename?: 'CustomerPaymentMethodPaypalBillingAgreementUpdatePayload'
  /** The customer payment method. */
  customerPaymentMethod?: Maybe<CustomerPaymentMethod>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<CustomerPaymentMethodUserError>
}

/** Return type for `customerPaymentMethodRemoteCreate` mutation. */
export type CustomerPaymentMethodRemoteCreatePayload = {
  __typename?: 'CustomerPaymentMethodRemoteCreatePayload'
  /** The customer payment method. */
  customerPaymentMethod?: Maybe<CustomerPaymentMethod>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<CustomerPaymentMethodRemoteUserError>
}

/** Return type for `customerPaymentMethodRemoteCreditCardCreate` mutation. */
export type CustomerPaymentMethodRemoteCreditCardCreatePayload = {
  __typename?: 'CustomerPaymentMethodRemoteCreditCardCreatePayload'
  /** The customer payment method. */
  customerPaymentMethod?: Maybe<CustomerPaymentMethod>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<CustomerPaymentMethodUserError>
}

/**
 * Input for a remote gateway payment method, only one remote reference permitted.
 *
 */
export type CustomerPaymentMethodRemoteInput = {
  /**
   * Input containing the fields for a remote authorize net customer profile.
   *
   */
  authorizeNetCustomerPaymentProfile?: InputMaybe<RemoteAuthorizeNetCustomerPaymentProfileInput>
  /**
   * Input containing the fields for a remote stripe payment method.
   *
   */
  stripePaymentMethod?: InputMaybe<RemoteStripePaymentMethodInput>
}

/** Represents an error in the input of a mutation. */
export type CustomerPaymentMethodRemoteUserError = DisplayableError & {
  __typename?: 'CustomerPaymentMethodRemoteUserError'
  /** The error code. */
  code?: Maybe<CustomerPaymentMethodRemoteUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `CustomerPaymentMethodRemoteUserError`. */
export enum CustomerPaymentMethodRemoteUserErrorCode {
  /** Authorize.net is not enabled for subscriptions. */
  AuthorizeNetNotEnabledForSubscriptions = 'AUTHORIZE_NET_NOT_ENABLED_FOR_SUBSCRIPTIONS',
  /** Exactly one remote reference is required. */
  ExactlyOneRemoteReferenceRequired = 'EXACTLY_ONE_REMOTE_REFERENCE_REQUIRED',
  /** The input value is invalid. */
  Invalid = 'INVALID',
  /** The input value needs to be blank. */
  Present = 'PRESENT',
  /** The input value is already taken. */
  Taken = 'TAKEN',
}

/** The revocation reason types for a customer payment method. */
export enum CustomerPaymentMethodRevocationReason {
  /** The Authorize.net payment gateway is not enabled. */
  AuthorizeNetGatewayNotEnabled = 'AUTHORIZE_NET_GATEWAY_NOT_ENABLED',
  /** Authorize.net did not return any payment methods. Make sure that the correct Authorize.net account is linked. */
  AuthorizeNetReturnedNoPaymentMethod = 'AUTHORIZE_NET_RETURNED_NO_PAYMENT_METHOD',
  /** The credit card failed to update. */
  FailedToUpdateCreditCard = 'FAILED_TO_UPDATE_CREDIT_CARD',
  /** The payment method was manually revoked. */
  ManuallyRevoked = 'MANUALLY_REVOKED',
  /** Failed to contact the Stripe API. */
  StripeApiAuthenticationError = 'STRIPE_API_AUTHENTICATION_ERROR',
  /** Invalid request. Failed to retrieve payment method from Stripe. */
  StripeApiInvalidRequestError = 'STRIPE_API_INVALID_REQUEST_ERROR',
  /** The Stripe payment gateway is not enabled. */
  StripeGatewayNotEnabled = 'STRIPE_GATEWAY_NOT_ENABLED',
  /** The Stripe payment method type should be card. */
  StripePaymentMethodNotCard = 'STRIPE_PAYMENT_METHOD_NOT_CARD',
  /** Stripe did not return any payment methods. Make sure that the correct Stripe account is linked. */
  StripeReturnedNoPaymentMethod = 'STRIPE_RETURNED_NO_PAYMENT_METHOD',
}

/** Return type for `customerPaymentMethodRevoke` mutation. */
export type CustomerPaymentMethodRevokePayload = {
  __typename?: 'CustomerPaymentMethodRevokePayload'
  /** The ID of the revoked customer payment method. */
  revokedCustomerPaymentMethodId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `customerPaymentMethodSendUpdateEmail` mutation. */
export type CustomerPaymentMethodSendUpdateEmailPayload = {
  __typename?: 'CustomerPaymentMethodSendUpdateEmailPayload'
  /** The customer to whom an update payment method email was sent. */
  customer?: Maybe<Customer>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Represents an error in the input of a mutation. */
export type CustomerPaymentMethodUserError = DisplayableError & {
  __typename?: 'CustomerPaymentMethodUserError'
  /** The error code. */
  code?: Maybe<CustomerPaymentMethodUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `CustomerPaymentMethodUserError`. */
export enum CustomerPaymentMethodUserErrorCode {
  /** The input value is invalid. */
  Invalid = 'INVALID',
  /** The input value needs to be blank. */
  Present = 'PRESENT',
  /** The input value is already taken. */
  Taken = 'TAKEN',
}

/** Represents a PayPal instrument for customer payment method. */
export type CustomerPaypalBillingAgreement = {
  __typename?: 'CustomerPaypalBillingAgreement'
  /** The billing address of this payment method. */
  billingAddress?: Maybe<CustomerPaymentInstrumentBillingAddress>
  /** Whether the PayPal billing agreement is inactive. */
  inactive: Scalars['Boolean']
  /** Whether the payment method can be revoked.The payment method can be revoked if there are no active subscription contracts. */
  isRevocable: Scalars['Boolean']
  /** The customers's PayPal account email address. */
  paypalAccountEmail?: Maybe<Scalars['String']>
}

/**
 * The possible product subscription states for a customer, as defined by the customer's subscription contracts.
 *
 */
export enum CustomerProductSubscriberStatus {
  /**
   * The customer has at least one active subscription contract.
   *
   */
  Active = 'ACTIVE',
  /**
   * The customer's last subscription contract was cancelled and there are no other active or paused
   * subscription contracts.
   *
   */
  Cancelled = 'CANCELLED',
  /**
   * The customer's last subscription contract expired and there are no other active or paused
   * subscription contracts.
   *
   */
  Expired = 'EXPIRED',
  /**
   * The customer's last subscription contract failed and there are no other active or paused
   * subscription contracts.
   *
   */
  Failed = 'FAILED',
  /**
   * The customer has never had a subscription contract.
   *
   */
  NeverSubscribed = 'NEVER_SUBSCRIBED',
  /**
   * The customer has at least one paused subscription contract and there are no other active
   * subscription contracts.
   *
   */
  Paused = 'PAUSED',
}

/** Return type for `customerRemoveTaxExemptions` mutation. */
export type CustomerRemoveTaxExemptionsPayload = {
  __typename?: 'CustomerRemoveTaxExemptionsPayload'
  /** The updated customer. */
  customer?: Maybe<Customer>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `customerReplaceTaxExemptions` mutation. */
export type CustomerReplaceTaxExemptionsPayload = {
  __typename?: 'CustomerReplaceTaxExemptionsPayload'
  /** The updated customer. */
  customer?: Maybe<Customer>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** The set of valid sort keys for the CustomerSavedSearch query. */
export enum CustomerSavedSearchSortKeys {
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `name` value. */
  Name = 'NAME',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/** Represents a Shop Pay card instrument for customer payment method. */
export type CustomerShopPayAgreement = {
  __typename?: 'CustomerShopPayAgreement'
  /** Whether the card is about to expire. */
  expiresSoon: Scalars['Boolean']
  /** The expiry month of the card. */
  expiryMonth: Scalars['Int']
  /** The expiry year of the card. */
  expiryYear: Scalars['Int']
  /** Whether the Shop Pay billing agreement is inactive. */
  inactive: Scalars['Boolean']
  /** The payment method can be revoked if there are no active subscription contracts. */
  isRevocable: Scalars['Boolean']
  /** The last 4 digits of the card. */
  lastDigits: Scalars['String']
  /** The masked card number with only the last 4 digits displayed. */
  maskedNumber: Scalars['String']
  /** The name of the card holder. */
  name: Scalars['String']
}

/** An error that occurs during execution of an SMS marketing consent mutation. */
export type CustomerSmsMarketingConsentError = DisplayableError & {
  __typename?: 'CustomerSmsMarketingConsentError'
  /** The error code. */
  code?: Maybe<CustomerSmsMarketingConsentErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `CustomerSmsMarketingConsentError`. */
export enum CustomerSmsMarketingConsentErrorCode {
  /** The input value isn't included in the list. */
  Inclusion = 'INCLUSION',
  /** Unexpected internal error happened. */
  InternalError = 'INTERNAL_ERROR',
  /** The input value is invalid. */
  Invalid = 'INVALID',
  /** Missing a required argument. */
  MissingArgument = 'MISSING_ARGUMENT',
}

/**
 * The marketing consent information when the customer consented to
 *         receiving marketing material by SMS.
 */
export type CustomerSmsMarketingConsentInput = {
  /**
   * The date and time when the customer consented to receive marketing material by SMS.
   * If no date is provided, then the date and time when the consent information was sent is used.
   *
   */
  consentUpdatedAt?: InputMaybe<Scalars['DateTime']>
  /**
   * The marketing subscription opt in level set when the customer consented to receive marketing information.
   *
   */
  marketingOptInLevel?: InputMaybe<CustomerMarketingOptInLevel>
  /** The current SMS marketing state for the customer. */
  marketingState: CustomerSmsMarketingState
}

/**
 * The record of when a customer consented to receive marketing material by SMS.
 *
 * The customer's consent state reflects the record with the most recent date when consent was updated.
 *
 */
export type CustomerSmsMarketingConsentState = {
  __typename?: 'CustomerSmsMarketingConsentState'
  /** The source from which the SMS marketing information for the customer was collected. */
  consentCollectedFrom?: Maybe<CustomerConsentCollectedFrom>
  /**
   * The date and time when the customer consented to receive marketing material by SMS.
   * If no date is provided, then the date and time when the consent information was sent is used.
   *
   */
  consentUpdatedAt?: Maybe<Scalars['DateTime']>
  /**
   * The marketing subscription opt in level set when the customer consented to receive marketing information.
   *
   */
  marketingOptInLevel: CustomerMarketingOptInLevel
  /** The current SMS marketing state for the customer. */
  marketingState: CustomerSmsMarketingState
}

/**
 * The SMS marketing consent information to update for a given customer ID.
 *
 */
export type CustomerSmsMarketingConsentUpdateInput = {
  /** The ID of the customer to update the SMS marketing consent information for. The customer must have a unique phone number associated to the record. If not, add the phone number using the `customerUpdate` mutation first. */
  customerId: Scalars['ID']
  /** The marketing consent information when the customer consented to receiving marketing material by SMS. */
  smsMarketingConsent: CustomerSmsMarketingConsentInput
}

/** Return type for `customerSmsMarketingConsentUpdate` mutation. */
export type CustomerSmsMarketingConsentUpdatePayload = {
  __typename?: 'CustomerSmsMarketingConsentUpdatePayload'
  /**
   * The updated customer.
   *
   */
  customer?: Maybe<Customer>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<CustomerSmsMarketingConsentError>
}

/**
 * The valid SMS marketing states for a customer’s phone number.
 *
 */
export enum CustomerSmsMarketingState {
  /**
   * The customer hasn't subscribed to SMS marketing.
   *
   */
  NotSubscribed = 'NOT_SUBSCRIBED',
  /**
   * The customer is in the process of subscribing to SMS marketing.
   *
   */
  Pending = 'PENDING',
  /**
   * The customer's personal data is erased. This value is internally-set and read-only.
   *
   */
  Redacted = 'REDACTED',
  /**
   * The customer is subscribed to SMS marketing.
   *
   */
  Subscribed = 'SUBSCRIBED',
  /**
   * The customer isn't currently subscribed to SMS marketing but was previously subscribed.
   *
   */
  Unsubscribed = 'UNSUBSCRIBED',
}

/** The set of valid sort keys for the Customer query. */
export enum CustomerSortKeys {
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `last_order_date` value. */
  LastOrderDate = 'LAST_ORDER_DATE',
  /** Sort by the `location` value. */
  Location = 'LOCATION',
  /** Sort by the `name` value. */
  Name = 'NAME',
  /** Sort by the `orders_count` value. */
  OrdersCount = 'ORDERS_COUNT',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
  /** Sort by the `total_spent` value. */
  TotalSpent = 'TOTAL_SPENT',
  /** Sort by the `updated_at` value. */
  UpdatedAt = 'UPDATED_AT',
}

/** The valid values for the state of a customer's account with a shop. */
export enum CustomerState {
  /** The customer declined the email invite to create an account. */
  Declined = 'DECLINED',
  /** The customer doesn't have an active account. Customer accounts can be disabled from the Shopify admin at any time. */
  Disabled = 'DISABLED',
  /** The customer has created an account. */
  Enabled = 'ENABLED',
  /** The customer has received an email invite to create an account. */
  Invited = 'INVITED',
}

/** Return type for `customerUpdateDefaultAddress` mutation. */
export type CustomerUpdateDefaultAddressPayload = {
  __typename?: 'CustomerUpdateDefaultAddressPayload'
  /** The customer whose address was updated. */
  customer?: Maybe<Customer>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `customerUpdate` mutation. */
export type CustomerUpdatePayload = {
  __typename?: 'CustomerUpdatePayload'
  /** The updated customer. */
  customer?: Maybe<Customer>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Represents a customer's session visiting a shop's online store, including information about the marketing activity attributed to starting the session. */
export type CustomerVisit = CustomerMoment &
  Node & {
    __typename?: 'CustomerVisit'
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** URL of the first page the customer landed on for the session. */
    landingPage?: Maybe<Scalars['URL']>
    /** Landing page information with URL linked in HTML. For example, the first page the customer visited was store.myshopify.com/products/1. */
    landingPageHtml?: Maybe<Scalars['HTML']>
    /**
     * Represent actions taken by an app, on behalf of a merchant,
     * to market Shopify resources such as products, collections, and discounts.
     *
     */
    marketingEvent?: Maybe<MarketingEvent>
    /** The date and time when the customer's session occurred. */
    occurredAt: Scalars['DateTime']
    /**
     * Marketing referral code from the link that the customer clicked to visit the store.
     * Supports the following URL attributes: _ref_, _source_, or _r_.
     * For example, if the URL is myshopifystore.com/products/slide?ref=j2tj1tn2, then this value is j2tj1tn2.
     *
     */
    referralCode?: Maybe<Scalars['String']>
    /** Referral information with URLs linked in HTML. */
    referralInfoHtml: Scalars['FormattedString']
    /**
     * Webpage where the customer clicked a link that sent them to the online store.
     * For example, _https://randomblog.com/page1_ or _android-app://com.google.android.gm_.
     *
     */
    referrerUrl?: Maybe<Scalars['URL']>
    /**
     * Source from which the customer visited the store, such as a platform (Facebook, Google), email, direct,
     * a website domain, QR code, or unknown.
     *
     */
    source: Scalars['String']
    /** Describes the source explicitly for first or last session. */
    sourceDescription?: Maybe<Scalars['String']>
    /** Type of marketing tactic. */
    sourceType?: Maybe<MarketingTactic>
    /** A set of UTM parameters gathered from the URL parameters of the referrer. */
    utmParameters?: Maybe<UtmParameters>
  }

/** Days of the week from Monday to Sunday. */
export enum DayOfTheWeek {
  /** Friday. */
  Friday = 'FRIDAY',
  /** Monday. */
  Monday = 'MONDAY',
  /** Saturday. */
  Saturday = 'SATURDAY',
  /** Sunday. */
  Sunday = 'SUNDAY',
  /** Thursday. */
  Thursday = 'THURSDAY',
  /** Tuesday. */
  Tuesday = 'TUESDAY',
  /** Wednesday. */
  Wednesday = 'WEDNESDAY',
}

/**
 * Deletion events chronicle the destruction of resources (e.g. products and collections).
 * Once deleted, the deletion event is the only trace of the original's existence,
 * as the resource itself has been removed and can no longer be accessed.
 *
 */
export type DeletionEvent = {
  __typename?: 'DeletionEvent'
  /** The date and time when the deletion event for the related resource was generated. */
  occurredAt: Scalars['DateTime']
  /** The id of the resource that was deleted. */
  subjectId: Scalars['ID']
  /** The type of resource that was deleted. */
  subjectType: DeletionEventSubjectType
}

/**
 * An auto-generated type for paginating through multiple DeletionEvents.
 *
 */
export type DeletionEventConnection = {
  __typename?: 'DeletionEventConnection'
  /** A list of edges. */
  edges: Array<DeletionEventEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one DeletionEvent and a cursor during pagination.
 *
 */
export type DeletionEventEdge = {
  __typename?: 'DeletionEventEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of DeletionEventEdge. */
  node: DeletionEvent
}

/** The set of valid sort keys for the DeletionEvent query. */
export enum DeletionEventSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/** The supported subject types of deletion events. */
export enum DeletionEventSubjectType {
  Collection = 'COLLECTION',
  Product = 'PRODUCT',
}

/** A shipping service and a list of countries that the service is available for. */
export type DeliveryAvailableService = {
  __typename?: 'DeliveryAvailableService'
  /** The countries the service provider ships to. */
  countries: DeliveryCountryCodesOrRestOfWorld
  /** The name of the service. */
  name: Scalars['String']
}

/** A shipping service provider or a carrier account. */
export type DeliveryCarrierService = Node & {
  __typename?: 'DeliveryCarrierService'
  /** The list of services offered for given destinations. */
  availableServicesForCountries: Array<DeliveryAvailableService>
  /** The properly formatted name of the shipping service provider, ready to display. */
  formattedName?: Maybe<Scalars['String']>
  /** The logo of the service provider. */
  icon: Image
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The name of the shipping service provider. */
  name?: Maybe<Scalars['String']>
}

/** A shipping service provider or a carrier account. */
export type DeliveryCarrierServiceAvailableServicesForCountriesArgs = {
  countryCodes?: InputMaybe<Array<CountryCode>>
  origins?: InputMaybe<Array<Scalars['ID']>>
  restOfWorld: Scalars['Boolean']
}

/** A carrier service and the associated list of shop locations. */
export type DeliveryCarrierServiceAndLocations = {
  __typename?: 'DeliveryCarrierServiceAndLocations'
  /** The carrier service. */
  carrierService: DeliveryCarrierService
  /** The list of locations that support this carrier service. */
  locations: Array<Location>
}

/** A condition that must pass for a delivery method definition to be applied to an order. */
export type DeliveryCondition = Node & {
  __typename?: 'DeliveryCondition'
  /** The value (weight or price) that the condition field is compared to. */
  conditionCriteria: DeliveryConditionCriteria
  /** The field to compare the criterion value against, using the operator. */
  field: DeliveryConditionField
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The operator to compare the field and criterion value. */
  operator: DeliveryConditionOperator
}

/** The value (weight or price) that the condition field is compared to. */
export type DeliveryConditionCriteria = MoneyV2 | Weight

/** The field type that the condition will be applied to. */
export enum DeliveryConditionField {
  /** The condition will check against the total price of the order. */
  TotalPrice = 'TOTAL_PRICE',
  /** The condition will check against the total weight of the order. */
  TotalWeight = 'TOTAL_WEIGHT',
}

/** The operator to use to determine if the condition passes. */
export enum DeliveryConditionOperator {
  /** The condition will check whether the field is greater than or equal to the criterion. */
  GreaterThanOrEqualTo = 'GREATER_THAN_OR_EQUAL_TO',
  /** The condition will check if the field is less than or equal to the criterion. */
  LessThanOrEqualTo = 'LESS_THAN_OR_EQUAL_TO',
}

/** A country that is used to define a shipping zone. */
export type DeliveryCountry = Node & {
  __typename?: 'DeliveryCountry'
  /**
   * A two-letter country code in ISO 3166-1 alpha-2 standard.
   * It also includes a flag indicating whether the country should be
   * a part of the 'Rest Of World' shipping zone.
   *
   */
  code: DeliveryCountryCodeOrRestOfWorld
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The full name of the country. */
  name: Scalars['String']
  /** The list of regions associated with this country. */
  provinces: Array<DeliveryProvince>
  /** The translated name of the country. The translation returned is based on the system's locale. */
  translatedName: Scalars['String']
}

/** The country details and the associated shipping zone. */
export type DeliveryCountryAndZone = {
  __typename?: 'DeliveryCountryAndZone'
  /** The country details. */
  country: DeliveryCountry
  /** The name of the shipping zone. */
  zone: Scalars['String']
}

/**
 * The country code and whether the country is a part of the 'Rest Of World' shipping zone.
 *
 */
export type DeliveryCountryCodeOrRestOfWorld = {
  __typename?: 'DeliveryCountryCodeOrRestOfWorld'
  /** The country code in the ISO 3166-1 alpha-2 format. */
  countryCode?: Maybe<CountryCode>
  /** Whether the country is a part of the 'Rest of World' shipping zone. */
  restOfWorld: Scalars['Boolean']
}

/**
 * The list of country codes and information whether the countries
 * are a part of the 'Rest Of World' shipping zone.
 *
 */
export type DeliveryCountryCodesOrRestOfWorld = {
  __typename?: 'DeliveryCountryCodesOrRestOfWorld'
  /** List of applicable country codes in the ISO 3166-1 alpha-2 format. */
  countryCodes: Array<CountryCode>
  /** Whether the countries are a part of the 'Rest of World' shipping zone. */
  restOfWorld: Scalars['Boolean']
}

/** Input fields to specify a country. */
export type DeliveryCountryInput = {
  /** The country code of the country in the ISO 3166-1 alpha-2 format. */
  code?: InputMaybe<CountryCode>
  /** Associate all available provinces with this country. */
  includeAllProvinces?: InputMaybe<Scalars['Boolean']>
  /** The regions associated with this country. */
  provinces?: InputMaybe<Array<DeliveryProvinceInput>>
  /** Whether the country is a part of the 'Rest of World' shipping zone. */
  restOfWorld?: InputMaybe<Scalars['Boolean']>
}

/** Whether the shop is blocked from converting to full multi-location delivery profiles mode. If the shop is blocked, then the blocking reasons are also returned. */
export type DeliveryLegacyModeBlocked = {
  __typename?: 'DeliveryLegacyModeBlocked'
  /** Whether the shop can convert to full multi-location delivery profiles mode. */
  blocked: Scalars['Boolean']
  /** The reasons why the shop is blocked from converting to full multi-location delivery profiles mode. */
  reasons?: Maybe<Array<DeliveryLegacyModeBlockedReason>>
}

/** Reasons the shop is blocked from converting to full multi-location delivery profiles mode. */
export enum DeliveryLegacyModeBlockedReason {
  /** Multi-Location mode is disabled. The shop can't convert to full multi-location delivery profiles mode. */
  MultiLocationDisabled = 'MULTI_LOCATION_DISABLED',
  /** There are no locations for this store that can fulfill online orders. */
  NoLocationsFulfillingOnlineOrders = 'NO_LOCATIONS_FULFILLING_ONLINE_ORDERS',
}

/**
 * A location group is a collection of active locations. They share zones and delivery methods across delivery
 * profiles.
 *
 */
export type DeliveryLocationGroup = Node & {
  __typename?: 'DeliveryLocationGroup'
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** A list of active locations that are part of this location group. */
  locations: LocationConnection
}

/**
 * A location group is a collection of active locations. They share zones and delivery methods across delivery
 * profiles.
 *
 */
export type DeliveryLocationGroupLocationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  includeInactive?: InputMaybe<Scalars['Boolean']>
  includeLegacy?: InputMaybe<Scalars['Boolean']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<LocationSortKeys>
}

/** Links a location group with a zone and the associated method definitions. */
export type DeliveryLocationGroupZone = {
  __typename?: 'DeliveryLocationGroupZone'
  /** The number of method definitions for the zone. */
  methodDefinitionCounts: DeliveryMethodDefinitionCounts
  /** The method definitions associated to a zone and location group. */
  methodDefinitions: DeliveryMethodDefinitionConnection
  /** The zone associated to a location group. */
  zone: DeliveryZone
}

/** Links a location group with a zone and the associated method definitions. */
export type DeliveryLocationGroupZoneMethodDefinitionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  eligible?: InputMaybe<Scalars['Boolean']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<MethodDefinitionSortKeys>
  type?: InputMaybe<DeliveryMethodDefinitionType>
}

/**
 * An auto-generated type for paginating through multiple DeliveryLocationGroupZones.
 *
 */
export type DeliveryLocationGroupZoneConnection = {
  __typename?: 'DeliveryLocationGroupZoneConnection'
  /** A list of edges. */
  edges: Array<DeliveryLocationGroupZoneEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one DeliveryLocationGroupZone and a cursor during pagination.
 *
 */
export type DeliveryLocationGroupZoneEdge = {
  __typename?: 'DeliveryLocationGroupZoneEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of DeliveryLocationGroupZoneEdge. */
  node: DeliveryLocationGroupZone
}

/** The input fields for a delivery zone associated to a location group and profile. */
export type DeliveryLocationGroupZoneInput = {
  /** A list of countries to associate with the zone. */
  countries?: InputMaybe<Array<DeliveryCountryInput>>
  /** A globally-unique identifier of the zone. */
  id?: InputMaybe<Scalars['ID']>
  /** A list of method definitions to create. */
  methodDefinitionsToCreate?: InputMaybe<Array<DeliveryMethodDefinitionInput>>
  /** A list of method definitions to update. */
  methodDefinitionsToUpdate?: InputMaybe<Array<DeliveryMethodDefinitionInput>>
  /** The name of the zone. */
  name?: InputMaybe<Scalars['String']>
}

/** The delivery method used by a fulfillment order. */
export type DeliveryMethod = Node & {
  __typename?: 'DeliveryMethod'
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The type of the delivery method. */
  methodType: DeliveryMethodType
}

/**
 * A method definition contains the delivery rate and the conditions that must be met for the method to be
 * applied.
 *
 */
export type DeliveryMethodDefinition = Node & {
  __typename?: 'DeliveryMethodDefinition'
  /** Whether this method definition is active. */
  active: Scalars['Boolean']
  /** The description of the method definition. */
  description?: Maybe<Scalars['String']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The method conditions that must pass for this method definition to be applied to an order. */
  methodConditions: Array<DeliveryCondition>
  /** The name of the method definition. */
  name: Scalars['String']
  /** The provided rate for this method definition, from a rate definition or participant. */
  rateProvider: DeliveryRateProvider
}

/**
 * An auto-generated type for paginating through multiple DeliveryMethodDefinitions.
 *
 */
export type DeliveryMethodDefinitionConnection = {
  __typename?: 'DeliveryMethodDefinitionConnection'
  /** A list of edges. */
  edges: Array<DeliveryMethodDefinitionEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * The number of method definitions for a zone, separated into merchant-owned and participant definitions.
 *
 */
export type DeliveryMethodDefinitionCounts = {
  __typename?: 'DeliveryMethodDefinitionCounts'
  /** The number of participant method definitions for the specified zone. */
  participantDefinitionsCount: Scalars['Int']
  /** The number of merchant-defined method definitions for the specified zone. */
  rateDefinitionsCount: Scalars['Int']
}

/**
 * An auto-generated type which holds one DeliveryMethodDefinition and a cursor during pagination.
 *
 */
export type DeliveryMethodDefinitionEdge = {
  __typename?: 'DeliveryMethodDefinitionEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of DeliveryMethodDefinitionEdge. */
  node: DeliveryMethodDefinition
}

/** The input fields for a method definition. */
export type DeliveryMethodDefinitionInput = {
  /** Whether to use this method definition during rate calculation. */
  active?: InputMaybe<Scalars['Boolean']>
  /** A list of conditions to update on the method definition. */
  conditionsToUpdate?: InputMaybe<Array<DeliveryUpdateConditionInput>>
  /** The description of the method definition. */
  description?: InputMaybe<Scalars['String']>
  /** A globally-unique identifier of the method definition. Use only when updating a method definiton. */
  id?: InputMaybe<Scalars['ID']>
  /** The name of the method definition. */
  name?: InputMaybe<Scalars['String']>
  /** A participant to apply to the method definition. */
  participant?: InputMaybe<DeliveryParticipantInput>
  /** A list of price conditions on the method definition. */
  priceConditionsToCreate?: InputMaybe<Array<DeliveryPriceConditionInput>>
  /** A rate definition to apply to the method definition. */
  rateDefinition?: InputMaybe<DeliveryRateDefinitionInput>
  /** A list of weight conditions on the method definition. */
  weightConditionsToCreate?: InputMaybe<Array<DeliveryWeightConditionInput>>
}

/** The different types of method definitions to filter by. */
export enum DeliveryMethodDefinitionType {
  /** A static merchant-defined rate. */
  Merchant = 'MERCHANT',
  /** A dynamic participant rate. */
  Participant = 'PARTICIPANT',
}

/** Possible method types that a delivery method can have. */
export enum DeliveryMethodType {
  /** The order is delivered using a local delivery service. */
  Local = 'LOCAL',
  /** No delivery is needed. */
  None = 'NONE',
  /** The order is picked up by the customer. */
  PickUp = 'PICK_UP',
  /** The order is delivered to a retail store. */
  Retail = 'RETAIL',
  /** The order is shipped. */
  Shipping = 'SHIPPING',
}

/**
 * A participant defines carrier-calculated rates for shipping services
 * with a possible merchant-defined fixed fee or a percentage-of-rate fee.
 *
 */
export type DeliveryParticipant = Node & {
  __typename?: 'DeliveryParticipant'
  /**
   * Whether to display new shipping services automatically to the customer when the service becomes available.
   *
   */
  adaptToNewServicesFlag: Scalars['Boolean']
  /** The carrier used for this participant. */
  carrierService: DeliveryCarrierService
  /** The merchant-defined fixed fee for this participant. */
  fixedFee?: Maybe<MoneyV2>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The carrier-specific services offered by the participant, and whether each service is active. */
  participantServices: Array<DeliveryParticipantService>
  /** The merchant-defined percentage-of-rate fee for this participant. */
  percentageOfRateFee: Scalars['Float']
}

/** The input fields for a participant. */
export type DeliveryParticipantInput = {
  /**
   * Whether to automatically display new shipping services to the customer when a service becomes available.
   *
   */
  adaptToNewServices?: InputMaybe<Scalars['Boolean']>
  /** The ID of the carrier service for this participant. */
  carrierServiceId?: InputMaybe<Scalars['ID']>
  /** The fixed feed that is defined by the merchant for this participant. */
  fixedFee?: InputMaybe<MoneyInput>
  /** The ID of the participant. */
  id?: InputMaybe<Scalars['ID']>
  /** The list of shipping services offered by the participant. */
  participantServices?: InputMaybe<Array<DeliveryParticipantServiceInput>>
  /** The merchant-defined percentage-of-rate fee for this participant. */
  percentageOfRateFee?: InputMaybe<Scalars['Float']>
}

/** A mail service provided by the participant. */
export type DeliveryParticipantService = {
  __typename?: 'DeliveryParticipantService'
  /** Whether the service is active. */
  active: Scalars['Boolean']
  /** The name of the service. */
  name: Scalars['String']
}

/** The input fields for a shipping service provided by a participant. */
export type DeliveryParticipantServiceInput = {
  /** Whether the service is active. */
  active: Scalars['Boolean']
  /** The name of the service. */
  name: Scalars['String']
}

/** The input fields for a price-based condition of a delivery method definition. */
export type DeliveryPriceConditionInput = {
  /** The monetary value to compare the price of an order to. */
  criteria?: InputMaybe<MoneyInput>
  /** The operator to use for comparison. */
  operator?: InputMaybe<DeliveryConditionOperator>
}

/** How many product variants are in a profile. This count is capped at 500. */
export type DeliveryProductVariantsCount = {
  __typename?: 'DeliveryProductVariantsCount'
  /** Whether the count has reached the cap of 500. */
  capped: Scalars['Boolean']
  /** The product variant count. */
  count: Scalars['Int']
}

/**
 * A shipping profile. In Shopify, a shipping profile is a set of shipping rates scoped to a set of products or variants that can be shipped from selected locations to zones.
 *
 */
export type DeliveryProfile = Node & {
  __typename?: 'DeliveryProfile'
  /** The number of active shipping rates for the profile. */
  activeMethodDefinitionsCount: Scalars['Int']
  /** Whether this is the default profile. */
  default: Scalars['Boolean']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** Whether this shop has enabled legacy compatibility mode for delivery profiles. */
  legacyMode: Scalars['Boolean']
  /** The number of locations without rates defined. */
  locationsWithoutRatesCount: Scalars['Int']
  /** The name of the delivery profile. */
  name: Scalars['String']
  /** The number of active origin locations for the profile. */
  originLocationCount: Scalars['Int']
  /**
   * The number of product variants for this profile. The count for the default profile is not supported and will return -1.
   * @deprecated Use `productVariantsCountV2` instead
   */
  productVariantsCount: Scalars['Int']
  /** How many product variants are in this profile. */
  productVariantsCountV2: DeliveryProductVariantsCount
  /** The products and variants associated with this profile. */
  profileItems: DeliveryProfileItemConnection
  /** The location groups and associated zones using this profile. */
  profileLocationGroups: Array<DeliveryProfileLocationGroup>
  /** Selling plan groups associated with the specified delivery profile. */
  sellingPlanGroups: SellingPlanGroupConnection
  /** List of locations that have not been assigned to a location group for this profile. */
  unassignedLocations: Array<Location>
  /** The number of countries with active rates to deliver to. */
  zoneCountryCount: Scalars['Int']
}

/**
 * A shipping profile. In Shopify, a shipping profile is a set of shipping rates scoped to a set of products or variants that can be shipped from selected locations to zones.
 *
 */
export type DeliveryProfileProfileItemsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<ProfileItemSortKeys>
}

/**
 * A shipping profile. In Shopify, a shipping profile is a set of shipping rates scoped to a set of products or variants that can be shipped from selected locations to zones.
 *
 */
export type DeliveryProfileSellingPlanGroupsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An auto-generated type for paginating through multiple DeliveryProfiles.
 *
 */
export type DeliveryProfileConnection = {
  __typename?: 'DeliveryProfileConnection'
  /** A list of edges. */
  edges: Array<DeliveryProfileEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one DeliveryProfile and a cursor during pagination.
 *
 */
export type DeliveryProfileEdge = {
  __typename?: 'DeliveryProfileEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of DeliveryProfileEdge. */
  node: DeliveryProfile
}

/** The input fields for a delivery profile. */
export type DeliveryProfileInput = {
  /** The list of condition IDs to delete. */
  conditionsToDelete?: InputMaybe<Array<Scalars['ID']>>
  /** The list of location groups to be created in the delivery profile. */
  locationGroupsToCreate?: InputMaybe<Array<DeliveryProfileLocationGroupInput>>
  /** The list of location groups to be deleted from the delivery profile. */
  locationGroupsToDelete?: InputMaybe<Array<Scalars['ID']>>
  /** The list of location groups to be updated in the delivery profile. */
  locationGroupsToUpdate?: InputMaybe<Array<DeliveryProfileLocationGroupInput>>
  /** The list of method definition IDs to delete. */
  methodDefinitionsToDelete?: InputMaybe<Array<Scalars['ID']>>
  /** The name of the delivery profile. */
  name?: InputMaybe<Scalars['String']>
  /** The list of location groups associated with the delivery profile. */
  profileLocationGroups?: InputMaybe<Array<DeliveryProfileLocationGroupInput>>
  /** The list of selling plan groups to be associated with the delivery profile. */
  sellingPlanGroupsToAssociate?: InputMaybe<Array<Scalars['ID']>>
  /** The list of selling plan groups to be dissociated with the delivery profile. */
  sellingPlanGroupsToDissociate?: InputMaybe<Array<Scalars['ID']>>
  /** The list of product variant IDs to be associated with the delivery profile. */
  variantsToAssociate?: InputMaybe<Array<Scalars['ID']>>
  /**
   * The list of product variant IDs to be dissociated from the delivery profile.
   * The dissociated product variants are moved back to the default delivery profile.
   *
   */
  variantsToDissociate?: InputMaybe<Array<Scalars['ID']>>
  /** The list of zone IDs to delete. */
  zonesToDelete?: InputMaybe<Array<Scalars['ID']>>
}

/** A product and the subset of associated variants that are part of this delivery profile. */
export type DeliveryProfileItem = Node & {
  __typename?: 'DeliveryProfileItem'
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** A product associated with this profile. */
  product: Product
  /** The product variants associated with this delivery profile. */
  variants: ProductVariantConnection
}

/** A product and the subset of associated variants that are part of this delivery profile. */
export type DeliveryProfileItemVariantsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<ProductVariantSortKeys>
}

/**
 * An auto-generated type for paginating through multiple DeliveryProfileItems.
 *
 */
export type DeliveryProfileItemConnection = {
  __typename?: 'DeliveryProfileItemConnection'
  /** A list of edges. */
  edges: Array<DeliveryProfileItemEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one DeliveryProfileItem and a cursor during pagination.
 *
 */
export type DeliveryProfileItemEdge = {
  __typename?: 'DeliveryProfileItemEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of DeliveryProfileItemEdge. */
  node: DeliveryProfileItem
}

/** Links a location group with zones. Both are associated to a delivery profile. */
export type DeliveryProfileLocationGroup = {
  __typename?: 'DeliveryProfileLocationGroup'
  /** The countries already selected in any zone for the specified location group. */
  countriesInAnyZone: Array<DeliveryCountryAndZone>
  /** The collection of locations that make up the specified location group. */
  locationGroup: DeliveryLocationGroup
  /** The applicable zones associated to the specified location group. */
  locationGroupZones: DeliveryLocationGroupZoneConnection
}

/** Links a location group with zones. Both are associated to a delivery profile. */
export type DeliveryProfileLocationGroupLocationGroupZonesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The input fields for a location group associated to a delivery profile. */
export type DeliveryProfileLocationGroupInput = {
  /** The globally-unique identifier of the delivery profile location group. */
  id?: InputMaybe<Scalars['ID']>
  /** The list of location IDs to be moved to this location group. */
  locations?: InputMaybe<Array<Scalars['ID']>>
  /** The list of location group zones to create. */
  zonesToCreate?: InputMaybe<Array<DeliveryLocationGroupZoneInput>>
  /** The list of location group zones to update. */
  zonesToUpdate?: InputMaybe<Array<DeliveryLocationGroupZoneInput>>
}

/** A region that is used to define a shipping zone. */
export type DeliveryProvince = Node & {
  __typename?: 'DeliveryProvince'
  /** The code of the region. */
  code: Scalars['String']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The full name of the region. */
  name: Scalars['String']
  /** The translated name of the region. The translation returned is based on the system's locale. */
  translatedName: Scalars['String']
}

/** The input fields to specify a region. */
export type DeliveryProvinceInput = {
  /** The code of the region. */
  code: Scalars['String']
}

/** The merchant-defined rate of the [DeliveryMethodDefinition](https://shopify.dev/api/admin-graphql/latest/objects/DeliveryMethodDefinition). */
export type DeliveryRateDefinition = Node & {
  __typename?: 'DeliveryRateDefinition'
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The price of this rate. */
  price: MoneyV2
}

/** The input fields for a rate definition. */
export type DeliveryRateDefinitionInput = {
  /** A globally-unique identifier of the rate definition. */
  id?: InputMaybe<Scalars['ID']>
  /** The price of the rate definition. */
  price: MoneyInput
}

/** A rate provided by a merchant-defined rate or a participant. */
export type DeliveryRateProvider = DeliveryParticipant | DeliveryRateDefinition

/**
 * The `DeliverySetting` object enables you to manage shop-wide shipping settings.
 * You can enable legacy compatibility mode for the multi-location delivery profiles feature
 * if the legacy mode isn't blocked.
 *
 */
export type DeliverySetting = {
  __typename?: 'DeliverySetting'
  /** Whether the shop is blocked from converting to full multi-location delivery profiles mode. If the shop is blocked, then the blocking reasons are also returned. */
  legacyModeBlocked: DeliveryLegacyModeBlocked
  /** Enables legacy compatability mode for the multi-location delivery profiles feature. */
  legacyModeProfiles: Scalars['Boolean']
}

/** The input fields for shop-level delivery settings. */
export type DeliverySettingInput = {
  /** Whether legacy compatability mode is enabled for the multi-location delivery profiles feature. */
  legacyModeProfiles?: InputMaybe<Scalars['Boolean']>
}

/** Return type for `deliverySettingUpdate` mutation. */
export type DeliverySettingUpdatePayload = {
  __typename?: 'DeliverySettingUpdatePayload'
  /** The updated delivery shop level settings. */
  setting?: Maybe<DeliverySetting>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `deliveryShippingOriginAssign` mutation. */
export type DeliveryShippingOriginAssignPayload = {
  __typename?: 'DeliveryShippingOriginAssignPayload'
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** The input fields for updating the condition of a delivery method definition. */
export type DeliveryUpdateConditionInput = {
  /** The value that will be used in comparison. */
  criteria?: InputMaybe<Scalars['Float']>
  /** The unit associated with the value that will be used in comparison. */
  criteriaUnit?: InputMaybe<Scalars['String']>
  /** The property of an order that will be used in comparison. */
  field?: InputMaybe<DeliveryConditionField>
  /** A globally-unique identifier of the condition. */
  id: Scalars['ID']
  /** The operator to use for comparison. */
  operator?: InputMaybe<DeliveryConditionOperator>
}

/** The input fields for a weight-based condition of a delivery method definition. */
export type DeliveryWeightConditionInput = {
  /** The weight value to compare the weight of an order to. */
  criteria?: InputMaybe<WeightInput>
  /** The operator to use for comparison. */
  operator?: InputMaybe<DeliveryConditionOperator>
}

/**
 * A zone is a group of countries that have the same shipping rates. Customers can order products from a store only if they choose a shipping destination that's included in one of the store's zones.
 *
 */
export type DeliveryZone = Node & {
  __typename?: 'DeliveryZone'
  /** The list of countries within the zone. */
  countries: Array<DeliveryCountry>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The name of the zone. */
  name: Scalars['String']
}

/** Digital wallet, such as Apple Pay, which can be used for accelerated checkouts. */
export enum DigitalWallet {
  /** Android Pay. */
  AndroidPay = 'ANDROID_PAY',
  /** Apple Pay. */
  ApplePay = 'APPLE_PAY',
  /** Google Pay. */
  GooglePay = 'GOOGLE_PAY',
  /** Shopify Pay. */
  ShopifyPay = 'SHOPIFY_PAY',
}

/**
 * An amount discounting the line that has been allocated by an associated discount application.
 *
 */
export type DiscountAllocation = {
  __typename?: 'DiscountAllocation'
  /**
   * Money amount allocated by the discount application.
   * @deprecated Use `allocatedAmountSet` instead
   */
  allocatedAmount: MoneyV2
  /** Money amount allocated by the discount application in shop and presentment currencies. */
  allocatedAmountSet: MoneyBag
  /** The discount of which this allocated amount originated from. */
  discountApplication: DiscountApplication
}

/** The fixed amount value of a discount. */
export type DiscountAmount = {
  __typename?: 'DiscountAmount'
  /** The value of the discount. */
  amount: MoneyV2
  /** If true, then the discount is applied to each of the entitled items. If false, then the amount is split across all of the entitled items. */
  appliesOnEachItem: Scalars['Boolean']
}

/** Specifies the value of the discount and how it is applied. */
export type DiscountAmountInput = {
  /** The value of the discount. */
  amount?: InputMaybe<Scalars['Decimal']>
  /** If true, then the discount is applied to each of the entitled items. If false, then the amount is split across all of the entitled items. */
  appliesOnEachItem?: InputMaybe<Scalars['Boolean']>
}

/**
 * Discount applications capture the intentions of a discount source at
 * the time of application on an order's line items or shipping lines.
 *
 */
export type DiscountApplication = {
  /** The method by which the discount's value is allocated to its entitled items. */
  allocationMethod: DiscountApplicationAllocationMethod
  /**
   * An ordered index that can be used to identify the discount application and indicate the precedence
   * of the discount application for calculations.
   *
   */
  index: Scalars['Int']
  /** How the discount amount is distributed on the discounted lines. */
  targetSelection: DiscountApplicationTargetSelection
  /** Whether the discount is applied on line items or shipping lines. */
  targetType: DiscountApplicationTargetType
  /** The value of the discount application. */
  value: PricingValue
}

/** The method by which the discount's value is allocated onto its entitled lines. */
export enum DiscountApplicationAllocationMethod {
  /** The value is spread across all entitled lines. */
  Across = 'ACROSS',
  /** The value is applied onto every entitled line. */
  Each = 'EACH',
  /** The value is specifically applied onto a particular line. */
  One = 'ONE',
}

/**
 * An auto-generated type for paginating through multiple DiscountApplications.
 *
 */
export type DiscountApplicationConnection = {
  __typename?: 'DiscountApplicationConnection'
  /** A list of edges. */
  edges: Array<DiscountApplicationEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one DiscountApplication and a cursor during pagination.
 *
 */
export type DiscountApplicationEdge = {
  __typename?: 'DiscountApplicationEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of DiscountApplicationEdge. */
  node: DiscountApplication
}

/** The method by which the discount's value is allocated onto its entitled lines. */
export enum DiscountApplicationLevel {
  /**
   * The discount was applied at the line level.
   * Line level discounts are factored into the discountedUnitPriceSet on line items.
   *
   */
  Line = 'LINE',
  /**
   * The discount was applied at the order level.
   * Order level discounts are not factored into the discountedUnitPriceSet on line items.
   *
   */
  Order = 'ORDER',
}

/**
 * Which lines on the order that the discount is allocated over, of the type
 * defined by the Discount Application's target_type.
 *
 */
export enum DiscountApplicationTargetSelection {
  /** The discount is allocated onto all the lines. */
  All = 'ALL',
  /** The discount is allocated onto only the lines it is entitled for. */
  Entitled = 'ENTITLED',
  /** The discount is allocated onto explicitly chosen lines. */
  Explicit = 'EXPLICIT',
}

/**
 * The type of line (i.e. line item or shipping line) on an order that the discount is applicable towards.
 *
 */
export enum DiscountApplicationTargetType {
  /** The discount applies onto line items. */
  LineItem = 'LINE_ITEM',
  /** The discount applies onto shipping lines. */
  ShippingLine = 'SHIPPING_LINE',
}

/** An automatic discount. */
export type DiscountAutomatic = DiscountAutomaticBasic | DiscountAutomaticBxgy

/** Return type for `discountAutomaticActivate` mutation. */
export type DiscountAutomaticActivatePayload = {
  __typename?: 'DiscountAutomaticActivatePayload'
  /** The activated automatic discount. */
  automaticDiscountNode?: Maybe<DiscountAutomaticNode>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** An automatic basic discount. */
export type DiscountAutomaticBasic = {
  __typename?: 'DiscountAutomaticBasic'
  /** The number of times the discount has been used. This value is updated asynchronously and can be different than the actual usage count. */
  asyncUsageCount: Scalars['Int']
  /** The date and time when the discount was created. */
  createdAt: Scalars['DateTime']
  /** The qualifying items in an order, the quantity of each one, and the total value of the discount. */
  customerGets: DiscountCustomerGets
  /** The date and time when the discount ends. For open-ended discounts, use `null`. */
  endsAt?: Maybe<Scalars['DateTime']>
  /** The minimum subtotal or quantity that's required for the discount to be applied. */
  minimumRequirement: DiscountMinimumRequirement
  /** A short summary of the discount. */
  shortSummary: Scalars['String']
  /** The date and time when the discount starts. */
  startsAt: Scalars['DateTime']
  /** The status of the discount. */
  status: DiscountStatus
  /** A detailed summary of the discount. */
  summary: Scalars['String']
  /** The title of the discount. */
  title: Scalars['String']
  /**
   * The number of times that the discount has been used.
   * @deprecated Use `asyncUsageCount` instead
   */
  usageCount: Scalars['Int']
}

/** Return type for `discountAutomaticBasicCreate` mutation. */
export type DiscountAutomaticBasicCreatePayload = {
  __typename?: 'DiscountAutomaticBasicCreatePayload'
  /** The created automatic discount. */
  automaticDiscountNode?: Maybe<DiscountAutomaticNode>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** Specifies input field to create or update automatic basic discount. */
export type DiscountAutomaticBasicInput = {
  /** The qualifying items in an order, the quantity of each one, and the total value of the discount. */
  customerGets?: InputMaybe<DiscountCustomerGetsInput>
  /** The date and time when the discount ends. For open-ended discounts, use `null`. */
  endsAt?: InputMaybe<Scalars['DateTime']>
  /** The minimum subtotal or quantity that's required for the discount to be applied. */
  minimumRequirement?: InputMaybe<DiscountMinimumRequirementInput>
  /** The date and time when the discount starts. */
  startsAt?: InputMaybe<Scalars['DateTime']>
  /** The title of the discount. */
  title?: InputMaybe<Scalars['String']>
}

/** Return type for `discountAutomaticBasicUpdate` mutation. */
export type DiscountAutomaticBasicUpdatePayload = {
  __typename?: 'DiscountAutomaticBasicUpdatePayload'
  /** The updated automatic discount. */
  automaticDiscountNode?: Maybe<DiscountAutomaticNode>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** Return type for `discountAutomaticBulkDelete` mutation. */
export type DiscountAutomaticBulkDeletePayload = {
  __typename?: 'DiscountAutomaticBulkDeletePayload'
  /** The asynchronous job removing the automatic discounts. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** An automatic BXGY discount. */
export type DiscountAutomaticBxgy = HasEvents &
  Node & {
    __typename?: 'DiscountAutomaticBxgy'
    /** The number of times the discount has been used. This value is updated asynchronously and can be different than the actual usage count. */
    asyncUsageCount: Scalars['Int']
    /** The date and time when the discount was created. */
    createdAt: Scalars['DateTime']
    /** The qualifying items and the quantity of each one that the customer has to buy to be eligible for the discount. */
    customerBuys: DiscountCustomerBuys
    /** The qualifying items in an order, the quantity of each one, and the total value of the discount. */
    customerGets: DiscountCustomerGets
    /** The date and time when the discount ends. For open-ended discounts, use `null`. */
    endsAt?: Maybe<Scalars['DateTime']>
    /** The paginated list of events associated with the host subject. */
    events: EventConnection
    /**
     * A legacy unique identifier for the discount.
     * @deprecated Use DiscountAutomaticNode.id instead.
     */
    id: Scalars['ID']
    /** The date and time when the discount starts. */
    startsAt: Scalars['DateTime']
    /** The status of the discount. */
    status: DiscountStatus
    /** A detailed summary of the discount. */
    summary: Scalars['String']
    /** The title of the discount. */
    title: Scalars['String']
    /**
     * The number of times that the discount has been used.
     * @deprecated Use `asyncUsageCount` instead
     */
    usageCount: Scalars['Int']
    /** The maximum number of times that the discount can be applied to an order. */
    usesPerOrderLimit?: Maybe<Scalars['Int']>
  }

/** An automatic BXGY discount. */
export type DiscountAutomaticBxgyEventsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<EventSortKeys>
}

/** Return type for `discountAutomaticBxgyCreate` mutation. */
export type DiscountAutomaticBxgyCreatePayload = {
  __typename?: 'DiscountAutomaticBxgyCreatePayload'
  /** The created automatic discount. */
  automaticDiscountNode?: Maybe<DiscountAutomaticNode>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** Specifies input field to create or update automatic bogo discount. */
export type DiscountAutomaticBxgyInput = {
  /** The qualifying items and the quantity of each one that the customer has to buy to be eligible for the discount. */
  customerBuys?: InputMaybe<DiscountCustomerBuysInput>
  /** The qualifying items in an order, the quantity of each one, and the total value of the discount. */
  customerGets?: InputMaybe<DiscountCustomerGetsInput>
  /** The date and time when the discount ends. For open-ended discounts, use `null`. */
  endsAt?: InputMaybe<Scalars['DateTime']>
  /** The date and time when the discount starts. */
  startsAt?: InputMaybe<Scalars['DateTime']>
  /** The title of the discount. */
  title?: InputMaybe<Scalars['String']>
  /** The maximum number of times that the discount can be applied to an order. */
  usesPerOrderLimit?: InputMaybe<Scalars['UnsignedInt64']>
}

/** Return type for `discountAutomaticBxgyUpdate` mutation. */
export type DiscountAutomaticBxgyUpdatePayload = {
  __typename?: 'DiscountAutomaticBxgyUpdatePayload'
  /** The updated automatic discount. */
  automaticDiscountNode?: Maybe<DiscountAutomaticNode>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/**
 * An auto-generated type for paginating through multiple DiscountAutomatics.
 *
 */
export type DiscountAutomaticConnection = {
  __typename?: 'DiscountAutomaticConnection'
  /** A list of edges. */
  edges: Array<DiscountAutomaticEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `discountAutomaticDeactivate` mutation. */
export type DiscountAutomaticDeactivatePayload = {
  __typename?: 'DiscountAutomaticDeactivatePayload'
  /** The deactivated automatic discount. */
  automaticDiscountNode?: Maybe<DiscountAutomaticNode>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** Return type for `discountAutomaticDelete` mutation. */
export type DiscountAutomaticDeletePayload = {
  __typename?: 'DiscountAutomaticDeletePayload'
  /** The deleted automatic discount ID. */
  deletedAutomaticDiscountId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/**
 * An auto-generated type which holds one DiscountAutomatic and a cursor during pagination.
 *
 */
export type DiscountAutomaticEdge = {
  __typename?: 'DiscountAutomaticEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of DiscountAutomaticEdge. */
  node: DiscountAutomatic
}

/** An automatic discount wrapper node. */
export type DiscountAutomaticNode = HasEvents &
  Node & {
    __typename?: 'DiscountAutomaticNode'
    /** An automatic discount. */
    automaticDiscount: DiscountAutomatic
    /** The paginated list of events associated with the host subject. */
    events: EventConnection
    /** A globally-unique identifier. */
    id: Scalars['ID']
  }

/** An automatic discount wrapper node. */
export type DiscountAutomaticNodeEventsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<EventSortKeys>
}

/**
 * An auto-generated type for paginating through multiple DiscountAutomaticNodes.
 *
 */
export type DiscountAutomaticNodeConnection = {
  __typename?: 'DiscountAutomaticNodeConnection'
  /** A list of edges. */
  edges: Array<DiscountAutomaticNodeEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one DiscountAutomaticNode and a cursor during pagination.
 *
 */
export type DiscountAutomaticNodeEdge = {
  __typename?: 'DiscountAutomaticNodeEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of DiscountAutomaticNodeEdge. */
  node: DiscountAutomaticNode
}

/** A code discount. */
export type DiscountCode =
  | DiscountCodeBasic
  | DiscountCodeBxgy
  | DiscountCodeFreeShipping

/** Return type for `discountCodeActivate` mutation. */
export type DiscountCodeActivatePayload = {
  __typename?: 'DiscountCodeActivatePayload'
  /** The activated code discount. */
  codeDiscountNode?: Maybe<DiscountCodeNode>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/**
 * Discount code applications capture the intentions of a discount code at
 * the time that it is applied onto an order.
 *
 */
export type DiscountCodeApplication = DiscountApplication & {
  __typename?: 'DiscountCodeApplication'
  /** The method by which the discount's value is allocated to its entitled items. */
  allocationMethod: DiscountApplicationAllocationMethod
  /** The string identifying the discount code that was used at the time of application. */
  code: Scalars['String']
  /**
   * An ordered index that can be used to identify the discount application and indicate the precedence
   * of the discount application for calculations.
   *
   */
  index: Scalars['Int']
  /** How the discount amount is distributed on the discounted lines. */
  targetSelection: DiscountApplicationTargetSelection
  /** Whether the discount is applied on line items or shipping lines. */
  targetType: DiscountApplicationTargetType
  /** The value of the discount application. */
  value: PricingValue
}

/** A basic code discount. */
export type DiscountCodeBasic = {
  __typename?: 'DiscountCodeBasic'
  /** Whether the discount can be applied only once per customer. */
  appliesOncePerCustomer: Scalars['Boolean']
  /** The number of times that the discount has been used. */
  asyncUsageCount: Scalars['Int']
  /** The number of redeem codes for the discount. */
  codeCount: Scalars['Int']
  /** A list of redeem codes for the discount. */
  codes: DiscountRedeemCodeConnection
  /** The date and time when the discount was created. */
  createdAt: Scalars['DateTime']
  /** The qualifying items in an order, the quantity of each one, and the total value of the discount. */
  customerGets: DiscountCustomerGets
  /** The customers that can use the discount. */
  customerSelection: DiscountCustomerSelection
  /** The date and time when the discount ends. For open-ended discounts, use `null`. */
  endsAt?: Maybe<Scalars['DateTime']>
  /** Indicates whether there are any timeline comments on the discount. */
  hasTimelineComment: Scalars['Boolean']
  /** The minimum subtotal or quantity that's required for the discount to be applied. */
  minimumRequirement?: Maybe<DiscountMinimumRequirement>
  /** The number of times a discount applies on recurring purchases (subscriptions). */
  recurringCycleLimit?: Maybe<Scalars['Int']>
  /** URLs that can be used to share the discount. */
  shareableUrls: Array<DiscountShareableUrl>
  /** A short summary of the discount. */
  shortSummary: Scalars['String']
  /** The date and time when the discount starts. */
  startsAt: Scalars['DateTime']
  /** The status of the discount. */
  status: DiscountStatus
  /** A detailed summary of the discount. */
  summary: Scalars['String']
  /** The title of the discount. */
  title: Scalars['String']
  /** The total sales from orders where the discount was used. */
  totalSales?: Maybe<MoneyV2>
  /** The maximum number of times that the discount can be used. */
  usageLimit?: Maybe<Scalars['Int']>
}

/** A basic code discount. */
export type DiscountCodeBasicCodesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<DiscountCodeSortKeys>
}

/** Return type for `discountCodeBasicCreate` mutation. */
export type DiscountCodeBasicCreatePayload = {
  __typename?: 'DiscountCodeBasicCreatePayload'
  /** The created code discount. */
  codeDiscountNode?: Maybe<DiscountCodeNode>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** Specifies input field to create or update code basic discount. */
export type DiscountCodeBasicInput = {
  /** Whether the discount can be applied only once per customer. */
  appliesOncePerCustomer?: InputMaybe<Scalars['Boolean']>
  /** The code to use the discount. */
  code?: InputMaybe<Scalars['String']>
  /** The qualifying items in an order, the quantity of each one, and the total value of the discount. */
  customerGets?: InputMaybe<DiscountCustomerGetsInput>
  /** The customers that can use the discount. */
  customerSelection?: InputMaybe<DiscountCustomerSelectionInput>
  /** The date and time when the discount ends. For open-ended discounts, use `null`. */
  endsAt?: InputMaybe<Scalars['DateTime']>
  /** The minimum subtotal or quantity that's required for the discount to be applied. */
  minimumRequirement?: InputMaybe<DiscountMinimumRequirementInput>
  /** The number of times a discount applies on recurring purchases (subscriptions). */
  recurringCycleLimit?: InputMaybe<Scalars['Int']>
  /** The date and time when the discount starts. */
  startsAt?: InputMaybe<Scalars['DateTime']>
  /** The title of the discount. */
  title?: InputMaybe<Scalars['String']>
  /** The maximum number of times that the discount can be used. For open-ended discounts, use `null`. */
  usageLimit?: InputMaybe<Scalars['Int']>
}

/** Return type for `discountCodeBasicUpdate` mutation. */
export type DiscountCodeBasicUpdatePayload = {
  __typename?: 'DiscountCodeBasicUpdatePayload'
  /** The updated code discount. */
  codeDiscountNode?: Maybe<DiscountCodeNode>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** Return type for `discountCodeBulkActivate` mutation. */
export type DiscountCodeBulkActivatePayload = {
  __typename?: 'DiscountCodeBulkActivatePayload'
  /** The asynchronous job that activates the code discounts. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** Return type for `discountCodeBulkDeactivate` mutation. */
export type DiscountCodeBulkDeactivatePayload = {
  __typename?: 'DiscountCodeBulkDeactivatePayload'
  /** The asynchronous job that deactivates the code discounts. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** Return type for `discountCodeBulkDelete` mutation. */
export type DiscountCodeBulkDeletePayload = {
  __typename?: 'DiscountCodeBulkDeletePayload'
  /** The asynchronous job that deletes the code discounts. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** A BXGY code discount. */
export type DiscountCodeBxgy = {
  __typename?: 'DiscountCodeBxgy'
  /** Whether the discount can be applied only once per customer. */
  appliesOncePerCustomer: Scalars['Boolean']
  /** The number of times that the discount has been used. */
  asyncUsageCount: Scalars['Int']
  /** The number of redeem codes for the discount. */
  codeCount: Scalars['Int']
  /** A list of redeem codes for the discount. */
  codes: DiscountRedeemCodeConnection
  /** The date and time when the discount was created. */
  createdAt: Scalars['DateTime']
  /** The qualifying items and the quantity of each one that the customer has to buy to be eligible for the discount. */
  customerBuys: DiscountCustomerBuys
  /** The qualifying items in an order, the quantity of each one, and the total value of the discount. */
  customerGets: DiscountCustomerGets
  /** The customers that can use the discount. */
  customerSelection: DiscountCustomerSelection
  /** The date and time when the discount ends. For open-ended discounts, use `null`. */
  endsAt?: Maybe<Scalars['DateTime']>
  /** Indicates whether there are any timeline comments on the discount. */
  hasTimelineComment: Scalars['Boolean']
  /** URLs that can be used to share the discount. */
  shareableUrls: Array<DiscountShareableUrl>
  /** The date and time when the discount starts. */
  startsAt: Scalars['DateTime']
  /** The status of the discount. */
  status: DiscountStatus
  /** A detailed summary of the discount. */
  summary: Scalars['String']
  /** The title of the discount. */
  title: Scalars['String']
  /** The total sales from orders where the discount was used. */
  totalSales?: Maybe<MoneyV2>
  /** The maximum number of times that the discount can be used. */
  usageLimit?: Maybe<Scalars['Int']>
  /** The maximum number of times that the discount can be applied to an order. */
  usesPerOrderLimit?: Maybe<Scalars['Int']>
}

/** A BXGY code discount. */
export type DiscountCodeBxgyCodesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<DiscountCodeSortKeys>
}

/** Return type for `discountCodeBxgyCreate` mutation. */
export type DiscountCodeBxgyCreatePayload = {
  __typename?: 'DiscountCodeBxgyCreatePayload'
  /** The created code discount. */
  codeDiscountNode?: Maybe<DiscountCodeNode>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** Specifies input field to create or update a BXGY code discount. */
export type DiscountCodeBxgyInput = {
  /** Whether the discount can be applied only once per customer. */
  appliesOncePerCustomer?: InputMaybe<Scalars['Boolean']>
  /** The code to use the discount. */
  code?: InputMaybe<Scalars['String']>
  /** The qualifying items and the quantity of each one that the customer has to buy to be eligible for the discount. */
  customerBuys?: InputMaybe<DiscountCustomerBuysInput>
  /** The qualifying items in an order, the quantity of each one, and the total value of the discount. */
  customerGets?: InputMaybe<DiscountCustomerGetsInput>
  /** The customers that can use the discount. */
  customerSelection?: InputMaybe<DiscountCustomerSelectionInput>
  /** The date and time when the discount ends. For open-ended discounts, use `null`. */
  endsAt?: InputMaybe<Scalars['DateTime']>
  /** The date and time when the discount starts. */
  startsAt?: InputMaybe<Scalars['DateTime']>
  /** The title of the discount. */
  title?: InputMaybe<Scalars['String']>
  /** The maximum number of times that the discount can be used. For open-ended discounts, use `null`. */
  usageLimit?: InputMaybe<Scalars['Int']>
  /** The maximum number of times that the discount can be applied to an order. */
  usesPerOrderLimit?: InputMaybe<Scalars['Int']>
}

/** Return type for `discountCodeBxgyUpdate` mutation. */
export type DiscountCodeBxgyUpdatePayload = {
  __typename?: 'DiscountCodeBxgyUpdatePayload'
  /** The updated code discount. */
  codeDiscountNode?: Maybe<DiscountCodeNode>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** Return type for `discountCodeDeactivate` mutation. */
export type DiscountCodeDeactivatePayload = {
  __typename?: 'DiscountCodeDeactivatePayload'
  /** The deactivated code discount. */
  codeDiscountNode?: Maybe<DiscountCodeNode>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** Return type for `discountCodeDelete` mutation. */
export type DiscountCodeDeletePayload = {
  __typename?: 'DiscountCodeDeletePayload'
  /** The deleted code discount ID. */
  deletedCodeDiscountId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** A free shipping code discount. */
export type DiscountCodeFreeShipping = {
  __typename?: 'DiscountCodeFreeShipping'
  /** Whether the discount applies on regular one-time-purchase shipping lines. */
  appliesOnOneTimePurchase: Scalars['Boolean']
  /** Whether the discount applies on subscription shipping lines. */
  appliesOnSubscription: Scalars['Boolean']
  /** Whether the discount can be applied only once per customer. */
  appliesOncePerCustomer: Scalars['Boolean']
  /** The number of times that the discount has been used. */
  asyncUsageCount: Scalars['Int']
  /** The number of redeem codes for the discount. */
  codeCount: Scalars['Int']
  /** A list of redeem codes for the discount. */
  codes: DiscountRedeemCodeConnection
  /** The date and time when the discount was created. */
  createdAt: Scalars['DateTime']
  /** The customers that can use the discount. */
  customerSelection: DiscountCustomerSelection
  /** A shipping destination that qualifies for the discount. */
  destinationSelection: DiscountShippingDestinationSelection
  /** The date and time when the discount ends. For open-ended discounts, use `null`. */
  endsAt?: Maybe<Scalars['DateTime']>
  /** Indicates whether there are any timeline comments on the discount. */
  hasTimelineComment: Scalars['Boolean']
  /** The maximum shipping price amount accepted to qualify for the discount. */
  maximumShippingPrice?: Maybe<MoneyV2>
  /** The minimum subtotal or quantity that's required for the discount to be applied. */
  minimumRequirement?: Maybe<DiscountMinimumRequirement>
  /** The number of times a discount applies on recurring purchases (subscriptions). */
  recurringCycleLimit?: Maybe<Scalars['Int']>
  /** URLs that can be used to share the discount. */
  shareableUrls: Array<DiscountShareableUrl>
  /** A short summary of the discount. */
  shortSummary: Scalars['String']
  /** The date and time when the discount starts. */
  startsAt: Scalars['DateTime']
  /** The status of the discount. */
  status: DiscountStatus
  /** A detailed summary of the discount. */
  summary: Scalars['String']
  /** The title of the discount. */
  title: Scalars['String']
  /** The total sales from orders where the discount was used. */
  totalSales?: Maybe<MoneyV2>
  /** The maximum number of times that the discount can be used. */
  usageLimit?: Maybe<Scalars['Int']>
}

/** A free shipping code discount. */
export type DiscountCodeFreeShippingCodesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<DiscountCodeSortKeys>
}

/** Return type for `discountCodeFreeShippingCreate` mutation. */
export type DiscountCodeFreeShippingCreatePayload = {
  __typename?: 'DiscountCodeFreeShippingCreatePayload'
  /** The created code discount. */
  codeDiscountNode?: Maybe<DiscountCodeNode>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** Specifies input field to create or update free shipping code discount. */
export type DiscountCodeFreeShippingInput = {
  /** Whether the discount applies on regular one-time-purchase items. */
  appliesOnOneTimePurchase?: InputMaybe<Scalars['Boolean']>
  /** Whether the discount applies on subscription items. */
  appliesOnSubscription?: InputMaybe<Scalars['Boolean']>
  /** Whether the discount can be applied only once per customer. */
  appliesOncePerCustomer?: InputMaybe<Scalars['Boolean']>
  /** The code to use the discount. */
  code?: InputMaybe<Scalars['String']>
  /** The customers that can use the discount. */
  customerSelection?: InputMaybe<DiscountCustomerSelectionInput>
  /** A list of destinations where the discount will apply. */
  destination?: InputMaybe<DiscountShippingDestinationSelectionInput>
  /** The date and time when the discount ends. For open-ended discounts, use `null`. */
  endsAt?: InputMaybe<Scalars['DateTime']>
  /** The maximum shipping price that qualifies for the discount. */
  maximumShippingPrice?: InputMaybe<Scalars['Decimal']>
  /** The minimum subtotal or quantity that's required for the discount to be applied. */
  minimumRequirement?: InputMaybe<DiscountMinimumRequirementInput>
  /** The number of times a discount applies on recurring purchases (subscriptions). */
  recurringCycleLimit?: InputMaybe<Scalars['Int']>
  /** The date and time when the discount starts. */
  startsAt?: InputMaybe<Scalars['DateTime']>
  /** The title of the discount. */
  title?: InputMaybe<Scalars['String']>
  /** The maximum number of times that the discount can be used. For open-ended discounts, use `null`. */
  usageLimit?: InputMaybe<Scalars['Int']>
}

/** Return type for `discountCodeFreeShippingUpdate` mutation. */
export type DiscountCodeFreeShippingUpdatePayload = {
  __typename?: 'DiscountCodeFreeShippingUpdatePayload'
  /** The updated code discount. */
  codeDiscountNode?: Maybe<DiscountCodeNode>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** A code discount wrapper node. */
export type DiscountCodeNode = HasEvents &
  Node & {
    __typename?: 'DiscountCodeNode'
    /** A code discount. */
    codeDiscount: DiscountCode
    /** The paginated list of events associated with the host subject. */
    events: EventConnection
    /** A globally-unique identifier. */
    id: Scalars['ID']
  }

/** A code discount wrapper node. */
export type DiscountCodeNodeEventsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<EventSortKeys>
}

/**
 * An auto-generated type for paginating through multiple DiscountCodeNodes.
 *
 */
export type DiscountCodeNodeConnection = {
  __typename?: 'DiscountCodeNodeConnection'
  /** A list of edges. */
  edges: Array<DiscountCodeNodeEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one DiscountCodeNode and a cursor during pagination.
 *
 */
export type DiscountCodeNodeEdge = {
  __typename?: 'DiscountCodeNodeEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of DiscountCodeNodeEdge. */
  node: DiscountCodeNode
}

/** Return type for `discountCodeRedeemCodeBulkDelete` mutation. */
export type DiscountCodeRedeemCodeBulkDeletePayload = {
  __typename?: 'DiscountCodeRedeemCodeBulkDeletePayload'
  /** The asynchronous job that deletes the discount redeem codes. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** The set of valid sort keys for the DiscountCode query. */
export enum DiscountCodeSortKeys {
  /** Sort by the `code` value. */
  Code = 'CODE',
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/** A list of collections that the discount can have as a prerequisite or entitlement. */
export type DiscountCollections = {
  __typename?: 'DiscountCollections'
  /** A list of collections that the discount can have as a prerequisite or entitlement. */
  collections: CollectionConnection
}

/** A list of collections that the discount can have as a prerequisite or entitlement. */
export type DiscountCollectionsCollectionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Specifies the collections attached to a discount. */
export type DiscountCollectionsInput = {
  /** Specifies list of collection ids to add. */
  add?: InputMaybe<Array<Scalars['ID']>>
  /** Specifies list of collection ids to remove. */
  remove?: InputMaybe<Array<Scalars['ID']>>
}

/** The shipping destination where the discount applies. */
export type DiscountCountries = {
  __typename?: 'DiscountCountries'
  /** The codes for the countries where the discount can be used. */
  countries: Array<CountryCode>
  /** Whether the discount is applicable to countries that have not been defined in the shop's shipping zones. */
  includeRestOfWorld: Scalars['Boolean']
}

/** Specifies a list of countries to add or remove from the free shipping discount. */
export type DiscountCountriesInput = {
  /** The country codes to add to the list of countries where the discount applies. */
  add?: InputMaybe<Array<CountryCode>>
  /** Whether the discount code is applicable to countries that have not been defined in the shop's shipping zones. */
  includeRestOfWorld?: InputMaybe<Scalars['Boolean']>
  /** The country codes to remove from the list of countries where the discount applies. */
  remove?: InputMaybe<Array<CountryCode>>
}

/** Whether the discount applies to all countries. */
export type DiscountCountryAll = {
  __typename?: 'DiscountCountryAll'
  /** Always true when resolved to this type. */
  allCountries: Scalars['Boolean']
}

/** Whether the discount applies to all customers. */
export type DiscountCustomerAll = {
  __typename?: 'DiscountCustomerAll'
  /** Always true when resolved to this type. */
  allCustomers: Scalars['Boolean']
}

/** The prerequisite items and prerequisite value. */
export type DiscountCustomerBuys = {
  __typename?: 'DiscountCustomerBuys'
  /** The items required for the discount to be applicable. */
  items: DiscountItems
  /** The prerequisite value. */
  value: DiscountCustomerBuysValue
}

/** Specifies the prerequisite items and prerequisite quantity. */
export type DiscountCustomerBuysInput = {
  /** The IDs of items that the customer buys. The items can be either collections or products. */
  items?: InputMaybe<DiscountItemsInput>
  /** The quantity of prerequisite items. */
  value?: InputMaybe<DiscountCustomerBuysValueInput>
}

/** The prerequisite quantity required for the discount to be applicable. */
export type DiscountCustomerBuysValue =
  | DiscountPurchaseAmount
  | DiscountQuantity

/** Specifies the prerequisite quantity for the discount. */
export type DiscountCustomerBuysValueInput = {
  /** The prerequisite purchase amount required for the discount to be applicable. */
  amount?: InputMaybe<Scalars['Decimal']>
  /** The quantity of prerequisite items. */
  quantity?: InputMaybe<Scalars['UnsignedInt64']>
}

/** The qualifying items in an order, the quantity of each one, and the total value of the discount. */
export type DiscountCustomerGets = {
  __typename?: 'DiscountCustomerGets'
  /** Whether the discount applies on regular one-time-purchase items. */
  appliesOnOneTimePurchase: Scalars['Boolean']
  /** Whether the discount applies on subscription items. */
  appliesOnSubscription: Scalars['Boolean']
  /** The items to which the discount applies. */
  items: DiscountItems
  /** Entitled quantity and the discount value. */
  value: DiscountCustomerGetsValue
}

/** Specifies the items that will be discounted, the quantity of items that will be discounted, and the value of discount. */
export type DiscountCustomerGetsInput = {
  /** Whether the discount applies on regular one-time-purchase items. */
  appliesOnOneTimePurchase?: InputMaybe<Scalars['Boolean']>
  /** Whether the discount applies on subscription items. */
  appliesOnSubscription?: InputMaybe<Scalars['Boolean']>
  /** The IDs of the items that the customer gets. The items can be either collections or products. */
  items?: InputMaybe<DiscountItemsInput>
  /** The quantity of items discounted and the discount value. */
  value?: InputMaybe<DiscountCustomerGetsValueInput>
}

/** The value of the discount and how it will be applied. */
export type DiscountCustomerGetsValue =
  | DiscountAmount
  | DiscountOnQuantity
  | DiscountPercentage

/** Specifies the quantity of items discounted and the discount value. */
export type DiscountCustomerGetsValueInput = {
  /** The value of the discount. */
  discountAmount?: InputMaybe<DiscountAmountInput>
  /** The quantity of the items that are discounted and the discount value. */
  discountOnQuantity?: InputMaybe<DiscountOnQuantityInput>
  /** The percentage value of the discount. Value must be between 0.00 - 1.00. */
  percentage?: InputMaybe<Scalars['Float']>
}

/** A list of customer saved searches that contain the customers to whom the discount applies. */
export type DiscountCustomerSavedSearches = {
  __typename?: 'DiscountCustomerSavedSearches'
  /**
   * A list of customer saved searches that contain the customers who can use the discount.
   * @deprecated Use `DiscountCustomerSegments.segments` instead.
   */
  savedSearches: Array<SavedSearch>
}

/** Specifies which customer saved searches to add to or remove from the discount. */
export type DiscountCustomerSavedSearchesInput = {
  /** A list of customer saved searches to add to the current list of customer saved searches. */
  add?: InputMaybe<Array<Scalars['ID']>>
  /** A list of customer saved searches to remove from the current list of customer saved searches. */
  remove?: InputMaybe<Array<Scalars['ID']>>
}

/** The type used for targeting a set of customers who are eligible for the discount. For example, the discount might be available to all customers or it might only be available to a specific set of customers. You can define the set of customers by targeting a list of customer segments, or by targeting a list of specific customers. */
export type DiscountCustomerSelection =
  | DiscountCustomerAll
  | DiscountCustomerSavedSearches
  | DiscountCustomers

/** Specifies the customers who can use this discount. */
export type DiscountCustomerSelectionInput = {
  /** Whether all customers can use this discount. */
  all?: InputMaybe<Scalars['Boolean']>
  /** The list of customer IDs to add or remove from the list of customers. */
  customers?: InputMaybe<DiscountCustomersInput>
}

/** A list of customers to whom the discount applies. */
export type DiscountCustomers = {
  __typename?: 'DiscountCustomers'
  /** A list of the customers that can use the discount. */
  customers: Array<Customer>
}

/** Specifies which customers to add to or remove from the discount. */
export type DiscountCustomersInput = {
  /** A list of customers to add to the current list of customers who can use the discount. */
  add?: InputMaybe<Array<Scalars['ID']>>
  /** A list of customers to remove from the current list of customers who can use the discount. */
  remove?: InputMaybe<Array<Scalars['ID']>>
}

/** The type of discount that will be applied. Currently, only percentage off is supported. */
export type DiscountEffect = DiscountPercentage

/** Specifies how the discount will be applied. Currently, only percentage off is supported. */
export type DiscountEffectInput = {
  /** The percentage value of the discount. Value must be between 0.00 - 1.00. */
  percentage?: InputMaybe<Scalars['Float']>
}

/** Possible error codes that can be returned by `DiscountUserError`. */
export enum DiscountErrorCode {
  /** The active period overlaps with other automatic discounts. At any given time, only one automatic discount can be active. */
  ActivePeriodOverlap = 'ACTIVE_PERIOD_OVERLAP',
  /** The input value is blank. */
  Blank = 'BLANK',
  /** The attribute selection contains conflicting settings. */
  Conflict = 'CONFLICT',
  /** The input value is already present. */
  Duplicate = 'DUPLICATE',
  /** The input value should be equal to the value allowed. */
  EqualTo = 'EQUAL_TO',
  /** The exceeded maximum allowed value. */
  ExceededMax = 'EXCEEDED_MAX',
  /** The input value should be greater than the minimum allowed value. */
  GreaterThan = 'GREATER_THAN',
  /** The input value should be greater than or equal to the minimum value allowed. */
  GreaterThanOrEqualTo = 'GREATER_THAN_OR_EQUAL_TO',
  /** The value is already present through another selection. */
  ImplicitDuplicate = 'IMPLICIT_DUPLICATE',
  /** The input value isn't included in the list. */
  Inclusion = 'INCLUSION',
  /** Unexpected internal error happened. */
  InternalError = 'INTERNAL_ERROR',
  /** The input value is invalid. */
  Invalid = 'INVALID',
  /** The input value should be less than the maximum value allowed. */
  LessThan = 'LESS_THAN',
  /** The input value should be less than or equal to the maximum value allowed. */
  LessThanOrEqualTo = 'LESS_THAN_OR_EQUAL_TO',
  /** Specify a minimum subtotal or a quantity, but not both. */
  MinimumSubtotalAndQuantityRangeBothPresent = 'MINIMUM_SUBTOTAL_AND_QUANTITY_RANGE_BOTH_PRESENT',
  /** Missing a required argument. */
  MissingArgument = 'MISSING_ARGUMENT',
  /** The input value needs to be blank. */
  Present = 'PRESENT',
  /** The input value is already taken. */
  Taken = 'TAKEN',
  /** The input value is too long. */
  TooLong = 'TOO_LONG',
  /** Too many arguments provided. */
  TooManyArguments = 'TOO_MANY_ARGUMENTS',
  /** The input value is too short. */
  TooShort = 'TOO_SHORT',
  /** The value is outside of the allowed range. */
  ValueOutsideRange = 'VALUE_OUTSIDE_RANGE',
}

/**
 * Entitled or prerequisite items on a discount. An item could be either collection or product or product_variant.
 *
 */
export type DiscountItems =
  | AllDiscountItems
  | DiscountCollections
  | DiscountProducts

/** Specifies the items attached to a discount. */
export type DiscountItemsInput = {
  /** Whether all items should be selected. */
  all?: InputMaybe<Scalars['Boolean']>
  /** The collections that are attached to a discount. */
  collections?: InputMaybe<DiscountCollectionsInput>
  /** The products and product variants that are attached to a discount. */
  products?: InputMaybe<DiscountProductsInput>
}

/** The minimum quantity of items required for the discount to apply. */
export type DiscountMinimumQuantity = {
  __typename?: 'DiscountMinimumQuantity'
  /** The minimum quantity of items that's required for the discount to be applied. */
  greaterThanOrEqualToQuantity: Scalars['UnsignedInt64']
}

/** Specifies the quantity minimum requirements for a discount. */
export type DiscountMinimumQuantityInput = {
  /** The minimum quantity of items that's required for the discount to be applied. */
  greaterThanOrEqualToQuantity?: InputMaybe<Scalars['UnsignedInt64']>
}

/** The minimum subtotal or quantity requirements for the discount. */
export type DiscountMinimumRequirement =
  | DiscountMinimumQuantity
  | DiscountMinimumSubtotal

/** Specifies the quantity or subtotal minimum requirements for a discount. */
export type DiscountMinimumRequirementInput = {
  /** The minimum required quantity. */
  quantity?: InputMaybe<DiscountMinimumQuantityInput>
  /** The minimum required subtotal. */
  subtotal?: InputMaybe<DiscountMinimumSubtotalInput>
}

/** The minimum subtotal required for the discount to apply. */
export type DiscountMinimumSubtotal = {
  __typename?: 'DiscountMinimumSubtotal'
  /** The minimum subtotal that's required for the discount to be applied. */
  greaterThanOrEqualToSubtotal: MoneyV2
}

/** Specifies the subtotal minimum requirements for a discount. */
export type DiscountMinimumSubtotalInput = {
  /** The minimum subtotal that's required for the discount to be applied. */
  greaterThanOrEqualToSubtotal?: InputMaybe<Scalars['Decimal']>
}

/** The quantity of items discounted, the discount value, and how the discount will be applied. */
export type DiscountOnQuantity = {
  __typename?: 'DiscountOnQuantity'
  /** The discount's effect on qualifying items. */
  effect: DiscountEffect
  /** The number of items being discounted. */
  quantity: DiscountQuantity
}

/** Specifies the quantity of items discounted and the discount value. */
export type DiscountOnQuantityInput = {
  /** The percentage value of the discount. */
  effect?: InputMaybe<DiscountEffectInput>
  /** The quantity of items that are discounted. */
  quantity?: InputMaybe<Scalars['UnsignedInt64']>
}

/** The percentage value of the discount. */
export type DiscountPercentage = {
  __typename?: 'DiscountPercentage'
  /** The percentage value of the discount. */
  percentage: Scalars['Float']
}

/** The entitled or prerequisite products and product variants for a discount. */
export type DiscountProducts = {
  __typename?: 'DiscountProducts'
  /** A list of product variants that the discount can have as a prerequisite or entitlement. */
  productVariants: ProductVariantConnection
  /** A list of products that the discount can have as a prerequisite or entitlement. */
  products: ProductConnection
}

/** The entitled or prerequisite products and product variants for a discount. */
export type DiscountProductsProductVariantsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The entitled or prerequisite products and product variants for a discount. */
export type DiscountProductsProductsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Specifies the products and product variants attached to a discount. */
export type DiscountProductsInput = {
  /** Specifies list of product variant ids to add. */
  productVariantsToAdd?: InputMaybe<Array<Scalars['ID']>>
  /** Specifies list of product variant ids to remove. */
  productVariantsToRemove?: InputMaybe<Array<Scalars['ID']>>
  /** Specifies list of product ids to add. */
  productsToAdd?: InputMaybe<Array<Scalars['ID']>>
  /** Specifies list of product ids to remove. */
  productsToRemove?: InputMaybe<Array<Scalars['ID']>>
}

/** The prerequisite purchase amount required for the discount to be applicable. */
export type DiscountPurchaseAmount = {
  __typename?: 'DiscountPurchaseAmount'
  /** Decimal money amount. */
  amount: Scalars['Decimal']
}

/** The quantity of items in discount. */
export type DiscountQuantity = {
  __typename?: 'DiscountQuantity'
  /** The quantity of items. */
  quantity: Scalars['UnsignedInt64']
}

/** A redeem code for a code discount. */
export type DiscountRedeemCode = {
  __typename?: 'DiscountRedeemCode'
  /** The number of times the discount has been used. This value is updated asynchronously and can be different than the actual usage count. */
  asyncUsageCount: Scalars['Int']
  /** The code of a discount. */
  code: Scalars['String']
  /** The application that created the discount code. */
  createdBy?: Maybe<App>
  /** A globally-unique identifier of the discount redeem code. */
  id: Scalars['ID']
}

/** Return type for `discountRedeemCodeBulkAdd` mutation. */
export type DiscountRedeemCodeBulkAddPayload = {
  __typename?: 'DiscountRedeemCodeBulkAddPayload'
  /** Tracks the progress of the bulk code creation. */
  bulkCreation?: Maybe<DiscountRedeemCodeBulkCreation>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<DiscountUserError>
}

/** Represents a bulk creation of discount redeem codes. */
export type DiscountRedeemCodeBulkCreation = Node & {
  __typename?: 'DiscountRedeemCodeBulkCreation'
  /** The codes associated with the bulk creation. */
  codes: DiscountRedeemCodeBulkCreationCodeConnection
  /** The number of codes to create. */
  codesCount: Scalars['Int']
  /** The date and time when the bulk creation was created. */
  createdAt: Scalars['DateTime']
  /** The code discount associated with the created codes. */
  discountCode?: Maybe<DiscountCodeNode>
  /** Whether the bulk creation is still queued (`false`) or has been run (`true`). */
  done: Scalars['Boolean']
  /** The number of codes that weren't created successfully. */
  failedCount: Scalars['Int']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The number of codes created successfully. */
  importedCount: Scalars['Int']
}

/** Represents a bulk creation of discount redeem codes. */
export type DiscountRedeemCodeBulkCreationCodesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a discount redeem code created by a bulk creation. */
export type DiscountRedeemCodeBulkCreationCode = {
  __typename?: 'DiscountRedeemCodeBulkCreationCode'
  /** The code of a discount that is sent for creation. */
  code: Scalars['String']
  /**
   * The discount redeem code of the successfully created code.
   *
   * If the code cannot be created, the field will be null.
   *
   */
  discountRedeemCode?: Maybe<DiscountRedeemCode>
  /** A list of errors during the creation process of the code. */
  errors: Array<DiscountUserError>
}

/**
 * An auto-generated type for paginating through multiple DiscountRedeemCodeBulkCreationCodes.
 *
 */
export type DiscountRedeemCodeBulkCreationCodeConnection = {
  __typename?: 'DiscountRedeemCodeBulkCreationCodeConnection'
  /** A list of edges. */
  edges: Array<DiscountRedeemCodeBulkCreationCodeEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one DiscountRedeemCodeBulkCreationCode and a cursor during pagination.
 *
 */
export type DiscountRedeemCodeBulkCreationCodeEdge = {
  __typename?: 'DiscountRedeemCodeBulkCreationCodeEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of DiscountRedeemCodeBulkCreationCodeEdge. */
  node: DiscountRedeemCodeBulkCreationCode
}

/**
 * An auto-generated type for paginating through multiple DiscountRedeemCodes.
 *
 */
export type DiscountRedeemCodeConnection = {
  __typename?: 'DiscountRedeemCodeConnection'
  /** A list of edges. */
  edges: Array<DiscountRedeemCodeEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one DiscountRedeemCode and a cursor during pagination.
 *
 */
export type DiscountRedeemCodeEdge = {
  __typename?: 'DiscountRedeemCodeEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of DiscountRedeemCodeEdge. */
  node: DiscountRedeemCode
}

/** Specifies the code attached to a discount. */
export type DiscountRedeemCodeInput = {
  /** The code of a discount. */
  code: Scalars['String']
}

/** The shareable URL for the discount code. */
export type DiscountShareableUrl = {
  __typename?: 'DiscountShareableUrl'
  /** The image URL of the item (product or collection) to which the discount applies. */
  targetItemImage?: Maybe<Image>
  /** The type of page that's associated with the URL. */
  targetType: DiscountShareableUrlTargetType
  /** The title of the page that's associated with the URL. */
  title: Scalars['String']
  /** The URL for the discount code. */
  url: Scalars['URL']
}

/** The page type where shareable URL lands. */
export enum DiscountShareableUrlTargetType {
  /** The collection page type. */
  Collection = 'COLLECTION',
  /** The home page type. */
  Home = 'HOME',
  /** The product page type. */
  Product = 'PRODUCT',
}

/** The selection of shipping countries to which this discount applies. */
export type DiscountShippingDestinationSelection =
  | DiscountCountries
  | DiscountCountryAll

/** Specifies the destinations where the free shipping discount will be applied. */
export type DiscountShippingDestinationSelectionInput = {
  /** Whether the discount code applies to all countries. */
  all?: InputMaybe<Scalars['Boolean']>
  /** A list of countries where the discount code will apply. */
  countries?: InputMaybe<DiscountCountriesInput>
}

/** The status of the discount. */
export enum DiscountStatus {
  /** The discount is active. */
  Active = 'ACTIVE',
  /** The discount is expired. */
  Expired = 'EXPIRED',
  /** The discount is scheduled. */
  Scheduled = 'SCHEDULED',
}

/** The type of line a subscription discount is applied on. */
export enum DiscountTargetType {
  /** Line item. */
  LineItem = 'LINE_ITEM',
  /** Shipping line. */
  ShippingLine = 'SHIPPING_LINE',
}

/** The original type of the discount. */
export enum DiscountType {
  /** Code discount type. */
  CodeDiscount = 'CODE_DISCOUNT',
  /** Manual discount type. */
  Manual = 'MANUAL',
}

/** An error that occurs during the execution of a discount mutation. */
export type DiscountUserError = DisplayableError & {
  __typename?: 'DiscountUserError'
  /** The error code. */
  code?: Maybe<DiscountErrorCode>
  /** Extra information about this error. */
  extraInfo?: Maybe<Scalars['String']>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Represents an error in the input of a mutation. */
export type DisplayableError = {
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** The possible statuses of a dispute. */
export enum DisputeStatus {
  Accepted = 'ACCEPTED',
  ChargeRefunded = 'CHARGE_REFUNDED',
  Lost = 'LOST',
  NeedsResponse = 'NEEDS_RESPONSE',
  UnderReview = 'UNDER_REVIEW',
  Won = 'WON',
}

/** The possible types for a dispute. */
export enum DisputeType {
  /** The dispute has turned into a chargeback. */
  Chargeback = 'CHARGEBACK',
  /** The dispute is in the inquiry phase. */
  Inquiry = 'INQUIRY',
}

/** A unique string that represents the address of a Shopify store on the Internet. */
export type Domain = Node & {
  __typename?: 'Domain'
  /** The host name of the domain (eg: `example.com`). */
  host: Scalars['String']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The localization of the domain, if it does not redirect. */
  localization?: Maybe<DomainLocalization>
  /** Whether SSL is enabled or not. */
  sslEnabled: Scalars['Boolean']
  /** The URL of the domain (eg: `https://example.com`). */
  url: Scalars['URL']
}

/** The country and language settings assigned to a domain. */
export type DomainLocalization = {
  __typename?: 'DomainLocalization'
  /** The ISO codes for the domain’s alternate locales. */
  alternateLocales: Array<Scalars['String']>
  /** The ISO code for the country assigned to the domain, or "*" for a domain set to "Rest of world". */
  country?: Maybe<Scalars['String']>
  /** The ISO code for the domain’s default locale. */
  defaultLocale: Scalars['String']
}

/**
 * Returns unfulfilled line items grouped by their fulfillment service. Each draft fulfillment contains additional information, such as whether the fulfillment requires shipping and whether a shipping label can be printed for it.
 *
 */
export type DraftFulfillment = {
  __typename?: 'DraftFulfillment'
  /** Whether a label can be purchased. */
  allowLabelPurchase: Scalars['Boolean']
  /** The line items (which might correspond to a variant) that are part of this draft fulfillment. */
  lineItems: Array<LineItem>
  /** Whether a fulfillment requires shipping. */
  requiresShipping: Scalars['Boolean']
  /** The service responsible for fulfilling the fulfillment. */
  service: FulfillmentService
}

/**
 * Represents a draft order. Merchants can use draft orders to create orders on behalf of their customers.
 *
 * ***Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type DraftOrder = CommentEventSubject &
  HasEvents &
  HasLocalizationExtensions &
  HasMetafields &
  LegacyInteroperability &
  Node & {
    __typename?: 'DraftOrder'
    /** Order-level discount applied to the draft order. */
    appliedDiscount?: Maybe<DraftOrderAppliedDiscount>
    /**
     * The billing address of the customer.
     *
     */
    billingAddress?: Maybe<MailingAddress>
    /**
     * Date and time when the draft order converted to a new order,
     * and the draft order's status changed to **Completed**.
     *
     */
    completedAt?: Maybe<Scalars['DateTime']>
    /** Date and time when the draft order was created in Shopify. */
    createdAt: Scalars['DateTime']
    /**
     * Three letter code for the currency of the store at the time that the invoice is sent.
     *
     */
    currencyCode: CurrencyCode
    /**
     * Custom information added to the draft order on behalf of your customer.
     *
     */
    customAttributes: Array<Attribute>
    /** Customer who will be sent an invoice for the draft order, if there is one. */
    customer?: Maybe<Customer>
    /** Email address of the customer, which is used to send notifications to. */
    email?: Maybe<Scalars['String']>
    /** List of events associated with the draft order. */
    events: EventConnection
    /** Whether the merchant has added timeline comments to the draft order. */
    hasTimelineComment: Scalars['Boolean']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** Date and time when the invoice was last emailed to the customer. */
    invoiceSentAt?: Maybe<Scalars['DateTime']>
    /** Link to the checkout, which is sent to your customer in the invoice email. */
    invoiceUrl?: Maybe<Scalars['URL']>
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** List of the line items in the draft order. */
    lineItems: DraftOrderLineItemConnection
    /** List of localization extensions for the resource. */
    localizationExtensions: LocalizationExtensionConnection
    /** Returns a metafield by namespace and key that belongs to the resource. */
    metafield?: Maybe<Metafield>
    /** List of metafields that belong to the resource. */
    metafields: MetafieldConnection
    /**
     * Unique identifier for the draft order, which is unique within the store. For example, _#D1223_.
     *
     */
    name: Scalars['String']
    /** Text from an optional note attached to the draft order. */
    note2?: Maybe<Scalars['String']>
    /** Order that was created from this draft order. */
    order?: Maybe<Order>
    /** The associated payment term for this draft order. */
    paymentTerms?: Maybe<PaymentTerms>
    /** Returns a private metafield by namespace and key that belongs to the resource. */
    privateMetafield?: Maybe<PrivateMetafield>
    /** List of private metafields that belong to the resource. */
    privateMetafields: PrivateMetafieldConnection
    /**
     * Whether or not the Draft Order is ready and can be completed. Draft Orders
     *         may have asynchronous operations that can take time to finish.
     */
    ready: Scalars['Boolean']
    /** The shipping address of the customer. */
    shippingAddress?: Maybe<MailingAddress>
    /** Line item that contains the shipping costs. */
    shippingLine?: Maybe<ShippingLine>
    /** Status of the draft order. */
    status: DraftOrderStatus
    /**
     * Subtotal of the line items and their discounts (does not contain shipping charges or shipping discounts, or taxes).
     *
     */
    subtotalPrice: Scalars['Money']
    /**
     * A comma separated list of tags associated with the draft order. Updating `tags` overwrites
     * any existing tags that were previously added to the draft order. To add new tags without overwriting
     * existing tags, use the [tagsAdd](https://shopify.dev/api/admin-graphql/latest/mutations/tagsadd)
     * mutation.
     *
     */
    tags: Array<Scalars['String']>
    /** Whether the draft order is tax exempt. */
    taxExempt: Scalars['Boolean']
    /** Total amount of taxes charged for each line item and shipping line. */
    taxLines: Array<TaxLine>
    /** Whether the line item prices include taxes. */
    taxesIncluded: Scalars['Boolean']
    /** Total amount of the draft order (includes taxes, shipping charges, and discounts). */
    totalPrice: Scalars['Money']
    /** Total shipping charge for the draft order. */
    totalShippingPrice: Scalars['Money']
    /** Total amount of taxes for the draft order. */
    totalTax: Scalars['Money']
    /** Total weight (grams) of the draft order. */
    totalWeight: Scalars['UnsignedInt64']
    /**
     * Date and time when the draft order was last changed.
     * The format is YYYY-MM-DD HH:mm:ss (for example, 2016-02-05 17:04:01).
     *
     */
    updatedAt: Scalars['DateTime']
  }

/**
 * Represents a draft order. Merchants can use draft orders to create orders on behalf of their customers.
 *
 * ***Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type DraftOrderEventsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<EventSortKeys>
}

/**
 * Represents a draft order. Merchants can use draft orders to create orders on behalf of their customers.
 *
 * ***Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type DraftOrderLineItemsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a draft order. Merchants can use draft orders to create orders on behalf of their customers.
 *
 * ***Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type DraftOrderLocalizationExtensionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  countryCodes?: InputMaybe<Array<CountryCode>>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  purposes?: InputMaybe<Array<LocalizationExtensionPurpose>>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a draft order. Merchants can use draft orders to create orders on behalf of their customers.
 *
 * ***Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type DraftOrderMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/**
 * Represents a draft order. Merchants can use draft orders to create orders on behalf of their customers.
 *
 * ***Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type DraftOrderMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a draft order. Merchants can use draft orders to create orders on behalf of their customers.
 *
 * ***Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type DraftOrderPrivateMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/**
 * Represents a draft order. Merchants can use draft orders to create orders on behalf of their customers.
 *
 * ***Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type DraftOrderPrivateMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The order-level discount applied to a draft order. */
export type DraftOrderAppliedDiscount = {
  __typename?: 'DraftOrderAppliedDiscount'
  /**
   * Amount of the order-level discount that is applied to the draft order.
   * @deprecated Use `amountV2` instead
   */
  amount: Scalars['Money']
  /** Amount of money discounted. */
  amountV2: MoneyV2
  /** Description of the order-level discount. */
  description: Scalars['String']
  /** Name of the order-level discount. */
  title?: Maybe<Scalars['String']>
  /**
   * Amount of the order level discount (when value_type is percentage,
   * the value in this field is the percentage discount).
   *
   */
  value: Scalars['Float']
  /** Type of the order-level discount. */
  valueType: DraftOrderAppliedDiscountType
}

/** The input fields for applying an order-level discount to a draft order. */
export type DraftOrderAppliedDiscountInput = {
  /**
   * The applied amount of the discount.
   *
   */
  amount?: InputMaybe<Scalars['Money']>
  /**
   * Reason for the discount.
   *
   */
  description?: InputMaybe<Scalars['String']>
  /**
   * Title of the discount.
   *
   */
  title?: InputMaybe<Scalars['String']>
  /**
   * The value of the discount.
   * If the type of the discount is fixed amount, then this is a fixed dollar amount.
   * If the type is percentage, then this is the percentage.
   *
   */
  value: Scalars['Float']
  /**
   * The type of discount.
   *
   */
  valueType: DraftOrderAppliedDiscountType
}

/** The valid discount types that can be applied to a draft order. */
export enum DraftOrderAppliedDiscountType {
  /** A fixed amount in the store's currency. */
  FixedAmount = 'FIXED_AMOUNT',
  /** A percentage of the order subtotal. */
  Percentage = 'PERCENTAGE',
}

/** Return type for `draftOrderCalculate` mutation. */
export type DraftOrderCalculatePayload = {
  __typename?: 'DraftOrderCalculatePayload'
  /** The calculated properties for a draft order. */
  calculatedDraftOrder?: Maybe<CalculatedDraftOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `draftOrderComplete` mutation. */
export type DraftOrderCompletePayload = {
  __typename?: 'DraftOrderCompletePayload'
  /** The completed draft order. */
  draftOrder?: Maybe<DraftOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type for paginating through multiple DraftOrders.
 *
 */
export type DraftOrderConnection = {
  __typename?: 'DraftOrderConnection'
  /** A list of edges. */
  edges: Array<DraftOrderEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `draftOrderCreate` mutation. */
export type DraftOrderCreatePayload = {
  __typename?: 'DraftOrderCreatePayload'
  /**
   * The created draft order.
   *
   */
  draftOrder?: Maybe<DraftOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Specifies the draft order to delete by its ID. */
export type DraftOrderDeleteInput = {
  /**
   * The ID of the draft order to delete.
   *
   */
  id: Scalars['ID']
}

/** Return type for `draftOrderDelete` mutation. */
export type DraftOrderDeletePayload = {
  __typename?: 'DraftOrderDeletePayload'
  /**
   * The ID of the deleted draft order.
   *
   */
  deletedId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one DraftOrder and a cursor during pagination.
 *
 */
export type DraftOrderEdge = {
  __typename?: 'DraftOrderEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of DraftOrderEdge. */
  node: DraftOrder
}

/** The input fields used to create or update a draft order. */
export type DraftOrderInput = {
  /**
   * The discount that will be applied to the draft order.
   * A draft order line item can have one discount. A draft order can also have one order-level discount.
   *
   */
  appliedDiscount?: InputMaybe<DraftOrderAppliedDiscountInput>
  /**
   * The mailing address associated with the payment method.
   *
   */
  billingAddress?: InputMaybe<MailingAddressInput>
  /**
   * Extra information added to the customer.
   *
   */
  customAttributes?: InputMaybe<Array<AttributeInput>>
  /**
   * Customer associated with the draft order.
   *
   */
  customerId?: InputMaybe<Scalars['ID']>
  /**
   * The customer's email address.
   *
   */
  email?: InputMaybe<Scalars['String']>
  /**
   * Product variant line item or custom line item associated to the draft order.
   * Each draft order must include at least one line item.
   *
   */
  lineItems?: InputMaybe<Array<DraftOrderLineItemInput>>
  /** The localization extensions attached to the draft order. For example, Tax IDs. */
  localizationExtensions?: InputMaybe<Array<LocalizationExtensionInput>>
  /**
   * Metafields attached to the draft order.
   *
   */
  metafields?: InputMaybe<Array<MetafieldInput>>
  /**
   * The text of an optional note that a shop owner can attach to the draft order.
   *
   */
  note?: InputMaybe<Scalars['String']>
  /** The fields used to create payment terms. */
  paymentTerms?: InputMaybe<PaymentTermsInput>
  /** The private metafields attached to the draft order. */
  privateMetafields?: InputMaybe<Array<PrivateMetafieldInput>>
  /**
   * The mailing address to where the order will be shipped.
   *
   */
  shippingAddress?: InputMaybe<MailingAddressInput>
  /**
   * A shipping line object, which details the shipping method used.
   *
   */
  shippingLine?: InputMaybe<ShippingLineInput>
  /**
   * A comma separated list of tags that have been added to the draft order.
   *
   */
  tags?: InputMaybe<Array<Scalars['String']>>
  /**
   * Whether or not taxes are exempt for the draft order.
   * If false, then Shopify will refer to the taxable field for each line item.
   * If a customer is applied to the draft order, then Shopify will use the customer's tax exempt field instead.
   *
   */
  taxExempt?: InputMaybe<Scalars['Boolean']>
  /**
   * Sent as part of a draft order object to load customer shipping information.
   *
   */
  useCustomerDefaultAddress?: InputMaybe<Scalars['Boolean']>
}

/** Return type for `draftOrderInvoicePreview` mutation. */
export type DraftOrderInvoicePreviewPayload = {
  __typename?: 'DraftOrderInvoicePreviewPayload'
  /** HTML to preview the draft order invoice email. */
  previewHtml?: Maybe<Scalars['HTML']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `draftOrderInvoiceSend` mutation. */
export type DraftOrderInvoiceSendPayload = {
  __typename?: 'DraftOrderInvoiceSendPayload'
  /** The draft order an invoice email is sent for. */
  draftOrder?: Maybe<DraftOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Represents a line item included in a draft order. */
export type DraftOrderLineItem = Node & {
  __typename?: 'DraftOrderLineItem'
  /**
   * Discount which will be applied to the line item or the overall order.
   *
   */
  appliedDiscount?: Maybe<DraftOrderAppliedDiscount>
  /**
   * Whether this is a product variant line item, or a custom line item.
   * If set to true indicates a custom line item. If set to false indicates a product variant line item.
   *
   */
  custom: Scalars['Boolean']
  /** List of additional information about the line item. */
  customAttributes: Array<Attribute>
  /**
   * Line item price after discounts are applied.
   *
   */
  discountedTotal: Scalars['Money']
  /**
   * The `discountedTotal` divided by `quantity`, resulting in the value of the discount per unit.
   *
   */
  discountedUnitPrice: Scalars['Money']
  /**
   * Name of the service provider who fulfilled the order.
   *
   * Valid values are either **manual** or the name of the provider.
   * For example, **amazon**, **shipwire**.
   *
   * Deleted fulfillment services will return null.
   *
   */
  fulfillmentService?: Maybe<FulfillmentService>
  /**
   * Weight in grams. Can only be specified if this is a custom line item.
   *
   * @deprecated Use `weight` instead
   */
  grams?: Maybe<Scalars['Int']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** Image associated with the draft order line item. */
  image?: Maybe<Image>
  /** Whether the line item represents the puchase of a gift card. */
  isGiftCard: Scalars['Boolean']
  /** Name of the product. */
  name: Scalars['String']
  /**
   * Total price (without discounts) of the line item, based on the original unit price of the variant x quantity.
   *
   */
  originalTotal: Scalars['Money']
  /** Variant price without any discounts applied. */
  originalUnitPrice: Scalars['Money']
  /**
   * The product corresponding to the line item’s product variant.
   *
   */
  product?: Maybe<Product>
  /** Number of variant items requested in the draft order. */
  quantity: Scalars['Int']
  /** Whether physical shipping is required for the variant. */
  requiresShipping: Scalars['Boolean']
  /** Variant SKU number. */
  sku?: Maybe<Scalars['String']>
  /**
   * A list of tax line objects, each of which details the total taxes applicable to the order.
   *
   */
  taxLines: Array<TaxLine>
  /** Whether the variant is taxable. */
  taxable: Scalars['Boolean']
  /** Title of the product or variant (this field only applies to custom line items). */
  title: Scalars['String']
  /**
   * Total value of the discount applied to the line item.
   *
   */
  totalDiscount: Scalars['Money']
  /**
   * Associated variant for the line item.
   *
   */
  variant?: Maybe<ProductVariant>
  /** Name of the variant. */
  variantTitle?: Maybe<Scalars['String']>
  /** Name of the vendor who made the variant. */
  vendor?: Maybe<Scalars['String']>
  /** Weight unit and value for a draft order line item. */
  weight?: Maybe<Weight>
}

/** Represents a line item included in a draft order. */
export type DraftOrderLineItemImageArgs = {
  crop?: InputMaybe<CropRegion>
  maxHeight?: InputMaybe<Scalars['Int']>
  maxWidth?: InputMaybe<Scalars['Int']>
  scale?: InputMaybe<Scalars['Int']>
}

/**
 * An auto-generated type for paginating through multiple DraftOrderLineItems.
 *
 */
export type DraftOrderLineItemConnection = {
  __typename?: 'DraftOrderLineItemConnection'
  /** A list of edges. */
  edges: Array<DraftOrderLineItemEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one DraftOrderLineItem and a cursor during pagination.
 *
 */
export type DraftOrderLineItemEdge = {
  __typename?: 'DraftOrderLineItemEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of DraftOrderLineItemEdge. */
  node: DraftOrderLineItem
}

/** The input fields used to create a line item for a draft order. */
export type DraftOrderLineItemInput = {
  /**
   * Discount which will be applied to the line item.
   *
   */
  appliedDiscount?: InputMaybe<DraftOrderAppliedDiscountInput>
  /**
   * Represents a generic custom attribute using a key value pair.
   *
   */
  customAttributes?: InputMaybe<Array<AttributeInput>>
  /** The weight in grams. This value is ignored when `variantId` is provided. This argument is deprecated: Use `weight` instead. */
  grams?: InputMaybe<Scalars['Int']>
  /** The price without any discounts applied. This value is ignored when `variantId` is provided. */
  originalUnitPrice?: InputMaybe<Scalars['Money']>
  /**
   * The number of products that were purchased.
   *
   */
  quantity: Scalars['Int']
  /**
   * Whether physical shipping is required. This value is ignored when `variantId` is provided.
   *
   */
  requiresShipping?: InputMaybe<Scalars['Boolean']>
  /** The SKU number of the item. This value is ignored when `variantId` is provided. */
  sku?: InputMaybe<Scalars['String']>
  /** Whether the item is taxable. This value is ignored when `variantId` is provided. */
  taxable?: InputMaybe<Scalars['Boolean']>
  /** Title of the item. Ignored when `variantId` is provided. */
  title?: InputMaybe<Scalars['String']>
  /**
   * The ID of the product variant corresponding to the line item.
   * Null if custom line item. Required if product variant line item.
   *
   */
  variantId?: InputMaybe<Scalars['ID']>
  /**
   * Specifies the weight unit and value inputs.
   * This value is ignored when `variantId` is provided.
   *
   */
  weight?: InputMaybe<WeightInput>
}

/** The set of valid sort keys for the DraftOrder query. */
export enum DraftOrderSortKeys {
  /** Sort by the `customer_name` value. */
  CustomerName = 'CUSTOMER_NAME',
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `number` value. */
  Number = 'NUMBER',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
  /** Sort by the `status` value. */
  Status = 'STATUS',
  /** Sort by the `total_price` value. */
  TotalPrice = 'TOTAL_PRICE',
  /** Sort by the `updated_at` value. */
  UpdatedAt = 'UPDATED_AT',
}

/** The valid statuses for a draft order. */
export enum DraftOrderStatus {
  /** The draft order has been paid. */
  Completed = 'COMPLETED',
  /** An invoice for the draft order has been sent to the customer. */
  InvoiceSent = 'INVOICE_SENT',
  /** The draft order is open. It has not been paid, and an invoice hasn't been sent. */
  Open = 'OPEN',
}

/** Return type for `draftOrderUpdate` mutation. */
export type DraftOrderUpdatePayload = {
  __typename?: 'DraftOrderUpdatePayload'
  /** The updated draft order. */
  draftOrder?: Maybe<DraftOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** The duty details for a line item. */
export type Duty = Node & {
  __typename?: 'Duty'
  /** The ISO 3166-1 alpha-2 country code of the country of origin used in calculating the duty. */
  countryCodeOfOrigin?: Maybe<CountryCode>
  /** The harmonized system code of the item used in calculating the duty. */
  harmonizedSystemCode?: Maybe<Scalars['String']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The amount of the duty. */
  price: MoneyBag
  /** A list of taxes charged on the duty. */
  taxLines: Array<TaxLine>
}

/** A sale associated with a duty charge. */
export type DutySale = Sale & {
  __typename?: 'DutySale'
  /** The type of order action that the sale represents. */
  actionType: SaleActionType
  /** The duty for the associated sale. */
  duty: Duty
  /** The unique identifier for the sale. */
  id: Scalars['ID']
  /** The line type assocated with the sale. */
  lineType: SaleLineType
  /** The number of units either ordered or intended to be returned. */
  quantity?: Maybe<Scalars['Int']>
  /** All individual taxes associated with the sale. */
  taxes: Array<SaleTax>
  /** The total sale amount after taxes and discounts. */
  totalAmount: MoneyBag
  /** The total discounts allocated to the sale after taxes. */
  totalDiscountAmountAfterTaxes: MoneyBag
  /** The total discounts allocated to the sale before taxes. */
  totalDiscountAmountBeforeTaxes: MoneyBag
  /** The total amount of taxes for the sale. */
  totalTaxAmount: MoneyBag
}

/** The attribute editable information. */
export type EditableProperty = {
  __typename?: 'EditableProperty'
  /** Whether the attribute is locked for editing. */
  locked: Scalars['Boolean']
  /** The reason the attribute is locked for editing. */
  reason?: Maybe<Scalars['FormattedString']>
}

/** Specifies the fields for an email. */
export type EmailInput = {
  /** Specifies any bcc recipients for the email. */
  bcc?: InputMaybe<Array<Scalars['String']>>
  /** Specifies the email body. */
  body?: InputMaybe<Scalars['String']>
  /** Specifies a custom message to include in the email. */
  customMessage?: InputMaybe<Scalars['String']>
  /** Specifies the email sender. */
  from?: InputMaybe<Scalars['String']>
  /** Specifies the email subject. */
  subject?: InputMaybe<Scalars['String']>
  /** Specifies the email recipient. */
  to?: InputMaybe<Scalars['String']>
}

/**
 * Events chronicle resource activities such as the creation of an article, the fulfillment of an order, or the
 * addition of a product.
 *
 */
export type Event = {
  /** The name of the app that created the event. */
  appTitle?: Maybe<Scalars['String']>
  /** Whether the event was created by an app. */
  attributeToApp: Scalars['Boolean']
  /** Whether the event was caused by an admin user. */
  attributeToUser: Scalars['Boolean']
  /** The date and time when the event was created. */
  createdAt: Scalars['DateTime']
  /** Whether the event is critical. */
  criticalAlert: Scalars['Boolean']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** Human readable text that describes the event. */
  message: Scalars['FormattedString']
}

/** Return type for `eventBridgeWebhookSubscriptionCreate` mutation. */
export type EventBridgeWebhookSubscriptionCreatePayload = {
  __typename?: 'EventBridgeWebhookSubscriptionCreatePayload'
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
  /** The webhook subscription that was created. */
  webhookSubscription?: Maybe<WebhookSubscription>
}

/**
 * Specifies the input fields for an EventBridge webhook subscription.
 *
 */
export type EventBridgeWebhookSubscriptionInput = {
  /** The ARN of the EventBridge partner event source. */
  arn?: InputMaybe<Scalars['ARN']>
  /** The format in which the webhook subscription should send the data. */
  format?: InputMaybe<WebhookSubscriptionFormat>
  /** The list of fields to be included in the webhook subscription. */
  includeFields?: InputMaybe<Array<Scalars['String']>>
  /** The list of namespaces for any metafields that should be included in the webhook subscription. */
  metafieldNamespaces?: InputMaybe<Array<Scalars['String']>>
}

/** Return type for `eventBridgeWebhookSubscriptionUpdate` mutation. */
export type EventBridgeWebhookSubscriptionUpdatePayload = {
  __typename?: 'EventBridgeWebhookSubscriptionUpdatePayload'
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
  /** The webhook subscription that was updated. */
  webhookSubscription?: Maybe<WebhookSubscription>
}

/**
 * An auto-generated type for paginating through multiple Events.
 *
 */
export type EventConnection = {
  __typename?: 'EventConnection'
  /** A list of edges. */
  edges: Array<EventEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one Event and a cursor during pagination.
 *
 */
export type EventEdge = {
  __typename?: 'EventEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of EventEdge. */
  node: Event
}

/** The set of valid sort keys for the Event query. */
export enum EventSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/**
 * Represents a video hosted outside of Shopify.
 *
 */
export type ExternalVideo = Media &
  Node & {
    __typename?: 'ExternalVideo'
    /** A word or phrase to share the nature or contents of a media. */
    alt?: Maybe<Scalars['String']>
    /**
     * The URL.
     * @deprecated Use `originUrl` instead
     */
    embeddedUrl: Scalars['URL']
    /** The host of the external video. */
    host: MediaHost
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The media content type. */
    mediaContentType: MediaContentType
    /** Any errors which have occurred on the media. */
    mediaErrors: Array<MediaError>
    /** The warnings attached to the media. */
    mediaWarnings: Array<MediaWarning>
    /** The preview image for the media. */
    preview?: Maybe<MediaPreviewImage>
    /** Current status of the media. */
    status: MediaStatus
  }

/** Requirements that must be met before an app can be installed. */
export type FailedRequirement = {
  __typename?: 'FailedRequirement'
  /** Action to be taken to resolve a failed requirement, including URL link. */
  action?: Maybe<NavigationItem>
  /**
   * A concise set of copy strings to be displayed to merchants, to guide them in resolving problems your app
   * encounters when trying to make use of their Shop and its resources.
   *
   */
  message: Scalars['String']
}

/** A file interface. */
export type File = {
  /** A word or phrase to describe the contents or the function of a file. */
  alt?: Maybe<Scalars['String']>
  /**
   * The date and time ([ISO 8601 format](http://en.wikipedia.org/wiki/ISO_8601)) when the product was created.
   *
   */
  createdAt: Scalars['DateTime']
  /** Any errors that have occurred on the file. */
  fileErrors: Array<FileError>
  /** The status of the file. */
  fileStatus: FileStatus
  /** The preview image for the media. */
  preview?: Maybe<MediaPreviewImage>
}

/**
 * An auto-generated type for paginating through multiple Files.
 *
 */
export type FileConnection = {
  __typename?: 'FileConnection'
  /** A list of edges. */
  edges: Array<FileEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** The possible content types for a file object. */
export enum FileContentType {
  /** A Shopify-hosted generic file. */
  File = 'FILE',
  /** A Shopify hosted image. */
  Image = 'IMAGE',
}

/** The input fields that are required to create a file object. */
export type FileCreateInput = {
  /** The alt text associated with the file. */
  alt?: InputMaybe<Scalars['String']>
  /** The file content type. */
  contentType?: InputMaybe<FileContentType>
  /**
   * An external URL or a signed upload URL of the file object.
   *
   */
  originalSource: Scalars['String']
}

/** Return type for `fileCreate` mutation. */
export type FileCreatePayload = {
  __typename?: 'FileCreatePayload'
  /** The newly created files. */
  files?: Maybe<Array<File>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<FilesUserError>
}

/** Return type for `fileDelete` mutation. */
export type FileDeletePayload = {
  __typename?: 'FileDeletePayload'
  /** The IDs of the deleted files. */
  deletedFileIds?: Maybe<Array<Scalars['ID']>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<FilesUserError>
}

/**
 * An auto-generated type which holds one File and a cursor during pagination.
 *
 */
export type FileEdge = {
  __typename?: 'FileEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of FileEdge. */
  node: File
}

/**
 * A file error.
 *
 */
export type FileError = {
  __typename?: 'FileError'
  /** Code representing the type of error. */
  code: FileErrorCode
  /** Additional details regarding the error. */
  details?: Maybe<Scalars['String']>
  /** Translated error message. */
  message: Scalars['String']
}

/** The error types for a file. */
export enum FileErrorCode {
  /** File could not be created because embed permissions are disabled for this video. */
  ExternalVideoEmbedDisabled = 'EXTERNAL_VIDEO_EMBED_DISABLED',
  /** File could not be created because video is either not found or still transcoding. */
  ExternalVideoEmbedNotFoundOrTranscoding = 'EXTERNAL_VIDEO_EMBED_NOT_FOUND_OR_TRANSCODING',
  /** File could not be created because the external video has an invalid aspect ratio. */
  ExternalVideoInvalidAspectRatio = 'EXTERNAL_VIDEO_INVALID_ASPECT_RATIO',
  /** File could not be created because the external video could not be found. */
  ExternalVideoNotFound = 'EXTERNAL_VIDEO_NOT_FOUND',
  /** File could not be created because the external video is not listed or is private. */
  ExternalVideoUnlisted = 'EXTERNAL_VIDEO_UNLISTED',
  /** File could not be created because the cumulative file storage limit would be exceeded. */
  FileStorageLimitExceeded = 'FILE_STORAGE_LIMIT_EXCEEDED',
  /** File could not be processed because the source could not be downloaded. */
  GenericFileDownloadFailure = 'GENERIC_FILE_DOWNLOAD_FAILURE',
  /** File could not be created because the size is too large. */
  GenericFileInvalidSize = 'GENERIC_FILE_INVALID_SIZE',
  /** File could not be processed because the image could not be downloaded. */
  ImageDownloadFailure = 'IMAGE_DOWNLOAD_FAILURE',
  /** File could not be processed because the image could not be processed. */
  ImageProcessingFailure = 'IMAGE_PROCESSING_FAILURE',
  /** File could not be created because the image has an invalid aspect ratio. */
  InvalidImageAspectRatio = 'INVALID_IMAGE_ASPECT_RATIO',
  /** File could not be created because the image size is too large. */
  InvalidImageFileSize = 'INVALID_IMAGE_FILE_SIZE',
  /** File could not be created because the image's resolution exceeds the max limit. */
  InvalidImageResolution = 'INVALID_IMAGE_RESOLUTION',
  /** File could not be processed because the signed URL was invalid. */
  InvalidSignedUrl = 'INVALID_SIGNED_URL',
  /** File timed out because it is currently being modified by another operation. */
  MediaTimeoutError = 'MEDIA_TIMEOUT_ERROR',
  /** File could not be created because the model file failed processing. */
  Model3DGlbOutputCreationError = 'MODEL3D_GLB_OUTPUT_CREATION_ERROR',
  /** File could not be created because the model can't be converted to USDZ format. */
  Model3DGlbToUsdzConversionError = 'MODEL3D_GLB_TO_USDZ_CONVERSION_ERROR',
  /** File could not be created because the model file failed processing. */
  Model3DProcessingFailure = 'MODEL3D_PROCESSING_FAILURE',
  /** File could not be created because the model's thumbnail generation failed. */
  Model3DThumbnailGenerationError = 'MODEL3D_THUMBNAIL_GENERATION_ERROR',
  /** Model failed validation. */
  Model3DValidationError = 'MODEL3D_VALIDATION_ERROR',
  /** File error has occurred for an unknown reason. */
  Unknown = 'UNKNOWN',
  /** File could not be created because the image is an unsupported file type. */
  UnsupportedImageFileType = 'UNSUPPORTED_IMAGE_FILE_TYPE',
  /** File could not be created because it has an invalid file type. */
  VideoInvalidFiletypeError = 'VIDEO_INVALID_FILETYPE_ERROR',
  /** File could not be created because it does not meet the maximum duration requirement. */
  VideoMaxDurationError = 'VIDEO_MAX_DURATION_ERROR',
  /** File could not be created because it does not meet the maximum height requirement. */
  VideoMaxHeightError = 'VIDEO_MAX_HEIGHT_ERROR',
  /** File could not be created because it does not meet the maximum width requirement. */
  VideoMaxWidthError = 'VIDEO_MAX_WIDTH_ERROR',
  /** File could not be created because the metadata could not be read. */
  VideoMetadataReadError = 'VIDEO_METADATA_READ_ERROR',
  /** File could not be created because it does not meet the minimum duration requirement. */
  VideoMinDurationError = 'VIDEO_MIN_DURATION_ERROR',
  /** File could not be created because it does not meet the minimum height requirement. */
  VideoMinHeightError = 'VIDEO_MIN_HEIGHT_ERROR',
  /** File could not be created because it does not meet the minimum width requirement. */
  VideoMinWidthError = 'VIDEO_MIN_WIDTH_ERROR',
  /** Video failed validation. */
  VideoValidationError = 'VIDEO_VALIDATION_ERROR',
}

/** The set of valid sort keys for the File query. */
export enum FileSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `filename` value. */
  Filename = 'FILENAME',
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `original_upload_size` value. */
  OriginalUploadSize = 'ORIGINAL_UPLOAD_SIZE',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/** The possible statuses for a file object. */
export enum FileStatus {
  /** File processing has failed. */
  Failed = 'FAILED',
  /** File is being processed. */
  Processing = 'PROCESSING',
  /** File is ready to be displayed. */
  Ready = 'READY',
  /** File has been uploaded but hasn't been processed. */
  Uploaded = 'UPLOADED',
}

/** The input fields that are required to update a file object. */
export type FileUpdateInput = {
  /** The alt text associated with the file. */
  alt?: InputMaybe<Scalars['String']>
  /** The file to update. */
  id: Scalars['ID']
}

/** Return type for `fileUpdate` mutation. */
export type FileUpdatePayload = {
  __typename?: 'FileUpdatePayload'
  /** The list of updated files. */
  files?: Maybe<Array<File>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<FilesUserError>
}

/** Possible error codes that can be returned by `FilesUserError`. */
export enum FilesErrorCode {
  /** The alt value exceeds the maximum limit of 512 characters. */
  AltValueLimitExceeded = 'ALT_VALUE_LIMIT_EXCEEDED',
  /** The search term must not be blank. */
  BlankSearch = 'BLANK_SEARCH',
  /** File does not exist. */
  FileDoesNotExist = 'FILE_DOES_NOT_EXIST',
  /** File has a pending operation. */
  FileLocked = 'FILE_LOCKED',
  /** The input value is invalid. */
  Invalid = 'INVALID',
  /** Search query isn't supported. */
  InvalidQuery = 'INVALID_QUERY',
  /** At least one argument is required. */
  MissingArguments = 'MISSING_ARGUMENTS',
  /** Specify one argument: search, IDs, or deleteAll. */
  TooManyArguments = 'TOO_MANY_ARGUMENTS',
  /** The file type is not supported. */
  UnacceptableAsset = 'UNACCEPTABLE_ASSET',
  /** The file is not supported on trial accounts. Select a plan to upload this file. */
  UnacceptableTrialAsset = 'UNACCEPTABLE_TRIAL_ASSET',
  /** The file is not supported on trial accounts that have not validated their email. Either select a plan or verify the shop owner email to upload this file. */
  UnacceptableUnverifiedTrialAsset = 'UNACCEPTABLE_UNVERIFIED_TRIAL_ASSET',
}

/** An error that happens during the execution of a Files API query or mutation. */
export type FilesUserError = DisplayableError & {
  __typename?: 'FilesUserError'
  /** The error code. */
  code?: Maybe<FilesErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** A filter option is one possible value in a search filter. */
export type FilterOption = {
  __typename?: 'FilterOption'
  /** The filter option's label for display purposes. */
  label: Scalars['String']
  /** The filter option's value. */
  value: Scalars['String']
}

/** Return type for `flowTriggerReceive` mutation. */
export type FlowTriggerReceivePayload = {
  __typename?: 'FlowTriggerReceivePayload'
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * Represents a fulfillment. In Shopify, a fulfillment represents a shipment of one or more items in an order. When an order has been completely fulfilled, it means that all the items that are included in the order have been sent to the customer. There can be more than one fulfillment for an order.
 *
 */
export type Fulfillment = LegacyInteroperability &
  Node & {
    __typename?: 'Fulfillment'
    /** The date and time when the fulfillment was created. */
    createdAt: Scalars['DateTime']
    /** The date that this fulfillment was delivered. */
    deliveredAt?: Maybe<Scalars['DateTime']>
    /** Human readable display status for this fulfillment. */
    displayStatus?: Maybe<FulfillmentDisplayStatus>
    /** The estimated date that this fulfillment will arrive. */
    estimatedDeliveryAt?: Maybe<Scalars['DateTime']>
    /** The history of events associated with this fulfillment. */
    events: FulfillmentEventConnection
    /** List of the fulfillment's line items. */
    fulfillmentLineItems: FulfillmentLineItemConnection
    /** A paginated list of fulfillment orders for the fulfillment. */
    fulfillmentOrders: FulfillmentOrderConnection
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The date and time when the fulfillment went into transit. */
    inTransitAt?: Maybe<Scalars['DateTime']>
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** The location that the fulfillment was processed at. */
    location?: Maybe<Location>
    /** Human readable reference identifier for this fulfillment. */
    name: Scalars['String']
    /** The order for which the fulfillment was created. */
    order: Order
    /** The address at which the fulfillment occurred. Typically this is the address of the warehouse or fulfillment center. */
    originAddress?: Maybe<FulfillmentOriginAddress>
    /** Whether any of the line items in the fulfillment require shipping. */
    requiresShipping: Scalars['Boolean']
    /** Fulfillment service associated with the fulfillment. */
    service?: Maybe<FulfillmentService>
    /** The status of the fulfillment. */
    status: FulfillmentStatus
    /** Sum of all line item quantities for the fulfillment. */
    totalQuantity: Scalars['Int']
    /**
     * Tracking information associated with the fulfillment,
     * such as the tracking company, tracking number, and tracking URL.
     *
     */
    trackingInfo: Array<FulfillmentTrackingInfo>
    /**
     * The date and time when the fulfillment was last modified.
     *
     */
    updatedAt: Scalars['DateTime']
  }

/**
 * Represents a fulfillment. In Shopify, a fulfillment represents a shipment of one or more items in an order. When an order has been completely fulfilled, it means that all the items that are included in the order have been sent to the customer. There can be more than one fulfillment for an order.
 *
 */
export type FulfillmentEventsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<FulfillmentEventSortKeys>
}

/**
 * Represents a fulfillment. In Shopify, a fulfillment represents a shipment of one or more items in an order. When an order has been completely fulfilled, it means that all the items that are included in the order have been sent to the customer. There can be more than one fulfillment for an order.
 *
 */
export type FulfillmentFulfillmentLineItemsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a fulfillment. In Shopify, a fulfillment represents a shipment of one or more items in an order. When an order has been completely fulfilled, it means that all the items that are included in the order have been sent to the customer. There can be more than one fulfillment for an order.
 *
 */
export type FulfillmentFulfillmentOrdersArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a fulfillment. In Shopify, a fulfillment represents a shipment of one or more items in an order. When an order has been completely fulfilled, it means that all the items that are included in the order have been sent to the customer. There can be more than one fulfillment for an order.
 *
 */
export type FulfillmentTrackingInfoArgs = {
  first?: InputMaybe<Scalars['Int']>
}

/** Return type for `fulfillmentCancel` mutation. */
export type FulfillmentCancelPayload = {
  __typename?: 'FulfillmentCancelPayload'
  /** The canceled fulfillment. */
  fulfillment?: Maybe<Fulfillment>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type for paginating through multiple Fulfillments.
 *
 */
export type FulfillmentConnection = {
  __typename?: 'FulfillmentConnection'
  /** A list of edges. */
  edges: Array<FulfillmentEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `fulfillmentCreate` mutation. */
export type FulfillmentCreatePayload = {
  __typename?: 'FulfillmentCreatePayload'
  /** The created fulfillment. */
  fulfillment?: Maybe<Fulfillment>
  /** The order for which the fulfillment is created. */
  order?: Maybe<Order>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `fulfillmentCreateV2` mutation. */
export type FulfillmentCreateV2Payload = {
  __typename?: 'FulfillmentCreateV2Payload'
  /** The created fulfillment. */
  fulfillment?: Maybe<Fulfillment>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** The display status of a fulfillment. */
export enum FulfillmentDisplayStatus {
  /** Displayed as **Attempted delivery**. */
  AttemptedDelivery = 'ATTEMPTED_DELIVERY',
  /** Displayed as **Canceled**. */
  Canceled = 'CANCELED',
  /** Displayed as **Confirmed**. */
  Confirmed = 'CONFIRMED',
  /** Displayed as **Delivered**. */
  Delivered = 'DELIVERED',
  /** Displayed as **Failure**. */
  Failure = 'FAILURE',
  /** Displayed as **Fulfilled**. */
  Fulfilled = 'FULFILLED',
  /** Displayed as **In transit**. */
  InTransit = 'IN_TRANSIT',
  /** Displayed as **Label printed**. */
  LabelPrinted = 'LABEL_PRINTED',
  /** Displayed as **Label purchased**. */
  LabelPurchased = 'LABEL_PURCHASED',
  /** Displayed as **Label voided**. */
  LabelVoided = 'LABEL_VOIDED',
  /** Displayed as **Marked as fulfilled**. */
  MarkedAsFulfilled = 'MARKED_AS_FULFILLED',
  /** Displayed as **Not delivered**. */
  NotDelivered = 'NOT_DELIVERED',
  /** Displayed as **Out for delivery**. */
  OutForDelivery = 'OUT_FOR_DELIVERY',
  /** Displayed as **Picked up**. */
  PickedUp = 'PICKED_UP',
  /** Displayed as **Ready for pickup**. */
  ReadyForPickup = 'READY_FOR_PICKUP',
  /** Displayed as **Submitted**. */
  Submitted = 'SUBMITTED',
}

/**
 * An auto-generated type which holds one Fulfillment and a cursor during pagination.
 *
 */
export type FulfillmentEdge = {
  __typename?: 'FulfillmentEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of FulfillmentEdge. */
  node: Fulfillment
}

/** The fulfillment event that describes the fulfilllment status at a particular time. */
export type FulfillmentEvent = Node & {
  __typename?: 'FulfillmentEvent'
  /** The time at which this fulfillment event happened. */
  happenedAt: Scalars['DateTime']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The status of this fulfillment event. */
  status: FulfillmentEventStatus
}

/**
 * An auto-generated type for paginating through multiple FulfillmentEvents.
 *
 */
export type FulfillmentEventConnection = {
  __typename?: 'FulfillmentEventConnection'
  /** A list of edges. */
  edges: Array<FulfillmentEventEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one FulfillmentEvent and a cursor during pagination.
 *
 */
export type FulfillmentEventEdge = {
  __typename?: 'FulfillmentEventEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of FulfillmentEventEdge. */
  node: FulfillmentEvent
}

/** The set of valid sort keys for the FulfillmentEvent query. */
export enum FulfillmentEventSortKeys {
  /** Sort by the `happened_at` value. */
  HappenedAt = 'HAPPENED_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/** The status that describes a fulfillment or delivery event. */
export enum FulfillmentEventStatus {
  /** A delivery was attempted. */
  AttemptedDelivery = 'ATTEMPTED_DELIVERY',
  /** The fulfillment is confirmed. This is the default value when no other information is available. */
  Confirmed = 'CONFIRMED',
  /** The fulfillment was successfully delivered. */
  Delivered = 'DELIVERED',
  /** The fulfillment request failed. */
  Failure = 'FAILURE',
  /** The fulfillment is in transit. */
  InTransit = 'IN_TRANSIT',
  /** A purchased shipping label has been printed. */
  LabelPrinted = 'LABEL_PRINTED',
  /** A shipping label has been purchased. */
  LabelPurchased = 'LABEL_PURCHASED',
  /** The fulfillment is out for delivery. */
  OutForDelivery = 'OUT_FOR_DELIVERY',
  /** The fulfillment is ready to be picked up. */
  ReadyForPickup = 'READY_FOR_PICKUP',
}

/**
 * A fulfillment hold currently applied on a fulfillment order.
 *
 */
export type FulfillmentHold = {
  __typename?: 'FulfillmentHold'
  /** The reason for the fulfillment hold. */
  reason: FulfillmentHoldReason
  /** Additional information about the fulfillment hold reason. */
  reasonNotes?: Maybe<Scalars['String']>
}

/** The reason for a fulfillment hold. */
export enum FulfillmentHoldReason {
  /** The fulfillment hold is applied because payment is pending. */
  AwaitingPayment = 'AWAITING_PAYMENT',
  /** The fulfillment hold is applied because of a high risk of fraud. */
  HighRiskOfFraud = 'HIGH_RISK_OF_FRAUD',
  /** The fulfillment hold is applied because of an incorrect address. */
  IncorrectAddress = 'INCORRECT_ADDRESS',
  /** The fulfillment hold is applied because inventory is out of stock. */
  InventoryOutOfStock = 'INVENTORY_OUT_OF_STOCK',
  /** The fulfillment hold is applied for another reason. */
  Other = 'OTHER',
}

/** The input fields used to create a fulfillment. */
export type FulfillmentInput = {
  /** The order line items to be fulfilled. */
  lineItems?: InputMaybe<Array<FulfillmentLineItemInput>>
  /** The ID of the location from which the line items will be fulfilled. */
  locationId: Scalars['ID']
  /**
   * Whether the customer is notified when the fulfillment is created.
   * If `true`, then a notification is sent when the fulfillment is created.
   *
   */
  notifyCustomer?: InputMaybe<Scalars['Boolean']>
  /** The ID of the order to be fulfilled. */
  orderId: Scalars['ID']
  /**
   * The address at which the fulfillment occurred.
   * Typically this is the address of a warehouse or a fulfillment center.
   *
   */
  originAddress?: InputMaybe<FulfillmentOriginAddressInput>
  /** A reference to the [ShippingMethod](https://shopify.dev/api/admin-graphql/latest/objects/shippingmethod) code, for example `FREE_SHIPPING`. */
  shippingMethod?: InputMaybe<Scalars['String']>
  /** The name of the tracking company. */
  trackingCompany?: InputMaybe<Scalars['String']>
  /** Tracking numbers associated with the fulfillment. */
  trackingNumbers?: InputMaybe<Array<Scalars['String']>>
  /** The URLs to track the fulfillment. */
  trackingUrls?: InputMaybe<Array<Scalars['String']>>
}

/** Represents a line item from an order that's included in a fulfillment. */
export type FulfillmentLineItem = Node & {
  __typename?: 'FulfillmentLineItem'
  /**
   * The total price after discounts are applied.
   * @deprecated Use `discountedTotalSet` instead
   */
  discountedTotal: Scalars['Money']
  /** The total price after discounts are applied in shop and presentment currencies. */
  discountedTotalSet: MoneyBag
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The associated order's line item. */
  lineItem: LineItem
  /**
   * The total price before discounts are applied.
   * @deprecated Use `originalTotalSet` instead
   */
  originalTotal: Scalars['Money']
  /** The total price before discounts are applied in shop and presentment currencies. */
  originalTotalSet: MoneyBag
  /** Number of line items in the fulfillment. */
  quantity?: Maybe<Scalars['Int']>
}

/**
 * An auto-generated type for paginating through multiple FulfillmentLineItems.
 *
 */
export type FulfillmentLineItemConnection = {
  __typename?: 'FulfillmentLineItemConnection'
  /** A list of edges. */
  edges: Array<FulfillmentLineItemEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one FulfillmentLineItem and a cursor during pagination.
 *
 */
export type FulfillmentLineItemEdge = {
  __typename?: 'FulfillmentLineItemEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of FulfillmentLineItemEdge. */
  node: FulfillmentLineItem
}

/** The input fields used to include a line item from an order in a fulfillment. */
export type FulfillmentLineItemInput = {
  /** The ID of the line item. */
  id: Scalars['ID']
  /** The quantity of the line item to be fulfilled. */
  quantity?: InputMaybe<Scalars['Int']>
}

/**
 * Represents a fulfillment order. In Shopify, a fulfillment order represents a group of one or more items
 * in an order that are to be fulfilled from the same location. There can be more than one fulfillment order
 * for an order at a given location.
 *
 */
export type FulfillmentOrder = Node & {
  __typename?: 'FulfillmentOrder'
  /** The fulfillment order's assigned location. This is the location expected to perform fulfillment. */
  assignedLocation: FulfillmentOrderAssignedLocation
  /** Delivery method of this fulfillment order. */
  deliveryMethod?: Maybe<DeliveryMethod>
  /** The destination where the items should be sent. */
  destination?: Maybe<FulfillmentOrderDestination>
  /** The date and time at which the fulfillment order will be fulfillable. */
  fulfillAt?: Maybe<Scalars['DateTime']>
  /** The fulfillment holds applied on the fulfillment order. */
  fulfillmentHolds: Array<FulfillmentHold>
  /** A list of fulfillments for the fulfillment order. */
  fulfillments: FulfillmentConnection
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The duties delivery method of this fulfillment order. */
  internationalDuties?: Maybe<FulfillmentOrderInternationalDuties>
  /** A list of the fulfillment order's line items. */
  lineItems: FulfillmentOrderLineItemConnection
  /** A list of locations that the fulfillment order can potentially move to. */
  locationsForMove: FulfillmentOrderLocationForMoveConnection
  /** A list of requests sent by the merchant to the fulfillment service for this fulfillment order. */
  merchantRequests: FulfillmentOrderMerchantRequestConnection
  /** The order that's associated with the fulfillment order. */
  order: Order
  /** The request status of the fulfillment order. */
  requestStatus: FulfillmentOrderRequestStatus
  /** The status of the fulfillment order. */
  status: FulfillmentOrderStatus
  /** The actions that can be performed on this fulfillment order. */
  supportedActions: Array<FulfillmentOrderSupportedAction>
}

/**
 * Represents a fulfillment order. In Shopify, a fulfillment order represents a group of one or more items
 * in an order that are to be fulfilled from the same location. There can be more than one fulfillment order
 * for an order at a given location.
 *
 */
export type FulfillmentOrderFulfillmentsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a fulfillment order. In Shopify, a fulfillment order represents a group of one or more items
 * in an order that are to be fulfilled from the same location. There can be more than one fulfillment order
 * for an order at a given location.
 *
 */
export type FulfillmentOrderLineItemsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a fulfillment order. In Shopify, a fulfillment order represents a group of one or more items
 * in an order that are to be fulfilled from the same location. There can be more than one fulfillment order
 * for an order at a given location.
 *
 */
export type FulfillmentOrderLocationsForMoveArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a fulfillment order. In Shopify, a fulfillment order represents a group of one or more items
 * in an order that are to be fulfilled from the same location. There can be more than one fulfillment order
 * for an order at a given location.
 *
 */
export type FulfillmentOrderMerchantRequestsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  kind?: InputMaybe<FulfillmentOrderMerchantRequestKind>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Return type for `fulfillmentOrderAcceptCancellationRequest` mutation. */
export type FulfillmentOrderAcceptCancellationRequestPayload = {
  __typename?: 'FulfillmentOrderAcceptCancellationRequestPayload'
  /** The fulfillment order whose cancellation request was accepted. */
  fulfillmentOrder?: Maybe<FulfillmentOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `fulfillmentOrderAcceptFulfillmentRequest` mutation. */
export type FulfillmentOrderAcceptFulfillmentRequestPayload = {
  __typename?: 'FulfillmentOrderAcceptFulfillmentRequestPayload'
  /** The fulfillment order whose fulfillment request was accepted. */
  fulfillmentOrder?: Maybe<FulfillmentOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** The actions that can be taken on a fulfillment order. */
export enum FulfillmentOrderAction {
  /** Cancels a fulfillment order. The corresponding mutation for this action is `fulfillmentOrderCancel`. */
  CancelFulfillmentOrder = 'CANCEL_FULFILLMENT_ORDER',
  /** Creates a fulfillment for selected line items in the fulfillment order. The corresponding mutation for this action is `fulfillmentCreateV2`. */
  CreateFulfillment = 'CREATE_FULFILLMENT',
  /** Opens an external URL to initiate the fulfillment process outside Shopify. This action should be paired with `FulfillmentOrderSupportedAction.externalUrl`. */
  External = 'EXTERNAL',
  /** Applies a fulfillment hold on an open fulfillment order. The corresponding mutation for this action is `fulfillmentOrderHold`. */
  Hold = 'HOLD',
  /** Marks the fulfillment order as open. The corresponding mutation for this action is `fulfillmentOrderOpen`. */
  MarkAsOpen = 'MARK_AS_OPEN',
  /** Moves a fulfillment order. The corresponding mutation for this action is `fulfillmentOrderMove`. */
  Move = 'MOVE',
  /** Releases the fulfillment hold on the fulfillment order. The corresponding mutation for this action is `fulfillmentOrderReleaseHold`. */
  ReleaseHold = 'RELEASE_HOLD',
  /** Sends a cancellation request to the fulfillment service of a fulfillment order. The corresponding mutation for this action is `fulfillmentOrderSubmitCancellationRequest`. */
  RequestCancellation = 'REQUEST_CANCELLATION',
  /** Sends a request for fulfilling selected line items in a fulfillment order to a fulfillment service. The corresponding mutation for this action is `fulfillmentOrderSubmitFulfillmentRequest`. */
  RequestFulfillment = 'REQUEST_FULFILLMENT',
}

/**
 * Represents the assigned location of a fulfillment order, which is a snapshot of the location
 * at which the fulfillment order was created. The assigned location is expected to perform fulfillment.
 *
 */
export type FulfillmentOrderAssignedLocation = {
  __typename?: 'FulfillmentOrderAssignedLocation'
  /** The first line of the address for the location. */
  address1?: Maybe<Scalars['String']>
  /** The second line of the address for the location. */
  address2?: Maybe<Scalars['String']>
  /** The city of the location. */
  city?: Maybe<Scalars['String']>
  /** The two-letter country code of the location. */
  countryCode: CountryCode
  /**
   * The location where the fulfillment order was created. This can differ from the
   * `FulfillmentOrderAssignedLocation` if the location was updated since the fulfillment order
   * was closed.
   *
   */
  location?: Maybe<Location>
  /** The name of the location. */
  name: Scalars['String']
  /** The phone number of the location. */
  phone?: Maybe<Scalars['String']>
  /** The province of the location. */
  province?: Maybe<Scalars['String']>
  /** The ZIP code of the location. */
  zip?: Maybe<Scalars['String']>
}

/** The assigment status to be used to filter fulfillment orders. */
export enum FulfillmentOrderAssignmentStatus {
  /**
   * Fulfillment orders for which the merchant has requested cancellation of
   * the previously accepted fulfillment request.
   *
   */
  CancellationRequested = 'CANCELLATION_REQUESTED',
  /**
   * Fulfillment orders for which the merchant's fulfillment request has been accepted.
   * Any number of fulfillments can be created on these fulfillment orders
   * to completely fulfill the requested items.
   *
   */
  FulfillmentAccepted = 'FULFILLMENT_ACCEPTED',
  /**
   * Fulfillment orders for which the merchant has requested fulfillment.
   *
   */
  FulfillmentRequested = 'FULFILLMENT_REQUESTED',
}

/** Return type for `fulfillmentOrderCancel` mutation. */
export type FulfillmentOrderCancelPayload = {
  __typename?: 'FulfillmentOrderCancelPayload'
  /** The fulfillment order that was marked as canceled. */
  fulfillmentOrder?: Maybe<FulfillmentOrder>
  /** The fulfillment order that was created to replace the canceled fulfillment order. */
  replacementFulfillmentOrder?: Maybe<FulfillmentOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `fulfillmentOrderClose` mutation. */
export type FulfillmentOrderClosePayload = {
  __typename?: 'FulfillmentOrderClosePayload'
  /** The fulfillment order that was marked as incomplete. */
  fulfillmentOrder?: Maybe<FulfillmentOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type for paginating through multiple FulfillmentOrders.
 *
 */
export type FulfillmentOrderConnection = {
  __typename?: 'FulfillmentOrderConnection'
  /** A list of edges. */
  edges: Array<FulfillmentOrderEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * Represents the destination where the items should be sent upon fulfillment.
 *
 */
export type FulfillmentOrderDestination = Node & {
  __typename?: 'FulfillmentOrderDestination'
  /** The first line of the address of the destination. */
  address1?: Maybe<Scalars['String']>
  /** The second line of the address of the destination. */
  address2?: Maybe<Scalars['String']>
  /** The city of the destination. */
  city?: Maybe<Scalars['String']>
  /** The company of the destination. */
  company?: Maybe<Scalars['String']>
  /** The two-letter country code of the destination. */
  countryCode?: Maybe<CountryCode>
  /** The email of the customer at the destination. */
  email?: Maybe<Scalars['String']>
  /** The first name of the customer at the destination. */
  firstName?: Maybe<Scalars['String']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The last name of the customer at the destination. */
  lastName?: Maybe<Scalars['String']>
  /** The phone number of the customer at the destination. */
  phone?: Maybe<Scalars['String']>
  /** The province of the destination. */
  province?: Maybe<Scalars['String']>
  /** The ZIP code of the destination. */
  zip?: Maybe<Scalars['String']>
}

/**
 * An auto-generated type which holds one FulfillmentOrder and a cursor during pagination.
 *
 */
export type FulfillmentOrderEdge = {
  __typename?: 'FulfillmentOrderEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of FulfillmentOrderEdge. */
  node: FulfillmentOrder
}

/** Input arguments for the fulfillment hold applied on the fulfillment order. */
export type FulfillmentOrderHoldInput = {
  /** Whether the merchant receives a notification about the fulfillment hold. The default value is `false`. */
  notifyMerchant?: InputMaybe<Scalars['Boolean']>
  /** The reason for the fulfillment hold. */
  reason: FulfillmentHoldReason
  /** Additional information about the fulfillment hold reason. */
  reasonNotes?: InputMaybe<Scalars['String']>
}

/** Return type for `fulfillmentOrderHold` mutation. */
export type FulfillmentOrderHoldPayload = {
  __typename?: 'FulfillmentOrderHoldPayload'
  /** The fulfillment order on which a fulfillment hold was applied. */
  fulfillmentOrder?: Maybe<FulfillmentOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<FulfillmentOrderHoldUserError>
}

/** An error that occurs during the execution of `FulfillmentOrderHold`. */
export type FulfillmentOrderHoldUserError = DisplayableError & {
  __typename?: 'FulfillmentOrderHoldUserError'
  /** The error code. */
  code?: Maybe<FulfillmentOrderHoldUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `FulfillmentOrderHoldUserError`. */
export enum FulfillmentOrderHoldUserErrorCode {
  /** The fulfillment order could not be found. */
  FulfillmentOrderNotFound = 'FULFILLMENT_ORDER_NOT_FOUND',
}

/**
 * The international duties relevant to a fulfillment order.
 *
 */
export type FulfillmentOrderInternationalDuties = {
  __typename?: 'FulfillmentOrderInternationalDuties'
  /** The method of duties payment. Example values: `DDP`, `DAP`. */
  incoterm: Scalars['String']
}

/**
 * Represents a line item belonging to a fulfillment order.
 *
 */
export type FulfillmentOrderLineItem = Node & {
  __typename?: 'FulfillmentOrderLineItem'
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The associated order line item. */
  lineItem: LineItem
  /** The number of units remaining to be fulfilled. */
  remainingQuantity: Scalars['Int']
  /** The total number of units to be fulfilled. */
  totalQuantity: Scalars['Int']
}

/**
 * An auto-generated type for paginating through multiple FulfillmentOrderLineItems.
 *
 */
export type FulfillmentOrderLineItemConnection = {
  __typename?: 'FulfillmentOrderLineItemConnection'
  /** A list of edges. */
  edges: Array<FulfillmentOrderLineItemEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one FulfillmentOrderLineItem and a cursor during pagination.
 *
 */
export type FulfillmentOrderLineItemEdge = {
  __typename?: 'FulfillmentOrderLineItemEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of FulfillmentOrderLineItemEdge. */
  node: FulfillmentOrderLineItem
}

/**
 * The input fields used to include the quantity of the fulfillment order line item that should be fulfilled.
 *
 */
export type FulfillmentOrderLineItemInput = {
  /** The ID of the fulfillment order line item. */
  id: Scalars['ID']
  /** The quantity of the fulfillment order line item. */
  quantity: Scalars['Int']
}

/**
 * The input fields used to include the line items of a specified fulfillment order that should be fulfilled.
 *
 */
export type FulfillmentOrderLineItemsInput = {
  /** The ID of the fulfillment order. */
  fulfillmentOrderId: Scalars['ID']
  /**
   * The fulfillment order line items to be fulfilled.
   * If left blank, all line items of the fulfillment order will be fulfilled.
   *
   */
  fulfillmentOrderLineItems?: InputMaybe<Array<FulfillmentOrderLineItemInput>>
}

/**
 * A location that a fulfillment order can potentially move to.
 *
 */
export type FulfillmentOrderLocationForMove = {
  __typename?: 'FulfillmentOrderLocationForMove'
  /** The location being considered as the fulfillment order's new assigned location. */
  location: Location
  /**
   * A human-readable string with the reason why the fulfillment order, or some of its line items, can't be
   * moved to the location.
   *
   */
  message?: Maybe<Scalars['String']>
  /** Whether the fulfillment order can be moved to the location. */
  movable: Scalars['Boolean']
}

/**
 * An auto-generated type for paginating through multiple FulfillmentOrderLocationForMoves.
 *
 */
export type FulfillmentOrderLocationForMoveConnection = {
  __typename?: 'FulfillmentOrderLocationForMoveConnection'
  /** A list of edges. */
  edges: Array<FulfillmentOrderLocationForMoveEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one FulfillmentOrderLocationForMove and a cursor during pagination.
 *
 */
export type FulfillmentOrderLocationForMoveEdge = {
  __typename?: 'FulfillmentOrderLocationForMoveEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of FulfillmentOrderLocationForMoveEdge. */
  node: FulfillmentOrderLocationForMove
}

/**
 * Represents a request made by the merchant to a fulfillment service for a fulfillment order.
 *
 */
export type FulfillmentOrderMerchantRequest = Node & {
  __typename?: 'FulfillmentOrderMerchantRequest'
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The kind of request made. */
  kind: FulfillmentOrderMerchantRequestKind
  /** The optional message that the merchant included in the request. */
  message?: Maybe<Scalars['String']>
  /**
   * Additional options requested by the merchant. These depend on the `kind` of the request.
   * For example, for a `FULFILLMENT_REQUEST`, one option is `notify_customer`, which indicates whether the
   * merchant intends to notify the customer upon fulfillment. The fulfillment service can then set
   * `notifyCustomer` when making calls to `FulfillmentCreateV2`.
   *
   */
  requestOptions?: Maybe<Scalars['JSON']>
  /** The response from the fulfillment service. */
  responseData?: Maybe<Scalars['JSON']>
  /** The timestamp when the request was made. */
  sentAt: Scalars['DateTime']
}

/**
 * An auto-generated type for paginating through multiple FulfillmentOrderMerchantRequests.
 *
 */
export type FulfillmentOrderMerchantRequestConnection = {
  __typename?: 'FulfillmentOrderMerchantRequestConnection'
  /** A list of edges. */
  edges: Array<FulfillmentOrderMerchantRequestEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one FulfillmentOrderMerchantRequest and a cursor during pagination.
 *
 */
export type FulfillmentOrderMerchantRequestEdge = {
  __typename?: 'FulfillmentOrderMerchantRequestEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of FulfillmentOrderMerchantRequestEdge. */
  node: FulfillmentOrderMerchantRequest
}

/** The kinds of request merchants can make to a fulfillment service. */
export enum FulfillmentOrderMerchantRequestKind {
  /**
   * The merchant requests cancellation of an `IN_PROGRESS` fulfillment order.
   *
   */
  CancellationRequest = 'CANCELLATION_REQUEST',
  /**
   * The merchant requests fulfillment for an `OPEN` fulfillment order.
   *
   */
  FulfillmentRequest = 'FULFILLMENT_REQUEST',
}

/** Return type for `fulfillmentOrderMove` mutation. */
export type FulfillmentOrderMovePayload = {
  __typename?: 'FulfillmentOrderMovePayload'
  /** A new fulfillment order representing of the all line items that were moved to the new location. */
  movedFulfillmentOrder?: Maybe<FulfillmentOrder>
  /** The fulfillment order that was moved. On success, this fulfillment order will be closed. */
  originalFulfillmentOrder?: Maybe<FulfillmentOrder>
  /**
   * A new fulfillment order representing the remaining line items that are still assigned to the original
   * location. This field is returned when any line items on the original fulfillment order can't be moved
   * because they are are not stocked at the new location.
   *
   */
  remainingFulfillmentOrder?: Maybe<FulfillmentOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `fulfillmentOrderOpen` mutation. */
export type FulfillmentOrderOpenPayload = {
  __typename?: 'FulfillmentOrderOpenPayload'
  /** The fulfillment order that was transitioned to open and is fulfillable. */
  fulfillmentOrder?: Maybe<FulfillmentOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `fulfillmentOrderRejectCancellationRequest` mutation. */
export type FulfillmentOrderRejectCancellationRequestPayload = {
  __typename?: 'FulfillmentOrderRejectCancellationRequestPayload'
  /** The fulfillment order whose cancellation request was rejected. */
  fulfillmentOrder?: Maybe<FulfillmentOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `fulfillmentOrderRejectFulfillmentRequest` mutation. */
export type FulfillmentOrderRejectFulfillmentRequestPayload = {
  __typename?: 'FulfillmentOrderRejectFulfillmentRequestPayload'
  /** The fulfillment order whose fulfillment request was rejected. */
  fulfillmentOrder?: Maybe<FulfillmentOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `fulfillmentOrderReleaseHold` mutation. */
export type FulfillmentOrderReleaseHoldPayload = {
  __typename?: 'FulfillmentOrderReleaseHoldPayload'
  /** The fulfillment order on which the hold was released. */
  fulfillmentOrder?: Maybe<FulfillmentOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<FulfillmentOrderReleaseHoldUserError>
}

/** An error that occurs during the execution of `FulfillmentOrderReleaseHold`. */
export type FulfillmentOrderReleaseHoldUserError = DisplayableError & {
  __typename?: 'FulfillmentOrderReleaseHoldUserError'
  /** The error code. */
  code?: Maybe<FulfillmentOrderReleaseHoldUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `FulfillmentOrderReleaseHoldUserError`. */
export enum FulfillmentOrderReleaseHoldUserErrorCode {
  /** The fulfillment order was not found. */
  FulfillmentOrderNotFound = 'FULFILLMENT_ORDER_NOT_FOUND',
}

/** The request status of a fulfillment order. */
export enum FulfillmentOrderRequestStatus {
  /** The fulfillment service accepted the merchant's fulfillment request. */
  Accepted = 'ACCEPTED',
  /**
   * The fulfillment service accepted the merchant's fulfillment cancellation request.
   *
   */
  CancellationAccepted = 'CANCELLATION_ACCEPTED',
  /**
   * The fulfillment service rejected the merchant's fulfillment cancellation request.
   *
   */
  CancellationRejected = 'CANCELLATION_REJECTED',
  /**
   * The merchant requested a cancellation of the fulfillment request for this fulfillment order.
   *
   */
  CancellationRequested = 'CANCELLATION_REQUESTED',
  /** The fulfillment service closed the fulfillment order without completing it. */
  Closed = 'CLOSED',
  /** The fulfillment service rejected the merchant's fulfillment request. */
  Rejected = 'REJECTED',
  /** The merchant requested fulfillment for this fulfillment order. */
  Submitted = 'SUBMITTED',
  /**
   * The initial request status for the newly-created fulfillment orders. This is the only valid
   * request status for fulfillment orders that aren't assigned to a fulfillment service.
   *
   */
  Unsubmitted = 'UNSUBMITTED',
}

/** Return type for `fulfillmentOrderReschedule` mutation. */
export type FulfillmentOrderReschedulePayload = {
  __typename?: 'FulfillmentOrderReschedulePayload'
  /** The fulfillment order that was rescheduled. */
  fulfillmentOrder?: Maybe<FulfillmentOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<FulfillmentOrderRescheduleUserError>
}

/** An error that occurs during the execution of `FulfillmentOrderReschedule`. */
export type FulfillmentOrderRescheduleUserError = DisplayableError & {
  __typename?: 'FulfillmentOrderRescheduleUserError'
  /** The error code. */
  code?: Maybe<FulfillmentOrderRescheduleUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `FulfillmentOrderRescheduleUserError`. */
export enum FulfillmentOrderRescheduleUserErrorCode {
  /** Fulfillment order could not be found. */
  FulfillmentOrderNotFound = 'FULFILLMENT_ORDER_NOT_FOUND',
}

/** The set of valid sort keys for the FulfillmentOrder query. */
export enum FulfillmentOrderSortKeys {
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/** The status of a fulfillment order. */
export enum FulfillmentOrderStatus {
  /** The fulfillment order has been cancelled by the merchant. */
  Cancelled = 'CANCELLED',
  /** The fulfillment order has been completed and closed. */
  Closed = 'CLOSED',
  /** The fulfillment order cannot be completed as requested. */
  Incomplete = 'INCOMPLETE',
  /** The fulfillment order is being processed. */
  InProgress = 'IN_PROGRESS',
  /** The fulfillment order is on hold. The fulfillment process can't be initiated until the hold on the fulfillment order is released. */
  OnHold = 'ON_HOLD',
  /** The fulfillment order is ready for fulfillment. */
  Open = 'OPEN',
  /** The fulfillment order is deferred and will be ready for fulfillment after the date and time specified in `fulfill_at`. */
  Scheduled = 'SCHEDULED',
}

/** Return type for `fulfillmentOrderSubmitCancellationRequest` mutation. */
export type FulfillmentOrderSubmitCancellationRequestPayload = {
  __typename?: 'FulfillmentOrderSubmitCancellationRequestPayload'
  /** The fulfillment order specified in the cancelation request. */
  fulfillmentOrder?: Maybe<FulfillmentOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `fulfillmentOrderSubmitFulfillmentRequest` mutation. */
export type FulfillmentOrderSubmitFulfillmentRequestPayload = {
  __typename?: 'FulfillmentOrderSubmitFulfillmentRequestPayload'
  /**
   * The original fulfillment order intended to request fulfillment for.
   *
   */
  originalFulfillmentOrder?: Maybe<FulfillmentOrder>
  /**
   * The fulfillment order that was submitted to the fulfillment service. This will be the same as
   * the original fulfillment order field. The exception to this is partial fulfillment requests or
   * fulfillment request for cancelled or incomplete fulfillment orders.
   *
   */
  submittedFulfillmentOrder?: Maybe<FulfillmentOrder>
  /**
   * This field will only be present for partial fulfillment requests. This will represent the new
   * fulfillment order with the remaining line items not submitted to the fulfillment service.
   *
   */
  unsubmittedFulfillmentOrder?: Maybe<FulfillmentOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * One of the actions that the fulfillment order supports in its current state.
 *
 */
export type FulfillmentOrderSupportedAction = {
  __typename?: 'FulfillmentOrderSupportedAction'
  /** The action value. */
  action: FulfillmentOrderAction
  /**
   * The external URL to be used to initiate the fulfillment process outside Shopify.
   * Applicable only when the `action` value is `EXTERNAL`.
   *
   */
  externalUrl?: Maybe<Scalars['URL']>
}

/** The address at which the fulfillment occurred. Typically this is the address of the warehouse or fulfillment center. */
export type FulfillmentOriginAddress = {
  __typename?: 'FulfillmentOriginAddress'
  /** The street address of the fulfillment location. */
  address1?: Maybe<Scalars['String']>
  /** The second line of the address. Typically the number of the apartment, suite, or unit. */
  address2?: Maybe<Scalars['String']>
  /** The city in which the fulfillment location is located. */
  city?: Maybe<Scalars['String']>
  /** The country code of the fulfillment location. */
  countryCode: Scalars['String']
  /** The province code of the fulfillment location. */
  provinceCode?: Maybe<Scalars['String']>
  /** The zip code of the fulfillment location. */
  zip?: Maybe<Scalars['String']>
}

/** The input fields used to include the address at which the fulfillment occurred. Typically the address of a warehouse or a fulfillment center. */
export type FulfillmentOriginAddressInput = {
  /** The street address of the fulfillment location. */
  address1?: InputMaybe<Scalars['String']>
  /** The second line of the address. Typically the number of the apartment, suite, or unit. */
  address2?: InputMaybe<Scalars['String']>
  /** The city in which the fulfillment location is located. */
  city?: InputMaybe<Scalars['String']>
  /** The country of the fulfillment location. */
  countryCode: Scalars['String']
  /** The province of the fulfillment location. */
  provinceCode?: InputMaybe<Scalars['String']>
  /** The zip code of the fulfillment location. */
  zip?: InputMaybe<Scalars['String']>
}

/**
 * Represents a fulfillment service. A fulfillment service is a third-party service that prepares and ships orders on behalf of the store owner.
 *
 */
export type FulfillmentService = {
  __typename?: 'FulfillmentService'
  /** The callback URL the fulfillment service has registered for requests. */
  callbackUrl?: Maybe<Scalars['URL']>
  /** Whether the fulfillment service has opted into fulfillment order based requests. */
  fulfillmentOrdersOptIn: Scalars['Boolean']
  /** Human-readable unique identifier for this fulfillment service. */
  handle: Scalars['String']
  /** The ID of the fulfillment service. */
  id: Scalars['ID']
  /** Whether the fulfillment service tracks product inventory and provides updates to Shopify. */
  inventoryManagement: Scalars['Boolean']
  /** Location associated with the fulfillment service. */
  location?: Maybe<Location>
  /** Whether the fulfillment service supports local deliveries. */
  productBased: Scalars['Boolean']
  /** The name of the fulfillment service as seen by merchants. */
  serviceName: Scalars['String']
  /** Shipping methods associated with the fulfillment service provider. */
  shippingMethods: Array<ShippingMethod>
  /** Type associated with the fulfillment service. */
  type: FulfillmentServiceType
}

/** Return type for `fulfillmentServiceCreate` mutation. */
export type FulfillmentServiceCreatePayload = {
  __typename?: 'FulfillmentServiceCreatePayload'
  /** The created fulfillment service. */
  fulfillmentService?: Maybe<FulfillmentService>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `fulfillmentServiceDelete` mutation. */
export type FulfillmentServiceDeletePayload = {
  __typename?: 'FulfillmentServiceDeletePayload'
  /** The ID of the deleted fulfillment service. */
  deletedId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** The type of a fulfillment service. */
export enum FulfillmentServiceType {
  /** Fulfillment by gift card. */
  GiftCard = 'GIFT_CARD',
  /** Manual fulfillment by the merchant. */
  Manual = 'MANUAL',
  /** Fullfillment by a third-party fulfillment service. */
  ThirdParty = 'THIRD_PARTY',
}

/** Return type for `fulfillmentServiceUpdate` mutation. */
export type FulfillmentServiceUpdatePayload = {
  __typename?: 'FulfillmentServiceUpdatePayload'
  /** The updated fulfillment service. */
  fulfillmentService?: Maybe<FulfillmentService>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** The status of a fulfillment. */
export enum FulfillmentStatus {
  /** The fulfillment was canceled. */
  Cancelled = 'CANCELLED',
  /** There was an error with the fulfillment request. */
  Error = 'ERROR',
  /** The fulfillment request failed. */
  Failure = 'FAILURE',
  /**
   * The third-party fulfillment service has acknowledged the fulfillment and is processing it.
   *
   */
  Open = 'OPEN',
  /**
   * Shopify has created the fulfillment and is waiting for the third-party fulfillment service to transition it to `open` or `success`.
   *
   */
  Pending = 'PENDING',
  /** The fulfillment was completed successfully. */
  Success = 'SUCCESS',
}

/** Represents the tracking information for a fulfillment. */
export type FulfillmentTrackingInfo = {
  __typename?: 'FulfillmentTrackingInfo'
  /** The name of the tracking company. */
  company?: Maybe<Scalars['String']>
  /** The tracking number of the fulfillment. */
  number?: Maybe<Scalars['String']>
  /** The URLs to track the fulfillment. */
  url?: Maybe<Scalars['URL']>
}

/** Return type for `fulfillmentTrackingInfoUpdate` mutation. */
export type FulfillmentTrackingInfoUpdatePayload = {
  __typename?: 'FulfillmentTrackingInfoUpdatePayload'
  /** The updated fulfillment with tracking information. */
  fulfillment?: Maybe<Fulfillment>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `fulfillmentTrackingInfoUpdateV2` mutation. */
export type FulfillmentTrackingInfoUpdateV2Payload = {
  __typename?: 'FulfillmentTrackingInfoUpdateV2Payload'
  /** The updated fulfillment with tracking information. */
  fulfillment?: Maybe<Fulfillment>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** The input fields that specify all possible fields for tracking information. */
export type FulfillmentTrackingInput = {
  /** The name of the tracking company. */
  company?: InputMaybe<Scalars['String']>
  /** The tracking number of the fulfillment. */
  number?: InputMaybe<Scalars['String']>
  /** The URL to track the fulfillment. */
  url?: InputMaybe<Scalars['URL']>
}

/** The input fields used to create a fulfillment from fulfillment orders. */
export type FulfillmentV2Input = {
  /**
   * Pairs of `fulfillment_order_id` and `fulfillment_order_line_items` that represent the fulfillment
   * order line items that have to be fulfilled for each fulfillment order.  For any given pair, if the
   * fulfillment order line items are left blank then all the fulfillment order line items of the
   * associated fulfillment order ID will be fulfilled.
   *
   */
  lineItemsByFulfillmentOrder: Array<FulfillmentOrderLineItemsInput>
  /**
   * Whether the customer is notified.
   * If `true`, then a notification is sent when the fulfillment is created.
   *
   */
  notifyCustomer?: InputMaybe<Scalars['Boolean']>
  /**
   * Address information about the location from which the order was fulfilled.
   *
   */
  originAddress?: InputMaybe<FulfillmentOriginAddressInput>
  /**
   * The fulfillment's tracking information, including a tracking URL, a tracking number,
   * and the company associated with the fulfillment.
   *
   */
  trackingInfo?: InputMaybe<FulfillmentTrackingInput>
}

/** A generic file. */
export type GenericFile = File &
  Node & {
    __typename?: 'GenericFile'
    /** A word or phrase to describe the contents or the function of a file. */
    alt?: Maybe<Scalars['String']>
    /**
     * The date and time ([ISO 8601 format](http://en.wikipedia.org/wiki/ISO_8601)) when the product was created.
     *
     */
    createdAt: Scalars['DateTime']
    /** Any errors that have occurred on the file. */
    fileErrors: Array<FileError>
    /** The status of the file. */
    fileStatus: FileStatus
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The preview image for the media. */
    preview?: Maybe<MediaPreviewImage>
    /** The URL of the file. */
    url?: Maybe<Scalars['URL']>
  }

/** Represents an issued gift card. */
export type GiftCard = Node & {
  __typename?: 'GiftCard'
  /** The gift card's remaining balance. */
  balance: MoneyV2
  /** The date and time at which the gift card was created. */
  createdAt: Scalars['DateTime']
  /** The customer who will receive the gift card. */
  customer?: Maybe<Customer>
  /** The date and time at which the gift card was disabled. */
  disabledAt?: Maybe<Scalars['DateTime']>
  /** Whether the gift card is enabled. */
  enabled: Scalars['Boolean']
  /** The date at which the gift card will expire. */
  expiresOn?: Maybe<Scalars['Date']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The initial value of the gift card. */
  initialValue: MoneyV2
  /** The final four characters of the gift card code. */
  lastCharacters: Scalars['String']
  /** The gift card code. Everything but the final four characters is masked. */
  maskedCode: Scalars['String']
  /** The note associated with the gift card, which is not visible to the customer. */
  note?: Maybe<Scalars['String']>
  /**
   * The order associated with the gift card. This value is `null` if the gift card was issued manually.
   *
   */
  order?: Maybe<Order>
}

/**
 * An auto-generated type for paginating through multiple GiftCards.
 *
 */
export type GiftCardConnection = {
  __typename?: 'GiftCardConnection'
  /** A list of edges. */
  edges: Array<GiftCardEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Specifies the input fields to issue a gift card. */
export type GiftCardCreateInput = {
  /**
   * The gift card's code. It must be 8-20 characters long and contain only letters(a-z) and numbers(0-9).
   * It is not case sensitive. If not provided, then a random code will be generated.
   *
   */
  code?: InputMaybe<Scalars['String']>
  /** The ID of the customer who will receive the gift card. Requires `write_customers` access_scope. */
  customerId?: InputMaybe<Scalars['ID']>
  /**
   * The date at which the gift card will expire. If not provided, then the gift card will never expire.
   *
   */
  expiresOn?: InputMaybe<Scalars['Date']>
  /** The initial value of the gift card. */
  initialValue: Scalars['Decimal']
  /** The note associated with the gift card, which is not visible to the customer. */
  note?: InputMaybe<Scalars['String']>
  /**
   * The suffix of the Liquid template that is used to render the gift card online.
   * For example, if the value is `birthday`, then the gift card is rendered using the template `gift_card.birthday.liquid`.
   * If not provided, then the default `gift_card.liquid` template is used.
   *
   */
  templateSuffix?: InputMaybe<Scalars['String']>
}

/** Return type for `giftCardCreate` mutation. */
export type GiftCardCreatePayload = {
  __typename?: 'GiftCardCreatePayload'
  /** The created gift card. */
  giftCard?: Maybe<GiftCard>
  /** The created gift card's code. */
  giftCardCode?: Maybe<Scalars['String']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<GiftCardUserError>
}

/** Return type for `giftCardDisable` mutation. */
export type GiftCardDisablePayload = {
  __typename?: 'GiftCardDisablePayload'
  /** The disabled gift card. */
  giftCard?: Maybe<GiftCard>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one GiftCard and a cursor during pagination.
 *
 */
export type GiftCardEdge = {
  __typename?: 'GiftCardEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of GiftCardEdge. */
  node: GiftCard
}

/** Possible error codes that can be returned by `GiftCardUserError`. */
export enum GiftCardErrorCode {
  /** The input value should be greater than the minimum allowed value. */
  GreaterThan = 'GREATER_THAN',
  /** Unexpected internal error happened. */
  InternalError = 'INTERNAL_ERROR',
  /** The input value is invalid. */
  Invalid = 'INVALID',
  /** Missing a required argument. */
  MissingArgument = 'MISSING_ARGUMENT',
  /** The input value is already taken. */
  Taken = 'TAKEN',
  /** The input value is too long. */
  TooLong = 'TOO_LONG',
  /** The input value is too short. */
  TooShort = 'TOO_SHORT',
}

/** A sale associated with a gift card. */
export type GiftCardSale = Sale & {
  __typename?: 'GiftCardSale'
  /** The type of order action that the sale represents. */
  actionType: SaleActionType
  /** The unique identifier for the sale. */
  id: Scalars['ID']
  /** The line item for the associated sale. */
  lineItem: LineItem
  /** The line type assocated with the sale. */
  lineType: SaleLineType
  /** The number of units either ordered or intended to be returned. */
  quantity?: Maybe<Scalars['Int']>
  /** All individual taxes associated with the sale. */
  taxes: Array<SaleTax>
  /** The total sale amount after taxes and discounts. */
  totalAmount: MoneyBag
  /** The total discounts allocated to the sale after taxes. */
  totalDiscountAmountAfterTaxes: MoneyBag
  /** The total discounts allocated to the sale before taxes. */
  totalDiscountAmountBeforeTaxes: MoneyBag
  /** The total amount of taxes for the sale. */
  totalTaxAmount: MoneyBag
}

/** The set of valid sort keys for the GiftCard query. */
export enum GiftCardSortKeys {
  /** Sort by the `amount_spent` value. */
  AmountSpent = 'AMOUNT_SPENT',
  /** Sort by the `balance` value. */
  Balance = 'BALANCE',
  /** Sort by the `code` value. */
  Code = 'CODE',
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `customer_name` value. */
  CustomerName = 'CUSTOMER_NAME',
  /** Sort by the `disabled_at` value. */
  DisabledAt = 'DISABLED_AT',
  /** Sort by the `expires_on` value. */
  ExpiresOn = 'EXPIRES_ON',
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `initial_value` value. */
  InitialValue = 'INITIAL_VALUE',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
  /** Sort by the `updated_at` value. */
  UpdatedAt = 'UPDATED_AT',
}

/** Specifies the input fields to update a gift card. */
export type GiftCardUpdateInput = {
  /**
   * The ID of the customer who will receive the gift card. The ID cannot be changed if the gift card already has an assigned customer ID.
   *
   */
  customerId?: InputMaybe<Scalars['ID']>
  /**
   * The date at which the gift card will expire. If set to `null`, then the gift card will never expire.
   *
   */
  expiresOn?: InputMaybe<Scalars['Date']>
  /** The note associated with the gift card, which is not visible to the customer. */
  note?: InputMaybe<Scalars['String']>
  /**
   * The suffix of the Liquid template that is used to render the gift card online.
   * For example, if the value is `birthday`, then the gift card is rendered using the template `gift_card.birthday.liquid`.
   *
   */
  templateSuffix?: InputMaybe<Scalars['String']>
}

/** Return type for `giftCardUpdate` mutation. */
export type GiftCardUpdatePayload = {
  __typename?: 'GiftCardUpdatePayload'
  /** The updated gift card. */
  giftCard?: Maybe<GiftCard>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Represents an error that happens during the execution of a gift card mutation. */
export type GiftCardUserError = DisplayableError & {
  __typename?: 'GiftCardUserError'
  /** The error code. */
  code?: Maybe<GiftCardErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Represents an object that has a list of events. */
export type HasEvents = {
  /** The paginated list of events associated with the host subject. */
  events: EventConnection
}

/** Represents an object that has a list of events. */
export type HasEventsEventsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<EventSortKeys>
}

/**
 * Localization extensions associated with the specified resource. For example, the tax id for government invoice.
 *
 */
export type HasLocalizationExtensions = {
  /** List of localization extensions for the resource. */
  localizationExtensions: LocalizationExtensionConnection
}

/**
 * Localization extensions associated with the specified resource. For example, the tax id for government invoice.
 *
 */
export type HasLocalizationExtensionsLocalizationExtensionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  countryCodes?: InputMaybe<Array<CountryCode>>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  purposes?: InputMaybe<Array<LocalizationExtensionPurpose>>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Resources that metafield definitions can be applied to. */
export type HasMetafieldDefinitions = {
  /** List of metafield definitions. */
  metafieldDefinitions: MetafieldDefinitionConnection
}

/** Resources that metafield definitions can be applied to. */
export type HasMetafieldDefinitionsMetafieldDefinitionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  pinnedStatus?: InputMaybe<MetafieldDefinitionPinnedStatus>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<MetafieldDefinitionSortKeys>
}

/** Represents information about the metafields associated to the specified resource. */
export type HasMetafields = {
  /** Returns a metafield by namespace and key that belongs to the resource. */
  metafield?: Maybe<Metafield>
  /** List of metafields that belong to the resource. */
  metafields: MetafieldConnection
  /** Returns a private metafield by namespace and key that belongs to the resource. */
  privateMetafield?: Maybe<PrivateMetafield>
  /** List of private metafields that belong to the resource. */
  privateMetafields: PrivateMetafieldConnection
}

/** Represents information about the metafields associated to the specified resource. */
export type HasMetafieldsMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/** Represents information about the metafields associated to the specified resource. */
export type HasMetafieldsMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents information about the metafields associated to the specified resource. */
export type HasMetafieldsPrivateMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/** Represents information about the metafields associated to the specified resource. */
export type HasMetafieldsPrivateMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Published translations associated with the resource. */
export type HasPublishedTranslations = {
  /** The translations associated with the resource. */
  translations: Array<PublishedTranslation>
}

/** Published translations associated with the resource. */
export type HasPublishedTranslationsTranslationsArgs = {
  locale: Scalars['String']
}

/** Represents an image resource. */
export type Image = HasMetafields & {
  __typename?: 'Image'
  /** A word or phrase to share the nature or contents of an image. */
  altText?: Maybe<Scalars['String']>
  /** The original height of the image in pixels. Returns `null` if the image is not hosted by Shopify. */
  height?: Maybe<Scalars['Int']>
  /** A unique identifier for the image. */
  id?: Maybe<Scalars['ID']>
  /** Returns a metafield by namespace and key that belongs to the resource. */
  metafield?: Maybe<Metafield>
  /** List of metafields that belong to the resource. */
  metafields: MetafieldConnection
  /**
   * The location of the original image as a URL.
   *
   * If there are any existing transformations in the original source URL, they will remain and not be stripped.
   *
   * @deprecated Use `url` instead
   */
  originalSrc: Scalars['URL']
  /** Returns a private metafield by namespace and key that belongs to the resource. */
  privateMetafield?: Maybe<PrivateMetafield>
  /** List of private metafields that belong to the resource. */
  privateMetafields: PrivateMetafieldConnection
  /**
   * The location of the image as a URL.
   * @deprecated Use `url` instead
   */
  src: Scalars['URL']
  /**
   * The location of the transformed image as a URL.
   *
   * All transformation arguments are considered "best-effort". If they can be applied to an image, they will be.
   * Otherwise any transformations which an image type does not support will be ignored.
   *
   * @deprecated Use `url(transform:)` instead
   */
  transformedSrc: Scalars['URL']
  /**
   * The location of the image as a URL.
   *
   * If no transform options are specified, then the original image will be preserved including any pre-applied transforms.
   *
   * All transformation options are considered "best-effort". Any transformation that the original image type doesn't support will be ignored.
   *
   * If you need multiple variations of the same image, then you can use [GraphQL aliases](https://graphql.org/learn/queries/#aliases).
   *
   */
  url: Scalars['URL']
  /** The original width of the image in pixels. Returns `null` if the image is not hosted by Shopify. */
  width?: Maybe<Scalars['Int']>
}

/** Represents an image resource. */
export type ImageMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/** Represents an image resource. */
export type ImageMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents an image resource. */
export type ImagePrivateMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/** Represents an image resource. */
export type ImagePrivateMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents an image resource. */
export type ImageTransformedSrcArgs = {
  crop?: InputMaybe<CropRegion>
  maxHeight?: InputMaybe<Scalars['Int']>
  maxWidth?: InputMaybe<Scalars['Int']>
  preferredContentType?: InputMaybe<ImageContentType>
  scale?: InputMaybe<Scalars['Int']>
}

/** Represents an image resource. */
export type ImageUrlArgs = {
  transform?: InputMaybe<ImageTransformInput>
}

/**
 * An auto-generated type for paginating through multiple Images.
 *
 */
export type ImageConnection = {
  __typename?: 'ImageConnection'
  /** A list of edges. */
  edges: Array<ImageEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** List of supported image content types. */
export enum ImageContentType {
  /** A JPG image. */
  Jpg = 'JPG',
  /** A PNG image. */
  Png = 'PNG',
  /** A WEBP image. */
  Webp = 'WEBP',
}

/**
 * An auto-generated type which holds one Image and a cursor during pagination.
 *
 */
export type ImageEdge = {
  __typename?: 'ImageEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of ImageEdge. */
  node: Image
}

/** Specifies the input fields for an image. */
export type ImageInput = {
  /** A word or phrase to share the nature or contents of an image. */
  altText?: InputMaybe<Scalars['String']>
  /** A globally-unique identifier. */
  id?: InputMaybe<Scalars['ID']>
  /** The URL of the image. May be a signed upload URL. */
  src?: InputMaybe<Scalars['String']>
}

/**
 * The available options for transforming an image.
 *
 * All transformation options are considered "best-effort". Any transformation that the original image type doesn't support will be ignored.
 *
 */
export type ImageTransformInput = {
  /** Crop the image according to the specified region. */
  crop?: InputMaybe<CropRegion>
  /**
   * Image height in pixels between 1 and 5760.
   *
   */
  maxHeight?: InputMaybe<Scalars['Int']>
  /**
   * Image width in pixels between 1 and 5760.
   *
   */
  maxWidth?: InputMaybe<Scalars['Int']>
  /**
   * Convert the source image into the preferred content type.
   * Supported conversions: `.svg` to `.png`, any file type to `.jpg`, and any file type to `.webp`.
   *
   */
  preferredContentType?: InputMaybe<ImageContentType>
  /**
   * Image size multiplier for high-resolution retina displays. Must be within 1..3.
   *
   */
  scale?: InputMaybe<Scalars['Int']>
}

/** Upload parameter of an image. */
export type ImageUploadParameter = {
  __typename?: 'ImageUploadParameter'
  /** Parameter name. */
  name: Scalars['String']
  /** Parameter value. */
  value: Scalars['String']
}

/** Return type for `inventoryActivate` mutation. */
export type InventoryActivatePayload = {
  __typename?: 'InventoryActivatePayload'
  /** The inventory level that was activated. */
  inventoryLevel?: Maybe<InventoryLevel>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Specifies the items and their adjustments. */
export type InventoryAdjustItemInput = {
  /** The change applied to the `available` quantity of the item at the location. */
  availableDelta: Scalars['Int']
  /** ID of the inventory item to adjust. */
  inventoryItemId: Scalars['ID']
}

/** Specifies the fields required to adjust the inventory quantity. */
export type InventoryAdjustQuantityInput = {
  /** The change applied to the `available` quantity of the item at the location. */
  availableDelta: Scalars['Int']
  /** ID of the inventory level to adjust. */
  inventoryLevelId: Scalars['ID']
}

/** Return type for `inventoryAdjustQuantity` mutation. */
export type InventoryAdjustQuantityPayload = {
  __typename?: 'InventoryAdjustQuantityPayload'
  /** Represents the updated inventory quantity of an inventory item at a specific location. */
  inventoryLevel?: Maybe<InventoryLevel>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `inventoryBulkAdjustQuantityAtLocation` mutation. */
export type InventoryBulkAdjustQuantityAtLocationPayload = {
  __typename?: 'InventoryBulkAdjustQuantityAtLocationPayload'
  /** Represents the updated inventory quantities of an inventory item at the location. */
  inventoryLevels?: Maybe<Array<InventoryLevel>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `inventoryDeactivate` mutation. */
export type InventoryDeactivatePayload = {
  __typename?: 'InventoryDeactivatePayload'
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * Represents the goods available to be shipped to a customer.
 * It holds essential information about the goods, including SKU and whether it is tracked.
 *
 */
export type InventoryItem = LegacyInteroperability &
  Node & {
    __typename?: 'InventoryItem'
    /** The ISO 3166-1 alpha-2 country code of where the item originated from. */
    countryCodeOfOrigin?: Maybe<CountryCode>
    /** A list of country specific harmonized system codes. */
    countryHarmonizedSystemCodes: CountryHarmonizedSystemCodeConnection
    /** The date and time when the inventory item was created. */
    createdAt: Scalars['DateTime']
    /** The number of inventory items that share the same SKU with this item. */
    duplicateSkuCount: Scalars['Int']
    /** The harmonized system code of the item. */
    harmonizedSystemCode?: Maybe<Scalars['String']>
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The URL that points to the inventory history for the item. */
    inventoryHistoryUrl?: Maybe<Scalars['URL']>
    /** The inventory item's quantities at the specified location. */
    inventoryLevel?: Maybe<InventoryLevel>
    /** A list of the inventory item's quantities for each location that the inventory item can be stocked at. */
    inventoryLevels: InventoryLevelConnection
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** The number of locations where this inventory item is stocked. */
    locationsCount: Scalars['Int']
    /** The ISO 3166-2 alpha-2 province code of where the item originated from. */
    provinceCodeOfOrigin?: Maybe<Scalars['String']>
    /** Whether the inventory item requires shipping. */
    requiresShipping: Scalars['Boolean']
    /** Inventory item SKU. */
    sku?: Maybe<Scalars['String']>
    /** Whether inventory levels are tracked for the item. */
    tracked: Scalars['Boolean']
    /** Whether the value of the `tracked` field for the inventory item can be changed. */
    trackedEditable: EditableProperty
    /** Unit cost associated with the inventory item. */
    unitCost?: Maybe<MoneyV2>
    /** The date and time when the inventory item was updated. */
    updatedAt: Scalars['DateTime']
    /** The variant that owns this inventory item. */
    variant: ProductVariant
  }

/**
 * Represents the goods available to be shipped to a customer.
 * It holds essential information about the goods, including SKU and whether it is tracked.
 *
 */
export type InventoryItemCountryHarmonizedSystemCodesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents the goods available to be shipped to a customer.
 * It holds essential information about the goods, including SKU and whether it is tracked.
 *
 */
export type InventoryItemInventoryLevelArgs = {
  locationId: Scalars['ID']
}

/**
 * Represents the goods available to be shipped to a customer.
 * It holds essential information about the goods, including SKU and whether it is tracked.
 *
 */
export type InventoryItemInventoryLevelsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An auto-generated type for paginating through multiple InventoryItems.
 *
 */
export type InventoryItemConnection = {
  __typename?: 'InventoryItemConnection'
  /** A list of edges. */
  edges: Array<InventoryItemEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one InventoryItem and a cursor during pagination.
 *
 */
export type InventoryItemEdge = {
  __typename?: 'InventoryItemEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of InventoryItemEdge. */
  node: InventoryItem
}

/** Specifies the input fields for an inventory item. */
export type InventoryItemInput = {
  /** Unit cost associated with the inventory item, the currency is the shop's default currency. */
  cost?: InputMaybe<Scalars['Decimal']>
  /** Whether the inventory item is tracked. */
  tracked?: InputMaybe<Scalars['Boolean']>
}

/** Inventory item. */
export type InventoryItemUpdateInput = {
  /** Unit cost associated with the inventory item, the currency is the shop's default currency. */
  cost?: InputMaybe<Scalars['Decimal']>
  /** The ISO 3166-1 alpha-2 country code of where the item originated from. */
  countryCodeOfOrigin?: InputMaybe<CountryCode>
  /** List of country-specific harmonized system codes. */
  countryHarmonizedSystemCodes?: InputMaybe<
    Array<CountryHarmonizedSystemCodeInput>
  >
  /** The harmonized system code of the inventory item. This must be a number between 6 and 13 digits. */
  harmonizedSystemCode?: InputMaybe<Scalars['String']>
  /** The ISO 3166-2 alpha-2 province/state code of where the item originated from. */
  provinceCodeOfOrigin?: InputMaybe<Scalars['String']>
  /** Whether the inventory item is tracked. The value must be true to adjust the item's inventory levels. */
  tracked?: InputMaybe<Scalars['Boolean']>
}

/** Return type for `inventoryItemUpdate` mutation. */
export type InventoryItemUpdatePayload = {
  __typename?: 'InventoryItemUpdatePayload'
  /** The inventory item that was updated. */
  inventoryItem?: Maybe<InventoryItem>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * The quantities of an inventory item that are related to a specific location.
 *
 */
export type InventoryLevel = Node & {
  __typename?: 'InventoryLevel'
  /** The quantity of inventory items that are available at the inventory level's associated location. */
  available: Scalars['Int']
  /** Whether the inventory items associated with the inventory level can be deactivated. */
  canDeactivate: Scalars['Boolean']
  /** The date and time when the inventory level was created. */
  createdAt: Scalars['DateTime']
  /** Describes either the impact of deactivating the inventory level, or why the inventory level can't be deactivated. */
  deactivationAlert?: Maybe<Scalars['String']>
  /** Describes, in HTML with embedded URLs, either the impact of deactivating the inventory level or why the inventory level can't be deactivated. */
  deactivationAlertHtml?: Maybe<Scalars['FormattedString']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The quantity of inventory items that are going to the inventory level's associated location. */
  incoming: Scalars['Int']
  /** Inventory item associated with the inventory level. */
  item: InventoryItem
  /** The location associated with the inventory level. */
  location: Location
  /** The date and time when the inventory level was updated. */
  updatedAt: Scalars['DateTime']
}

/**
 * An auto-generated type for paginating through multiple InventoryLevels.
 *
 */
export type InventoryLevelConnection = {
  __typename?: 'InventoryLevelConnection'
  /** A list of edges. */
  edges: Array<InventoryLevelEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one InventoryLevel and a cursor during pagination.
 *
 */
export type InventoryLevelEdge = {
  __typename?: 'InventoryLevelEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of InventoryLevelEdge. */
  node: InventoryLevel
}

/** Specifies the input fields for an inventory level. */
export type InventoryLevelInput = {
  /** The available quantity of an inventory item at a location. */
  availableQuantity: Scalars['Int']
  /** The ID of a location. */
  locationId: Scalars['ID']
}

/** A job corresponds to some long running task that the client should poll for status. */
export type Job = {
  __typename?: 'Job'
  /** This indicates if the job is still queued or has been run. */
  done: Scalars['Boolean']
  /** A globally-unique identifier that's returned when running an asynchronous mutation. */
  id: Scalars['ID']
  /** This field will only resolve once the job is done. Can be used to ask for object(s) that have been changed by the job. */
  query?: Maybe<QueryRoot>
}

/**
 * Interoperability metadata for types that directly correspond to a REST Admin API resource.
 * For example, on the Product type, LegacyInteroperability returns metadata for the corresponding [Product object](https://shopify.dev/api/admin-graphql/latest/objects/product) in the REST Admin API.
 *
 */
export type LegacyInteroperability = {
  /** The ID of the corresponding resource in the REST Admin API. */
  legacyResourceId: Scalars['UnsignedInt64']
}

/**
 * The total number of pending orders on a shop if less then a maximum, or that maximum.
 * The atMax field indicates when this maximum has been reached.
 *
 */
export type LimitedPendingOrderCount = {
  __typename?: 'LimitedPendingOrderCount'
  /** This is set when the number of pending orders has reached the maximum. */
  atMax: Scalars['Boolean']
  /**
   * The number of pendings orders on the shop.
   * Limited to a maximum of 10000.
   *
   */
  count: Scalars['Int']
}

/** Represents a single line item on an order. */
export type LineItem = Node & {
  __typename?: 'LineItem'
  /**
   * Whether the line item can be restocked.
   * @deprecated Use `restockable` instead
   */
  canRestock: Scalars['Boolean']
  /** The subscription contract associated with this line item. */
  contract?: Maybe<SubscriptionContract>
  /** The line item's quantity, minus the removed quantity. */
  currentQuantity: Scalars['Int']
  /** A list of additional information about the line item. */
  customAttributes: Array<Attribute>
  /** The discounts that have been allocated onto the line item by discount applications. */
  discountAllocations: Array<DiscountAllocation>
  /**
   * The total line price after discounts are applied, in shop currency.
   * @deprecated Use `discountedTotalSet` instead
   */
  discountedTotal: Scalars['Money']
  /** The total line price after discounts are applied, in shop and presentment currencies. */
  discountedTotalSet: MoneyBag
  /**
   * The approximate split price of a line item unit, in shop currency. This value doesn't include discounts applied to the entire order.
   * @deprecated Use `discountedUnitPriceSet` instead
   */
  discountedUnitPrice: Scalars['Money']
  /** The approximate split price of a line item unit, in shop and presentment currencies. This value doesn't include discounts applied to the entire order. */
  discountedUnitPriceSet: MoneyBag
  /** The duties associated with the line item. */
  duties: Array<Duty>
  /**
   * The total number of units to fulfill.
   * @deprecated Use [FulfillmentOrderLineItem#remainingQuantity](https://shopify.dev/api/admin-graphql/latest/objects/FulfillmentOrderLineItem#field-fulfillmentorderlineitem-remainingquantity) instead.
   */
  fulfillableQuantity: Scalars['Int']
  /**
   * The service provider that fulfills the line item.
   *
   * Deleted fulfillment services will return null.
   *
   * @deprecated Use [FulfillmentOrder#assignedLocation](https://shopify.dev/api/admin-graphql/latest/objects/FulfillmentOrder#field-fulfillmentorder-assignedlocation) instead.
   */
  fulfillmentService?: Maybe<FulfillmentService>
  /**
   * The line item's fulfillment status. Returns 'fulfilled' if fulfillableQuantity >= quantity,
   * 'partial' if  fulfillableQuantity > 0, and 'unfulfilled' otherwise.
   *
   * @deprecated Use [FulfillmentOrderLineItem#remainingQuantity](https://shopify.dev/api/admin-graphql/latest/objects/FulfillmentOrderLineItem#field-fulfillmentorderlineitem-remainingquantity) instead
   */
  fulfillmentStatus: Scalars['String']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The image associated to the line item's variant. */
  image?: Maybe<Image>
  /** Whether the line item can be edited or not. */
  merchantEditable: Scalars['Boolean']
  /** The name of the product. */
  name: Scalars['String']
  /**
   * The total number of units that can't be fulfilled.
   *         For example, if items have been refunded, or the item is not something that can be fulfilled,
   *         like a tip.Please see the [FulfillmentOrder](https://shopify.dev/api/admin-graphql/latest/objects/FulfillmentOrder) object for more fulfillment details.
   */
  nonFulfillableQuantity: Scalars['Int']
  /**
   * The total price without discounts applied, in shop currency.
   * This value is based on the unit price of the variant x quantity.
   *
   * @deprecated Use `originalTotalSet` instead
   */
  originalTotal: Scalars['Money']
  /** The total price in shop and presentment currencies, without discounts applied. This value is based on the unit price of the variant x quantity. */
  originalTotalSet: MoneyBag
  /**
   * The variant unit price without discounts applied, in shop currency.
   * @deprecated Use `originalUnitPriceSet` instead
   */
  originalUnitPrice: Scalars['Money']
  /** The variant unit price without discounts applied, in shop and presentment currencies. */
  originalUnitPriceSet: MoneyBag
  /** The Product object associated with this line item's variant. */
  product?: Maybe<Product>
  /** The number of variant units ordered. */
  quantity: Scalars['Int']
  /** The line item's quantity, minus the removed quantity. */
  refundableQuantity: Scalars['Int']
  /** Whether physical shipping is required for the variant. */
  requiresShipping: Scalars['Boolean']
  /** Whether the line item can be restocked. */
  restockable: Scalars['Boolean']
  /** The selling plan details associated with the line item. */
  sellingPlan?: Maybe<LineItemSellingPlan>
  /** The variant SKU number. */
  sku?: Maybe<Scalars['String']>
  /** The taxes charged for this line item. */
  taxLines: Array<TaxLine>
  /** Whether the variant is taxable. */
  taxable: Scalars['Boolean']
  /** The title of the product. */
  title: Scalars['String']
  /**
   * The sum of all AppliedDiscounts on this line item, in shop currency.
   * @deprecated Use `totalDiscountSet` instead
   */
  totalDiscount: Scalars['Money']
  /** The sum of all AppliedDiscounts on this line item, in shop and presentment currencies. */
  totalDiscountSet: MoneyBag
  /**
   * The total discounted value of unfulfilled units, in shop currency.
   * @deprecated Use `unfulfilledDiscountedTotalSet` instead
   */
  unfulfilledDiscountedTotal: Scalars['Money']
  /** The total discounted value of unfulfilled units, in shop and presentment currencies. */
  unfulfilledDiscountedTotalSet: MoneyBag
  /**
   * The total price, without any discounts applied. This value is based on the unit price of the variant x quantity of all unfulfilled units, in shop currency.
   * @deprecated Use `unfulfilledOriginalTotalSet` instead
   */
  unfulfilledOriginalTotal: Scalars['Money']
  /** The total price, without any discounts applied. This value is based on the unit price of the variant x quantity of all unfulfilled units, in shop and presentment currencies. */
  unfulfilledOriginalTotalSet: MoneyBag
  /** The number of units not yet fulfilled. */
  unfulfilledQuantity: Scalars['Int']
  /** The Variant object associated with this line item. */
  variant?: Maybe<ProductVariant>
  /** The name of the variant. */
  variantTitle?: Maybe<Scalars['String']>
  /** The name of the vendor who made the variant. */
  vendor?: Maybe<Scalars['String']>
}

/** Represents a single line item on an order. */
export type LineItemImageArgs = {
  crop?: InputMaybe<CropRegion>
  maxHeight?: InputMaybe<Scalars['Int']>
  maxWidth?: InputMaybe<Scalars['Int']>
  scale?: InputMaybe<Scalars['Int']>
}

/** Represents a single line item on an order. */
export type LineItemTaxLinesArgs = {
  first?: InputMaybe<Scalars['Int']>
}

/**
 * An auto-generated type for paginating through multiple LineItems.
 *
 */
export type LineItemConnection = {
  __typename?: 'LineItemConnection'
  /** A list of edges. */
  edges: Array<LineItemEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one LineItem and a cursor during pagination.
 *
 */
export type LineItemEdge = {
  __typename?: 'LineItemEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of LineItemEdge. */
  node: LineItem
}

/** Represents a single line item on an order. */
export type LineItemMutable = Node & {
  __typename?: 'LineItemMutable'
  /**
   * Whether the line item can be restocked.
   * @deprecated Use `restockable` instead
   */
  canRestock: Scalars['Boolean']
  /** A list of additional information about the line item. */
  customAttributes: Array<Attribute>
  /** The discounts that have been allocated onto the line item by discount applications. */
  discountAllocations: Array<DiscountAllocation>
  /**
   * The total line price after discounts are applied, in shop currency.
   * @deprecated Use `discountedTotalSet` instead
   */
  discountedTotal: Scalars['Money']
  /** The total line price after discounts are applied, in shop and presentment currencies. */
  discountedTotalSet: MoneyBag
  /**
   * The approximate split price of a line item unit, in shop currency. This value doesn't include discounts applied to the entire order.
   * @deprecated Use `discountedUnitPriceSet` instead
   */
  discountedUnitPrice: Scalars['Money']
  /** The approximate split price of a line item unit, in shop and presentment currencies. This value doesn't include discounts applied to the entire order. */
  discountedUnitPriceSet: MoneyBag
  /** The total number of units to fulfill. */
  fulfillableQuantity: Scalars['Int']
  /**
   * The service provider that fulfills the line item.
   *
   * Deleted fulfillment services will return null.
   *
   */
  fulfillmentService?: Maybe<FulfillmentService>
  /**
   * The line item's fulfillment status. Returns 'fulfilled' if fulfillableQuantity >= quantity,
   * 'partial' if  fulfillableQuantity > 0, and 'unfulfilled' otherwise.
   *
   */
  fulfillmentStatus: Scalars['String']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The image associated to the line item's variant. */
  image?: Maybe<Image>
  /** Whether the line item can be edited or not. */
  merchantEditable: Scalars['Boolean']
  /** The name of the product. */
  name: Scalars['String']
  /** The total number of units that can't be fulfilled. For example, if items have been refunded, or the item is not something that can be fulfilled, like a tip. */
  nonFulfillableQuantity: Scalars['Int']
  /**
   * The total price without any discounts applied, in shop currency. ""This value is based on the unit price of the variant x quantity.
   *
   * @deprecated Use `originalTotalSet` instead
   */
  originalTotal: Scalars['Money']
  /** The total price in shop and presentment currencies, without discounts applied. This value is based on the unit price of the variant x quantity. */
  originalTotalSet: MoneyBag
  /**
   * The variant unit price without discounts applied, in shop currency.
   * @deprecated Use `originalUnitPriceSet` instead
   */
  originalUnitPrice: Scalars['Money']
  /** The variant unit price without discounts applied, in shop and presentment currencies. */
  originalUnitPriceSet: MoneyBag
  /** The Product object associated with this line item's variant. */
  product?: Maybe<Product>
  /** The number of variant units ordered. */
  quantity: Scalars['Int']
  /** The line item's quantity, minus the removed quantity. */
  refundableQuantity: Scalars['Int']
  /** Whether physical shipping is required for the variant. */
  requiresShipping: Scalars['Boolean']
  /** Whether the line item can be restocked. */
  restockable: Scalars['Boolean']
  /** The variant SKU number. */
  sku?: Maybe<Scalars['String']>
  /** The TaxLine object connected to this line item. */
  taxLines: Array<TaxLine>
  /** Whether the variant is taxable. */
  taxable: Scalars['Boolean']
  /** The title of the product. */
  title: Scalars['String']
  /**
   * The sum of all AppliedDiscounts on this line item, in shop currency.
   * @deprecated Use `totalDiscountSet` instead
   */
  totalDiscount: Scalars['Money']
  /** The sum of all AppliedDiscounts on this line item in shop and presentment currencies. */
  totalDiscountSet: MoneyBag
  /**
   * The total discounted value of unfulfilled units, in shop currency.
   * @deprecated Use `unfulfilledDiscountedTotalSet` instead
   */
  unfulfilledDiscountedTotal: Scalars['Money']
  /** The total discounted value of unfulfilled units, in shop and presentment currencies. */
  unfulfilledDiscountedTotalSet: MoneyBag
  /**
   * The total price without any discounts applied. This value is based on the unit price of the variant x quantity of all unfulfilled units, in shop currency.
   * @deprecated Use `unfulfilledOriginalTotalSet` instead
   */
  unfulfilledOriginalTotal: Scalars['Money']
  /** The total price without any discounts applied. This value is based on the unit price of the variant x quantity of all unfulfilled units, in shop and presentment currencies. */
  unfulfilledOriginalTotalSet: MoneyBag
  /** The number of units not yet fulfilled. */
  unfulfilledQuantity: Scalars['Int']
  /** The Variant object associated with this line item. */
  variant?: Maybe<ProductVariant>
  /** The name of the variant. */
  variantTitle?: Maybe<Scalars['String']>
  /** The name of the vendor who made the variant. */
  vendor?: Maybe<Scalars['String']>
}

/** Represents a single line item on an order. */
export type LineItemMutableImageArgs = {
  crop?: InputMaybe<CropRegion>
  maxHeight?: InputMaybe<Scalars['Int']>
  maxWidth?: InputMaybe<Scalars['Int']>
  scale?: InputMaybe<Scalars['Int']>
}

/** Represents a single line item on an order. */
export type LineItemMutableTaxLinesArgs = {
  first?: InputMaybe<Scalars['Int']>
}

/**
 * An auto-generated type for paginating through multiple LineItemMutables.
 *
 */
export type LineItemMutableConnection = {
  __typename?: 'LineItemMutableConnection'
  /** A list of edges. */
  edges: Array<LineItemMutableEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one LineItemMutable and a cursor during pagination.
 *
 */
export type LineItemMutableEdge = {
  __typename?: 'LineItemMutableEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of LineItemMutableEdge. */
  node: LineItemMutable
}

/** Represents the selling plan for a line item. */
export type LineItemSellingPlan = {
  __typename?: 'LineItemSellingPlan'
  /** The name of the selling plan for display purposes. */
  name: Scalars['String']
}

/** A link to direct users to. */
export type Link = HasPublishedTranslations & {
  __typename?: 'Link'
  /** A context-sensitive label for the link. */
  label: Scalars['String']
  /** The translations associated with the resource. */
  translations: Array<PublishedTranslation>
  /** The URL that the link visits. */
  url: Scalars['URL']
}

/** A link to direct users to. */
export type LinkTranslationsArgs = {
  locale: Scalars['String']
}

/** A locale. */
export type Locale = {
  __typename?: 'Locale'
  /** Locale ISO code. */
  isoCode: Scalars['String']
  /** Human-readable locale name. */
  name: Scalars['String']
}

/** Represents the value captured by a localization extension. Localization extensions are additional fields required by certain countries on international orders. For example, some countries require additional fields for customs information or tax identification numbers. */
export type LocalizationExtension = {
  __typename?: 'LocalizationExtension'
  /** Country ISO 3166-1 alpha-2 code. */
  countryCode: CountryCode
  /** The localized extension keys that are allowed. */
  key: LocalizationExtensionKey
  /** The purpose of this localization extension. */
  purpose: LocalizationExtensionPurpose
  /** The localized extension title. */
  title: Scalars['String']
  /** The value of the field. */
  value: Scalars['String']
}

/**
 * An auto-generated type for paginating through multiple LocalizationExtensions.
 *
 */
export type LocalizationExtensionConnection = {
  __typename?: 'LocalizationExtensionConnection'
  /** A list of edges. */
  edges: Array<LocalizationExtensionEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one LocalizationExtension and a cursor during pagination.
 *
 */
export type LocalizationExtensionEdge = {
  __typename?: 'LocalizationExtensionEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of LocalizationExtensionEdge. */
  node: LocalizationExtension
}

/**
 * Specifies the input fields for a LocalizationExtensionInput.
 *
 */
export type LocalizationExtensionInput = {
  /** The key for the localization extension. */
  key: LocalizationExtensionKey
  /** The localization extension value. */
  value: Scalars['String']
}

/** The key of a localization extension. */
export enum LocalizationExtensionKey {
  /** Extension key 'shipping_credential_br' for country BR. */
  ShippingCredentialBr = 'SHIPPING_CREDENTIAL_BR',
  /** Extension key 'shipping_credential_cn' for country CN. */
  ShippingCredentialCn = 'SHIPPING_CREDENTIAL_CN',
  /** Extension key 'shipping_credential_kr' for country KR. */
  ShippingCredentialKr = 'SHIPPING_CREDENTIAL_KR',
  /** Extension key 'tax_credential_br' for country BR. */
  TaxCredentialBr = 'TAX_CREDENTIAL_BR',
  /** Extension key 'tax_credential_it' for country IT. */
  TaxCredentialIt = 'TAX_CREDENTIAL_IT',
  /** Extension key 'tax_email_it' for country IT. */
  TaxEmailIt = 'TAX_EMAIL_IT',
}

/** The purpose of a localization extension. */
export enum LocalizationExtensionPurpose {
  /** Extensions that are used for shipping purposes, for example, customs clearance. */
  Shipping = 'SHIPPING',
  /** Extensions that are used for taxes purposes, for example, invoicing. */
  Tax = 'TAX',
}

/**
 * Represents the location where the physical good resides.
 *
 */
export type Location = HasMetafieldDefinitions &
  LegacyInteroperability &
  Node & {
    __typename?: 'Location'
    /** Whether this location can be reactivated. */
    activatable: Scalars['Boolean']
    /** The address of this location. */
    address: LocationAddress
    /** Whether the location address has been verified. */
    addressVerified: Scalars['Boolean']
    /** Whether this location can be deactivated. */
    deactivatable: Scalars['Boolean']
    /** The date and time ([ISO 8601 format](http://en.wikipedia.org/wiki/ISO_8601)) that the location was deactivated at. For example, 3:30 pm on September 7, 2019 in the time zone of UTC (Universal Time Coordinated) is represented as `"2019-09-07T15:50:00Z`". */
    deactivatedAt?: Maybe<Scalars['String']>
    /** Whether this location can be deleted. */
    deletable: Scalars['Boolean']
    /** Name of the service provider that fulfills from this location. */
    fulfillmentService?: Maybe<FulfillmentService>
    /** Whether this location can fulfill online orders. */
    fulfillsOnlineOrders: Scalars['Boolean']
    /** Whether this location has active inventory. */
    hasActiveInventory: Scalars['Boolean']
    /** Whether this location has orders that need to be fulfilled. */
    hasUnfulfilledOrders: Scalars['Boolean']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The quantities of an inventory item at this location. */
    inventoryLevel?: Maybe<InventoryLevel>
    /** A list of the quantities of the inventory items that can be stocked at this location. */
    inventoryLevels: InventoryLevelConnection
    /** Whether the location is active. */
    isActive: Scalars['Boolean']
    /**
     * Whether the location is your primary location for shipping inventory.
     * @deprecated The concept of a primary location is deprecated, shipsInventory can be used to get a fallback location
     */
    isPrimary: Scalars['Boolean']
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** List of metafield definitions. */
    metafieldDefinitions: MetafieldDefinitionConnection
    /** The name of the location. */
    name: Scalars['String']
    /** Whether this location is used for calculating shipping rates. In multi-origin shipping mode, this flag is ignored. */
    shipsInventory: Scalars['Boolean']
    /** List of suggested addresses for this location (empty if none). */
    suggestedAddresses: Array<LocationSuggestedAddress>
  }

/**
 * Represents the location where the physical good resides.
 *
 */
export type LocationInventoryLevelArgs = {
  inventoryItemId: Scalars['ID']
}

/**
 * Represents the location where the physical good resides.
 *
 */
export type LocationInventoryLevelsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents the location where the physical good resides.
 *
 */
export type LocationMetafieldDefinitionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  pinnedStatus?: InputMaybe<MetafieldDefinitionPinnedStatus>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<MetafieldDefinitionSortKeys>
}

/**
 * Represents the address of a location.
 *
 */
export type LocationAddress = {
  __typename?: 'LocationAddress'
  /** The first line of the address for the location. */
  address1?: Maybe<Scalars['String']>
  /** The second line of the address for the location. */
  address2?: Maybe<Scalars['String']>
  /** The city of the location. */
  city?: Maybe<Scalars['String']>
  /** The country of the location. */
  country?: Maybe<Scalars['String']>
  /** The country code of the location. */
  countryCode?: Maybe<Scalars['String']>
  /** A formatted version of the address for the location. */
  formatted: Array<Scalars['String']>
  /** The latitude coordinates of the location. */
  latitude?: Maybe<Scalars['Float']>
  /** The longitude coordinates of the location. */
  longitude?: Maybe<Scalars['Float']>
  /** The phone number of the location. */
  phone?: Maybe<Scalars['String']>
  /** The province of the location. */
  province?: Maybe<Scalars['String']>
  /**
   * The code for the province, state, or district of the address of the location.
   *
   */
  provinceCode?: Maybe<Scalars['String']>
  /** The ZIP code of the location. */
  zip?: Maybe<Scalars['String']>
}

/**
 * An auto-generated type for paginating through multiple Locations.
 *
 */
export type LocationConnection = {
  __typename?: 'LocationConnection'
  /** A list of edges. */
  edges: Array<LocationEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one Location and a cursor during pagination.
 *
 */
export type LocationEdge = {
  __typename?: 'LocationEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of LocationEdge. */
  node: Location
}

/** The set of valid sort keys for the Location query. */
export enum LocationSortKeys {
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `name` value. */
  Name = 'NAME',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/**
 * Represents a suggested address for a location.
 *
 */
export type LocationSuggestedAddress = {
  __typename?: 'LocationSuggestedAddress'
  /** The first line of the suggested address. */
  address1?: Maybe<Scalars['String']>
  /** The second line of the suggested address. */
  address2?: Maybe<Scalars['String']>
  /** The city of the suggested address. */
  city?: Maybe<Scalars['String']>
  /** The country of the suggested address. */
  country?: Maybe<Scalars['String']>
  /** The country code of the suggested address. */
  countryCode?: Maybe<CountryCode>
  /** A formatted version of the suggested address. */
  formatted: Array<Scalars['String']>
  /** The province of the suggested address. */
  province?: Maybe<Scalars['String']>
  /** The code for the province, state, or district of the suggested address. */
  provinceCode?: Maybe<Scalars['String']>
  /** The ZIP code of the suggested address. */
  zip?: Maybe<Scalars['String']>
}

/**
 * Represents a customer mailing address.
 *
 * For example, a customer's default address and an order's billing address are both mailling addresses.
 *
 */
export type MailingAddress = Node & {
  __typename?: 'MailingAddress'
  /** The first line of the address. Typically the street address or PO Box number. */
  address1?: Maybe<Scalars['String']>
  /**
   * The second line of the address. Typically the number of the apartment, suite, or unit.
   *
   */
  address2?: Maybe<Scalars['String']>
  /**
   * The name of the city, district, village, or town.
   *
   */
  city?: Maybe<Scalars['String']>
  /**
   * The name of the customer's company or organization.
   *
   */
  company?: Maybe<Scalars['String']>
  /**
   * The name of the country.
   *
   */
  country?: Maybe<Scalars['String']>
  /**
   * The two-letter code for the country of the address.
   *
   * For example, US.
   *
   * @deprecated Use `countryCodeV2` instead
   */
  countryCode?: Maybe<Scalars['String']>
  /**
   * The two-letter code for the country of the address.
   *
   * For example, US.
   *
   */
  countryCodeV2?: Maybe<CountryCode>
  /** The first name of the customer. */
  firstName?: Maybe<Scalars['String']>
  /** A formatted version of the address, customized by the provided arguments. */
  formatted: Array<Scalars['String']>
  /** A comma-separated list of the values for city, province, and country. */
  formattedArea?: Maybe<Scalars['String']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The last name of the customer. */
  lastName?: Maybe<Scalars['String']>
  /** The latitude coordinate of the customer address. */
  latitude?: Maybe<Scalars['Float']>
  /** The longitude coordinate of the customer address. */
  longitude?: Maybe<Scalars['Float']>
  /**
   * The full name of the customer, based on firstName and lastName.
   *
   */
  name?: Maybe<Scalars['String']>
  /**
   * A unique phone number for the customer.
   *
   * Formatted using E.164 standard. For example, _+16135551111_.
   *
   */
  phone?: Maybe<Scalars['String']>
  /** The region of the address, such as the province, state, or district. */
  province?: Maybe<Scalars['String']>
  /**
   * The two-letter code for the region.
   *
   * For example, ON.
   *
   */
  provinceCode?: Maybe<Scalars['String']>
  /** The zip or postal code of the address. */
  zip?: Maybe<Scalars['String']>
}

/**
 * Represents a customer mailing address.
 *
 * For example, a customer's default address and an order's billing address are both mailling addresses.
 *
 */
export type MailingAddressFormattedArgs = {
  withCompany?: InputMaybe<Scalars['Boolean']>
  withName?: InputMaybe<Scalars['Boolean']>
}

/** The fields used to create or update a mailing address. */
export type MailingAddressInput = {
  /**
   * The first line of the address. Typically the street address or PO Box number.
   *
   */
  address1?: InputMaybe<Scalars['String']>
  /**
   * The second line of the address. Typically the number of the apartment, suite, or unit.
   *
   */
  address2?: InputMaybe<Scalars['String']>
  /**
   * The name of the city, district, village, or town.
   *
   */
  city?: InputMaybe<Scalars['String']>
  /**
   * The name of the customer's company or organization.
   *
   */
  company?: InputMaybe<Scalars['String']>
  /** The name of the country. This argument is deprecated: Use `countryCode` instead. */
  country?: InputMaybe<Scalars['String']>
  /** The two-letter code for the country of the address. */
  countryCode?: InputMaybe<CountryCode>
  /** The first name of the customer. */
  firstName?: InputMaybe<Scalars['String']>
  /** This argument is deprecated: Not needed for 90% of mutations, and provided separately where it is needed. */
  id?: InputMaybe<Scalars['ID']>
  /** The last name of the customer. */
  lastName?: InputMaybe<Scalars['String']>
  /**
   * A unique phone number for the customer.
   *
   * Formatted using E.164 standard. For example, _+16135551111_.
   *
   */
  phone?: InputMaybe<Scalars['String']>
  /** The region of the address, such as the province, state, or district. This argument is deprecated: Use `provinceCode` instead. */
  province?: InputMaybe<Scalars['String']>
  /**
   * The code for the region of the address, such as the province, state, or district.
   * For example QC for Quebec, Canada.
   *
   */
  provinceCode?: InputMaybe<Scalars['String']>
  /** The zip or postal code of the address. */
  zip?: InputMaybe<Scalars['String']>
}

/**
 * Manual discount applications capture the intentions of a discount that was manually created for an order.
 *
 */
export type ManualDiscountApplication = DiscountApplication & {
  __typename?: 'ManualDiscountApplication'
  /** The method by which the discount's value is allocated to its entitled items. */
  allocationMethod: DiscountApplicationAllocationMethod
  /** The description of the discount application. */
  description?: Maybe<Scalars['String']>
  /**
   * An ordered index that can be used to identify the discount application and indicate the precedence
   * of the discount application for calculations.
   *
   */
  index: Scalars['Int']
  /** How the discount amount is distributed on the discounted lines. */
  targetSelection: DiscountApplicationTargetSelection
  /** Whether the discount is applied on line items or shipping lines. */
  targetType: DiscountApplicationTargetType
  /** The title of the discount application. */
  title: Scalars['String']
  /** The value of the discount application. */
  value: PricingValue
}

/**
 * The marketing activity resource represents marketing that a
 *         merchant created through an app.
 */
export type MarketingActivity = Node & {
  __typename?: 'MarketingActivity'
  /** The URL of the marketing activity listing page in the marketing section. */
  activityListUrl?: Maybe<Scalars['URL']>
  /** The amount spent on the marketing activity. */
  adSpend?: Maybe<MoneyV2>
  /** The app which created this marketing activity. */
  app: App
  /** The errors generated when an app publishes the marketing activity. */
  appErrors?: Maybe<MarketingActivityExtensionAppErrors>
  /** The allocated budget for the marketing activity. */
  budget?: Maybe<MarketingBudget>
  /** The date and time when the marketing activity was created. */
  createdAt: Scalars['DateTime']
  /** The completed content in the marketing activity creation form. */
  formData?: Maybe<Scalars['String']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /**
   * Whether the marketing activity is in the main workflow version of
   *           the marketing automation.
   */
  inMainWorkflowVersion: Scalars['Boolean']
  /** The available marketing channels for a marketing activity. */
  marketingChannel: MarketingChannel
  /** Associated marketing event of this marketing activity. */
  marketingEvent?: Maybe<MarketingEvent>
  /** A contextual description of the marketing activity based on the platform and tactic used. */
  sourceAndMedium: Scalars['String']
  /** The current state of the marketing activity. */
  status: MarketingActivityStatus
  /**
   * The severity of the marketing activity's status.
   * @deprecated Use `statusBadgeTypeV2` instead
   */
  statusBadgeType?: Maybe<MarketingActivityStatusBadgeType>
  /** The rendered status of the marketing activity. */
  statusLabel: Scalars['String']
  /**
   * The [date and time](
   *           https://help.shopify.com/https://en.wikipedia.org/wiki/ISO_8601
   *           ) when the activity's status last changed.
   */
  statusTransitionedAt?: Maybe<Scalars['DateTime']>
  /** The method of marketing used for this marketing activity. */
  tactic: MarketingTactic
  /** The status to which the marketing activity is currently transitioning. */
  targetStatus?: Maybe<MarketingActivityStatus>
  /** The marketing activity's title, which is rendered on the marketing listing page. */
  title: Scalars['String']
  /** The date and time when the marketing activity was updated. */
  updatedAt: Scalars['DateTime']
  /**
   * The set of [Urchin Tracking Module](
   *           https://help.shopify.com/https://en.wikipedia.org/wiki/UTM_parameters
   *           ) used in the URL for tracking this marketing activity.
   */
  utmParameters?: Maybe<UtmParameters>
}

/** This type combines budget amount and its marketing budget type. */
export type MarketingActivityBudgetInput = {
  /** Budget type for marketing activity. */
  budgetType?: InputMaybe<MarketingBudgetBudgetType>
  /** Amount of budget for the marketing activity. */
  total?: InputMaybe<MoneyInput>
}

/**
 * An auto-generated type for paginating through multiple MarketingActivities.
 *
 */
export type MarketingActivityConnection = {
  __typename?: 'MarketingActivityConnection'
  /** A list of edges. */
  edges: Array<MarketingActivityEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Specifies the input fields required to create a marketing activity. */
export type MarketingActivityCreateInput = {
  /** The budget for this marketing activity. */
  budget?: InputMaybe<MarketingActivityBudgetInput>
  /** Encoded context containing marketing campaign id. */
  context?: InputMaybe<Scalars['String']>
  /** The form data in JSON serialized as a string. */
  formData?: InputMaybe<Scalars['String']>
  /** The ID of the marketing activity extension. */
  marketingActivityExtensionId: Scalars['ID']
  /** The title of the marketing activity. */
  marketingActivityTitle?: InputMaybe<Scalars['String']>
  /** The current state of the marketing activity. */
  status: MarketingActivityStatus
  /**
   * Specifies the
   * [Urchin Traffic Module (UTM) parameters](https://en.wikipedia.org/wiki/UTM_parameters)
   * that are associated with a related marketing campaign. UTMInput is required for all Marketing
   * tactics except Storefront App.
   *
   */
  utm?: InputMaybe<UtmInput>
}

/** Return type for `marketingActivityCreate` mutation. */
export type MarketingActivityCreatePayload = {
  __typename?: 'MarketingActivityCreatePayload'
  /** The created marketing activity. */
  marketingActivity?: Maybe<MarketingActivity>
  /** The path to return back to shopify admin from embedded editor. */
  redirectPath?: Maybe<Scalars['String']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one MarketingActivity and a cursor during pagination.
 *
 */
export type MarketingActivityEdge = {
  __typename?: 'MarketingActivityEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of MarketingActivityEdge. */
  node: MarketingActivity
}

/** The error code resulted from the marketing activity extension integration. */
export enum MarketingActivityExtensionAppErrorCode {
  /** The app is either not responding or returning unexpected data. */
  ApiError = 'API_ERROR',
  /** The app needs to be installed. */
  InstallRequiredError = 'INSTALL_REQUIRED_ERROR',
  /** The shop/user must be onboarded to use the app. */
  NotOnboardedError = 'NOT_ONBOARDED_ERROR',
  /** The app has returned an error when invoking the platform. */
  PlatformError = 'PLATFORM_ERROR',
  /** The app has returned validation errors. */
  ValidationError = 'VALIDATION_ERROR',
}

/** Represents errors returned from apps when using the marketing activity extension. */
export type MarketingActivityExtensionAppErrors = {
  __typename?: 'MarketingActivityExtensionAppErrors'
  /** The app error type. */
  code: MarketingActivityExtensionAppErrorCode
  /** The list of errors returned by the app. */
  userErrors: Array<UserError>
}

/** The set of valid sort keys for the MarketingActivity query. */
export enum MarketingActivitySortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
  /** Sort by the `title` value. */
  Title = 'TITLE',
}

/** Status helps to identify if this marketing activity has been completed, queued, failed etc. */
export enum MarketingActivityStatus {
  /** This marketing activity is currently running. */
  Active = 'ACTIVE',
  /** This marketing activity is permanently unavailable. */
  Deleted = 'DELETED',
  /** This marketing activity was deleted and it was triggered from outside of Shopify. */
  DeletedExternally = 'DELETED_EXTERNALLY',
  /** This marketing activity is disconnected and no longer editable. */
  Disconnected = 'DISCONNECTED',
  /** This marketing activity has been edited, but it is not yet created. */
  Draft = 'DRAFT',
  /** This marketing activity is unable to run. */
  Failed = 'FAILED',
  /** This marketing activity has completed running. */
  Inactive = 'INACTIVE',
  /** This marketing activity is currently not running. */
  Paused = 'PAUSED',
  /** This marketing activity is pending creation on the app's marketing platform. */
  Pending = 'PENDING',
  /** This marketing activity is scheduled to run. */
  Scheduled = 'SCHEDULED',
  /** The marketing activity's status is unknown. */
  Undefined = 'UNDEFINED',
}

/** StatusBadgeType helps to identify the color of the status badge. */
export enum MarketingActivityStatusBadgeType {
  /** This status badge has type attention. */
  Attention = 'ATTENTION',
  /** This status badge has type default. */
  Default = 'DEFAULT',
  /** This status badge has type info. */
  Info = 'INFO',
  /** This status badge has type success. */
  Success = 'SUCCESS',
  /** This status badge has type warning. */
  Warning = 'WARNING',
}

/** Specifies the input fields required to update a marketing activity. */
export type MarketingActivityUpdateInput = {
  /** The cumulative amount spent on the marketing activity. This argument is deprecated: Use `MarketingEngagementCreate.MarketingEngagementInput.adSpend` GraphQL to send the ad spend. */
  adSpend?: InputMaybe<MoneyInput>
  /** The budget for the marketing activity. */
  budget?: InputMaybe<MarketingActivityBudgetInput>
  /** Encoded context provided by Shopify during the update marketing activity callback. This argument is deprecated: This context is no longer needed by Shopify in the callback. */
  context?: InputMaybe<Scalars['String']>
  /**
   * Error messages generated when the app was trying to complete this activity.
   * Learn more about the
   * JSON[format expected for the error messages](/apps/app-extensions/marketing-activities/reference
   * /status#failed-status).
   *
   */
  errors?: InputMaybe<Scalars['JSON']>
  /**
   * The form data of the marketing activity. This is only used if the marketing activity is
   *               integrated with the external editor.
   */
  formData?: InputMaybe<Scalars['String']>
  /** The ID of the marketing activity. */
  id: Scalars['ID']
  /**
   * A list of the item IDs that were marketed in this marketing activity. Valid types for these items are:
   * * `Product`
   * * `Shop`
   *
   */
  marketedResources?: InputMaybe<Array<Scalars['ID']>>
  /** The ID of the recommendation that the marketing activity was created from, if one exists. */
  marketingRecommendationId?: InputMaybe<Scalars['ID']>
  /**
   * The current state of the marketing activity. Learn more about
   * [marketing activity status](/apps/app-extensions/marketing-activities/reference/status).
   *
   */
  status?: InputMaybe<MarketingActivityStatus>
  /** The target state that the marketing activity is transitioning to. Learn more about [marketing activity status](/apps/app-extensions/marketing-activities/reference/status). */
  targetStatus?: InputMaybe<MarketingActivityStatus>
  /** The title of the marketing activity. */
  title?: InputMaybe<Scalars['String']>
  /**
   * Specifies the
   * [Urchin Traffic Module (UTM) parameters](https://en.wikipedia.org/wiki/UTM_parameters)
   * that are associated with a related marketing campaign. UTMInput is required for all Marketing
   * tactics except Storefront App. The utm field can only be set once and never modified.
   *
   */
  utm?: InputMaybe<UtmInput>
}

/** Return type for `marketingActivityUpdate` mutation. */
export type MarketingActivityUpdatePayload = {
  __typename?: 'MarketingActivityUpdatePayload'
  /** The updated marketing activity. */
  marketingActivity?: Maybe<MarketingActivity>
  /** The redirect path from the embedded editor to the Shopify admin. */
  redirectPath?: Maybe<Scalars['String']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * This type combines budget amount and its marketing budget type.
 *
 */
export type MarketingBudget = {
  __typename?: 'MarketingBudget'
  /** The budget type for a marketing activity. */
  budgetType: MarketingBudgetBudgetType
  /** The amount of budget for marketing activity. */
  total: MoneyV2
}

/** The budget type for a marketing activity. */
export enum MarketingBudgetBudgetType {
  /** A daily budget. */
  Daily = 'DAILY',
  /** A budget for the lifetime of a marketing activity. */
  Lifetime = 'LIFETIME',
}

/**
 * The available marketing channels for a marketing activity or event. A marketing channel is broad category of marketing, used for reporting aggregation.
 *
 */
export enum MarketingChannel {
  /** Displayed ads. */
  Display = 'DISPLAY',
  /** Email. */
  Email = 'EMAIL',
  /** Referral links. */
  Referral = 'REFERRAL',
  /** Paid search. */
  Search = 'SEARCH',
  /** Social media. */
  Social = 'SOCIAL',
}

/** Marketing engagement represents customer activity taken on a marketing event. */
export type MarketingEngagement = {
  __typename?: 'MarketingEngagement'
  /** The total ad spend for the day, if the marketing event is a paid ad with a daily spend. */
  adSpend?: Maybe<MoneyV2>
  /** The total number of clicks on the marketing event for the day. */
  clicksCount?: Maybe<Scalars['Int']>
  /** The total number of comments for the day. */
  commentsCount?: Maybe<Scalars['Int']>
  /** The total number of complaints for the day. */
  complaintsCount?: Maybe<Scalars['Int']>
  /** The total number of fails for the day. */
  failsCount?: Maybe<Scalars['Int']>
  /** The total number of favorites for the day. */
  favoritesCount?: Maybe<Scalars['Int']>
  /** The date time at which the data was fetched. */
  fetchedAt?: Maybe<Scalars['DateTime']>
  /** The total number of impressions for the day. */
  impressionsCount?: Maybe<Scalars['Int']>
  /** Whether the engagements are reported as lifetime values rather than daily totals. */
  isCumulative?: Maybe<Scalars['Boolean']>
  /** The marketing activity related to this engagement. */
  marketingActivity: MarketingActivity
  /** The date that these engagements occurred on. */
  occurredOn: Scalars['Date']
  /** The total number of sends for the day. */
  sendsCount?: Maybe<Scalars['Int']>
  /** The total number of shares for the day. */
  sharesCount?: Maybe<Scalars['Int']>
  /** The total number of unique clicks for the day. */
  uniqueClicksCount?: Maybe<Scalars['Int']>
  /** The total number of unique views for the day. */
  uniqueViewsCount?: Maybe<Scalars['Int']>
  /** The total number of unsubscribes for the day. */
  unsubscribesCount?: Maybe<Scalars['Int']>
  /** The UTC Offset that the app is using to determine which date to allocate spend to. */
  utcOffset?: Maybe<Scalars['UtcOffset']>
  /** The total number of views for the day. */
  viewsCount?: Maybe<Scalars['Int']>
}

/** Return type for `marketingEngagementCreate` mutation. */
export type MarketingEngagementCreatePayload = {
  __typename?: 'MarketingEngagementCreatePayload'
  /** The marketing engagement that was created. */
  marketingEngagement?: Maybe<MarketingEngagement>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** This object represents marketing engagement input fields for a marketing engagement. */
export type MarketingEngagementInput = {
  /** The total ad spend for the day, if the marketing event is a paid ad with a daily spend. */
  adSpend?: InputMaybe<MoneyInput>
  /** The total number of clicks on the marketing event for the day. */
  clicksCount?: InputMaybe<Scalars['Int']>
  /** The total number of comments for the day. */
  commentsCount?: InputMaybe<Scalars['Int']>
  /** The total number of complaints for the day. */
  complaintsCount?: InputMaybe<Scalars['Int']>
  /** The total number of fails for the day. */
  failsCount?: InputMaybe<Scalars['Int']>
  /** The total number of favorites for the day. */
  favoritesCount?: InputMaybe<Scalars['Int']>
  /** The date time at which the data was fetched. */
  fetchedAt?: InputMaybe<Scalars['DateTime']>
  /** The total number of impressions for the day. */
  impressionsCount?: InputMaybe<Scalars['Int']>
  /** Whether the engagements are reported as lifetime values rather than daily totals. */
  isCumulative?: InputMaybe<Scalars['Boolean']>
  /** The date that these engagements occurred on. */
  occurredOn: Scalars['Date']
  /** The total number of sends for the day. */
  sendsCount?: InputMaybe<Scalars['Int']>
  /** The total number of shares for the day. */
  sharesCount?: InputMaybe<Scalars['Int']>
  /** The total number of unique clicks for the day. */
  uniqueClicksCount?: InputMaybe<Scalars['Int']>
  /** The total number of unique views for the day. */
  uniqueViewsCount?: InputMaybe<Scalars['Int']>
  /** The total number of unsubscribes for the day. */
  unsubscribesCount?: InputMaybe<Scalars['Int']>
  /** The UTC Offset that the app is using to determine which date to allocate spend to. */
  utcOffset?: InputMaybe<Scalars['UtcOffset']>
  /** The total number of views for the day. */
  viewsCount?: InputMaybe<Scalars['Int']>
}

/** Represents actions that market a merchant's store or products. */
export type MarketingEvent = LegacyInteroperability &
  Node & {
    __typename?: 'MarketingEvent'
    /** The app that the marketing event is attributed to. */
    app: App
    /** The marketing channel used by the marketing event. */
    channel?: Maybe<MarketingChannel>
    /** A human-readable description of the marketing event. */
    description?: Maybe<Scalars['String']>
    /** The date and time when the marketing event ended. */
    endedAt?: Maybe<Scalars['DateTime']>
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** The URL where the marketing event can be managed. */
    manageUrl?: Maybe<Scalars['URL']>
    /** The URL where the marketing event can be previewed. */
    previewUrl?: Maybe<Scalars['URL']>
    /** An optional ID that helps Shopify validate engagement data. */
    remoteId?: Maybe<Scalars['String']>
    /** The date and time when the marketing event is scheduled to end. */
    scheduledToEndAt?: Maybe<Scalars['DateTime']>
    /**
     * Where the `MarketingEvent` occurred and what kind of content was used.
     * Because `utmSource` and `utmMedium` are often used interchangeably, this is
     * based on a combination of `marketingChannel`, `referringDomain`, and `type` to
     * provide a consistent representation for any given piece of marketing
     * regardless of the app that created it.
     *
     */
    sourceAndMedium: Scalars['String']
    /** The date and time when the marketing event started. */
    startedAt: Scalars['DateTime']
    /**
     * The display text for the marketing event type.
     * @deprecated Use `sourceAndMedium` instead
     */
    targetTypeDisplayText: Scalars['String']
    /** The marketing event type. */
    type: MarketingTactic
    /** The name of the marketing campaign. */
    utmCampaign?: Maybe<Scalars['String']>
    /** The medium that the marketing campaign is using. Example values: `cpc`, `banner`. */
    utmMedium?: Maybe<Scalars['String']>
    /** The referrer of the marketing event. Example values: `google`, `newsletter`. */
    utmSource?: Maybe<Scalars['String']>
  }

/**
 * An auto-generated type for paginating through multiple MarketingEvents.
 *
 */
export type MarketingEventConnection = {
  __typename?: 'MarketingEventConnection'
  /** A list of edges. */
  edges: Array<MarketingEventEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one MarketingEvent and a cursor during pagination.
 *
 */
export type MarketingEventEdge = {
  __typename?: 'MarketingEventEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of MarketingEventEdge. */
  node: MarketingEvent
}

/** The set of valid sort keys for the MarketingEvent query. */
export enum MarketingEventSortKeys {
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
  /** Sort by the `started_at` value. */
  StartedAt = 'STARTED_AT',
}

/** The available types of marketing event. */
export enum MarketingTactic {
  /** An abandoned cart recovery email. */
  AbandonedCart = 'ABANDONED_CART',
  /** An ad, such as a Facebook ad. */
  Ad = 'AD',
  /** An affiliate link. */
  Affiliate = 'AFFILIATE',
  /** A direct visit to the online store. */
  Direct = 'DIRECT',
  /** A display ad. */
  Display = 'DISPLAY',
  /** A follow-up email. */
  FollowUp = 'FOLLOW_UP',
  /** A link. */
  Link = 'LINK',
  /** A loyalty program. */
  Loyalty = 'LOYALTY',
  /** A messaging app, such as Facebook Messenger. */
  Message = 'MESSAGE',
  /** A newsletter. */
  Newsletter = 'NEWSLETTER',
  /** A notification in the Shopify admin. */
  Notification = 'NOTIFICATION',
  /** A blog post. */
  Post = 'POST',
  /** A promotional receipt. */
  Receipt = 'RECEIPT',
  /** A retargeting ad. */
  Retargeting = 'RETARGETING',
  /** Paid search. */
  Search = 'SEARCH',
  /** Search engine optimization. */
  Seo = 'SEO',
  /** A popup on the online store. */
  StorefrontApp = 'STOREFRONT_APP',
  /** A transactional email. */
  Transactional = 'TRANSACTIONAL',
}

/** Represents a media interface. */
export type Media = {
  /** A word or phrase to share the nature or contents of a media. */
  alt?: Maybe<Scalars['String']>
  /** The media content type. */
  mediaContentType: MediaContentType
  /** Any errors which have occurred on the media. */
  mediaErrors: Array<MediaError>
  /** The warnings attached to the media. */
  mediaWarnings: Array<MediaWarning>
  /** The preview image for the media. */
  preview?: Maybe<MediaPreviewImage>
  /** Current status of the media. */
  status: MediaStatus
}

/**
 * An auto-generated type for paginating through multiple Media.
 *
 */
export type MediaConnection = {
  __typename?: 'MediaConnection'
  /** A list of edges. */
  edges: Array<MediaEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** The possible content types for a media object. */
export enum MediaContentType {
  /** An externally hosted video. */
  ExternalVideo = 'EXTERNAL_VIDEO',
  /** A Shopify hosted image. */
  Image = 'IMAGE',
  /** A 3d model. */
  Model_3D = 'MODEL_3D',
  /** A Shopify hosted video. */
  Video = 'VIDEO',
}

/**
 * An auto-generated type which holds one Media and a cursor during pagination.
 *
 */
export type MediaEdge = {
  __typename?: 'MediaEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of MediaEdge. */
  node: Media
}

/**
 * Represents a media error.
 *
 */
export type MediaError = {
  __typename?: 'MediaError'
  /** Code representing the type of error. */
  code: MediaErrorCode
  /** Additional details regarding the error. */
  details?: Maybe<Scalars['String']>
  /** Translated error message. */
  message: Scalars['String']
}

/** Error types for media. */
export enum MediaErrorCode {
  /** Media could not be created because embed permissions are disabled for this video. */
  ExternalVideoEmbedDisabled = 'EXTERNAL_VIDEO_EMBED_DISABLED',
  /** Media could not be created because video is either not found or still transcoding. */
  ExternalVideoEmbedNotFoundOrTranscoding = 'EXTERNAL_VIDEO_EMBED_NOT_FOUND_OR_TRANSCODING',
  /** Media could not be created because the external video has an invalid aspect ratio. */
  ExternalVideoInvalidAspectRatio = 'EXTERNAL_VIDEO_INVALID_ASPECT_RATIO',
  /** Media could not be created because the external video could not be found. */
  ExternalVideoNotFound = 'EXTERNAL_VIDEO_NOT_FOUND',
  /** Media could not be created because the external video is not listed or is private. */
  ExternalVideoUnlisted = 'EXTERNAL_VIDEO_UNLISTED',
  /** Media could not be created because the cumulative file storage limit would be exceeded. */
  FileStorageLimitExceeded = 'FILE_STORAGE_LIMIT_EXCEEDED',
  /** File could not be processed because the source could not be downloaded. */
  GenericFileDownloadFailure = 'GENERIC_FILE_DOWNLOAD_FAILURE',
  /** File could not be created because the size is too large. */
  GenericFileInvalidSize = 'GENERIC_FILE_INVALID_SIZE',
  /** Media could not be processed because the image could not be downloaded. */
  ImageDownloadFailure = 'IMAGE_DOWNLOAD_FAILURE',
  /** Media could not be processed because the image could not be processed. */
  ImageProcessingFailure = 'IMAGE_PROCESSING_FAILURE',
  /** Media could not be created because the image has an invalid aspect ratio. */
  InvalidImageAspectRatio = 'INVALID_IMAGE_ASPECT_RATIO',
  /** Media could not be created because the image size is too large. */
  InvalidImageFileSize = 'INVALID_IMAGE_FILE_SIZE',
  /** Media could not be created because the image's resolution exceeds the max limit. */
  InvalidImageResolution = 'INVALID_IMAGE_RESOLUTION',
  /** Media could not be processed because the signed URL was invalid. */
  InvalidSignedUrl = 'INVALID_SIGNED_URL',
  /** Media timed out because it is currently being modified by another operation. */
  MediaTimeoutError = 'MEDIA_TIMEOUT_ERROR',
  /** Media could not be created because the model file failed processing. */
  Model3DGlbOutputCreationError = 'MODEL3D_GLB_OUTPUT_CREATION_ERROR',
  /** Media could not be created because the model can't be converted to USDZ format. */
  Model3DGlbToUsdzConversionError = 'MODEL3D_GLB_TO_USDZ_CONVERSION_ERROR',
  /** Media could not be created because the model file failed processing. */
  Model3DProcessingFailure = 'MODEL3D_PROCESSING_FAILURE',
  /** Media could not be created because the model's thumbnail generation failed. */
  Model3DThumbnailGenerationError = 'MODEL3D_THUMBNAIL_GENERATION_ERROR',
  /** Model failed validation. */
  Model3DValidationError = 'MODEL3D_VALIDATION_ERROR',
  /** Media error has occured for unknown reason. */
  Unknown = 'UNKNOWN',
  /** Media could not be created because the image is an unsupported file type. */
  UnsupportedImageFileType = 'UNSUPPORTED_IMAGE_FILE_TYPE',
  /** Media could not be created because it has an invalid file type. */
  VideoInvalidFiletypeError = 'VIDEO_INVALID_FILETYPE_ERROR',
  /** Media could not be created because it does not meet the maximum duration requirement. */
  VideoMaxDurationError = 'VIDEO_MAX_DURATION_ERROR',
  /** Media could not be created because it does not meet the maximum height requirement. */
  VideoMaxHeightError = 'VIDEO_MAX_HEIGHT_ERROR',
  /** Media could not be created because it does not meet the maximum width requirement. */
  VideoMaxWidthError = 'VIDEO_MAX_WIDTH_ERROR',
  /** Media could not be created because the metadata could not be read. */
  VideoMetadataReadError = 'VIDEO_METADATA_READ_ERROR',
  /** Media could not be created because it does not meet the minimum duration requirement. */
  VideoMinDurationError = 'VIDEO_MIN_DURATION_ERROR',
  /** Media could not be created because it does not meet the minimum height requirement. */
  VideoMinHeightError = 'VIDEO_MIN_HEIGHT_ERROR',
  /** Media could not be created because it does not meet the minimum width requirement. */
  VideoMinWidthError = 'VIDEO_MIN_WIDTH_ERROR',
  /** Video failed validation. */
  VideoValidationError = 'VIDEO_VALIDATION_ERROR',
}

/** Host for a Media Resource. */
export enum MediaHost {
  /** Host for Vimeo embedded videos. */
  Vimeo = 'VIMEO',
  /** Host for YouTube embedded videos. */
  Youtube = 'YOUTUBE',
}

/**
 * An image hosted on Shopify.
 *
 */
export type MediaImage = File &
  Media &
  Node & {
    __typename?: 'MediaImage'
    /** A word or phrase to share the nature or contents of a media. */
    alt?: Maybe<Scalars['String']>
    /**
     * The date and time ([ISO 8601 format](http://en.wikipedia.org/wiki/ISO_8601)) when the product was created.
     *
     */
    createdAt: Scalars['DateTime']
    /** Any errors that have occurred on the file. */
    fileErrors: Array<FileError>
    /** The status of the file. */
    fileStatus: FileStatus
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The image for the media. Returns `null` until `status` is `READY`. */
    image?: Maybe<Image>
    /** The media content type. */
    mediaContentType: MediaContentType
    /** Any errors which have occurred on the media. */
    mediaErrors: Array<MediaError>
    /** The warnings attached to the media. */
    mediaWarnings: Array<MediaWarning>
    /** The MIME type of the image. */
    mimeType?: Maybe<Scalars['String']>
    /** The preview image for the media. */
    preview?: Maybe<MediaPreviewImage>
    /** Current status of the media. */
    status: MediaStatus
  }

/** Represents the preview image for a media. */
export type MediaPreviewImage = {
  __typename?: 'MediaPreviewImage'
  /** The preview image for the media. Returns `null` until `status` is `READY`. */
  image?: Maybe<Image>
  /** Current status of the preview image. */
  status: MediaPreviewImageStatus
}

/** The possible statuses for a media preview image. */
export enum MediaPreviewImageStatus {
  /** Preview image processing has failed. */
  Failed = 'FAILED',
  /** Preview image is being processed. */
  Processing = 'PROCESSING',
  /** Preview image is ready to be displayed. */
  Ready = 'READY',
  /** Preview image is uploaded but not yet processed. */
  Uploaded = 'UPLOADED',
}

/** The possible statuses for a media object. */
export enum MediaStatus {
  /** Media processing has failed. */
  Failed = 'FAILED',
  /** Media is being processed. */
  Processing = 'PROCESSING',
  /** Media is ready to be displayed. */
  Ready = 'READY',
  /** Media has been uploaded but not yet processed. */
  Uploaded = 'UPLOADED',
}

/** Represents an error that happens during execution of a Media query or mutation. */
export type MediaUserError = DisplayableError & {
  __typename?: 'MediaUserError'
  /** The error code. */
  code?: Maybe<MediaUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `MediaUserError`. */
export enum MediaUserErrorCode {
  /** The input value is blank. */
  Blank = 'BLANK',
  /** The input value is invalid. */
  Invalid = 'INVALID',
  /** Invalid media type. */
  InvalidMediaType = 'INVALID_MEDIA_TYPE',
  /** Exceeded the maximum number of 100 variant-media pairs per mutation call. */
  MaximumVariantMediaPairsExceeded = 'MAXIMUM_VARIANT_MEDIA_PAIRS_EXCEEDED',
  /** Media cannot be modified. It is currently being modified by another operation. */
  MediaCannotBeModified = 'MEDIA_CANNOT_BE_MODIFIED',
  /** Media does not exist. */
  MediaDoesNotExist = 'MEDIA_DOES_NOT_EXIST',
  /** Media does not exist on the given product. */
  MediaDoesNotExistOnProduct = 'MEDIA_DOES_NOT_EXIST_ON_PRODUCT',
  /** The specified media is not attached to the specified variant. */
  MediaIsNotAttachedToVariant = 'MEDIA_IS_NOT_ATTACHED_TO_VARIANT',
  /** Model3d creation throttle was exceeded. */
  Model3DThrottleExceeded = 'MODEL3D_THROTTLE_EXCEEDED',
  /** Model validation failed. */
  Model3DValidationError = 'MODEL3D_VALIDATION_ERROR',
  /** Non-ready media are not supported. */
  NonReadyMedia = 'NON_READY_MEDIA',
  /** Product does not exist. */
  ProductDoesNotExist = 'PRODUCT_DOES_NOT_EXIST',
  /** Exceeded the limit of media per product. */
  ProductMediaLimitExceeded = 'PRODUCT_MEDIA_LIMIT_EXCEEDED',
  /** Product variant already has attached media. */
  ProductVariantAlreadyHasMedia = 'PRODUCT_VARIANT_ALREADY_HAS_MEDIA',
  /** Variant does not exist on the given product. */
  ProductVariantDoesNotExistOnProduct = 'PRODUCT_VARIANT_DOES_NOT_EXIST_ON_PRODUCT',
  /** Variant specified in more than one pair. */
  ProductVariantSpecifiedMultipleTimes = 'PRODUCT_VARIANT_SPECIFIED_MULTIPLE_TIMES',
  /** Exceeded the limit of media per shop. */
  ShopMediaLimitExceeded = 'SHOP_MEDIA_LIMIT_EXCEEDED',
  /** Only one mediaId is allowed per variant-media input pair. */
  TooManyMediaPerInputPair = 'TOO_MANY_MEDIA_PER_INPUT_PAIR',
  /** Video creation throttle was exceeded. */
  VideoThrottleExceeded = 'VIDEO_THROTTLE_EXCEEDED',
  /** Video validation failed. */
  VideoValidationError = 'VIDEO_VALIDATION_ERROR',
}

/**
 * Represents a media warning.
 *
 */
export type MediaWarning = {
  __typename?: 'MediaWarning'
  /** The code representing the type of warning. */
  code: MediaWarningCode
  /** Translated warning message. */
  message?: Maybe<Scalars['String']>
}

/** Warning types for media. */
export enum MediaWarningCode {
  /** 3D model physical size might be invalid. The dimensions of your model are very large. Consider reviewing your model to ensure they are correct. */
  ModelLargePhysicalSize = 'MODEL_LARGE_PHYSICAL_SIZE',
  /** 3D model physical size might be invalid. The dimensions of your model are very small. Consider reviewing your model to ensure they are correct. */
  ModelSmallPhysicalSize = 'MODEL_SMALL_PHYSICAL_SIZE',
}

/** Merchant approval for accelerated onboarding to channel integration apps. */
export type MerchantApprovalSignals = {
  __typename?: 'MerchantApprovalSignals'
  /** Whether the shop's Shopify Payments account identity is verified. Returns `false` if the identity is unverified or if the shop doesn't have a Shopify Payments account. */
  identityVerified: Scalars['Boolean']
  /** Whether Shopify has pre-verified the merchant's business for onboarding to channel integration apps. Returns `false` if the shop is not marked for verification. */
  verifiedByShopify: Scalars['Boolean']
}

/**
 * Metafields enable you to attach additional information to a Shopify resource, such as a [Product](https://shopify.dev/api/admin-graphql/latest/objects/product) or a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection).
 * For more information about where you can attach metafields refer to [HasMetafields](https://shopify.dev/api/admin/graphql/reference/common-objects/HasMetafields).
 * Some examples of the data that metafields enable you to store are specifications, size charts, downloadable documents, release dates, images, or part numbers.
 * Metafields are identified by an owner resource, namespace, and key. and store a value along with type information for that value.
 *
 */
export type Metafield = LegacyInteroperability &
  Node & {
    __typename?: 'Metafield'
    /** The date and time when the metafield was created. */
    createdAt: Scalars['DateTime']
    /**
     * The optional, associated metafield definition that maps to this metafield's namespace and key pair.
     *
     */
    definition?: Maybe<MetafieldDefinition>
    /** The description of the metafield. */
    description?: Maybe<Scalars['String']>
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /**
     * The unique identifier for the metafield in its namespace.
     *
     */
    key: Scalars['String']
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /**
     * A container for a group of metafields.
     * Grouping metafields within a namespace prevents your metafields from conflicting with other metafields that have the same key name.
     *
     */
    namespace: Scalars['String']
    /** The resource that the metafield is attached to. */
    owner: HasMetafields
    /**
     * The resource that the metafield is attached to.
     *
     */
    ownerType: MetafieldOwnerType
    /** Returns a reference object if the metafield definition's type is a resource reference. */
    reference?: Maybe<MetafieldReference>
    /**
     * The type of data that the metafield stores in the `value` field.
     * See the list of [supported types](https://shopify.dev/apps/metafields/types).
     *
     */
    type: Scalars['String']
    /** The date and time when the metafield was updated. */
    updatedAt: Scalars['DateTime']
    /**
     * The data to store in the metafield. The data is always stored as a string, regardless of the metafield's type.
     *
     */
    value: Scalars['String']
  }

/**
 * An auto-generated type for paginating through multiple Metafields.
 *
 */
export type MetafieldConnection = {
  __typename?: 'MetafieldConnection'
  /** A list of edges. */
  edges: Array<MetafieldEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * Metafield definitions enable you to define additional validation constraints for metafields, and enable the
 * merchant to edit metafield values in context.
 *
 */
export type MetafieldDefinition = Node & {
  __typename?: 'MetafieldDefinition'
  /** The description of a metafield definition. */
  description?: Maybe<Scalars['String']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The key name used to identify a metafield definition within a namespace. */
  key: Scalars['String']
  /** The list of metafields associated with a metafield definition. */
  metafields: MetafieldConnection
  /** The count of metafields under a metafield definition. */
  metafieldsCount: Scalars['Int']
  /** The human-readable name for the metafield definition. */
  name: Scalars['String']
  /** The namespace of the metafield definition. You can use a namespace to group related metafields. */
  namespace: Scalars['String']
  /**
   * The resource type that the metafield definition is attached to. For example, `Product` or `Collection`.
   *
   */
  ownerType: MetafieldOwnerType
  /** The position of the metafield definition in the pinned list. */
  pinnedPosition?: Maybe<Scalars['Int']>
  /** The standard metafield definition template associated with a metafield definition. */
  standardTemplate?: Maybe<StandardMetafieldDefinitionTemplate>
  /** The type of data that the metafield will store. */
  type: MetafieldDefinitionType
  /** The validation status for the existing metafields within a metafield definition. */
  validationStatus: MetafieldDefinitionValidationStatus
  /**
   * A list of [validation options](https://shopify.dev/apps/metafields/definitions/validation) for
   * the metafield. For example, for a metafield with the type `date`, you can set a minimum date validation, so
   * that the metafield will only store dates after the specific minimum date.
   *
   */
  validations: Array<MetafieldDefinitionValidation>
}

/**
 * Metafield definitions enable you to define additional validation constraints for metafields, and enable the
 * merchant to edit metafield values in context.
 *
 */
export type MetafieldDefinitionMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  validationStatus?: InputMaybe<MetafieldValidationStatus>
}

/**
 * Metafield definitions enable you to define additional validation constraints for metafields, and enable the
 * merchant to edit metafield values in context.
 *
 */
export type MetafieldDefinitionMetafieldsCountArgs = {
  validationStatus?: InputMaybe<MetafieldValidationStatus>
}

/**
 * An auto-generated type for paginating through multiple MetafieldDefinitions.
 *
 */
export type MetafieldDefinitionConnection = {
  __typename?: 'MetafieldDefinitionConnection'
  /** A list of edges. */
  edges: Array<MetafieldDefinitionEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `metafieldDefinitionCreate` mutation. */
export type MetafieldDefinitionCreatePayload = {
  __typename?: 'MetafieldDefinitionCreatePayload'
  /** The metafield definition that was created. */
  createdDefinition?: Maybe<MetafieldDefinition>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<MetafieldDefinitionCreateUserError>
}

/** An error that occurs during the execution of `MetafieldDefinitionCreate`. */
export type MetafieldDefinitionCreateUserError = DisplayableError & {
  __typename?: 'MetafieldDefinitionCreateUserError'
  /** The error code. */
  code?: Maybe<MetafieldDefinitionCreateUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `MetafieldDefinitionCreateUserError`. */
export enum MetafieldDefinitionCreateUserErrorCode {
  /** A duplicate option. */
  DuplicateOption = 'DUPLICATE_OPTION',
  /** The input value isn't included in the list. */
  Inclusion = 'INCLUSION',
  /** The input value is invalid. */
  Invalid = 'INVALID',
  /** An invalid option. */
  InvalidOption = 'INVALID_OPTION',
  /** The maximum limit of definitions per owner type has exceeded. */
  LimitExceeded = 'LIMIT_EXCEEDED',
  /** The pinned limit has been reached for the owner type. */
  PinnedLimitReached = 'PINNED_LIMIT_REACHED',
  /** The input value needs to be blank. */
  Present = 'PRESENT',
  /** This namespace and key combination is reserved for standard definitions. */
  ReservedNamespaceKey = 'RESERVED_NAMESPACE_KEY',
  /** The definition limit per owner type has exceeded. */
  ResourceTypeLimitExceeded = 'RESOURCE_TYPE_LIMIT_EXCEEDED',
  /** The input value is already taken. */
  Taken = 'TAKEN',
  /** The input value is too long. */
  TooLong = 'TOO_LONG',
  /** The input value is too short. */
  TooShort = 'TOO_SHORT',
  /** This namespace and key combination is already in use for a set of your metafields. */
  UnstructuredAlreadyExists = 'UNSTRUCTURED_ALREADY_EXISTS',
}

/** Return type for `metafieldDefinitionDelete` mutation. */
export type MetafieldDefinitionDeletePayload = {
  __typename?: 'MetafieldDefinitionDeletePayload'
  /** The id of the deleted metafield definition. */
  deletedDefinitionId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<MetafieldDefinitionDeleteUserError>
}

/** An error that occurs during the execution of `MetafieldDefinitionDelete`. */
export type MetafieldDefinitionDeleteUserError = DisplayableError & {
  __typename?: 'MetafieldDefinitionDeleteUserError'
  /** The error code. */
  code?: Maybe<MetafieldDefinitionDeleteUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `MetafieldDefinitionDeleteUserError`. */
export enum MetafieldDefinitionDeleteUserErrorCode {
  /** An internal error occurred. */
  InternalError = 'INTERNAL_ERROR',
  /** Definition not found. */
  NotFound = 'NOT_FOUND',
  /** The input value needs to be blank. */
  Present = 'PRESENT',
}

/**
 * An auto-generated type which holds one MetafieldDefinition and a cursor during pagination.
 *
 */
export type MetafieldDefinitionEdge = {
  __typename?: 'MetafieldDefinitionEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of MetafieldDefinitionEdge. */
  node: MetafieldDefinition
}

/**
 * Specifies the input fields that are required to create a metafield definition.
 *
 */
export type MetafieldDefinitionInput = {
  /** The description for the metafield definition. */
  description?: InputMaybe<Scalars['String']>
  /** The key name used to identify a metafield definition within a namespace. */
  key: Scalars['String']
  /** The human-readable name for the metafield definition. */
  name: Scalars['String']
  /** The namespace to group a metafield definition. */
  namespace: Scalars['String']
  /** The resource type that the metafield definition is attached to. */
  ownerType: MetafieldOwnerType
  /** Whether to pin the metafield definition. */
  pin?: InputMaybe<Scalars['Boolean']>
  /** The type of data that the metafield will store. */
  type: Scalars['String']
  /**
   * A list of [validation options](https://shopify.dev/apps/metafields/definitions/validation) for
   * the metafield. For example, for a metafield with the type `date`, you can set a minimum date validation, so
   * that the metafield will only store dates after the specific minimum date.
   *
   */
  validations?: InputMaybe<Array<MetafieldDefinitionValidationInput>>
}

/** Return type for `metafieldDefinitionPin` mutation. */
export type MetafieldDefinitionPinPayload = {
  __typename?: 'MetafieldDefinitionPinPayload'
  /** The metafield definition that was pinned. */
  pinnedDefinition?: Maybe<MetafieldDefinition>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<MetafieldDefinitionPinUserError>
}

/** An error that occurs during the execution of `MetafieldDefinitionPin`. */
export type MetafieldDefinitionPinUserError = DisplayableError & {
  __typename?: 'MetafieldDefinitionPinUserError'
  /** The error code. */
  code?: Maybe<MetafieldDefinitionPinUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `MetafieldDefinitionPinUserError`. */
export enum MetafieldDefinitionPinUserErrorCode {
  /** The metafield definition is already pinned. */
  AlreadyPinned = 'ALREADY_PINNED',
  /** An internal error occurred. */
  InternalError = 'INTERNAL_ERROR',
  /** The metafield definition was not found. */
  NotFound = 'NOT_FOUND',
  /** The pinned limit has been reached for owner type. */
  PinnedLimitReached = 'PINNED_LIMIT_REACHED',
}

/** Possible metafield definition pinned statuses. */
export enum MetafieldDefinitionPinnedStatus {
  /** All metafield definitions. */
  Any = 'ANY',
  /** Only metafield definitions that are pinned. */
  Pinned = 'PINNED',
  /** Only metafield definitions that are not pinned. */
  Unpinned = 'UNPINNED',
}

/** The set of valid sort keys for the MetafieldDefinition query. */
export enum MetafieldDefinitionSortKeys {
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `name` value. */
  Name = 'NAME',
  /** Sort by the `pinned_position` value. */
  PinnedPosition = 'PINNED_POSITION',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/**
 * The type and name for the optional validation configuration of a metafield.
 *
 * For example, a supported validation might consist of a `max` name and a `number_integer` type.
 * This validation can then be used to enforce a maximum character length for a `single_line_text_field` metafield.
 *
 */
export type MetafieldDefinitionSupportedValidation = {
  __typename?: 'MetafieldDefinitionSupportedValidation'
  /** The name of the metafield definition validation. */
  name: Scalars['String']
  /** The type of input for the validation. */
  type: Scalars['String']
}

/**
 * A metafield definition type provides basic foundation and validation for a metafield.
 *
 */
export type MetafieldDefinitionType = {
  __typename?: 'MetafieldDefinitionType'
  /** The category associated with the metafield definition type. */
  category: Scalars['String']
  /**
   * The name of the type for the metafield definition.
   * See the list of [supported types](https://shopify.dev/apps/metafields/types).
   *
   */
  name: Scalars['String']
  /** The supported validations for a metafield definition type. */
  supportedValidations: Array<MetafieldDefinitionSupportedValidation>
  /** Whether metafields without a definition can be migrated to a definition of this type. */
  supportsDefinitionMigrations: Scalars['Boolean']
  /**
   * The value type for a metafield created with this definition type.
   * @deprecated `valueType` is deprecated and `name` should be used for type information.
   */
  valueType: MetafieldValueType
}

/** Return type for `metafieldDefinitionUnpin` mutation. */
export type MetafieldDefinitionUnpinPayload = {
  __typename?: 'MetafieldDefinitionUnpinPayload'
  /** The metafield definition that was unpinned. */
  unpinnedDefinition?: Maybe<MetafieldDefinition>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<MetafieldDefinitionUnpinUserError>
}

/** An error that occurs during the execution of `MetafieldDefinitionUnpin`. */
export type MetafieldDefinitionUnpinUserError = DisplayableError & {
  __typename?: 'MetafieldDefinitionUnpinUserError'
  /** The error code. */
  code?: Maybe<MetafieldDefinitionUnpinUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `MetafieldDefinitionUnpinUserError`. */
export enum MetafieldDefinitionUnpinUserErrorCode {
  /** An internal error occurred. */
  InternalError = 'INTERNAL_ERROR',
  /** The metafield definition was not found. */
  NotFound = 'NOT_FOUND',
  /** The metafield definition isn't pinned. */
  NotPinned = 'NOT_PINNED',
}

/**
 * Specifies the input fields that are required to update a metafield definition.
 *
 */
export type MetafieldDefinitionUpdateInput = {
  /** The description for the metafield definition. */
  description?: InputMaybe<Scalars['String']>
  /** The key name used to identify a metafield definition within a namespace. */
  key: Scalars['String']
  /** The human-readable name for the metafield definition. */
  name?: InputMaybe<Scalars['String']>
  /** The namespace to group a metafield definition. */
  namespace: Scalars['String']
  /** The resource type that the metafield definition is attached to. */
  ownerType: MetafieldOwnerType
  /** Whether to pin the metafield definition. */
  pin?: InputMaybe<Scalars['Boolean']>
}

/** Return type for `metafieldDefinitionUpdate` mutation. */
export type MetafieldDefinitionUpdatePayload = {
  __typename?: 'MetafieldDefinitionUpdatePayload'
  /** The metafield definition that was updated. */
  updatedDefinition?: Maybe<MetafieldDefinition>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<MetafieldDefinitionUpdateUserError>
}

/** An error that occurs during the execution of `MetafieldDefinitionUpdate`. */
export type MetafieldDefinitionUpdateUserError = DisplayableError & {
  __typename?: 'MetafieldDefinitionUpdateUserError'
  /** The error code. */
  code?: Maybe<MetafieldDefinitionUpdateUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `MetafieldDefinitionUpdateUserError`. */
export enum MetafieldDefinitionUpdateUserErrorCode {
  /** An internal error occurred. */
  InternalError = 'INTERNAL_ERROR',
  /** An invalid input. */
  InvalidInput = 'INVALID_INPUT',
  /** The metafield definition wasn't found. */
  NotFound = 'NOT_FOUND',
  /** The pinned limit has been reached for the owner type. */
  PinnedLimitReached = 'PINNED_LIMIT_REACHED',
  /** The input value needs to be blank. */
  Present = 'PRESENT',
  /** The input value is too long. */
  TooLong = 'TOO_LONG',
}

/**
 * A configured metafield definition validation.
 *
 * For example, for a metafield definition of `number_integer` type, you can set a validation with the name `max`
 * and a value of `15`. This validation will ensure that the value of the metafield is a number less than or equal to 15.
 *
 * Refer to the [list of supported validations](https://shopify.dev/api/admin/graphql/reference/common-objects/metafieldDefinitionTypes#examples-Fetch_all_metafield_definition_types).
 *
 */
export type MetafieldDefinitionValidation = {
  __typename?: 'MetafieldDefinitionValidation'
  /** The validation name. */
  name: Scalars['String']
  /** The name for the metafield type of this validation. */
  type: Scalars['String']
  /** The validation value. */
  value?: Maybe<Scalars['String']>
}

/**
 * The name and value for a metafield definition validation.
 *
 * For example, for a metafield definition of `single_line_text_field` type, you can set a validation with the name `min` and a value of `10`.
 * This validation will ensure that the value of the metafield is at least 10 characters.
 *
 * Refer to the [list of supported validations](https://shopify.dev/api/admin/graphql/reference/common-objects/metafieldDefinitionTypes#examples-Fetch_all_metafield_definition_types).
 *
 */
export type MetafieldDefinitionValidationInput = {
  /** The name for the metafield definition validation. */
  name: Scalars['String']
  /** The value for the metafield definition validation. */
  value: Scalars['String']
}

/** Possible metafield definition validation statuses. */
export enum MetafieldDefinitionValidationStatus {
  /** All of this definition's metafields are valid. */
  AllValid = 'ALL_VALID',
  /** Asynchronous validation of this definition's metafields is in progress. */
  InProgress = 'IN_PROGRESS',
  /** Some of this definition's metafields are invalid. */
  SomeInvalid = 'SOME_INVALID',
}

/** Specifies the input fields to delete a metafield. */
export type MetafieldDeleteInput = {
  /** The ID of the metafield to delete. */
  id: Scalars['ID']
}

/** Return type for `metafieldDelete` mutation. */
export type MetafieldDeletePayload = {
  __typename?: 'MetafieldDeletePayload'
  /** The ID of the deleted metafield. */
  deletedId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one Metafield and a cursor during pagination.
 *
 */
export type MetafieldEdge = {
  __typename?: 'MetafieldEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of MetafieldEdge. */
  node: Metafield
}

/**
 * The input fields to use to create or update a metafield through a mutation on the owning resource.
 * An alternative way to create or update a metafield is by using the
 * [metafieldsSet](https://shopify.dev/api/admin-graphql/latest/mutations/metafieldsSet) mutation.
 *
 */
export type MetafieldInput = {
  /** The description of the metafield. */
  description?: InputMaybe<Scalars['String']>
  /**
   * The unique ID of the metafield. You don't include an ID when you create a metafield because the metafield ID
   * is created automatically. The ID is required when you update a metafield.
   *
   */
  id?: InputMaybe<Scalars['ID']>
  /** The key name of the metafield. Required when creating but optional when updating. */
  key?: InputMaybe<Scalars['String']>
  /**
   * The namespace for a metafield. The namespace is required when you create a metafield and is optional when you
   * update a metafield.
   *
   */
  namespace?: InputMaybe<Scalars['String']>
  /**
   * The metafield's [type](https://shopify.dev/apps/metafields/types). The metafield type is required
   * when you create a metafield and is optional when you update a metafield.
   *
   */
  type?: InputMaybe<Scalars['String']>
  /** The value of a metafield. */
  value?: InputMaybe<Scalars['String']>
}

/** Possible types of a metafield's owner resource. */
export enum MetafieldOwnerType {
  /** The Article metafield owner type. */
  Article = 'ARTICLE',
  /** The Blog metafield owner type. */
  Blog = 'BLOG',
  /** The Collection metafield owner type. */
  Collection = 'COLLECTION',
  /** The Customer metafield owner type. */
  Customer = 'CUSTOMER',
  /** The Draft Order metafield owner type. */
  Draftorder = 'DRAFTORDER',
  /** The Order metafield owner type. */
  Order = 'ORDER',
  /** The Page metafield owner type. */
  Page = 'PAGE',
  /** The Product metafield owner type. */
  Product = 'PRODUCT',
  /** The Product Image metafield owner type. */
  Productimage = 'PRODUCTIMAGE',
  /** The Product Variant metafield owner type. */
  Productvariant = 'PRODUCTVARIANT',
  /** The Shop metafield owner type. */
  Shop = 'SHOP',
}

/**
 * The resource referenced by the metafield value.
 *
 */
export type MetafieldReference =
  | GenericFile
  | MediaImage
  | OnlineStorePage
  | Product
  | ProductVariant

/**
 * By default, the Storefront API can't read metafields. To make specific metafields visible in the Storefront API,
 * you need to create a `MetafieldStorefrontVisibility` record. A `MetafieldStorefrontVisibility` record is a list
 * of the metafields, defined by the `owner_type`, `namespace`, and `key`, to make visible in the Storefront API.
 *
 * See [expose metafields in the Storefront API](https://shopify.dev/custom-storefront/products/metafields#expose-metafields)
 * for more details.
 *
 */
export type MetafieldStorefrontVisibility = LegacyInteroperability &
  Node & {
    __typename?: 'MetafieldStorefrontVisibility'
    /** The date and time when the metafield was set to visible in the Storefront API. */
    createdAt: Scalars['DateTime']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The key of a metafield to make visible in the Storefront API. */
    key: Scalars['String']
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** The namespace of a metafield to make visible in the Storefront API. */
    namespace: Scalars['String']
    /** The owner type of a metafield to make visible in the Storefront API. */
    ownerType: MetafieldOwnerType
    /**
     * The date and time when the `MetafieldStorefrontVisilibty` record was updated.
     *
     */
    updatedAt: Scalars['DateTime']
  }

/**
 * An auto-generated type for paginating through multiple MetafieldStorefrontVisibilities.
 *
 */
export type MetafieldStorefrontVisibilityConnection = {
  __typename?: 'MetafieldStorefrontVisibilityConnection'
  /** A list of edges. */
  edges: Array<MetafieldStorefrontVisibilityEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `metafieldStorefrontVisibilityCreate` mutation. */
export type MetafieldStorefrontVisibilityCreatePayload = {
  __typename?: 'MetafieldStorefrontVisibilityCreatePayload'
  /** The `MetafieldStorefrontVisibility` that was created. */
  metafieldStorefrontVisibility?: Maybe<MetafieldStorefrontVisibility>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `metafieldStorefrontVisibilityDelete` mutation. */
export type MetafieldStorefrontVisibilityDeletePayload = {
  __typename?: 'MetafieldStorefrontVisibilityDeletePayload'
  /** The ID of the deleted `MetafieldStorefrontVisibility` record. */
  deletedMetafieldStorefrontVisibilityId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one MetafieldStorefrontVisibility and a cursor during pagination.
 *
 */
export type MetafieldStorefrontVisibilityEdge = {
  __typename?: 'MetafieldStorefrontVisibilityEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of MetafieldStorefrontVisibilityEdge. */
  node: MetafieldStorefrontVisibility
}

/**
 * Specifies the input fields to create a `MetafieldStorefrontVisibility` record.
 *
 */
export type MetafieldStorefrontVisibilityInput = {
  /** The key of a metafield to make visible in the Storefront API. */
  key: Scalars['String']
  /** The namespace of a metafield to make visible in the Storefront API. */
  namespace: Scalars['String']
  /** The owner type of a metafield to make visible in the Storefront API. */
  ownerType: MetafieldOwnerType
}

/** Possible metafield validation statuses. */
export enum MetafieldValidationStatus {
  /** Any validation status (valid or invalid). */
  Any = 'ANY',
  /** Invalid (according to definition). */
  Invalid = 'INVALID',
  /** Valid (according to definition). */
  Valid = 'VALID',
}

/**
 * Legacy type information for the stored value.
 * Replaced by `type`.
 *
 */
export enum MetafieldValueType {
  /** A `true` or `false` value. */
  Boolean = 'BOOLEAN',
  /** A whole number. */
  Integer = 'INTEGER',
  /** A JSON string. */
  JsonString = 'JSON_STRING',
  /** A text field. */
  String = 'STRING',
}

/** Specifies the input fields for a metafield value to set. */
export type MetafieldsSetInput = {
  /** The key name of the metafield. */
  key: Scalars['String']
  /**
   * A container for a group of metafields.
   * Grouping metafields in a namespace prevents your metafields from conflicting with other metafields that have the same key name.
   *
   */
  namespace: Scalars['String']
  /** The ID of the owner resource. */
  ownerId: Scalars['ID']
  /**
   * The type of data that the metafield stores.
   * The type of data must be a [supported type](https://shopify.dev/apps/metafields/types).
   *
   */
  type: Scalars['String']
  /**
   * The data to store in the metafield. The data is always stored as a string, regardless of the metafield's type.
   *
   */
  value: Scalars['String']
}

/** Return type for `metafieldsSet` mutation. */
export type MetafieldsSetPayload = {
  __typename?: 'MetafieldsSetPayload'
  /** The list of metafields that were set. */
  metafields?: Maybe<Array<Metafield>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<MetafieldsSetUserError>
}

/** An error that occurs during the execution of `MetafieldsSet`. */
export type MetafieldsSetUserError = DisplayableError & {
  __typename?: 'MetafieldsSetUserError'
  /** The error code. */
  code?: Maybe<MetafieldsSetUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `MetafieldsSetUserError`. */
export enum MetafieldsSetUserErrorCode {
  /** The input value is blank. */
  Blank = 'BLANK',
  /** The input value isn't included in the list. */
  Inclusion = 'INCLUSION',
  /** The type is invalid. */
  InvalidType = 'INVALID_TYPE',
  /** The value is invalid for metafield type or for definition options. */
  InvalidValue = 'INVALID_VALUE',
  /** The input value should be less than or equal to the maximum value allowed. */
  LessThanOrEqualTo = 'LESS_THAN_OR_EQUAL_TO',
  /** The input value needs to be blank. */
  Present = 'PRESENT',
  /** The input value is too long. */
  TooLong = 'TOO_LONG',
  /** The input value is too short. */
  TooShort = 'TOO_SHORT',
}

/** The set of valid sort keys for the MethodDefinition query. */
export enum MethodDefinitionSortKeys {
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `rate_provider_type` value. */
  RateProviderType = 'RATE_PROVIDER_TYPE',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/**
 * Represents a Shopify hosted 3D model.
 *
 */
export type Model3d = Media &
  Node & {
    __typename?: 'Model3d'
    /** A word or phrase to share the nature or contents of a media. */
    alt?: Maybe<Scalars['String']>
    /** The bounding box information of the 3d model. */
    boundingBox?: Maybe<Model3dBoundingBox>
    /** The filename of the 3d model. */
    filename: Scalars['String']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The media content type. */
    mediaContentType: MediaContentType
    /** Any errors which have occurred on the media. */
    mediaErrors: Array<MediaError>
    /** The warnings attached to the media. */
    mediaWarnings: Array<MediaWarning>
    /** The original source for a 3d model. */
    originalSource?: Maybe<Model3dSource>
    /** The preview image for the media. */
    preview?: Maybe<MediaPreviewImage>
    /** The sources for a 3d model. */
    sources: Array<Model3dSource>
    /** Current status of the media. */
    status: MediaStatus
  }

/**
 * Bounding box information of a 3d model.
 *
 */
export type Model3dBoundingBox = {
  __typename?: 'Model3dBoundingBox'
  /**
   * Size in meters of the smallest volume which contains the 3d model.
   *
   */
  size: Vector3
}

/**
 * Represents a source for a Shopify hosted 3d model.
 *
 */
export type Model3dSource = {
  __typename?: 'Model3dSource'
  /** The filesize of the 3d model. */
  filesize: Scalars['Int']
  /** The format of the 3d model. */
  format: Scalars['String']
  /** The MIME type of the 3d model. */
  mimeType: Scalars['String']
  /** The URL of the 3d model. */
  url: Scalars['String']
}

/**
 * A collection of monetary values in their respective currencies. Typically used in the context of multi-currency pricing and transactions,
 * when an amount in the shop's currency is converted to the customer's currency of choice (the presentment currency).
 *
 */
export type MoneyBag = {
  __typename?: 'MoneyBag'
  /** Amount in presentment currency. */
  presentmentMoney: MoneyV2
  /** Amount in shop currency. */
  shopMoney: MoneyV2
}

/** Specifies the fields for a monetary value with currency. */
export type MoneyInput = {
  /** Decimal money amount. */
  amount: Scalars['Decimal']
  /** Currency of the money. */
  currencyCode: CurrencyCode
}

/**
 * A monetary value with currency.
 *
 */
export type MoneyV2 = {
  __typename?: 'MoneyV2'
  /** Decimal money amount. */
  amount: Scalars['Decimal']
  /** Currency of the money. */
  currencyCode: CurrencyCode
}

/** An individual move to perform of an object to a position. */
export type MoveInput = {
  /** The ID of the object to be moved. */
  id: Scalars['ID']
  /** The new position of the object in the set, using a 0 based index. */
  newPosition: Scalars['UnsignedInt64']
}

/** The schema's entry point for all mutation operations. */
export type Mutation = {
  __typename?: 'Mutation'
  /** Allows an app to create a credit for a shop that can be used towards future app purchases. */
  appCreditCreate?: Maybe<AppCreditCreatePayload>
  /**
   * Charges a shop for features or services one time.
   * This type of charge is recommended for apps that aren't billed on a recurring basis.
   * Test and demo shops aren't charged.
   *
   */
  appPurchaseOneTimeCreate?: Maybe<AppPurchaseOneTimeCreatePayload>
  /** Creates a record of the attributed revenue for the app. This mutation should only be used to capture transactions that are not managed by the Billing API. */
  appRevenueAttributionRecordCreate?: Maybe<AppRevenueAttributionRecordCreatePayload>
  /** Deletes a record of the attributed revenue for the app. */
  appRevenueAttributionRecordDelete?: Maybe<AppRevenueAttributionRecordDeletePayload>
  /** Cancels an app subscription on a store. */
  appSubscriptionCancel?: Maybe<AppSubscriptionCancelPayload>
  /** Allows an app to charge a store for features or services on a recurring basis. */
  appSubscriptionCreate?: Maybe<AppSubscriptionCreatePayload>
  /** Updates the capped amount on the usage pricing plan of an app subscription line item. */
  appSubscriptionLineItemUpdate?: Maybe<AppSubscriptionLineItemUpdatePayload>
  /** Creates an app usage record. */
  appUsageRecordCreate?: Maybe<AppUsageRecordCreatePayload>
  /**
   * Starts the cancelation process of a running bulk operation.
   *
   * There may be a short delay from when a cancelation starts until the operation is actually canceled.
   *
   */
  bulkOperationCancel?: Maybe<BulkOperationCancelPayload>
  /**
   * Creates and runs a bulk operation mutation.
   *
   * To learn how to bulk import large volumes of data asynchronously, refer to the
   * [bulk import data guide](https://shopify.dev/api/usage/bulk-operations/imports).
   *
   */
  bulkOperationRunMutation?: Maybe<BulkOperationRunMutationPayload>
  /**
   * Creates and runs a bulk operation query.
   *
   * See the [bulk operations guide](https://shopify.dev/api/usage/bulk-operations/imports) for more details.
   *
   */
  bulkOperationRunQuery?: Maybe<BulkOperationRunQueryPayload>
  /** Creates product feedback for multiple products. */
  bulkProductResourceFeedbackCreate?: Maybe<BulkProductResourceFeedbackCreatePayload>
  /** Adds products to a collection. */
  collectionAddProducts?: Maybe<CollectionAddProductsPayload>
  /**
   * Creates a collection.
   *
   */
  collectionCreate?: Maybe<CollectionCreatePayload>
  /** Deletes a collection. */
  collectionDelete?: Maybe<CollectionDeletePayload>
  /**
   * Publishes a collection to a channel.
   * @deprecated Use `publishablePublish` instead
   */
  collectionPublish?: Maybe<CollectionPublishPayload>
  /** Removes a set of products from a given collection. It can take a long time to run. Instead of returning a collection it returns a job, which should be polled. */
  collectionRemoveProducts?: Maybe<CollectionRemoveProductsPayload>
  /** Asynchronously reorders a set of products from a given collection. */
  collectionReorderProducts?: Maybe<CollectionReorderProductsPayload>
  /**
   * Unpublishes a collection.
   * @deprecated Use `publishableUnpublish` instead
   */
  collectionUnpublish?: Maybe<CollectionUnpublishPayload>
  /** Updates a collection. */
  collectionUpdate?: Maybe<CollectionUpdatePayload>
  /** Add tax exemptions for the customer. */
  customerAddTaxExemptions?: Maybe<CustomerAddTaxExemptionsPayload>
  /** Create a new customer. */
  customerCreate?: Maybe<CustomerCreatePayload>
  /** Delete a customer. */
  customerDelete?: Maybe<CustomerDeletePayload>
  /** Generate an account activation URL for a customer. */
  customerGenerateAccountActivationUrl?: Maybe<CustomerGenerateAccountActivationUrlPayload>
  /** Creates a credit card payment method for a customer. */
  customerPaymentMethodCreditCardCreate?: Maybe<CustomerPaymentMethodCreditCardCreatePayload>
  /** Updates the credit card payment method for a customer. */
  customerPaymentMethodCreditCardUpdate?: Maybe<CustomerPaymentMethodCreditCardUpdatePayload>
  /**
   * Returns a URL that allows the customer to update a specific payment method.
   *
   * Currently, `customerPaymentMethodGetUpdateUrl` only supports Shop Pay.
   *
   */
  customerPaymentMethodGetUpdateUrl?: Maybe<CustomerPaymentMethodGetUpdateUrlPayload>
  /** Creates a PayPal billing agreement for a customer. */
  customerPaymentMethodPaypalBillingAgreementCreate?: Maybe<CustomerPaymentMethodPaypalBillingAgreementCreatePayload>
  /** Updates a PayPal billing agreement for a customer. */
  customerPaymentMethodPaypalBillingAgreementUpdate?: Maybe<CustomerPaymentMethodPaypalBillingAgreementUpdatePayload>
  /** Create a payment method from remote gateway identifiers. */
  customerPaymentMethodRemoteCreate?: Maybe<CustomerPaymentMethodRemoteCreatePayload>
  /**
   * Create a payment method from a credit card stored by Stripe.
   * @deprecated Use `customerPaymentMethodRemoteCreate` instead
   */
  customerPaymentMethodRemoteCreditCardCreate?: Maybe<CustomerPaymentMethodRemoteCreditCardCreatePayload>
  /** Revokes a customer's payment method. */
  customerPaymentMethodRevoke?: Maybe<CustomerPaymentMethodRevokePayload>
  /** Sends a link to the customer so they can update a specific payment method. */
  customerPaymentMethodSendUpdateEmail?: Maybe<CustomerPaymentMethodSendUpdateEmailPayload>
  /** Remove tax exemptions from a customer. */
  customerRemoveTaxExemptions?: Maybe<CustomerRemoveTaxExemptionsPayload>
  /** Replace tax exemptions for a customer. */
  customerReplaceTaxExemptions?: Maybe<CustomerReplaceTaxExemptionsPayload>
  /**
   * Update a customer's SMS marketing consent information.
   *
   */
  customerSmsMarketingConsentUpdate?: Maybe<CustomerSmsMarketingConsentUpdatePayload>
  /** Updates a customer's attributes. */
  customerUpdate?: Maybe<CustomerUpdatePayload>
  /** Updates a customer's default address. */
  customerUpdateDefaultAddress?: Maybe<CustomerUpdateDefaultAddressPayload>
  /** Create a delivery profile. */
  deliveryProfileCreate?: Maybe<DeliveryProfileCreatePayload>
  /** Enqueue the removal of a delivery profile. */
  deliveryProfileRemove?: Maybe<DeliveryProfileRemovePayload>
  /** Update a delivery profile. */
  deliveryProfileUpdate?: Maybe<DeliveryProfileUpdatePayload>
  /** Set the delivery settings for a shop. */
  deliverySettingUpdate?: Maybe<DeliverySettingUpdatePayload>
  /**
   * Assigns a location as the shipping origin while using legacy compatibility mode for multi-location delivery profiles.
   *
   */
  deliveryShippingOriginAssign?: Maybe<DeliveryShippingOriginAssignPayload>
  /** Activates an automatic discount. */
  discountAutomaticActivate?: Maybe<DiscountAutomaticActivatePayload>
  /** Creates a basic automatic discount. */
  discountAutomaticBasicCreate?: Maybe<DiscountAutomaticBasicCreatePayload>
  /** Updates a basic automatic discount using its ID and input. */
  discountAutomaticBasicUpdate?: Maybe<DiscountAutomaticBasicUpdatePayload>
  /**
   * Asynchronously delete automatic discounts in bulk if a `search` or `saved_search_id` argument is provided or if a
   * maximum discount threshold is reached (1,000). Otherwise, deletions will occur inline.
   * **Warning:** All automatic discounts will be deleted if a blank `search` argument is provided.
   *
   */
  discountAutomaticBulkDelete?: Maybe<DiscountAutomaticBulkDeletePayload>
  /** Creates a BXGY automatic discount. */
  discountAutomaticBxgyCreate?: Maybe<DiscountAutomaticBxgyCreatePayload>
  /** Updates a BXGY automatic discount using its ID and input. */
  discountAutomaticBxgyUpdate?: Maybe<DiscountAutomaticBxgyUpdatePayload>
  /** Deactivates an automatic discount. */
  discountAutomaticDeactivate?: Maybe<DiscountAutomaticDeactivatePayload>
  /** Deletes an automatic discount. */
  discountAutomaticDelete?: Maybe<DiscountAutomaticDeletePayload>
  /** Activates a code discount. */
  discountCodeActivate?: Maybe<DiscountCodeActivatePayload>
  /** Creates a basic code discount. */
  discountCodeBasicCreate?: Maybe<DiscountCodeBasicCreatePayload>
  /** Updates a basic code discount. */
  discountCodeBasicUpdate?: Maybe<DiscountCodeBasicUpdatePayload>
  /**
   * Asynchronously activate code discounts in bulk using a search query, a `savedSearchId` or a list of IDs.
   *
   */
  discountCodeBulkActivate?: Maybe<DiscountCodeBulkActivatePayload>
  /**
   * Asynchronously deactivates code discounts in bulk using a search query, a `savedSearchId` or a list of IDs.
   *
   */
  discountCodeBulkDeactivate?: Maybe<DiscountCodeBulkDeactivatePayload>
  /**
   * Asynchronously delete code discounts in bulk using a search query, a `savedSearchId` or a list of IDs.
   *
   */
  discountCodeBulkDelete?: Maybe<DiscountCodeBulkDeletePayload>
  /** Creates a BXGY code discount. */
  discountCodeBxgyCreate?: Maybe<DiscountCodeBxgyCreatePayload>
  /** Updates a BXGY code discount. */
  discountCodeBxgyUpdate?: Maybe<DiscountCodeBxgyUpdatePayload>
  /** Deactivates a code discount. */
  discountCodeDeactivate?: Maybe<DiscountCodeDeactivatePayload>
  /** Deletes a code discount. */
  discountCodeDelete?: Maybe<DiscountCodeDeletePayload>
  /** Creates a free shipping code discount. */
  discountCodeFreeShippingCreate?: Maybe<DiscountCodeFreeShippingCreatePayload>
  /** Updates a free shipping code discount. */
  discountCodeFreeShippingUpdate?: Maybe<DiscountCodeFreeShippingUpdatePayload>
  /**
   * Asynchronously delete discount redeem codes in bulk. Specify the redeem codes to delete by providing a
   * search query, a `savedSearchId`, or a list of redeem code IDs.
   *
   */
  discountCodeRedeemCodeBulkDelete?: Maybe<DiscountCodeRedeemCodeBulkDeletePayload>
  /**
   * Asynchronously add discount redeem codes in bulk. Specify the codes to add
   * and the discount code ID that the codes will belong to.
   *
   */
  discountRedeemCodeBulkAdd?: Maybe<DiscountRedeemCodeBulkAddPayload>
  /**
   * Calculates the properties of a draft order. Useful for determining information
   * such as total taxes or price without actually creating a draft order.
   *
   */
  draftOrderCalculate?: Maybe<DraftOrderCalculatePayload>
  /** Completes a draft order and creates an order. */
  draftOrderComplete?: Maybe<DraftOrderCompletePayload>
  /** Creates a draft order. */
  draftOrderCreate?: Maybe<DraftOrderCreatePayload>
  /** Deletes a draft order. */
  draftOrderDelete?: Maybe<DraftOrderDeletePayload>
  /** Previews a draft order invoice email. */
  draftOrderInvoicePreview?: Maybe<DraftOrderInvoicePreviewPayload>
  /** Sends an email invoice for a draft order. */
  draftOrderInvoiceSend?: Maybe<DraftOrderInvoiceSendPayload>
  /** Updates a draft order. */
  draftOrderUpdate?: Maybe<DraftOrderUpdatePayload>
  /**
   * Creates a new Amazon EventBridge webhook subscription.
   *
   */
  eventBridgeWebhookSubscriptionCreate?: Maybe<EventBridgeWebhookSubscriptionCreatePayload>
  /**
   * Updates an Amazon EventBridge webhook subscription.
   *
   */
  eventBridgeWebhookSubscriptionUpdate?: Maybe<EventBridgeWebhookSubscriptionUpdatePayload>
  /**
   * Creates file assets using an external URL or for files that were previously uploaded using the
   * [stagedUploadsCreate mutation](https://shopify.dev/api/admin-graphql/latest/mutations/stageduploadscreate).
   * These files are added to the [Files page](https://shopify.com/admin/settings/files) in Shopify admin.
   *
   */
  fileCreate?: Maybe<FileCreatePayload>
  /** Deletes file assets. */
  fileDelete?: Maybe<FileDeletePayload>
  /** Updates a file asset. */
  fileUpdate?: Maybe<FileUpdatePayload>
  /** Triggers a workflow defined by the merchant in Shopify Flow. To learn more, see [_Create Shopify Flow triggers_](https://shopify.dev/apps/flow/triggers). */
  flowTriggerReceive?: Maybe<FlowTriggerReceivePayload>
  /** Cancels a fulfillment. */
  fulfillmentCancel?: Maybe<FulfillmentCancelPayload>
  /**
   * Creates a fulfillment for an order.
   * @deprecated Use the new [fulfillmentOrder](https://shopify.dev/tutorials/manage-fulfillments-with-fulfillment-and-fulfillmentorder-resources) APIs to manage fulfillments.
   */
  fulfillmentCreate?: Maybe<FulfillmentCreatePayload>
  /**
   * Creates a fulfillment for one or many fulfillment orders.
   * The fulfillment orders are associated with the same order and are assigned to the same location.
   *
   */
  fulfillmentCreateV2?: Maybe<FulfillmentCreateV2Payload>
  /** Accept a cancellation request sent to a fulfillment service for a fulfillment order. */
  fulfillmentOrderAcceptCancellationRequest?: Maybe<FulfillmentOrderAcceptCancellationRequestPayload>
  /** Accepts a fulfillment request sent to a fulfillment service for a fulfillment order. */
  fulfillmentOrderAcceptFulfillmentRequest?: Maybe<FulfillmentOrderAcceptFulfillmentRequestPayload>
  /** Marks a fulfillment order as canceled. */
  fulfillmentOrderCancel?: Maybe<FulfillmentOrderCancelPayload>
  /** Marks an in-progress fulfillment order as incomplete, indicating the fulfillment service is unable to ship any remaining items and intends to close the fulfillment order. */
  fulfillmentOrderClose?: Maybe<FulfillmentOrderClosePayload>
  /** Applies a fulfillment hold on an open fulfillment order. */
  fulfillmentOrderHold?: Maybe<FulfillmentOrderHoldPayload>
  /** Moves a fulfillment order to a new location. */
  fulfillmentOrderMove?: Maybe<FulfillmentOrderMovePayload>
  /** Marks a scheduled fulfillment order as open. */
  fulfillmentOrderOpen?: Maybe<FulfillmentOrderOpenPayload>
  /** Rejects a cancellation request sent to a fulfillment service for a fulfillment order. */
  fulfillmentOrderRejectCancellationRequest?: Maybe<FulfillmentOrderRejectCancellationRequestPayload>
  /** Rejects a fulfillment request sent to a fulfillment service for a fulfillment order. */
  fulfillmentOrderRejectFulfillmentRequest?: Maybe<FulfillmentOrderRejectFulfillmentRequestPayload>
  /** Releases the fulfillment hold on a fulfillment order. */
  fulfillmentOrderReleaseHold?: Maybe<FulfillmentOrderReleaseHoldPayload>
  /** Reschedules a scheduled fulfillment order. */
  fulfillmentOrderReschedule?: Maybe<FulfillmentOrderReschedulePayload>
  /** Sends a cancellation request to the fulfillment service of a fulfillment order. */
  fulfillmentOrderSubmitCancellationRequest?: Maybe<FulfillmentOrderSubmitCancellationRequestPayload>
  /** Sends a fulfillment request to the fulfillment service of a fulfillment order. */
  fulfillmentOrderSubmitFulfillmentRequest?: Maybe<FulfillmentOrderSubmitFulfillmentRequestPayload>
  /** Creates a fulfillment service. */
  fulfillmentServiceCreate?: Maybe<FulfillmentServiceCreatePayload>
  /** Deletes a fulfillment service. */
  fulfillmentServiceDelete?: Maybe<FulfillmentServiceDeletePayload>
  /** Updates a fulfillment service. */
  fulfillmentServiceUpdate?: Maybe<FulfillmentServiceUpdatePayload>
  /**
   * Updates tracking information for a fulfillment.
   * @deprecated Use the new [fulfillmentOrder](https://shopify.dev/tutorials/manage-fulfillments-with-fulfillment-and-fulfillmentorder-resources) APIs to manage fulfillments.
   */
  fulfillmentTrackingInfoUpdate?: Maybe<FulfillmentTrackingInfoUpdatePayload>
  /** Updates tracking information for a fulfillment. */
  fulfillmentTrackingInfoUpdateV2?: Maybe<FulfillmentTrackingInfoUpdateV2Payload>
  /** Create a gift card. */
  giftCardCreate?: Maybe<GiftCardCreatePayload>
  /**
   * Disable a gift card. A disabled gift card cannot be used by a customer. A disabled gift card cannot be re-enabled.
   *
   */
  giftCardDisable?: Maybe<GiftCardDisablePayload>
  /** Update a gift card. */
  giftCardUpdate?: Maybe<GiftCardUpdatePayload>
  /** Activate an inventory item at a location. */
  inventoryActivate?: Maybe<InventoryActivatePayload>
  /** Adjusts the inventory by a certain quantity. */
  inventoryAdjustQuantity?: Maybe<InventoryAdjustQuantityPayload>
  /** Adjusts the inventory at a location for multiple inventory items. */
  inventoryBulkAdjustQuantityAtLocation?: Maybe<InventoryBulkAdjustQuantityAtLocationPayload>
  /** Stop tracking an inventory item's quantities at a location. */
  inventoryDeactivate?: Maybe<InventoryDeactivatePayload>
  /** Updates an inventory item. */
  inventoryItemUpdate?: Maybe<InventoryItemUpdatePayload>
  /** Create new marketing activity. */
  marketingActivityCreate?: Maybe<MarketingActivityCreatePayload>
  /** Updates a marketing activity with the latest information. */
  marketingActivityUpdate?: Maybe<MarketingActivityUpdatePayload>
  /** Creates a new marketing event engagement for a marketing activity. */
  marketingEngagementCreate?: Maybe<MarketingEngagementCreatePayload>
  /**
   * Creates a metafield definition.
   *
   */
  metafieldDefinitionCreate?: Maybe<MetafieldDefinitionCreatePayload>
  /**
   * Delete a metafield definition.
   * Optionally deletes all associated metafields asynchronously when specified.
   *
   */
  metafieldDefinitionDelete?: Maybe<MetafieldDefinitionDeletePayload>
  /**
   * You can organize your metafields in your Shopify admin by pinning/unpinning metafield definitions.
   * The order of your pinned metafield definitions determines the order in which your metafields are displayed
   * on the corresponding pages in your Shopify admin. By default, only pinned metafields are automatically displayed.
   *
   */
  metafieldDefinitionPin?: Maybe<MetafieldDefinitionPinPayload>
  /**
   * You can organize your metafields in your Shopify admin by pinning/unpinning metafield definitions.
   * The order of your pinned metafield definitions determines the order in which your metafields are displayed
   * on the corresponding pages in your Shopify admin. By default, only pinned metafields are automatically displayed.
   *
   */
  metafieldDefinitionUnpin?: Maybe<MetafieldDefinitionUnpinPayload>
  /**
   * Updates a metafield definition.
   *
   */
  metafieldDefinitionUpdate?: Maybe<MetafieldDefinitionUpdatePayload>
  /** Deletes a metafield. */
  metafieldDelete?: Maybe<MetafieldDeletePayload>
  /**
   * Creates a `MetafieldStorefrontVisibility` record to make all metafields that belong to the specified resource
   * and have the established `namespace` and `key` combination visible in the Storefront API.
   *
   */
  metafieldStorefrontVisibilityCreate?: Maybe<MetafieldStorefrontVisibilityCreatePayload>
  /**
   * Deletes a `MetafieldStorefrontVisibility` record. All metafields that belongs to the specified record will no
   * longer be visible in the Storefront API.
   *
   */
  metafieldStorefrontVisibilityDelete?: Maybe<MetafieldStorefrontVisibilityDeletePayload>
  /**
   * Sets metafield values. Metafield values will be set regardless if they were previously created or not.
   *
   * Allows a maximum of 25 metafields to be set at a time.
   *
   */
  metafieldsSet?: Maybe<MetafieldsSetPayload>
  /** Captures payment for an authorized transaction on an order. An order can only be captured if it has a successful authorization transaction. Capturing an order will claim the money reserved by the authorization. */
  orderCapture?: Maybe<OrderCapturePayload>
  /**
   * Closes an open order.
   *
   */
  orderClose?: Maybe<OrderClosePayload>
  /** Adds a custom line item to an existing order. For example, you could add a gift wrapping service as a [custom line item](https://shopify.dev/api/examples/order-editing#add-a-custom-line-item). To learn how to edit existing orders, refer to [Edit an existing order with Admin API](https://shopify.dev/api/examples/order-editing). */
  orderEditAddCustomItem?: Maybe<OrderEditAddCustomItemPayload>
  /** Adds a discount to a newly added line item on the current order edit. More information on how to use the GraphQL Admin API to edit an existing order can be found in [this guide](https://shopify.dev/api/examples/order-editing). */
  orderEditAddLineItemDiscount?: Maybe<OrderEditAddLineItemDiscountPayload>
  /** Adds a line item from an existing product variant. */
  orderEditAddVariant?: Maybe<OrderEditAddVariantPayload>
  /**
   * Starts editing an order. Mutations are operating on `OrderEdit`.
   * All order edits start with `orderEditBegin`, have any number of `orderEdit`* mutations made, and end with `orderEditCommit`.
   *
   */
  orderEditBegin?: Maybe<OrderEditBeginPayload>
  /**
   * Applies and saves staged changes to an order. Mutations are operating on `OrderEdit`.
   * All order edits start with `orderEditBegin`, have any number of `orderEdit`* mutations made, and end with `orderEditCommit`.
   *
   */
  orderEditCommit?: Maybe<OrderEditCommitPayload>
  /** Removes a line item discount that was applied as part of an order edit. */
  orderEditRemoveLineItemDiscount?: Maybe<OrderEditRemoveLineItemDiscountPayload>
  /** Sets the quantity of a line item on an order that is being edited. More information on how to use the GraphQL Admin API to edit an existing order can be found in [this guide](https://shopify.dev/api/examples/order-editing). */
  orderEditSetQuantity?: Maybe<OrderEditSetQuantityPayload>
  /** Sends an email invoice for an order. */
  orderInvoiceSend?: Maybe<OrderInvoiceSendPayload>
  /**
   * Marks an order as paid. You can only mark an order as paid if it isn't already fully paid.
   *
   */
  orderMarkAsPaid?: Maybe<OrderMarkAsPaidPayload>
  /**
   * Opens a closed order.
   *
   */
  orderOpen?: Maybe<OrderOpenPayload>
  /** Updates the fields of an order. */
  orderUpdate?: Maybe<OrderUpdatePayload>
  /** Create payment terms. */
  paymentTermsCreate?: Maybe<PaymentTermsCreatePayload>
  /** Delete payment terms. */
  paymentTermsDelete?: Maybe<PaymentTermsDeletePayload>
  /** Update payment terms. */
  paymentTermsUpdate?: Maybe<PaymentTermsUpdatePayload>
  /** Creates a price list. You can use the `priceListCreate` mutation to create a new price list for a country. This enables you to sell your products with international pricing. */
  priceListCreate?: Maybe<PriceListCreatePayload>
  /** Delete a price list. You can use the `priceListDelete` mutation to delete a price list, so that it no longer applies for products in that country. To delete a price list, you need to specify the price list ID. */
  priceListDelete?: Maybe<PriceListDeletePayload>
  /** Creates or updates fixed prices on a price list. You can use the `priceListFixedPricesAdd` mutation to set a fixed price for specific product variants. This lets you change product variant pricing on a per country basis. Any existing fixed price list prices for these variants will be overwritten. */
  priceListFixedPricesAdd?: Maybe<PriceListFixedPricesAddPayload>
  /** Deletes specific fixed prices from a price list using a product variant ID. You can use the `priceListFixedPricesDelete` mutation to delete a set of fixed prices from a price list. After deleting the set of fixed prices from the price list, the price of each product variant reverts to the original price that was determined by the price list adjustment. */
  priceListFixedPricesDelete?: Maybe<PriceListFixedPricesDeletePayload>
  /** Update a price list. You can update a price list to make changes to percentage-based price adjustments. You can use the `priceListUpdate` mutation to update an existing price list for a country. This lets you change product pricing on a per country basis. As part of the mutation, you can change the name, percentage-based adjustment, currency, and country. */
  priceListUpdate?: Maybe<PriceListUpdatePayload>
  /** Activate a price rule. */
  priceRuleActivate?: Maybe<PriceRuleActivatePayload>
  /** Create a price rule using the input. */
  priceRuleCreate?: Maybe<PriceRuleCreatePayload>
  /** Deactivate a price rule. */
  priceRuleDeactivate?: Maybe<PriceRuleDeactivatePayload>
  /** Delete a price rule. */
  priceRuleDelete?: Maybe<PriceRuleDeletePayload>
  /** Create a discount code for a price rule. */
  priceRuleDiscountCodeCreate?: Maybe<PriceRuleDiscountCodeCreatePayload>
  /** Update a discount code for a price rule. */
  priceRuleDiscountCodeUpdate?: Maybe<PriceRuleDiscountCodeUpdatePayload>
  /** Update a price rule using its id and an input. */
  priceRuleUpdate?: Maybe<PriceRuleUpdatePayload>
  /**
   * Deletes a private metafield.
   * Private metafields are automatically deleted when the app that created them is uninstalled.
   *
   */
  privateMetafieldDelete?: Maybe<PrivateMetafieldDeletePayload>
  /**
   * Creates or updates a private metafield. Use private metafields when you don't want the metafield data to be accessible by merchants or other apps.
   * Private metafields are accessible only by the application that created them and only from the GraphQL Admin API.
   *
   * An application can create a maximum of 10 private metafields per shop resource.
   *
   */
  privateMetafieldUpsert?: Maybe<PrivateMetafieldUpsertPayload>
  /** Appends images to a product. */
  productAppendImages?: Maybe<ProductAppendImagesPayload>
  /** Changes the status of a product. This allows you to set the availability of the product across all channels. */
  productChangeStatus?: Maybe<ProductChangeStatusPayload>
  /** Creates a product. */
  productCreate?: Maybe<ProductCreatePayload>
  /** Creates media for a product. */
  productCreateMedia?: Maybe<ProductCreateMediaPayload>
  /** Deletes a product, including all associated variants and media. */
  productDelete?: Maybe<ProductDeletePayload>
  /** Removes product images from the product. */
  productDeleteImages?: Maybe<ProductDeleteImagesPayload>
  /** Deletes media for a product. */
  productDeleteMedia?: Maybe<ProductDeleteMediaPayload>
  /** Duplicates a product. */
  productDuplicate?: Maybe<ProductDuplicatePayload>
  /** Updates an image of a product. */
  productImageUpdate?: Maybe<ProductImageUpdatePayload>
  /**
   * Adds multiple selling plan groups to a product.
   *
   */
  productJoinSellingPlanGroups?: Maybe<ProductJoinSellingPlanGroupsPayload>
  /**
   * Removes multiple groups from a product.
   *
   */
  productLeaveSellingPlanGroups?: Maybe<ProductLeaveSellingPlanGroupsPayload>
  /**
   * Publishes a product. Products that are sold exclusively on subscription (`requiresSellingPlan: true`) can only be published on online stores.
   * @deprecated Use `publishablePublish` instead
   */
  productPublish?: Maybe<ProductPublishPayload>
  /** Asynchronously reorders a set of images for a given product. */
  productReorderImages?: Maybe<ProductReorderImagesPayload>
  /** Asynchronously Reoders the media attached to a product. */
  productReorderMedia?: Maybe<ProductReorderMediaPayload>
  /**
   * Unpublishes a product.
   * @deprecated Use `publishableUnpublish` instead
   */
  productUnpublish?: Maybe<ProductUnpublishPayload>
  /**
   * Updates a product. If you update a product, and only include some variants in the update,
   * then any variants not included will be deleted. To safely manage variants without the risk of
   * deleting excluded variants, use
   * [productVariantsBulkUpdate](https://shopify.dev/api/admin-graphql/latest/mutations/productvariantsbulkupdate).
   * If you want to update a single variant, then use
   * [productVariantUpdate](https://shopify.dev/api/admin-graphql/latest/mutations/productvariantupdate).
   *
   */
  productUpdate?: Maybe<ProductUpdatePayload>
  /** Updates media for a product. */
  productUpdateMedia?: Maybe<ProductUpdateMediaPayload>
  /** Appends media from a product to variants of the product. */
  productVariantAppendMedia?: Maybe<ProductVariantAppendMediaPayload>
  /** Creates a product variant. */
  productVariantCreate?: Maybe<ProductVariantCreatePayload>
  /** Deletes a product variant. */
  productVariantDelete?: Maybe<ProductVariantDeletePayload>
  /** Deletes media from product variants. */
  productVariantDetachMedia?: Maybe<ProductVariantDetachMediaPayload>
  /**
   * Adds multiple selling plan groups to a product variant.
   *
   */
  productVariantJoinSellingPlanGroups?: Maybe<ProductVariantJoinSellingPlanGroupsPayload>
  /**
   * Remove multiple groups from a product variant.
   *
   */
  productVariantLeaveSellingPlanGroups?: Maybe<ProductVariantLeaveSellingPlanGroupsPayload>
  /** Updates a product variant. */
  productVariantUpdate?: Maybe<ProductVariantUpdatePayload>
  /** Creates product variants in bulk. */
  productVariantsBulkCreate?: Maybe<ProductVariantsBulkCreatePayload>
  /** Deletes product variants in bulk. */
  productVariantsBulkDelete?: Maybe<ProductVariantsBulkDeletePayload>
  /** Bulk reorder product variants. */
  productVariantsBulkReorder?: Maybe<ProductVariantsBulkReorderPayload>
  /** Updates product variants in bulk. */
  productVariantsBulkUpdate?: Maybe<ProductVariantsBulkUpdatePayload>
  /** Creates a new Google Cloud Pub/Sub webhook subscription. */
  pubSubWebhookSubscriptionCreate?: Maybe<PubSubWebhookSubscriptionCreatePayload>
  /** Updates a Google Cloud Pub/Sub webhook subscription. */
  pubSubWebhookSubscriptionUpdate?: Maybe<PubSubWebhookSubscriptionUpdatePayload>
  /** Publishes a resource to a channel. If the resource is a product, then it's visible in the channel only if the product status is `active`. Products that are sold exclusively on subscription (`requiresSellingPlan: true`) can be published only on online stores. */
  publishablePublish?: Maybe<PublishablePublishPayload>
  /** Publishes a resource to current channel. If the resource is a product, then it's visible in the channel only if the product status is `active`. Products that are sold exclusively on subscription (`requiresSellingPlan: true`) can be published only on online stores. */
  publishablePublishToCurrentChannel?: Maybe<PublishablePublishToCurrentChannelPayload>
  /** Unpublishes a resource from a channel. If the resource is a product, then it's visible in the channel only if the product status is `active`. */
  publishableUnpublish?: Maybe<PublishableUnpublishPayload>
  /** Unpublishes a resource from the current channel. If the resource is a product, then it's visible in the channel only if the product status is `active`. */
  publishableUnpublishToCurrentChannel?: Maybe<PublishableUnpublishToCurrentChannelPayload>
  /** Creates a refund. */
  refundCreate?: Maybe<RefundCreatePayload>
  /** Creates a saved search. */
  savedSearchCreate?: Maybe<SavedSearchCreatePayload>
  /** Delete a saved search. */
  savedSearchDelete?: Maybe<SavedSearchDeletePayload>
  /** Update a saved search. */
  savedSearchUpdate?: Maybe<SavedSearchUpdatePayload>
  /**
   * Creates a new script tag.
   *
   */
  scriptTagCreate?: Maybe<ScriptTagCreatePayload>
  /**
   * Deletes a script tag.
   *
   */
  scriptTagDelete?: Maybe<ScriptTagDeletePayload>
  /**
   * Updates a script tag.
   *
   */
  scriptTagUpdate?: Maybe<ScriptTagUpdatePayload>
  /**
   * Adds multiple product variants to a selling plan group.
   *
   */
  sellingPlanGroupAddProductVariants?: Maybe<SellingPlanGroupAddProductVariantsPayload>
  /**
   * Adds multiple products to a selling plan group.
   *
   */
  sellingPlanGroupAddProducts?: Maybe<SellingPlanGroupAddProductsPayload>
  /** Creates a Selling Plan Group. */
  sellingPlanGroupCreate?: Maybe<SellingPlanGroupCreatePayload>
  /** Delete a Selling Plan Group. */
  sellingPlanGroupDelete?: Maybe<SellingPlanGroupDeletePayload>
  /**
   * Removes multiple product variants from a selling plan group.
   *
   */
  sellingPlanGroupRemoveProductVariants?: Maybe<SellingPlanGroupRemoveProductVariantsPayload>
  /**
   * Removes multiple products from a selling plan group.
   *
   */
  sellingPlanGroupRemoveProducts?: Maybe<SellingPlanGroupRemoveProductsPayload>
  /** Update a Selling Plan Group. */
  sellingPlanGroupUpdate?: Maybe<SellingPlanGroupUpdatePayload>
  /** Deletes a shipping package. */
  shippingPackageDelete?: Maybe<ShippingPackageDeletePayload>
  /**
   * Set a shipping package as the default.
   * The default shipping package is the one used to calculate shipping costs on checkout.
   *
   */
  shippingPackageMakeDefault?: Maybe<ShippingPackageMakeDefaultPayload>
  /** Updates a shipping package. */
  shippingPackageUpdate?: Maybe<ShippingPackageUpdatePayload>
  /** Deletes a locale for a shop. This also deletes all translations of this locale. */
  shopLocaleDisable?: Maybe<ShopLocaleDisablePayload>
  /** Adds a locale for a shop. The newly added locale is in the unpublished state. */
  shopLocaleEnable?: Maybe<ShopLocaleEnablePayload>
  /** Updates a locale for a shop. */
  shopLocaleUpdate?: Maybe<ShopLocaleUpdatePayload>
  /** Updates a shop policy. */
  shopPolicyUpdate?: Maybe<ShopPolicyUpdatePayload>
  /**
   * Generates the URL and signed paramaters needed to upload an asset to Shopify.
   * @deprecated Use `stagedUploadsCreate` instead
   */
  stagedUploadTargetGenerate?: Maybe<StagedUploadTargetGeneratePayload>
  /**
   * Uploads multiple images.
   * @deprecated Use `stagedUploadsCreate` instead
   */
  stagedUploadTargetsGenerate?: Maybe<StagedUploadTargetsGeneratePayload>
  /** Creates staged upload target URLs for each input and is the first step in the upload process. The returned upload targets with URLs can be used as endpoints to upload the files. */
  stagedUploadsCreate?: Maybe<StagedUploadsCreatePayload>
  /**
   * Activates the specified standard metafield definition from its template.
   *
   * Refer to the [list of standard metafield definition templates](https://shopify.dev/api/admin/graphql/reference/common-objects/standardMetafieldDefinitionTemplates#examples-Get_a_list_of_standard_metafield_definition_templates).
   *
   */
  standardMetafieldDefinitionEnable?: Maybe<StandardMetafieldDefinitionEnablePayload>
  /** Creates a storefront access token. */
  storefrontAccessTokenCreate?: Maybe<StorefrontAccessTokenCreatePayload>
  /** Deletes a storefront access token. */
  storefrontAccessTokenDelete?: Maybe<StorefrontAccessTokenDeletePayload>
  /** Creates a new subscription billing attempt. For more information, refer to [Contracts](https://shopify.dev/apps/subscriptions/contracts#create-a-billing-attempt). */
  subscriptionBillingAttemptCreate?: Maybe<SubscriptionBillingAttemptCreatePayload>
  /** Creates a Subscription Contract. */
  subscriptionContractCreate?: Maybe<SubscriptionContractCreatePayload>
  /** Sets the next billing date of a Subscription Contract. */
  subscriptionContractSetNextBillingDate?: Maybe<SubscriptionContractSetNextBillingDatePayload>
  /** Updates a Subscription Contract. */
  subscriptionContractUpdate?: Maybe<SubscriptionContractUpdatePayload>
  /** Commits the updates of a Subscription Contract draft. */
  subscriptionDraftCommit?: Maybe<SubscriptionDraftCommitPayload>
  /** Adds a subscription discount to a subscription draft. */
  subscriptionDraftDiscountAdd?: Maybe<SubscriptionDraftDiscountAddPayload>
  /** Applies a code discount on the subscription draft. */
  subscriptionDraftDiscountCodeApply?: Maybe<SubscriptionDraftDiscountCodeApplyPayload>
  /** Removes a subscription discount from a subscription draft. */
  subscriptionDraftDiscountRemove?: Maybe<SubscriptionDraftDiscountRemovePayload>
  /** Updates a subscription discount on a subscription draft. */
  subscriptionDraftDiscountUpdate?: Maybe<SubscriptionDraftDiscountUpdatePayload>
  /** Adds a subscription free shipping discount to a subscription draft. */
  subscriptionDraftFreeShippingDiscountAdd?: Maybe<SubscriptionDraftFreeShippingDiscountAddPayload>
  /** Updates a subscription free shipping discount on a subscription draft. */
  subscriptionDraftFreeShippingDiscountUpdate?: Maybe<SubscriptionDraftFreeShippingDiscountUpdatePayload>
  /** Adds a subscription line to a subscription draft. */
  subscriptionDraftLineAdd?: Maybe<SubscriptionDraftLineAddPayload>
  /** Removes a subscription line from a subscription draft. */
  subscriptionDraftLineRemove?: Maybe<SubscriptionDraftLineRemovePayload>
  /** Updates a subscription line on a subscription draft. */
  subscriptionDraftLineUpdate?: Maybe<SubscriptionDraftLineUpdatePayload>
  /** Updates a Subscription Draft. */
  subscriptionDraftUpdate?: Maybe<SubscriptionDraftUpdatePayload>
  /** Add tags to an order, a draft order, a customer, a product, or an online store article. */
  tagsAdd?: Maybe<TagsAddPayload>
  /** Remove tags from an order, a draft order, a customer, a product, or an online store article. */
  tagsRemove?: Maybe<TagsRemovePayload>
  /** Creates or updates translations. */
  translationsRegister?: Maybe<TranslationsRegisterPayload>
  /** Deletes translations. */
  translationsRemove?: Maybe<TranslationsRemovePayload>
  /**
   * Asynchronously delete [URL redirects](https://shopify.dev/api/admin-graphql/latest/objects/UrlRedirect) in bulk.
   *
   */
  urlRedirectBulkDeleteAll?: Maybe<UrlRedirectBulkDeleteAllPayload>
  /**
   * Asynchronously delete [URLRedirect](https://shopify.dev/api/admin-graphql/latest/objects/UrlRedirect)
   * objects in bulk by IDs.
   * Learn more about [URLRedirect](https://help.shopify.com/en/manual/online-store/menus-and-links/url-redirect)
   * objects.
   *
   */
  urlRedirectBulkDeleteByIds?: Maybe<UrlRedirectBulkDeleteByIdsPayload>
  /** Asynchronously delete redirects in bulk. */
  urlRedirectBulkDeleteBySavedSearch?: Maybe<UrlRedirectBulkDeleteBySavedSearchPayload>
  /** Asynchronously delete redirects in bulk. */
  urlRedirectBulkDeleteBySearch?: Maybe<UrlRedirectBulkDeleteBySearchPayload>
  /**
   * Creates a [`UrlRedirect`](https://shopify.dev/api/admin-graphql/latest/objects/UrlRedirect) object.
   *
   */
  urlRedirectCreate?: Maybe<UrlRedirectCreatePayload>
  /**
   * Deletes a [`UrlRedirect`](https://shopify.dev/api/admin-graphql/latest/objects/UrlRedirect) object.
   *
   */
  urlRedirectDelete?: Maybe<UrlRedirectDeletePayload>
  /**
   * Creates a [`UrlRedirectImport`](https://shopify.dev/api/admin-graphql/latest/objects/UrlRedirectImport) object.
   *
   * After creating the `UrlRedirectImport` object, the `UrlRedirectImport` request can be performed using the [`urlRedirectImportSubmit`](https://shopify.dev/api/admin-graphql/latest/mutations/urlRedirectImportSubmit) mutation.
   *
   */
  urlRedirectImportCreate?: Maybe<UrlRedirectImportCreatePayload>
  /**
   * Submits a `UrlRedirectImport` request to be processed.
   *
   * The `UrlRedirectImport` request is first created with the [`urlRedirectImportCreate`](https://shopify.dev/api/admin-graphql/latest/mutations/urlRedirectImportCreate) mutation.
   *
   */
  urlRedirectImportSubmit?: Maybe<UrlRedirectImportSubmitPayload>
  /**
   * Updates a URL redirect.
   *
   */
  urlRedirectUpdate?: Maybe<UrlRedirectUpdatePayload>
  /**
   * Creates a new webhook subscription.
   *
   */
  webhookSubscriptionCreate?: Maybe<WebhookSubscriptionCreatePayload>
  /**
   * Deletes a webhook subscription.
   *
   */
  webhookSubscriptionDelete?: Maybe<WebhookSubscriptionDeletePayload>
  /**
   * Updates a webhook subscription.
   *
   */
  webhookSubscriptionUpdate?: Maybe<WebhookSubscriptionUpdatePayload>
}

/** The schema's entry point for all mutation operations. */
export type MutationAppCreditCreateArgs = {
  amount: MoneyInput
  description: Scalars['String']
  test?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry point for all mutation operations. */
export type MutationAppPurchaseOneTimeCreateArgs = {
  name: Scalars['String']
  price: MoneyInput
  returnUrl: Scalars['URL']
  test?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry point for all mutation operations. */
export type MutationAppRevenueAttributionRecordCreateArgs = {
  appRevenueAttributionRecord: AppRevenueAttributionRecordInput
}

/** The schema's entry point for all mutation operations. */
export type MutationAppRevenueAttributionRecordDeleteArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationAppSubscriptionCancelArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationAppSubscriptionCreateArgs = {
  lineItems: Array<AppSubscriptionLineItemInput>
  name: Scalars['String']
  returnUrl: Scalars['URL']
  test?: InputMaybe<Scalars['Boolean']>
  trialDays?: InputMaybe<Scalars['Int']>
}

/** The schema's entry point for all mutation operations. */
export type MutationAppSubscriptionLineItemUpdateArgs = {
  cappedAmount: MoneyInput
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationAppUsageRecordCreateArgs = {
  description: Scalars['String']
  price: MoneyInput
  subscriptionLineItemId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationBulkOperationCancelArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationBulkOperationRunMutationArgs = {
  clientIdentifier?: InputMaybe<Scalars['String']>
  mutation: Scalars['String']
  stagedUploadPath: Scalars['String']
}

/** The schema's entry point for all mutation operations. */
export type MutationBulkOperationRunQueryArgs = {
  query: Scalars['String']
}

/** The schema's entry point for all mutation operations. */
export type MutationBulkProductResourceFeedbackCreateArgs = {
  feedbackInput: Array<ProductResourceFeedbackInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationCollectionAddProductsArgs = {
  id: Scalars['ID']
  productIds: Array<Scalars['ID']>
}

/** The schema's entry point for all mutation operations. */
export type MutationCollectionCreateArgs = {
  input: CollectionInput
}

/** The schema's entry point for all mutation operations. */
export type MutationCollectionDeleteArgs = {
  input: CollectionDeleteInput
}

/** The schema's entry point for all mutation operations. */
export type MutationCollectionPublishArgs = {
  input: CollectionPublishInput
}

/** The schema's entry point for all mutation operations. */
export type MutationCollectionRemoveProductsArgs = {
  id: Scalars['ID']
  productIds: Array<Scalars['ID']>
}

/** The schema's entry point for all mutation operations. */
export type MutationCollectionReorderProductsArgs = {
  id: Scalars['ID']
  moves: Array<MoveInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationCollectionUnpublishArgs = {
  input: CollectionUnpublishInput
}

/** The schema's entry point for all mutation operations. */
export type MutationCollectionUpdateArgs = {
  input: CollectionInput
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerAddTaxExemptionsArgs = {
  customerId: Scalars['ID']
  taxExemptions: Array<TaxExemption>
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerCreateArgs = {
  input: CustomerInput
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerDeleteArgs = {
  input: CustomerDeleteInput
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerGenerateAccountActivationUrlArgs = {
  customerId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerPaymentMethodCreditCardCreateArgs = {
  billingAddress: MailingAddressInput
  customerId: Scalars['ID']
  sessionId: Scalars['String']
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerPaymentMethodCreditCardUpdateArgs = {
  billingAddress: MailingAddressInput
  id: Scalars['ID']
  sessionId: Scalars['String']
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerPaymentMethodGetUpdateUrlArgs = {
  customerPaymentMethodId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerPaymentMethodPaypalBillingAgreementCreateArgs = {
  billingAddress?: InputMaybe<MailingAddressInput>
  billingAgreementId: Scalars['String']
  customerId: Scalars['ID']
  inactive?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerPaymentMethodPaypalBillingAgreementUpdateArgs = {
  billingAddress: MailingAddressInput
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerPaymentMethodRemoteCreateArgs = {
  customerId: Scalars['ID']
  remoteReference: CustomerPaymentMethodRemoteInput
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerPaymentMethodRemoteCreditCardCreateArgs = {
  customerId: Scalars['ID']
  stripeCustomerId: Scalars['String']
  stripePaymentMethodId?: InputMaybe<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerPaymentMethodRevokeArgs = {
  customerPaymentMethodId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerPaymentMethodSendUpdateEmailArgs = {
  customerPaymentMethodId: Scalars['ID']
  email?: InputMaybe<EmailInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerRemoveTaxExemptionsArgs = {
  customerId: Scalars['ID']
  taxExemptions: Array<TaxExemption>
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerReplaceTaxExemptionsArgs = {
  customerId: Scalars['ID']
  taxExemptions: Array<TaxExemption>
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerSmsMarketingConsentUpdateArgs = {
  input: CustomerSmsMarketingConsentUpdateInput
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerUpdateArgs = {
  input: CustomerInput
}

/** The schema's entry point for all mutation operations. */
export type MutationCustomerUpdateDefaultAddressArgs = {
  addressId: Scalars['ID']
  customerId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDeliveryProfileCreateArgs = {
  profile: DeliveryProfileInput
}

/** The schema's entry point for all mutation operations. */
export type MutationDeliveryProfileRemoveArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDeliveryProfileUpdateArgs = {
  id: Scalars['ID']
  leaveLegacyModeProfiles?: InputMaybe<Scalars['Boolean']>
  profile: DeliveryProfileInput
}

/** The schema's entry point for all mutation operations. */
export type MutationDeliverySettingUpdateArgs = {
  setting: DeliverySettingInput
}

/** The schema's entry point for all mutation operations. */
export type MutationDeliveryShippingOriginAssignArgs = {
  locationId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountAutomaticActivateArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountAutomaticBasicCreateArgs = {
  automaticBasicDiscount: DiscountAutomaticBasicInput
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountAutomaticBasicUpdateArgs = {
  automaticBasicDiscount: DiscountAutomaticBasicInput
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountAutomaticBulkDeleteArgs = {
  ids?: InputMaybe<Array<Scalars['ID']>>
  savedSearchId?: InputMaybe<Scalars['ID']>
  search?: InputMaybe<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountAutomaticBxgyCreateArgs = {
  automaticBxgyDiscount: DiscountAutomaticBxgyInput
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountAutomaticBxgyUpdateArgs = {
  automaticBxgyDiscount: DiscountAutomaticBxgyInput
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountAutomaticDeactivateArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountAutomaticDeleteArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountCodeActivateArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountCodeBasicCreateArgs = {
  basicCodeDiscount: DiscountCodeBasicInput
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountCodeBasicUpdateArgs = {
  basicCodeDiscount: DiscountCodeBasicInput
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountCodeBulkActivateArgs = {
  ids?: InputMaybe<Array<Scalars['ID']>>
  savedSearchId?: InputMaybe<Scalars['ID']>
  search?: InputMaybe<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountCodeBulkDeactivateArgs = {
  ids?: InputMaybe<Array<Scalars['ID']>>
  savedSearchId?: InputMaybe<Scalars['ID']>
  search?: InputMaybe<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountCodeBulkDeleteArgs = {
  ids?: InputMaybe<Array<Scalars['ID']>>
  savedSearchId?: InputMaybe<Scalars['ID']>
  search?: InputMaybe<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountCodeBxgyCreateArgs = {
  bxgyCodeDiscount: DiscountCodeBxgyInput
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountCodeBxgyUpdateArgs = {
  bxgyCodeDiscount: DiscountCodeBxgyInput
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountCodeDeactivateArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountCodeDeleteArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountCodeFreeShippingCreateArgs = {
  freeShippingCodeDiscount: DiscountCodeFreeShippingInput
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountCodeFreeShippingUpdateArgs = {
  freeShippingCodeDiscount: DiscountCodeFreeShippingInput
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountCodeRedeemCodeBulkDeleteArgs = {
  discountId: Scalars['ID']
  ids?: InputMaybe<Array<Scalars['ID']>>
  savedSearchId?: InputMaybe<Scalars['ID']>
  search?: InputMaybe<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationDiscountRedeemCodeBulkAddArgs = {
  codes: Array<DiscountRedeemCodeInput>
  discountId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDraftOrderCalculateArgs = {
  input: DraftOrderInput
}

/** The schema's entry point for all mutation operations. */
export type MutationDraftOrderCompleteArgs = {
  id: Scalars['ID']
  paymentPending?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry point for all mutation operations. */
export type MutationDraftOrderCreateArgs = {
  input: DraftOrderInput
}

/** The schema's entry point for all mutation operations. */
export type MutationDraftOrderDeleteArgs = {
  input: DraftOrderDeleteInput
}

/** The schema's entry point for all mutation operations. */
export type MutationDraftOrderInvoicePreviewArgs = {
  email?: InputMaybe<EmailInput>
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDraftOrderInvoiceSendArgs = {
  email?: InputMaybe<EmailInput>
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationDraftOrderUpdateArgs = {
  id: Scalars['ID']
  input: DraftOrderInput
}

/** The schema's entry point for all mutation operations. */
export type MutationEventBridgeWebhookSubscriptionCreateArgs = {
  topic: WebhookSubscriptionTopic
  webhookSubscription: EventBridgeWebhookSubscriptionInput
}

/** The schema's entry point for all mutation operations. */
export type MutationEventBridgeWebhookSubscriptionUpdateArgs = {
  id: Scalars['ID']
  webhookSubscription: EventBridgeWebhookSubscriptionInput
}

/** The schema's entry point for all mutation operations. */
export type MutationFileCreateArgs = {
  files: Array<FileCreateInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationFileDeleteArgs = {
  fileIds: Array<Scalars['ID']>
}

/** The schema's entry point for all mutation operations. */
export type MutationFileUpdateArgs = {
  files: Array<FileUpdateInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationFlowTriggerReceiveArgs = {
  body: Scalars['String']
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentCancelArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentCreateArgs = {
  input: FulfillmentInput
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentCreateV2Args = {
  fulfillment: FulfillmentV2Input
  message?: InputMaybe<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentOrderAcceptCancellationRequestArgs = {
  id: Scalars['ID']
  message?: InputMaybe<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentOrderAcceptFulfillmentRequestArgs = {
  id: Scalars['ID']
  message?: InputMaybe<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentOrderCancelArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentOrderCloseArgs = {
  id: Scalars['ID']
  message?: InputMaybe<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentOrderHoldArgs = {
  fulfillmentHold: FulfillmentOrderHoldInput
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentOrderMoveArgs = {
  id: Scalars['ID']
  newLocationId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentOrderOpenArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentOrderRejectCancellationRequestArgs = {
  id: Scalars['ID']
  message?: InputMaybe<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentOrderRejectFulfillmentRequestArgs = {
  id: Scalars['ID']
  message?: InputMaybe<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentOrderReleaseHoldArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentOrderRescheduleArgs = {
  fulfillAt: Scalars['DateTime']
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentOrderSubmitCancellationRequestArgs = {
  id: Scalars['ID']
  message?: InputMaybe<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentOrderSubmitFulfillmentRequestArgs = {
  fulfillmentOrderLineItems?: InputMaybe<Array<FulfillmentOrderLineItemInput>>
  id: Scalars['ID']
  message?: InputMaybe<Scalars['String']>
  notifyCustomer?: InputMaybe<Scalars['Boolean']>
  shippingMethod?: InputMaybe<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentServiceCreateArgs = {
  callbackUrl?: InputMaybe<Scalars['URL']>
  fulfillmentOrdersOptIn?: InputMaybe<Scalars['Boolean']>
  inventoryManagement?: InputMaybe<Scalars['Boolean']>
  name: Scalars['String']
  trackingSupport?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentServiceDeleteArgs = {
  destinationLocationId?: InputMaybe<Scalars['ID']>
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentServiceUpdateArgs = {
  callbackUrl?: InputMaybe<Scalars['URL']>
  fulfillmentOrdersOptIn?: InputMaybe<Scalars['Boolean']>
  id: Scalars['ID']
  name?: InputMaybe<Scalars['String']>
  trackingSupport?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentTrackingInfoUpdateArgs = {
  fulfillmentId: Scalars['ID']
  trackingInfoUpdateInput: TrackingInfoUpdateInput
}

/** The schema's entry point for all mutation operations. */
export type MutationFulfillmentTrackingInfoUpdateV2Args = {
  fulfillmentId: Scalars['ID']
  notifyCustomer?: InputMaybe<Scalars['Boolean']>
  trackingInfoInput: FulfillmentTrackingInput
}

/** The schema's entry point for all mutation operations. */
export type MutationGiftCardCreateArgs = {
  input: GiftCardCreateInput
}

/** The schema's entry point for all mutation operations. */
export type MutationGiftCardDisableArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationGiftCardUpdateArgs = {
  id: Scalars['ID']
  input: GiftCardUpdateInput
}

/** The schema's entry point for all mutation operations. */
export type MutationInventoryActivateArgs = {
  available?: InputMaybe<Scalars['Int']>
  inventoryItemId: Scalars['ID']
  locationId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationInventoryAdjustQuantityArgs = {
  input: InventoryAdjustQuantityInput
}

/** The schema's entry point for all mutation operations. */
export type MutationInventoryBulkAdjustQuantityAtLocationArgs = {
  inventoryItemAdjustments: Array<InventoryAdjustItemInput>
  locationId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationInventoryDeactivateArgs = {
  inventoryLevelId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationInventoryItemUpdateArgs = {
  id: Scalars['ID']
  input: InventoryItemUpdateInput
}

/** The schema's entry point for all mutation operations. */
export type MutationMarketingActivityCreateArgs = {
  input: MarketingActivityCreateInput
}

/** The schema's entry point for all mutation operations. */
export type MutationMarketingActivityUpdateArgs = {
  input: MarketingActivityUpdateInput
}

/** The schema's entry point for all mutation operations. */
export type MutationMarketingEngagementCreateArgs = {
  marketingActivityId: Scalars['ID']
  marketingEngagement: MarketingEngagementInput
}

/** The schema's entry point for all mutation operations. */
export type MutationMetafieldDefinitionCreateArgs = {
  definition: MetafieldDefinitionInput
}

/** The schema's entry point for all mutation operations. */
export type MutationMetafieldDefinitionDeleteArgs = {
  deleteAllAssociatedMetafields?: InputMaybe<Scalars['Boolean']>
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationMetafieldDefinitionPinArgs = {
  definitionId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationMetafieldDefinitionUnpinArgs = {
  definitionId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationMetafieldDefinitionUpdateArgs = {
  definition: MetafieldDefinitionUpdateInput
}

/** The schema's entry point for all mutation operations. */
export type MutationMetafieldDeleteArgs = {
  input: MetafieldDeleteInput
}

/** The schema's entry point for all mutation operations. */
export type MutationMetafieldStorefrontVisibilityCreateArgs = {
  input: MetafieldStorefrontVisibilityInput
}

/** The schema's entry point for all mutation operations. */
export type MutationMetafieldStorefrontVisibilityDeleteArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationMetafieldsSetArgs = {
  metafields: Array<MetafieldsSetInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationOrderCaptureArgs = {
  input: OrderCaptureInput
}

/** The schema's entry point for all mutation operations. */
export type MutationOrderCloseArgs = {
  input: OrderCloseInput
}

/** The schema's entry point for all mutation operations. */
export type MutationOrderEditAddCustomItemArgs = {
  id: Scalars['ID']
  locationId?: InputMaybe<Scalars['ID']>
  price: MoneyInput
  quantity: Scalars['Int']
  requiresShipping?: InputMaybe<Scalars['Boolean']>
  taxable?: InputMaybe<Scalars['Boolean']>
  title: Scalars['String']
}

/** The schema's entry point for all mutation operations. */
export type MutationOrderEditAddLineItemDiscountArgs = {
  discount: OrderEditAppliedDiscountInput
  id: Scalars['ID']
  lineItemId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationOrderEditAddVariantArgs = {
  allowDuplicates?: InputMaybe<Scalars['Boolean']>
  id: Scalars['ID']
  locationId?: InputMaybe<Scalars['ID']>
  quantity: Scalars['Int']
  variantId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationOrderEditBeginArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationOrderEditCommitArgs = {
  id: Scalars['ID']
  notifyCustomer?: InputMaybe<Scalars['Boolean']>
  staffNote?: InputMaybe<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationOrderEditRemoveLineItemDiscountArgs = {
  discountApplicationId: Scalars['ID']
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationOrderEditSetQuantityArgs = {
  id: Scalars['ID']
  lineItemId: Scalars['ID']
  quantity: Scalars['Int']
  restock?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry point for all mutation operations. */
export type MutationOrderInvoiceSendArgs = {
  email?: InputMaybe<EmailInput>
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationOrderMarkAsPaidArgs = {
  input: OrderMarkAsPaidInput
}

/** The schema's entry point for all mutation operations. */
export type MutationOrderOpenArgs = {
  input: OrderOpenInput
}

/** The schema's entry point for all mutation operations. */
export type MutationOrderUpdateArgs = {
  input: OrderInput
}

/** The schema's entry point for all mutation operations. */
export type MutationPaymentTermsCreateArgs = {
  paymentTermsAttributes: PaymentTermsCreateInput
  referenceId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationPaymentTermsDeleteArgs = {
  input: PaymentTermsDeleteInput
}

/** The schema's entry point for all mutation operations. */
export type MutationPaymentTermsUpdateArgs = {
  input: PaymentTermsUpdateInput
}

/** The schema's entry point for all mutation operations. */
export type MutationPriceListCreateArgs = {
  input: PriceListCreateInput
}

/** The schema's entry point for all mutation operations. */
export type MutationPriceListDeleteArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationPriceListFixedPricesAddArgs = {
  priceListId: Scalars['ID']
  prices: Array<PriceListPriceInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationPriceListFixedPricesDeleteArgs = {
  priceListId: Scalars['ID']
  variantIds: Array<Scalars['ID']>
}

/** The schema's entry point for all mutation operations. */
export type MutationPriceListUpdateArgs = {
  id: Scalars['ID']
  input: PriceListUpdateInput
}

/** The schema's entry point for all mutation operations. */
export type MutationPriceRuleActivateArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationPriceRuleCreateArgs = {
  priceRule: PriceRuleInput
  priceRuleDiscountCode?: InputMaybe<PriceRuleDiscountCodeInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationPriceRuleDeactivateArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationPriceRuleDeleteArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationPriceRuleDiscountCodeCreateArgs = {
  code: Scalars['String']
  priceRuleId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationPriceRuleDiscountCodeUpdateArgs = {
  code: Scalars['String']
  priceRuleId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationPriceRuleUpdateArgs = {
  id: Scalars['ID']
  priceRule: PriceRuleInput
  priceRuleDiscountCode?: InputMaybe<PriceRuleDiscountCodeInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationPrivateMetafieldDeleteArgs = {
  input: PrivateMetafieldDeleteInput
}

/** The schema's entry point for all mutation operations. */
export type MutationPrivateMetafieldUpsertArgs = {
  input: PrivateMetafieldInput
}

/** The schema's entry point for all mutation operations. */
export type MutationProductAppendImagesArgs = {
  input: ProductAppendImagesInput
}

/** The schema's entry point for all mutation operations. */
export type MutationProductChangeStatusArgs = {
  productId: Scalars['ID']
  status: ProductStatus
}

/** The schema's entry point for all mutation operations. */
export type MutationProductCreateArgs = {
  input: ProductInput
  media?: InputMaybe<Array<CreateMediaInput>>
}

/** The schema's entry point for all mutation operations. */
export type MutationProductCreateMediaArgs = {
  media: Array<CreateMediaInput>
  productId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationProductDeleteArgs = {
  input: ProductDeleteInput
}

/** The schema's entry point for all mutation operations. */
export type MutationProductDeleteImagesArgs = {
  id: Scalars['ID']
  imageIds: Array<Scalars['ID']>
}

/** The schema's entry point for all mutation operations. */
export type MutationProductDeleteMediaArgs = {
  mediaIds: Array<Scalars['ID']>
  productId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationProductDuplicateArgs = {
  includeImages?: InputMaybe<Scalars['Boolean']>
  newStatus?: InputMaybe<ProductStatus>
  newTitle: Scalars['String']
  productId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationProductImageUpdateArgs = {
  image: ImageInput
  productId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationProductJoinSellingPlanGroupsArgs = {
  id: Scalars['ID']
  sellingPlanGroupIds: Array<Scalars['ID']>
}

/** The schema's entry point for all mutation operations. */
export type MutationProductLeaveSellingPlanGroupsArgs = {
  id: Scalars['ID']
  sellingPlanGroupIds: Array<Scalars['ID']>
}

/** The schema's entry point for all mutation operations. */
export type MutationProductPublishArgs = {
  input: ProductPublishInput
}

/** The schema's entry point for all mutation operations. */
export type MutationProductReorderImagesArgs = {
  id: Scalars['ID']
  moves: Array<MoveInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationProductReorderMediaArgs = {
  id: Scalars['ID']
  moves: Array<MoveInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationProductUnpublishArgs = {
  input: ProductUnpublishInput
}

/** The schema's entry point for all mutation operations. */
export type MutationProductUpdateArgs = {
  input: ProductInput
}

/** The schema's entry point for all mutation operations. */
export type MutationProductUpdateMediaArgs = {
  media: Array<UpdateMediaInput>
  productId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationProductVariantAppendMediaArgs = {
  productId: Scalars['ID']
  variantMedia: Array<ProductVariantAppendMediaInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationProductVariantCreateArgs = {
  input: ProductVariantInput
}

/** The schema's entry point for all mutation operations. */
export type MutationProductVariantDeleteArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationProductVariantDetachMediaArgs = {
  productId: Scalars['ID']
  variantMedia: Array<ProductVariantDetachMediaInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationProductVariantJoinSellingPlanGroupsArgs = {
  id: Scalars['ID']
  sellingPlanGroupIds: Array<Scalars['ID']>
}

/** The schema's entry point for all mutation operations. */
export type MutationProductVariantLeaveSellingPlanGroupsArgs = {
  id: Scalars['ID']
  sellingPlanGroupIds: Array<Scalars['ID']>
}

/** The schema's entry point for all mutation operations. */
export type MutationProductVariantUpdateArgs = {
  input: ProductVariantInput
}

/** The schema's entry point for all mutation operations. */
export type MutationProductVariantsBulkCreateArgs = {
  productId: Scalars['ID']
  variants: Array<ProductVariantsBulkInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationProductVariantsBulkDeleteArgs = {
  productId: Scalars['ID']
  variantsIds: Array<Scalars['ID']>
}

/** The schema's entry point for all mutation operations. */
export type MutationProductVariantsBulkReorderArgs = {
  positions: Array<ProductVariantPositionInput>
  productId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationProductVariantsBulkUpdateArgs = {
  productId: Scalars['ID']
  variants: Array<ProductVariantsBulkInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationPubSubWebhookSubscriptionCreateArgs = {
  topic: WebhookSubscriptionTopic
  webhookSubscription: PubSubWebhookSubscriptionInput
}

/** The schema's entry point for all mutation operations. */
export type MutationPubSubWebhookSubscriptionUpdateArgs = {
  id: Scalars['ID']
  webhookSubscription?: InputMaybe<PubSubWebhookSubscriptionInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationPublishablePublishArgs = {
  id: Scalars['ID']
  input: Array<PublicationInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationPublishablePublishToCurrentChannelArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationPublishableUnpublishArgs = {
  id: Scalars['ID']
  input: Array<PublicationInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationPublishableUnpublishToCurrentChannelArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationRefundCreateArgs = {
  input: RefundInput
}

/** The schema's entry point for all mutation operations. */
export type MutationSavedSearchCreateArgs = {
  input: SavedSearchCreateInput
}

/** The schema's entry point for all mutation operations. */
export type MutationSavedSearchDeleteArgs = {
  input: SavedSearchDeleteInput
}

/** The schema's entry point for all mutation operations. */
export type MutationSavedSearchUpdateArgs = {
  input: SavedSearchUpdateInput
}

/** The schema's entry point for all mutation operations. */
export type MutationScriptTagCreateArgs = {
  input: ScriptTagInput
}

/** The schema's entry point for all mutation operations. */
export type MutationScriptTagDeleteArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationScriptTagUpdateArgs = {
  id: Scalars['ID']
  input: ScriptTagInput
}

/** The schema's entry point for all mutation operations. */
export type MutationSellingPlanGroupAddProductVariantsArgs = {
  id: Scalars['ID']
  productVariantIds: Array<Scalars['ID']>
}

/** The schema's entry point for all mutation operations. */
export type MutationSellingPlanGroupAddProductsArgs = {
  id: Scalars['ID']
  productIds: Array<Scalars['ID']>
}

/** The schema's entry point for all mutation operations. */
export type MutationSellingPlanGroupCreateArgs = {
  input: SellingPlanGroupInput
  resources?: InputMaybe<SellingPlanGroupResourceInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationSellingPlanGroupDeleteArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationSellingPlanGroupRemoveProductVariantsArgs = {
  id: Scalars['ID']
  productVariantIds: Array<Scalars['ID']>
}

/** The schema's entry point for all mutation operations. */
export type MutationSellingPlanGroupRemoveProductsArgs = {
  id: Scalars['ID']
  productIds: Array<Scalars['ID']>
}

/** The schema's entry point for all mutation operations. */
export type MutationSellingPlanGroupUpdateArgs = {
  id: Scalars['ID']
  input?: InputMaybe<SellingPlanGroupInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationShippingPackageDeleteArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationShippingPackageMakeDefaultArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationShippingPackageUpdateArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationShopLocaleDisableArgs = {
  locale: Scalars['String']
}

/** The schema's entry point for all mutation operations. */
export type MutationShopLocaleEnableArgs = {
  locale: Scalars['String']
}

/** The schema's entry point for all mutation operations. */
export type MutationShopLocaleUpdateArgs = {
  locale: Scalars['String']
  shopLocale: ShopLocaleInput
}

/** The schema's entry point for all mutation operations. */
export type MutationShopPolicyUpdateArgs = {
  shopPolicy: ShopPolicyInput
}

/** The schema's entry point for all mutation operations. */
export type MutationStagedUploadTargetGenerateArgs = {
  input: StagedUploadTargetGenerateInput
}

/** The schema's entry point for all mutation operations. */
export type MutationStagedUploadTargetsGenerateArgs = {
  input: Array<StageImageInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationStagedUploadsCreateArgs = {
  input: Array<StagedUploadInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationStandardMetafieldDefinitionEnableArgs = {
  id: Scalars['ID']
  ownerType: MetafieldOwnerType
  pin?: Scalars['Boolean']
}

/** The schema's entry point for all mutation operations. */
export type MutationStorefrontAccessTokenCreateArgs = {
  input: StorefrontAccessTokenInput
}

/** The schema's entry point for all mutation operations. */
export type MutationStorefrontAccessTokenDeleteArgs = {
  input: StorefrontAccessTokenDeleteInput
}

/** The schema's entry point for all mutation operations. */
export type MutationSubscriptionBillingAttemptCreateArgs = {
  subscriptionBillingAttemptInput: SubscriptionBillingAttemptInput
  subscriptionContractId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationSubscriptionContractCreateArgs = {
  input: SubscriptionContractCreateInput
}

/** The schema's entry point for all mutation operations. */
export type MutationSubscriptionContractSetNextBillingDateArgs = {
  contractId: Scalars['ID']
  date: Scalars['DateTime']
}

/** The schema's entry point for all mutation operations. */
export type MutationSubscriptionContractUpdateArgs = {
  contractId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationSubscriptionDraftCommitArgs = {
  draftId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationSubscriptionDraftDiscountAddArgs = {
  draftId: Scalars['ID']
  input: SubscriptionManualDiscountInput
}

/** The schema's entry point for all mutation operations. */
export type MutationSubscriptionDraftDiscountCodeApplyArgs = {
  draftId: Scalars['ID']
  redeemCode: Scalars['String']
}

/** The schema's entry point for all mutation operations. */
export type MutationSubscriptionDraftDiscountRemoveArgs = {
  discountId: Scalars['ID']
  draftId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationSubscriptionDraftDiscountUpdateArgs = {
  discountId: Scalars['ID']
  draftId: Scalars['ID']
  input: SubscriptionManualDiscountInput
}

/** The schema's entry point for all mutation operations. */
export type MutationSubscriptionDraftFreeShippingDiscountAddArgs = {
  draftId: Scalars['ID']
  input: SubscriptionFreeShippingDiscountInput
}

/** The schema's entry point for all mutation operations. */
export type MutationSubscriptionDraftFreeShippingDiscountUpdateArgs = {
  discountId: Scalars['ID']
  draftId: Scalars['ID']
  input: SubscriptionFreeShippingDiscountInput
}

/** The schema's entry point for all mutation operations. */
export type MutationSubscriptionDraftLineAddArgs = {
  draftId: Scalars['ID']
  input: SubscriptionLineInput
}

/** The schema's entry point for all mutation operations. */
export type MutationSubscriptionDraftLineRemoveArgs = {
  draftId: Scalars['ID']
  lineId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationSubscriptionDraftLineUpdateArgs = {
  draftId: Scalars['ID']
  input: SubscriptionLineUpdateInput
  lineId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationSubscriptionDraftUpdateArgs = {
  draftId: Scalars['ID']
  input: SubscriptionDraftInput
}

/** The schema's entry point for all mutation operations. */
export type MutationTagsAddArgs = {
  id: Scalars['ID']
  tags: Array<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationTagsRemoveArgs = {
  id: Scalars['ID']
  tags: Array<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationTranslationsRegisterArgs = {
  resourceId: Scalars['ID']
  translations: Array<TranslationInput>
}

/** The schema's entry point for all mutation operations. */
export type MutationTranslationsRemoveArgs = {
  locales: Array<Scalars['String']>
  resourceId: Scalars['ID']
  translationKeys: Array<Scalars['String']>
}

/** The schema's entry point for all mutation operations. */
export type MutationUrlRedirectBulkDeleteByIdsArgs = {
  ids: Array<Scalars['ID']>
}

/** The schema's entry point for all mutation operations. */
export type MutationUrlRedirectBulkDeleteBySavedSearchArgs = {
  savedSearchId: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationUrlRedirectBulkDeleteBySearchArgs = {
  search: Scalars['String']
}

/** The schema's entry point for all mutation operations. */
export type MutationUrlRedirectCreateArgs = {
  urlRedirect: UrlRedirectInput
}

/** The schema's entry point for all mutation operations. */
export type MutationUrlRedirectDeleteArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationUrlRedirectImportCreateArgs = {
  url: Scalars['URL']
}

/** The schema's entry point for all mutation operations. */
export type MutationUrlRedirectImportSubmitArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationUrlRedirectUpdateArgs = {
  id: Scalars['ID']
  urlRedirect: UrlRedirectInput
}

/** The schema's entry point for all mutation operations. */
export type MutationWebhookSubscriptionCreateArgs = {
  topic: WebhookSubscriptionTopic
  webhookSubscription: WebhookSubscriptionInput
}

/** The schema's entry point for all mutation operations. */
export type MutationWebhookSubscriptionDeleteArgs = {
  id: Scalars['ID']
}

/** The schema's entry point for all mutation operations. */
export type MutationWebhookSubscriptionUpdateArgs = {
  id: Scalars['ID']
  webhookSubscription: WebhookSubscriptionInput
}

/** A signed upload parameter for uploading an asset to Shopify. */
export type MutationsStagedUploadTargetGenerateUploadParameter = {
  __typename?: 'MutationsStagedUploadTargetGenerateUploadParameter'
  /** The upload parameter name. */
  name: Scalars['String']
  /** The upload parameter value. */
  value: Scalars['String']
}

/**
 * A default cursor that you can use in queries to paginate your results. Each edge in a connection can
 * return a cursor, which is a reference to the edge's position in the connection. You can use an edge's cursor as
 * the starting point to retrieve the nodes before or after it in a connection.
 *
 * To learn more about using cursor-based pagination, refer to
 * [Paginating results with GraphQL](https://shopify.dev/api/usage/pagination-graphql).
 *
 */
export type Navigable = {
  /**
   * A default cursor that returns the single next record, sorted ascending by ID.
   *
   */
  defaultCursor: Scalars['String']
}

/** A navigation item, holding basic link attributes. */
export type NavigationItem = {
  __typename?: 'NavigationItem'
  /** The unique identifier of the navigation item. */
  id: Scalars['String']
  /** The name of the navigation item. */
  title: Scalars['String']
  /** The URL of the page that the navigation item links to. */
  url: Scalars['URL']
}

/**
 * An object with an ID field to support global identification, in accordance with the
 * [Relay specification](https://relay.dev/graphql/objectidentification.htm#sec-Node-Interface).
 * This interface is used by the [node](https://shopify.dev/api/admin-graphql/unstable/queries/node)
 * and [nodes](https://shopify.dev/api/admin-graphql/unstable/queries/nodes) queries.
 *
 */
export type Node = {
  /** A globally-unique identifier. */
  id: Scalars['ID']
}

/**
 * An article in the blogging system. You can query articles from
 * [the REST API](https://shopify.dev/api/admin-rest/latest/resources/article
 * if you need to access more information about an article. Currently, `OnlineStoreArticle` is
 * only useful to pass an article `id` to the `tagsAdd` mutation. For more information, refer to
 * the [tagsAdd](https://shopify.dev/api/admin-graphql/latest/mutations/tagsadd) mutation.
 *
 */
export type OnlineStoreArticle = HasPublishedTranslations &
  Navigable &
  Node & {
    __typename?: 'OnlineStoreArticle'
    /**
     * A default cursor that returns the single next record, sorted ascending by ID.
     *
     */
    defaultCursor: Scalars['String']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The translations associated with the resource. */
    translations: Array<PublishedTranslation>
  }

/**
 * An article in the blogging system. You can query articles from
 * [the REST API](https://shopify.dev/api/admin-rest/latest/resources/article
 * if you need to access more information about an article. Currently, `OnlineStoreArticle` is
 * only useful to pass an article `id` to the `tagsAdd` mutation. For more information, refer to
 * the [tagsAdd](https://shopify.dev/api/admin-graphql/latest/mutations/tagsadd) mutation.
 *
 */
export type OnlineStoreArticleTranslationsArgs = {
  locale: Scalars['String']
}

/**
 * Shopify stores come with a built-in blogging engine, allowing a shop to have one or more blogs.  Blogs are meant
 * to be used as a type of magazine or newsletter for the shop, with content that changes over time.
 *
 */
export type OnlineStoreBlog = HasPublishedTranslations &
  Node & {
    __typename?: 'OnlineStoreBlog'
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The translations associated with the resource. */
    translations: Array<PublishedTranslation>
  }

/**
 * Shopify stores come with a built-in blogging engine, allowing a shop to have one or more blogs.  Blogs are meant
 * to be used as a type of magazine or newsletter for the shop, with content that changes over time.
 *
 */
export type OnlineStoreBlogTranslationsArgs = {
  locale: Scalars['String']
}

/** A custom page on the Online Store. */
export type OnlineStorePage = HasPublishedTranslations &
  Navigable &
  Node & {
    __typename?: 'OnlineStorePage'
    /**
     * A default cursor that returns the single next record, sorted ascending by ID.
     *
     */
    defaultCursor: Scalars['String']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The translations associated with the resource. */
    translations: Array<PublishedTranslation>
  }

/** A custom page on the Online Store. */
export type OnlineStorePageTranslationsArgs = {
  locale: Scalars['String']
}

/** Online Store preview URL of the object. */
export type OnlineStorePreviewable = {
  /** The online store preview URL. */
  onlineStorePreviewUrl?: Maybe<Scalars['URL']>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type Order = CommentEventSubject &
  HasEvents &
  HasLocalizationExtensions &
  HasMetafieldDefinitions &
  HasMetafields &
  LegacyInteroperability &
  Node & {
    __typename?: 'Order'
    /** A list of sales agreements associated with the order. */
    agreements: SalesAgreementConnection
    /**
     * A list of messages that appear on the order page in the Shopify admin.
     *
     */
    alerts: Array<ResourceAlert>
    /** The application that created the order. */
    app?: Maybe<OrderApp>
    /**
     * The billing address of the customer.
     *
     */
    billingAddress?: Maybe<MailingAddress>
    /** Whether the billing address matches the shipping address. */
    billingAddressMatchesShippingAddress: Scalars['Boolean']
    /** Whether the order can be manually marked as paid. */
    canMarkAsPaid: Scalars['Boolean']
    /** Whether a customer email exists for the order. */
    canNotifyCustomer: Scalars['Boolean']
    /**
     * The reason provided when the order was canceled.
     * Returns `null` if the order wasn't canceled.
     *
     */
    cancelReason?: Maybe<OrderCancelReason>
    /**
     * The date and time when the order was canceled.
     * Returns `null` if the order wasn't canceled.
     *
     */
    cancelledAt?: Maybe<Scalars['DateTime']>
    /**
     * Whether payment for the order can be captured.
     *
     */
    capturable: Scalars['Boolean']
    /**
     * The total order-level discount amount, before returns, in shop currency.
     * @deprecated Use `cartDiscountAmountSet` instead
     */
    cartDiscountAmount?: Maybe<Scalars['Money']>
    /** The total order-level discount amount, before returns, in shop and presentment currencies. */
    cartDiscountAmountSet?: Maybe<MoneyBag>
    /**
     * The channel that created the order.
     * @deprecated Use `publication` instead
     */
    channel?: Maybe<Channel>
    /** The IP address of the API client that created the order. */
    clientIp?: Maybe<Scalars['String']>
    /** Whether the order is closed. */
    closed: Scalars['Boolean']
    /**
     * The date and time when the order was closed.
     * Returns `null` if the order is not closed.
     *
     */
    closedAt?: Maybe<Scalars['DateTime']>
    /** Whether inventory has been reserved for the order. */
    confirmed: Scalars['Boolean']
    /** Date and time when the order was created in Shopify. */
    createdAt: Scalars['DateTime']
    /** The shop currency when the order was placed. */
    currencyCode: CurrencyCode
    /**
     * The current order-level discount amount after all order updates, in shop and presentment currencies.
     *
     */
    currentCartDiscountAmountSet: MoneyBag
    /** The sum of the quantities for all line items that contribute to the order's current subtotal price. */
    currentSubtotalLineItemsQuantity: Scalars['Int']
    /**
     * The sum of the prices for all line items after discounts and returns, in shop and presentment currencies.
     * If `taxesIncluded` is `true`, then the subtotal also includes tax.
     *
     */
    currentSubtotalPriceSet: MoneyBag
    /**
     * A list of all tax lines applied to line items on the order, after returns.
     * Tax line prices represent the total price for all tax lines with the same `rate` and `title`.
     *
     */
    currentTaxLines: Array<TaxLine>
    /**
     * The total amount discounted on the order after returns, in shop and presentment currencies.
     * This includes both order and line level discounts.
     *
     */
    currentTotalDiscountsSet: MoneyBag
    /**
     * The total amount of duties after returns, in shop and presentment currencies.
     * Returns `null` if duties aren't applicable.
     *
     */
    currentTotalDutiesSet?: Maybe<MoneyBag>
    /**
     * The total price of the order, after returns, in shop and presentment currencies.
     * This includes taxes and discounts.
     *
     */
    currentTotalPriceSet: MoneyBag
    /**
     * The sum of the prices of all tax lines applied to line items on the order, after returns, in shop and presentment currencies.
     *
     */
    currentTotalTaxSet: MoneyBag
    /** The total weight of the order after returns, in grams. */
    currentTotalWeight: Scalars['UnsignedInt64']
    /**
     * A list of the custom attributes added to the order.
     *
     */
    customAttributes: Array<Attribute>
    /**
     * The customer that placed the order.
     *
     */
    customer?: Maybe<Customer>
    /** Whether the customer agreed to receive marketing materials. */
    customerAcceptsMarketing: Scalars['Boolean']
    /**
     * The customer's visits and interactions with the online store before placing the order.
     *
     * @deprecated Use `customerJourneySummary` instead
     */
    customerJourney?: Maybe<CustomerJourney>
    /**
     * The customer's visits and interactions with the online store before placing the order.
     *
     */
    customerJourneySummary?: Maybe<CustomerJourneySummary>
    /**
     * A two-letter or three-letter language code, optionally followed by a region modifier.
     *
     */
    customerLocale?: Maybe<Scalars['String']>
    /** A list of discounts that are applied to the order. */
    discountApplications: DiscountApplicationConnection
    /** The discount code used for the order. */
    discountCode?: Maybe<Scalars['String']>
    /**
     * The primary address of the customer.
     * Returns `null` if neither the shipping address nor the billing address was provided.
     *
     */
    displayAddress?: Maybe<MailingAddress>
    /**
     * The financial status of the order that can be shown to the merchant.
     * This field does not capture all the details of an order's financial state. It should only be used for display summary purposes.
     *
     */
    displayFinancialStatus?: Maybe<OrderDisplayFinancialStatus>
    /**
     * The fulfillment status for the order that can be shown to the merchant.
     * This field does not capture all the details of an order's fulfillment state. It should only be used for display summary purposes.
     * For a more granular view of the fulfillment status, refer to the [FulfillmentOrder](https://shopify.dev/api/admin-graphql/latest/objects/FulfillmentOrder) object.
     *
     */
    displayFulfillmentStatus: OrderDisplayFulfillmentStatus
    /** A list of the disputes associated with the order. */
    disputes: Array<OrderDisputeSummary>
    /**
     * A list of draft fulfillments that can be created for the order, which includes line items that can be partially fulfilled.
     *
     * @deprecated Use `fulfillmentOrders` instead
     */
    draftFulfillments: Array<DraftFulfillment>
    /** Whether the order has had any edits applied. */
    edited: Scalars['Boolean']
    /** The email address associated with the customer. */
    email?: Maybe<Scalars['String']>
    /**
     * Whether taxes on the order are estimated.
     * This field returns `false` when taxes on the order are finalized and aren't subject to any changes.
     *
     */
    estimatedTaxes: Scalars['Boolean']
    /** A list of events associated with the order. */
    events: EventConnection
    /**
     * Whether there are line items that can be fulfilled.
     * This field returns `false` when the order has no fulfillable line items.
     * For a more granular view of the fulfillment status, refer to the [FulfillmentOrder](https://shopify.dev/api/admin-graphql/latest/objects/FulfillmentOrder) object.
     *
     */
    fulfillable: Scalars['Boolean']
    /** A list of fulfillment orders for the order. */
    fulfillmentOrders: FulfillmentOrderConnection
    /** List of shipments for the order. */
    fulfillments: Array<Fulfillment>
    /** Whether the order has been paid in full. */
    fullyPaid: Scalars['Boolean']
    /** Whether the merchant added a timeline comment to the order. */
    hasTimelineComment: Scalars['Boolean']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /**
     * The URL of the first page of the online store that the customer visited before they submitted the order.
     * @deprecated Use `customerJourneySummary.lastVisit.landingPageHtml` instead
     */
    landingPageDisplayText?: Maybe<Scalars['String']>
    /**
     * The first page of the online store that the customer visited before they submitted the order.
     * @deprecated Use `customerJourneySummary.lastVisit.landingPage` instead
     */
    landingPageUrl?: Maybe<Scalars['URL']>
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** A list of the order's line items. */
    lineItems: LineItemConnection
    /**
     * A list of the order's line items.
     * @deprecated Use `lineItems` instead
     */
    lineItemsMutable: LineItemMutableConnection
    /** List of localization extensions for the resource. */
    localizationExtensions: LocalizationExtensionConnection
    /**
     * The fulfillment location that was assigned when the order was created.
     * Use the [`FulfillmentOrder`](https://shopify.dev/api/admin-graphql/latest/objects/fulfillmentorder) object for up-to-date fulfillment location information.
     *
     * @deprecated Use `physicalLocation` instead
     */
    location?: Maybe<Scalars['String']>
    /** Whether the order can be edited by the merchant. For example, canceled orders can’t be edited. */
    merchantEditable: Scalars['Boolean']
    /**
     * A list of reasons why the order can't be edited. For example, "Canceled orders can’t be edited".
     *
     */
    merchantEditableErrors: Array<Scalars['String']>
    /** Returns a metafield by namespace and key that belongs to the resource. */
    metafield?: Maybe<Metafield>
    /** List of metafield definitions. */
    metafieldDefinitions: MetafieldDefinitionConnection
    /** List of metafields that belong to the resource. */
    metafields: MetafieldConnection
    /**
     * The unique identifier for the order that appears on the order page in the Shopify admin and the order status page.
     * For example, "#1001", "EN1001", or "1001-A".
     * This value isn't unique across multiple stores.
     *
     */
    name: Scalars['String']
    /**
     * The net payment for the order, based on the total amount received minus the total amount refunded, in shop currency.
     *
     * @deprecated Use `netPaymentSet` instead
     */
    netPayment: Scalars['Money']
    /** The net payment for the order, based on the total amount received minus the total amount refunded, in shop and presentment currencies. */
    netPaymentSet: MoneyBag
    /**
     * A list of line items that can't be fulfilled.
     * For example, tips and fully refunded line items can't be fulfilled.
     * For a more granular view of the fulfillment status, refer to the [FulfillmentOrder](https://shopify.dev/api/admin-graphql/latest/objects/FulfillmentOrder) object.
     *
     */
    nonFulfillableLineItems: LineItemConnection
    /**
     * The contents of the note associated with the order.
     *
     */
    note?: Maybe<Scalars['String']>
    /**
     * The total amount of duties before returns, in shop and presentment currencies.
     * Returns `null` if duties aren't applicable.
     *
     */
    originalTotalDutiesSet?: Maybe<MoneyBag>
    /** The total price of the order at the time of order creation, in shop and presentment currencies. */
    originalTotalPriceSet: MoneyBag
    /** The payment collection details for the order. */
    paymentCollectionDetails: OrderPaymentCollectionDetails
    /**
     * A list of the names of all payment gateways used for the order.
     * For example, "Shopify Payments" and "Cash on Delivery (COD)".
     *
     */
    paymentGatewayNames: Array<Scalars['String']>
    /** The payment terms associated with the order. */
    paymentTerms?: Maybe<PaymentTerms>
    /** The phone number associated with the customer. */
    phone?: Maybe<Scalars['String']>
    /**
     * The fulfillment location that was assigned when the order was created.
     * Use the [`FulfillmentOrder`](https://shopify.dev/api/admin-graphql/latest/objects/fulfillmentorder) object for up to date fulfillment location information.
     *
     */
    physicalLocation?: Maybe<Location>
    /** The payment `CurrencyCode` of the customer for the order. */
    presentmentCurrencyCode: CurrencyCode
    /** Returns a private metafield by namespace and key that belongs to the resource. */
    privateMetafield?: Maybe<PrivateMetafield>
    /** List of private metafields that belong to the resource. */
    privateMetafields: PrivateMetafieldConnection
    /**
     * The date and time when the order was processed.
     * This date and time might not match the date and time when the order was created.
     *
     */
    processedAt: Scalars['DateTime']
    /** The publication that the order was created from. */
    publication?: Maybe<Publication>
    /**
     * The marketing referral code from the link that the customer clicked to visit the store.
     * Supports the following URL attributes: "ref", "source", or "r".
     * For example, if the URL is `{shop}.myshopify.com/products/slide?ref=j2tj1tn2`, then this value is `j2tj1tn2`.
     *
     * @deprecated Use `customerJourneySummary.lastVisit.referralCode` instead
     */
    referralCode?: Maybe<Scalars['String']>
    /**
     * A web domain or short description of the source that sent the customer to your online store. For example, "shopify.com" or "email".
     *
     * @deprecated Use `customerJourneySummary.lastVisit.referralInfoHtml` instead
     */
    referrerDisplayText?: Maybe<Scalars['String']>
    /**
     * The URL of the webpage where the customer clicked a link that sent them to your online store.
     *
     * @deprecated Use `customerJourneySummary.lastVisit.referrerUrl` instead
     */
    referrerUrl?: Maybe<Scalars['URL']>
    /** The difference between the suggested and actual refund amount of all refunds that have been applied to the order. A positive value indicates a difference in the merchant's favor, and a negative value indicates a difference in the customer's favor. */
    refundDiscrepancySet: MoneyBag
    /**
     * Whether the order can be refunded.
     *
     */
    refundable: Scalars['Boolean']
    /**
     * A list of refunds that have been applied to the order.
     *
     */
    refunds: Array<Refund>
    /**
     * Whether the order has shipping lines or at least one line item on the order that requires shipping.
     *
     */
    requiresShipping: Scalars['Boolean']
    /**
     * Whether any line item on the order can be restocked.
     *
     */
    restockable: Scalars['Boolean']
    /** The fraud risk level of the order. */
    riskLevel: OrderRiskLevel
    /** A list of risks associated with the order. */
    risks: Array<OrderRisk>
    /** The mailing address of the customer. */
    shippingAddress?: Maybe<MailingAddress>
    /** A summary of all shipping costs on the order. */
    shippingLine?: Maybe<ShippingLine>
    /** A list of the order's shipping lines. */
    shippingLines: ShippingLineConnection
    /** The sum of the quantities for all line items that contribute to the order's subtotal price. */
    subtotalLineItemsQuantity: Scalars['Int']
    /**
     * The sum of the prices for all line items after discounts and before returns, in shop currency.
     * If `taxesIncluded` is `true`, then the subtotal also includes tax.
     *
     * @deprecated Use `subtotalPriceSet` instead
     */
    subtotalPrice?: Maybe<Scalars['Money']>
    /**
     * The sum of the prices for all line items after discounts and before returns, in shop and presentment currencies.
     * If `taxesIncluded` is `true`, then the subtotal also includes tax.
     *
     */
    subtotalPriceSet?: Maybe<MoneyBag>
    /** A suggested refund for the order. */
    suggestedRefund?: Maybe<SuggestedRefund>
    /**
     * A comma separated list of tags associated with the order. Updating `tags` overwrites
     * any existing tags that were previously added to the order. To add new tags without overwriting
     * existing tags, use the [tagsAdd](https://shopify.dev/api/admin-graphql/latest/mutations/tagsadd)
     * mutation.
     *
     */
    tags: Array<Scalars['String']>
    /**
     * A list of all tax lines applied to line items on the order, before returns.
     * Tax line prices represent the total price for all tax lines with the same `rate` and `title`.
     *
     */
    taxLines: Array<TaxLine>
    /** Whether taxes are included in the subtotal price of the order. */
    taxesIncluded: Scalars['Boolean']
    /**
     * Whether the order is a test.
     * Test orders are made using the Shopify Bogus Gateway or a payment provider with test mode enabled.
     * A test order cannot be converted into a real order and vice versa.
     *
     */
    test: Scalars['Boolean']
    /**
     * The authorized amount that is uncaptured or undercaptured, in shop currency.
     * This amount isn't adjusted for returns.
     *
     * @deprecated Use `totalCapturableSet` instead
     */
    totalCapturable: Scalars['Money']
    /**
     * The authorized amount that is uncaptured or undercaptured, in shop and presentment currencies.
     * This amount isn't adjusted for returns.
     *
     */
    totalCapturableSet: MoneyBag
    /**
     * The total amount discounted on the order before returns, in shop currency.
     * This includes both order and line level discounts.
     *
     * @deprecated Use `totalDiscountsSet` instead
     */
    totalDiscounts?: Maybe<Scalars['Money']>
    /**
     * The total amount discounted on the order before returns, in shop and presentment currencies.
     * This includes both order and line level discounts.
     *
     */
    totalDiscountsSet?: Maybe<MoneyBag>
    /**
     * The total amount not yet transacted for the order, in shop and presentment currencies.
     * A positive value indicates a difference in the merchant's favor (payment from customer to merchant) and a negative value indicates a difference in the customer's favor (refund from merchant to customer).
     *
     */
    totalOutstandingSet: MoneyBag
    /**
     * The total price of the order, before returns, in shop currency.
     * This includes taxes and discounts.
     *
     * @deprecated Use `totalPriceSet` instead
     */
    totalPrice: Scalars['Money']
    /**
     * The total price of the order, before returns, in shop and presentment currencies.
     * This includes taxes and discounts.
     *
     */
    totalPriceSet: MoneyBag
    /**
     * The total amount received from the customer before returns, in shop currency.
     * @deprecated Use `totalReceivedSet` instead
     */
    totalReceived: Scalars['Money']
    /** The total amount received from the customer before returns, in shop and presentment currencies. */
    totalReceivedSet: MoneyBag
    /**
     * The total amount that was refunded, in shop currency.
     * @deprecated Use `totalRefundedSet` instead
     */
    totalRefunded: Scalars['Money']
    /** The total amount that was refunded, in shop and presentment currencies. */
    totalRefundedSet: MoneyBag
    /** The total amount of shipping that was refunded, in shop and presentment currencies. */
    totalRefundedShippingSet: MoneyBag
    /**
     * The total shipping amount before discounts and returns, in shop currency.
     * @deprecated Use `totalShippingPriceSet` instead
     */
    totalShippingPrice: Scalars['Money']
    /** The total shipping amount before discounts and returns, in shop and presentment currencies. */
    totalShippingPriceSet: MoneyBag
    /**
     * The total tax amount before returns, in shop currency.
     * @deprecated Use `totalTaxSet` instead
     */
    totalTax?: Maybe<Scalars['Money']>
    /** The total tax amount before returns, in shop and presentment currencies. */
    totalTaxSet?: Maybe<MoneyBag>
    /**
     * The sum of all tip amounts for the order, in shop currency.
     * @deprecated Use `totalTipReceivedSet` instead
     */
    totalTipReceived: MoneyV2
    /** The sum of all tip amounts for the order, in shop and presentment currencies. */
    totalTipReceivedSet: MoneyBag
    /** The total weight of the order before returns, in grams. */
    totalWeight?: Maybe<Scalars['UnsignedInt64']>
    /** A list of transactions associated with the order. */
    transactions: Array<OrderTransaction>
    /**
     * Whether no payments have been made for the order.
     *
     */
    unpaid: Scalars['Boolean']
    /** The date and time when the order was modified last. */
    updatedAt: Scalars['DateTime']
  }

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderAgreementsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderDiscountApplicationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderEventsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<EventSortKeys>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderFulfillmentOrdersArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  displayable?: InputMaybe<Scalars['Boolean']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderFulfillmentsArgs = {
  first?: InputMaybe<Scalars['Int']>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderLineItemsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderLineItemsMutableArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderLocalizationExtensionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  countryCodes?: InputMaybe<Array<CountryCode>>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  purposes?: InputMaybe<Array<LocalizationExtensionPurpose>>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderMetafieldDefinitionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  pinnedStatus?: InputMaybe<MetafieldDefinitionPinnedStatus>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<MetafieldDefinitionSortKeys>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderNonFulfillableLineItemsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderPrivateMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderPrivateMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderRefundsArgs = {
  first?: InputMaybe<Scalars['Int']>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderRisksArgs = {
  first?: InputMaybe<Scalars['Int']>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderShippingLinesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderSuggestedRefundArgs = {
  refundDuties?: InputMaybe<Array<RefundDutyInput>>
  refundLineItems?: InputMaybe<Array<RefundLineItemInput>>
  refundShipping?: InputMaybe<Scalars['Boolean']>
  shippingAmount?: InputMaybe<Scalars['Money']>
  suggestFullRefund?: InputMaybe<Scalars['Boolean']>
}

/**
 * An order is a customer's request to purchase one or more products from a shop. You can retrieve and update orders using the Order object.
 * Learn more about [editing an existing order with the Admin API](https://shopify.dev/api/examples/order-editing).
 *
 * Only the last 60 days' worth of orders from a store are accessible from the `Order` object by default. If you want to access older orders,
 * then you need to [request access to all orders](https://shopify.dev/apps/auth/oauth#orders-permissions). If your app is granted
 * access, then you can add the `read_all_orders` scope to your app along with `read_orders` or `write_orders`.
 * [Private apps](https://shopify.dev/apps/auth/basic-http) are not affected by this change and are automatically granted the scope.
 *
 * **Caution:** Only use this data if it's required for your app's functionality. Shopify will restrict [access to scopes](https://shopify.dev/api/usage/access-scopes) for apps that don't have a legitimate use for the associated data.
 *
 */
export type OrderTransactionsArgs = {
  capturable?: InputMaybe<Scalars['Boolean']>
  first?: InputMaybe<Scalars['Int']>
  manuallyResolvable?: InputMaybe<Scalars['Boolean']>
}

/**
 * The possible order action types for a
 * [sales agreement](https://shopify.dev/api/admin-graphql/latest/interfaces/salesagreement).
 *
 */
export enum OrderActionType {
  /** An order with a purchase or charge. */
  Order = 'ORDER',
  /** An edit to the order. */
  OrderEdit = 'ORDER_EDIT',
  /** A refund on the order. */
  Refund = 'REFUND',
  /** An unknown agreement action. Represents new actions that may be added in future versions. */
  Unknown = 'UNKNOWN',
}

/** An agreement associated with an order placement. */
export type OrderAgreement = SalesAgreement & {
  __typename?: 'OrderAgreement'
  /** The application that created the agreement. */
  app?: Maybe<App>
  /** The date and time at which the agreement occured. */
  happenedAt: Scalars['DateTime']
  /** The unique identifier for the agreement. */
  id: Scalars['ID']
  /** The order associated with the agreement. */
  order: Order
  /** The reason the agremeent was created. */
  reason: OrderActionType
  /** The sales associated with the agreement. */
  sales: SaleConnection
}

/** An agreement associated with an order placement. */
export type OrderAgreementSalesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * The [application](https://shopify.dev/apps) that created the order.
 *
 */
export type OrderApp = {
  __typename?: 'OrderApp'
  /** The application icon. */
  icon: Image
  /** The name of the application. */
  name: Scalars['String']
}

/** Represents the reason that the order is being canceled. Valid values are: customer, fraud, inventory, declined, other. */
export enum OrderCancelReason {
  /** The customer wanted to cancel the order. */
  Customer = 'CUSTOMER',
  /** Payment was declined. */
  Declined = 'DECLINED',
  /** The order was fraudulent. */
  Fraud = 'FRAUD',
  /** There was insufficient inventory. */
  Inventory = 'INVENTORY',
  /** Some other reason not listed. */
  Other = 'OTHER',
}

/** Specifies the authorized transaction to capture and the total amount to capture from it. */
export type OrderCaptureInput = {
  /** The amount to capture. The capture amount can't be greater than the amount of the authorized transaction. */
  amount: Scalars['Money']
  /** The currency (in ISO format) that is used to capture the order. This must be the presentment currency (the currency used by the customer) and is a required field for orders where the currency and presentment currency differ. */
  currency?: InputMaybe<CurrencyCode>
  /** The ID of the order to capture. */
  id: Scalars['ID']
  /** The ID of the authorized transaction to capture. */
  parentTransactionId: Scalars['ID']
}

/** Return type for `orderCapture` mutation. */
export type OrderCapturePayload = {
  __typename?: 'OrderCapturePayload'
  /** The created capture transaction. */
  transaction?: Maybe<OrderTransaction>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Specifies an open order to close. */
export type OrderCloseInput = {
  /** The ID of the order to close. */
  id: Scalars['ID']
}

/** Return type for `orderClose` mutation. */
export type OrderClosePayload = {
  __typename?: 'OrderClosePayload'
  /** The closed order. */
  order?: Maybe<Order>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type for paginating through multiple Orders.
 *
 */
export type OrderConnection = {
  __typename?: 'OrderConnection'
  /** A list of edges. */
  edges: Array<OrderEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Represents the order's current financial status. */
export enum OrderDisplayFinancialStatus {
  /** Displayed as **Authorized**. */
  Authorized = 'AUTHORIZED',
  /** Displayed as **Expired**. */
  Expired = 'EXPIRED',
  /** Displayed as **Paid**. */
  Paid = 'PAID',
  /** Displayed as **Partially paid**. */
  PartiallyPaid = 'PARTIALLY_PAID',
  /** Displayed as **Partially refunded**. */
  PartiallyRefunded = 'PARTIALLY_REFUNDED',
  /** Displayed as **Pending**. */
  Pending = 'PENDING',
  /** Displayed as **Refunded**. */
  Refunded = 'REFUNDED',
  /** Displayed as **Voided**. */
  Voided = 'VOIDED',
}

/** Represents the order's aggregated fulfillment status for display purposes. */
export enum OrderDisplayFulfillmentStatus {
  /** Displayed as **Fulfilled**. All the items in the order have been fulfilled. */
  Fulfilled = 'FULFILLED',
  /** Displayed as **In progress**. Some of the items in the order have been fulfilled, or a request for fulfillment has been sent to the fulfillment service. */
  InProgress = 'IN_PROGRESS',
  /** Displayed as **On hold**. All of the unfulfilled items in this order are on hold. */
  OnHold = 'ON_HOLD',
  /** Displayed as **Open**. None of the items in the order have been fulfilled. Replaced by "UNFULFILLED" status. */
  Open = 'OPEN',
  /** Displayed as **Partially fulfilled**. Some of the items in the order have been fulfilled. */
  PartiallyFulfilled = 'PARTIALLY_FULFILLED',
  /** Displayed as **Pending fulfillment**. A request for fulfillment of some items awaits a response from the fulfillment service. Replaced by the "IN_PROGRESS" status. */
  PendingFulfillment = 'PENDING_FULFILLMENT',
  /** Displayed as **Restocked**. All the items in the order have been restocked. Replaced by the "UNFULFILLED" status. */
  Restocked = 'RESTOCKED',
  /** Displayed as **Scheduled**. All of the unfulfilled items in this order are scheduled for fulfillment at later time. */
  Scheduled = 'SCHEDULED',
  /** Displayed as **Unfulfilled**. None of the items in the order have been fulfilled. */
  Unfulfilled = 'UNFULFILLED',
}

/** A summary of the important details for a dispute on an order. */
export type OrderDisputeSummary = Node & {
  __typename?: 'OrderDisputeSummary'
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The type that the dispute was initiated as. */
  initiatedAs: DisputeType
  /** The current status of the dispute. */
  status: DisputeStatus
}

/**
 * An auto-generated type which holds one Order and a cursor during pagination.
 *
 */
export type OrderEdge = {
  __typename?: 'OrderEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of OrderEdge. */
  node: Order
}

/** Return type for `orderEditAddCustomItem` mutation. */
export type OrderEditAddCustomItemPayload = {
  __typename?: 'OrderEditAddCustomItemPayload'
  /** The custom line item that will be added to the order based on the current edits. */
  calculatedLineItem?: Maybe<CalculatedLineItem>
  /** An order with the edits applied but not saved. */
  calculatedOrder?: Maybe<CalculatedOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `orderEditAddLineItemDiscount` mutation. */
export type OrderEditAddLineItemDiscountPayload = {
  __typename?: 'OrderEditAddLineItemDiscountPayload'
  /** The discount applied to a line item during this order edit. */
  addedDiscountStagedChange?: Maybe<OrderStagedChangeAddLineItemDiscount>
  /** The line item with the edits applied but not saved. */
  calculatedLineItem?: Maybe<CalculatedLineItem>
  /** An order with the edits applied but not saved. */
  calculatedOrder?: Maybe<CalculatedOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `orderEditAddVariant` mutation. */
export type OrderEditAddVariantPayload = {
  __typename?: 'OrderEditAddVariantPayload'
  /**
   * The [calculated line item](https://shopify.dev/api/admin-graphql/latest/objects/calculatedlineitem)
   * that's added during this order edit.
   *
   */
  calculatedLineItem?: Maybe<CalculatedLineItem>
  /**
   * The [calculated order](https://shopify.dev/api/admin-graphql/latest/objects/calculatedorder)
   * with the edits applied but not saved.
   *
   */
  calculatedOrder?: Maybe<CalculatedOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** An agreement associated with an edit to the order. */
export type OrderEditAgreement = SalesAgreement & {
  __typename?: 'OrderEditAgreement'
  /** The application that created the agreement. */
  app?: Maybe<App>
  /** The date and time at which the agreement occured. */
  happenedAt: Scalars['DateTime']
  /** The unique identifier for the agreement. */
  id: Scalars['ID']
  /** The reason the agremeent was created. */
  reason: OrderActionType
  /** The sales associated with the agreement. */
  sales: SaleConnection
}

/** An agreement associated with an edit to the order. */
export type OrderEditAgreementSalesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The input fields used to add a discount during an order edit. */
export type OrderEditAppliedDiscountInput = {
  /** The description of the discount. */
  description?: InputMaybe<Scalars['String']>
  /** The value of the discount as a fixed amount. */
  fixedValue?: InputMaybe<MoneyInput>
  /** The value of the discount as a percentage. */
  percentValue?: InputMaybe<Scalars['Float']>
}

/** Return type for `orderEditBegin` mutation. */
export type OrderEditBeginPayload = {
  __typename?: 'OrderEditBeginPayload'
  /** The order that will be edited. */
  calculatedOrder?: Maybe<CalculatedOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `orderEditCommit` mutation. */
export type OrderEditCommitPayload = {
  __typename?: 'OrderEditCommitPayload'
  /** The order with changes applied. */
  order?: Maybe<Order>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `orderEditRemoveLineItemDiscount` mutation. */
export type OrderEditRemoveLineItemDiscountPayload = {
  __typename?: 'OrderEditRemoveLineItemDiscountPayload'
  /** The calculated line item after removal of the discount. */
  calculatedLineItem?: Maybe<CalculatedLineItem>
  /** An order with the edits applied but not saved. */
  calculatedOrder?: Maybe<CalculatedOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `orderEditSetQuantity` mutation. */
export type OrderEditSetQuantityPayload = {
  __typename?: 'OrderEditSetQuantityPayload'
  /** The calculated line item with the edits applied but not saved. */
  calculatedLineItem?: Maybe<CalculatedLineItem>
  /** The calculated order with the edits applied but not saved. */
  calculatedOrder?: Maybe<CalculatedOrder>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Specifies the information to be updated on an order when using the orderUpdate mutation. */
export type OrderInput = {
  /** A new list of custom attributes for the order. Overwrites the existing custom attributes. */
  customAttributes?: InputMaybe<Array<AttributeInput>>
  /** A new customer email address for the order. Overwrites the existing email address. */
  email?: InputMaybe<Scalars['String']>
  /** The ID of the order to update. */
  id: Scalars['ID']
  /** A list of new [localization extensions](https://shopify.dev/api/admin-graphql/latest/objects/localizationextension) to add to the existing list of localization extensions for the order. */
  localizationExtensions?: InputMaybe<Array<LocalizationExtensionInput>>
  /** A list of new metafields to add to the existing metafields for the order. */
  metafields?: InputMaybe<Array<MetafieldInput>>
  /** The new contents for the note associated with the order. Overwrites the existing note. */
  note?: InputMaybe<Scalars['String']>
  /** The new shipping address for the order. Overwrites the existing shipping address. */
  shippingAddress?: InputMaybe<MailingAddressInput>
  /** A new list of tags for the order. Overwrites the existing tags. */
  tags?: InputMaybe<Array<Scalars['String']>>
}

/** Return type for `orderInvoiceSend` mutation. */
export type OrderInvoiceSendPayload = {
  __typename?: 'OrderInvoiceSendPayload'
  /** The order associated with the invoice email. */
  order?: Maybe<Order>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<OrderInvoiceSendUserError>
}

/** An error that occurs during the execution of `OrderInvoiceSend`. */
export type OrderInvoiceSendUserError = DisplayableError & {
  __typename?: 'OrderInvoiceSendUserError'
  /** The error code. */
  code?: Maybe<OrderInvoiceSendUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `OrderInvoiceSendUserError`. */
export enum OrderInvoiceSendUserErrorCode {
  /** An error occurred while sending the invoice. */
  OrderInvoiceSendUnsuccessful = 'ORDER_INVOICE_SEND_UNSUCCESSFUL',
}

/** Specifies the order to mark as paid. */
export type OrderMarkAsPaidInput = {
  /** The ID of the order to mark as paid. */
  id: Scalars['ID']
}

/** Return type for `orderMarkAsPaid` mutation. */
export type OrderMarkAsPaidPayload = {
  __typename?: 'OrderMarkAsPaidPayload'
  /** The order marked as paid. */
  order?: Maybe<Order>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Specifies a closed order to open. */
export type OrderOpenInput = {
  /** The ID of the order to open. */
  id: Scalars['ID']
}

/** Return type for `orderOpen` mutation. */
export type OrderOpenPayload = {
  __typename?: 'OrderOpenPayload'
  /** The opened order. */
  order?: Maybe<Order>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** The payment collection details for an order that requires additional payment following an edit to the order. */
export type OrderPaymentCollectionDetails = {
  __typename?: 'OrderPaymentCollectionDetails'
  /** The URL to use for collecting an additional payment on the order. */
  additionalPaymentCollectionUrl?: Maybe<Scalars['URL']>
}

/** Represents a fraud check on an order. */
export type OrderRisk = {
  __typename?: 'OrderRisk'
  /** Whether the risk level is shown in the Shopify admin. If false, then this order risk is ignored when Shopify determines the overall risk level for the order. */
  display: Scalars['Boolean']
  /**
   * The likelihood that an order is fraudulent, based on this order risk.
   *
   * The level can be set by Shopify risk analysis or by an app.
   *
   */
  level?: Maybe<OrderRiskLevel>
  /** The risk message that's shown to the merchant in the Shopify admin. */
  message?: Maybe<Scalars['String']>
}

/** The likelihood that an order is fraudulent. */
export enum OrderRiskLevel {
  /** There is a high level of risk that this order is fraudulent. */
  High = 'HIGH',
  /** There is a low level of risk that this order is fraudulent. */
  Low = 'LOW',
  /** There is a medium level of risk that this order is fraudulent. */
  Medium = 'MEDIUM',
}

/** The set of valid sort keys for the Order query. */
export enum OrderSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `customer_name` value. */
  CustomerName = 'CUSTOMER_NAME',
  /** Sort by the `financial_status` value. */
  FinancialStatus = 'FINANCIAL_STATUS',
  /** Sort by the `fulfillment_status` value. */
  FulfillmentStatus = 'FULFILLMENT_STATUS',
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `order_number` value. */
  OrderNumber = 'ORDER_NUMBER',
  /** Sort by the `processed_at` value. */
  ProcessedAt = 'PROCESSED_AT',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
  /** Sort by the `total_price` value. */
  TotalPrice = 'TOTAL_PRICE',
  /** Sort by the `updated_at` value. */
  UpdatedAt = 'UPDATED_AT',
}

/**
 * A change that has been applied to an order.
 *
 */
export type OrderStagedChange =
  | OrderStagedChangeAddCustomItem
  | OrderStagedChangeAddLineItemDiscount
  | OrderStagedChangeAddShippingLine
  | OrderStagedChangeAddVariant
  | OrderStagedChangeDecrementItem
  | OrderStagedChangeIncrementItem

/**
 * A change to the order representing the addition of a
 * custom line item. For example, you might want to add gift wrapping service
 * as a custom line item.
 *
 */
export type OrderStagedChangeAddCustomItem = {
  __typename?: 'OrderStagedChangeAddCustomItem'
  /** The price of an individual item without any discounts applied. This value cannot be negative. */
  originalUnitPrice: MoneyV2
  /** The quantity of the custom item to add to the order. This value must be greater than zero. */
  quantity: Scalars['Int']
  /** The title of the custom item. */
  title: Scalars['String']
}

/**
 * The discount applied to an item that was added during the current order edit.
 *
 */
export type OrderStagedChangeAddLineItemDiscount = {
  __typename?: 'OrderStagedChangeAddLineItemDiscount'
  /** The description of the discount. */
  description: Scalars['String']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The pricing value of the discount. */
  value: PricingValue
}

/**
 * A new [shipping line](https://shopify.dev/api/admin-graphql/latest/objects/shippingline)
 * added as part of an order edit.
 *
 */
export type OrderStagedChangeAddShippingLine = {
  __typename?: 'OrderStagedChangeAddShippingLine'
  /** The phone number at the shipping address. */
  phone?: Maybe<Scalars['String']>
  /**
   * The shipping line's title that is shown to the buyer.
   *
   */
  presentmentTitle?: Maybe<Scalars['String']>
  /** The price that applies to the shipping line. */
  price: MoneyV2
  /** The title of the shipping line. */
  title?: Maybe<Scalars['String']>
}

/**
 * A change to the order representing the addition of an existing product variant.
 *
 */
export type OrderStagedChangeAddVariant = {
  __typename?: 'OrderStagedChangeAddVariant'
  /** The quantity of the product variant that was added. */
  quantity: Scalars['Int']
  /** The product variant that was added. */
  variant: ProductVariant
}

/**
 * An auto-generated type for paginating through multiple OrderStagedChanges.
 *
 */
export type OrderStagedChangeConnection = {
  __typename?: 'OrderStagedChangeConnection'
  /** A list of edges. */
  edges: Array<OrderStagedChangeEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An removal of items from an existing line item on the order.
 *
 */
export type OrderStagedChangeDecrementItem = {
  __typename?: 'OrderStagedChangeDecrementItem'
  /** The number of items removed. */
  delta: Scalars['Int']
  /** The original line item. */
  lineItem: LineItem
  /** The intention to restock the removed items. */
  restock: Scalars['Boolean']
}

/**
 * An auto-generated type which holds one OrderStagedChange and a cursor during pagination.
 *
 */
export type OrderStagedChangeEdge = {
  __typename?: 'OrderStagedChangeEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of OrderStagedChangeEdge. */
  node: OrderStagedChange
}

/**
 * An addition of items to an existing line item on the order.
 *
 */
export type OrderStagedChangeIncrementItem = {
  __typename?: 'OrderStagedChangeIncrementItem'
  /** The number of items added. */
  delta: Scalars['Int']
  /** The original line item. */
  lineItem: LineItem
}

/**
 * A payment transaction in the context of an order.
 *
 */
export type OrderTransaction = Node & {
  __typename?: 'OrderTransaction'
  /** The masked account number associated with the payment method. */
  accountNumber?: Maybe<Scalars['String']>
  /**
   * The amount of money.
   * @deprecated Use `amountSet` instead
   */
  amount: Scalars['Money']
  /** The amount and currency of the transaction in shop and presentment currencies. */
  amountSet: MoneyBag
  /**
   * The amount and currency of the transaction.
   * @deprecated Use `amountSet` instead
   */
  amountV2: MoneyV2
  /** Authorization code associated with the transaction. */
  authorizationCode?: Maybe<Scalars['String']>
  /**
   * The time when the authorization expires. This field is available only to stores on a Shopify Plus plan and is populated only for Shopify Payments authorizations.
   *
   */
  authorizationExpiresAt?: Maybe<Scalars['DateTime']>
  /** Date and time when the transaction was created. */
  createdAt: Scalars['DateTime']
  /** A standardized error code, independent of the payment provider. */
  errorCode?: Maybe<OrderTransactionErrorCode>
  /**
   * The transaction fees charged on the order transaction. Only present for Shopify Payments transactions.
   *
   */
  fees: Array<TransactionFee>
  /** The human-readable payment gateway name used to process the transaction. */
  formattedGateway?: Maybe<Scalars['String']>
  /** The payment gateway used to process the transaction. */
  gateway?: Maybe<Scalars['String']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The kind of transaction. */
  kind: OrderTransactionKind
  /** Whether the transaction can be manually captured. */
  manuallyCapturable: Scalars['Boolean']
  /**
   * Specifies the available amount to refund on the gateway.
   * This value is only available for transactions of type `SuggestedRefund`.
   *
   * @deprecated Use `maximumRefundableV2` instead
   */
  maximumRefundable?: Maybe<Scalars['Money']>
  /**
   * Specifies the available amount with currency to refund on the gateway.
   * This value is only available for transactions of type `SuggestedRefund`.
   *
   */
  maximumRefundableV2?: Maybe<MoneyV2>
  /** The associated order. */
  order?: Maybe<Order>
  /** The associated parent transaction, for example the authorization of a capture. */
  parentTransaction?: Maybe<OrderTransaction>
  /** The payment icon to display for the transaction. */
  paymentIcon?: Maybe<Image>
  /**
   * The payment method used for the transaction. This value is `null` if the payment method is unknown.
   * @deprecated Use `paymentIcon` instead
   */
  paymentMethod?: Maybe<PaymentMethods>
  /** Date and time when the transaction was processed. */
  processedAt?: Maybe<Scalars['DateTime']>
  /**
   * The transaction receipt that the payment gateway attaches to the transaction.
   * The value of this field depends on which payment gateway processed the transaction.
   *
   * @deprecated Use `receiptJson` instead
   */
  receipt?: Maybe<Scalars['String']>
  /** The settlement currency. */
  settlementCurrency?: Maybe<CurrencyCode>
  /** The rate used when converting the transaction amount to settlement currency. */
  settlementCurrencyRate?: Maybe<Scalars['Decimal']>
  /**
   * Contains all Shopify Payments information related to an order transaction. This field is available only to stores on a Shopify Plus plan.
   *
   */
  shopifyPaymentsSet?: Maybe<ShopifyPaymentsTransactionSet>
  /** The status of this transaction. */
  status: OrderTransactionStatus
  /** Whether the transaction is a test transaction. */
  test: Scalars['Boolean']
  /**
   * Specifies the available amount to capture on the gateway.
   * Only available when an amount is capturable or manually mark as paid.
   *
   * @deprecated Use `totalUnsettledSet` instead
   */
  totalUnsettled?: Maybe<Scalars['Money']>
  /**
   * Specifies the available amount with currency to capture on the gateway in shop and presentment currencies.
   * Only available when an amount is capturable or manually mark as paid.
   *
   */
  totalUnsettledSet?: Maybe<MoneyBag>
  /**
   * Specifies the available amount with currency to capture on the gateway.
   * Only available when an amount is capturable or manually mark as paid.
   *
   * @deprecated Use `totalUnsettledSet` instead
   */
  totalUnsettledV2?: Maybe<MoneyV2>
}

/**
 * A payment transaction in the context of an order.
 *
 */
export type OrderTransactionPaymentIconArgs = {
  crop?: InputMaybe<CropRegion>
  maxHeight?: InputMaybe<Scalars['Int']>
  maxWidth?: InputMaybe<Scalars['Int']>
  scale?: InputMaybe<Scalars['Int']>
}

/**
 * An auto-generated type for paginating through multiple OrderTransactions.
 *
 */
export type OrderTransactionConnection = {
  __typename?: 'OrderTransactionConnection'
  /** A list of edges. */
  edges: Array<OrderTransactionEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one OrderTransaction and a cursor during pagination.
 *
 */
export type OrderTransactionEdge = {
  __typename?: 'OrderTransactionEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of OrderTransactionEdge. */
  node: OrderTransaction
}

/** A standardized error code, independent of the payment provider. */
export enum OrderTransactionErrorCode {
  /** The payment method was invalid. */
  AmazonPaymentsInvalidPaymentMethod = 'AMAZON_PAYMENTS_INVALID_PAYMENT_METHOD',
  /** The maximum amount has been captured. */
  AmazonPaymentsMaxAmountCharged = 'AMAZON_PAYMENTS_MAX_AMOUNT_CHARGED',
  /** The maximum amount has been refunded. */
  AmazonPaymentsMaxAmountRefunded = 'AMAZON_PAYMENTS_MAX_AMOUNT_REFUNDED',
  /** The maximum of 10 authorizations has been captured for an order. */
  AmazonPaymentsMaxAuthorizationsCaptured = 'AMAZON_PAYMENTS_MAX_AUTHORIZATIONS_CAPTURED',
  /** The maximum of 10 refunds has been processed for an order. */
  AmazonPaymentsMaxRefundsProcessed = 'AMAZON_PAYMENTS_MAX_REFUNDS_PROCESSED',
  /** The order was canceled, which canceled all open authorizations. */
  AmazonPaymentsOrderReferenceCanceled = 'AMAZON_PAYMENTS_ORDER_REFERENCE_CANCELED',
  /** The order was not confirmed within three hours. */
  AmazonPaymentsStale = 'AMAZON_PAYMENTS_STALE',
  /** Call the card issuer. */
  CallIssuer = 'CALL_ISSUER',
  /** The card was declined. */
  CardDeclined = 'CARD_DECLINED',
  /** There is an error in the gateway or merchant configuration. */
  ConfigError = 'CONFIG_ERROR',
  /** The card is expired. */
  ExpiredCard = 'EXPIRED_CARD',
  /** There was an unknown error with processing the payment. */
  GenericError = 'GENERIC_ERROR',
  /** The address does not match the card number. */
  IncorrectAddress = 'INCORRECT_ADDRESS',
  /** The CVC does not match the card number. */
  IncorrectCvc = 'INCORRECT_CVC',
  /** The card number is incorrect. */
  IncorrectNumber = 'INCORRECT_NUMBER',
  /** The entered PIN is incorrect. */
  IncorrectPin = 'INCORRECT_PIN',
  /** The ZIP or postal code does not match the card number. */
  IncorrectZip = 'INCORRECT_ZIP',
  /** The amount is either too high or too low for the provider. */
  InvalidAmount = 'INVALID_AMOUNT',
  /** The payment method is not available in the customer's country. */
  InvalidCountry = 'INVALID_COUNTRY',
  /** The format of the CVC is incorrect. */
  InvalidCvc = 'INVALID_CVC',
  /** The format of the expiry date is incorrect. */
  InvalidExpiryDate = 'INVALID_EXPIRY_DATE',
  /** The format of the card number is incorrect. */
  InvalidNumber = 'INVALID_NUMBER',
  /** The payment method is momentarily unavailable. */
  PaymentMethodUnavailable = 'PAYMENT_METHOD_UNAVAILABLE',
  /**
   * The card has been reported as lost or stolen, and the card issuer has requested that the merchant keep the card and call the number on the back.
   *
   */
  PickUpCard = 'PICK_UP_CARD',
  /** There was an error while processing the payment. */
  ProcessingError = 'PROCESSING_ERROR',
  /** A real card was used but the gateway was in test mode. */
  TestModeLiveCard = 'TEST_MODE_LIVE_CARD',
  /** The gateway or merchant configuration doesn't support a feature, such as network tokenization. */
  UnsupportedFeature = 'UNSUPPORTED_FEATURE',
}

/** Specifies the information needed to create an order transaction. */
export type OrderTransactionInput = {
  /** The amount of money for this transaction. */
  amount: Scalars['Money']
  /** The payment gateway to use for this transaction. */
  gateway: Scalars['String']
  /** The kind of transaction. */
  kind: OrderTransactionKind
  /** The ID of the order associated with the transaction. */
  orderId: Scalars['ID']
  /** The ID of the optional parent transaction, for example the authorization of a capture. */
  parentId?: InputMaybe<Scalars['ID']>
}

/** The different kinds of order transactions. */
export enum OrderTransactionKind {
  /**
   * An amount reserved against the cardholder's funding source.
   * Money does not change hands until the authorization is captured.
   *
   */
  Authorization = 'AUTHORIZATION',
  /** A transfer of the money that was reserved by an authorization. */
  Capture = 'CAPTURE',
  /**
   * The money returned to the customer when they've paid too much during a cash transaction.
   *
   */
  Change = 'CHANGE',
  /** An authorization for a payment taken with an EMV credit card reader. */
  EmvAuthorization = 'EMV_AUTHORIZATION',
  /**
   * A partial or full return of captured funds to the cardholder.
   * A refund can happen only after a capture is processed.
   *
   */
  Refund = 'REFUND',
  /** An authorization and capture performed together in a single step. */
  Sale = 'SALE',
  /** A suggested refund transaction that can be used to create a refund. */
  SuggestedRefund = 'SUGGESTED_REFUND',
  /** A cancelation of an authorization transaction. */
  Void = 'VOID',
}

/** The different states that an `OrderTransaction` can have. */
export enum OrderTransactionStatus {
  /** Awaiting a response. */
  AwaitingResponse = 'AWAITING_RESPONSE',
  /** There was an error while processing the transaction. */
  Error = 'ERROR',
  /** The transaction failed. */
  Failure = 'FAILURE',
  /** The transaction is pending. */
  Pending = 'PENDING',
  /** The transaction succeeded. */
  Success = 'SUCCESS',
  /** The transaction status is unknown. */
  Unknown = 'UNKNOWN',
}

/** Return type for `orderUpdate` mutation. */
export type OrderUpdatePayload = {
  __typename?: 'OrderUpdatePayload'
  /** The updated order. */
  order?: Maybe<Order>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * Returns information about pagination in a connection, in accordance with the
 * [Relay specification](https://relay.dev/graphql/connections.htm#sec-undefined.PageInfo).
 *
 */
export type PageInfo = {
  __typename?: 'PageInfo'
  /** Whether there are more pages to fetch following the current page. */
  hasNextPage: Scalars['Boolean']
  /** Whether there are any pages prior to the current page. */
  hasPreviousPage: Scalars['Boolean']
}

/** Some of the payment methods used in Shopify. */
export enum PaymentMethods {
  AmericanExpress = 'AMERICAN_EXPRESS',
  Bitcoin = 'BITCOIN',
  Bogus = 'BOGUS',
  Dankort = 'DANKORT',
  DinersClub = 'DINERS_CLUB',
  Discover = 'DISCOVER',
  Dogecoin = 'DOGECOIN',
  /** The payment method for Elo payment. */
  Elo = 'ELO',
  Forbrugsforeningen = 'FORBRUGSFORENINGEN',
  /** The payment method for Interac payment. */
  Interac = 'INTERAC',
  Jcb = 'JCB',
  Litecoin = 'LITECOIN',
  Maestro = 'MAESTRO',
  Mastercard = 'MASTERCARD',
  Paypal = 'PAYPAL',
  /** The payment method for UnionPay payment. */
  Unionpay = 'UNIONPAY',
  Visa = 'VISA',
}

/** Represents the payment schedule for a single payment defined in the payment terms. */
export type PaymentSchedule = Node & {
  __typename?: 'PaymentSchedule'
  /** Amount owed for this payment schedule. */
  amount: MoneyV2
  /** Date and time when the payment schedule is paid or fulfilled. */
  completedAt?: Maybe<Scalars['DateTime']>
  /** Date and time when the payment schedule is due. */
  dueAt?: Maybe<Scalars['DateTime']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** Date and time when the invoice is sent. */
  issuedAt?: Maybe<Scalars['DateTime']>
}

/**
 * An auto-generated type for paginating through multiple PaymentSchedules.
 *
 */
export type PaymentScheduleConnection = {
  __typename?: 'PaymentScheduleConnection'
  /** A list of edges. */
  edges: Array<PaymentScheduleEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one PaymentSchedule and a cursor during pagination.
 *
 */
export type PaymentScheduleEdge = {
  __typename?: 'PaymentScheduleEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of PaymentScheduleEdge. */
  node: PaymentSchedule
}

/** The input fields used to create a payment schedule for payment terms. */
export type PaymentScheduleInput = {
  /** Specifies the date and time when the payment schedule is due. This field must be provided for fixed type payment terms. */
  dueAt?: InputMaybe<Scalars['DateTime']>
  /** Specifies the date and time that the payment schedule was issued. This field must be provided for net type payment terms. */
  issuedAt?: InputMaybe<Scalars['DateTime']>
}

/** Settings related to payments. */
export type PaymentSettings = {
  __typename?: 'PaymentSettings'
  /** List of the digital wallets which the shop supports. */
  supportedDigitalWallets: Array<DigitalWallet>
}

/** Represents the payment terms for an order or draft order. */
export type PaymentTerms = Node & {
  __typename?: 'PaymentTerms'
  /**
   * Duration of payment terms in days based on the payment terms template used to create the payment terms.
   *
   */
  dueInDays?: Maybe<Scalars['Int']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** Whether the payment terms have overdue payment schedules. */
  overdue: Scalars['Boolean']
  /** List of schedules for the payment terms. */
  paymentSchedules: PaymentScheduleConnection
  /** The name of the payment terms template used to create the payment terms. */
  paymentTermsName: Scalars['String']
  /** The type of a payment terms template used to create the payment terms. */
  paymentTermsType: PaymentTermsType
  /** The translated payment terms name. */
  translatedName: Scalars['String']
}

/** Represents the payment terms for an order or draft order. */
export type PaymentTermsPaymentSchedulesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The input fields used to create a payment terms. */
export type PaymentTermsCreateInput = {
  /** Specifies the payment schedules for the payment terms. */
  paymentSchedules?: InputMaybe<Array<PaymentScheduleInput>>
  /** Specifies the payment terms template ID used to generate payment terms. */
  paymentTermsTemplateId: Scalars['ID']
}

/** Return type for `paymentTermsCreate` mutation. */
export type PaymentTermsCreatePayload = {
  __typename?: 'PaymentTermsCreatePayload'
  /** The created payment terms. */
  paymentTerms?: Maybe<PaymentTerms>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<PaymentTermsCreateUserError>
}

/** An error that occurs during the execution of `PaymentTermsCreate`. */
export type PaymentTermsCreateUserError = DisplayableError & {
  __typename?: 'PaymentTermsCreateUserError'
  /** The error code. */
  code?: Maybe<PaymentTermsCreateUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `PaymentTermsCreateUserError`. */
export enum PaymentTermsCreateUserErrorCode {
  /** An error occurred while creating payment terms. */
  PaymentTermsCreationUnsuccessful = 'PAYMENT_TERMS_CREATION_UNSUCCESSFUL',
}

/** The input fields used to delete the payment terms. */
export type PaymentTermsDeleteInput = {
  /** The ID of the payment terms being deleted. */
  paymentTermsId: Scalars['ID']
}

/** Return type for `paymentTermsDelete` mutation. */
export type PaymentTermsDeletePayload = {
  __typename?: 'PaymentTermsDeletePayload'
  /** The deleted payment terms id. */
  deletedId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<PaymentTermsDeleteUserError>
}

/** An error that occurs during the execution of `PaymentTermsDelete`. */
export type PaymentTermsDeleteUserError = DisplayableError & {
  __typename?: 'PaymentTermsDeleteUserError'
  /** The error code. */
  code?: Maybe<PaymentTermsDeleteUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `PaymentTermsDeleteUserError`. */
export enum PaymentTermsDeleteUserErrorCode {
  /** An error occurred while deleting payment terms. */
  PaymentTermsDeleteUnsuccessful = 'PAYMENT_TERMS_DELETE_UNSUCCESSFUL',
}

/** The input fields used to create a payment terms. */
export type PaymentTermsInput = {
  /** Specifies the payment schedules for the payment terms. */
  paymentSchedules?: InputMaybe<Array<PaymentScheduleInput>>
  /** Specifies the payment terms template ID used to generate payment terms. */
  paymentTermsTemplateId?: InputMaybe<Scalars['ID']>
}

/** Represents the payment terms template object. */
export type PaymentTermsTemplate = Node & {
  __typename?: 'PaymentTermsTemplate'
  /** The description of the payment terms template. */
  description: Scalars['String']
  /** The number of days between the issued date and due date if this is the net type of payment terms. */
  dueInDays?: Maybe<Scalars['Int']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The name of the payment terms template. */
  name: Scalars['String']
  /** The type of the payment terms template. */
  paymentTermsType: PaymentTermsType
  /** The translated payment terms template name. */
  translatedName: Scalars['String']
}

/** The type of a payment terms or a payment terms template. */
export enum PaymentTermsType {
  /** The payment terms or payment terms template is fixed type. */
  Fixed = 'FIXED',
  /** The payment terms or payment terms template is net type. */
  Net = 'NET',
  /** The payment terms or payment terms template is due on receipt. */
  Receipt = 'RECEIPT',
  /** The type of the payment terms or payment terms template is unknown. */
  Unknown = 'UNKNOWN',
}

/** The input fields used to update the payment terms. */
export type PaymentTermsUpdateInput = {
  /** The attributes used to update the payment terms. */
  paymentTermsAttributes: PaymentTermsInput
  /** The ID of the payment terms being updated. */
  paymentTermsId: Scalars['ID']
}

/** Return type for `paymentTermsUpdate` mutation. */
export type PaymentTermsUpdatePayload = {
  __typename?: 'PaymentTermsUpdatePayload'
  /** The updated payment terms. */
  paymentTerms?: Maybe<PaymentTerms>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<PaymentTermsUpdateUserError>
}

/** An error that occurs during the execution of `PaymentTermsUpdate`. */
export type PaymentTermsUpdateUserError = DisplayableError & {
  __typename?: 'PaymentTermsUpdateUserError'
  /** The error code. */
  code?: Maybe<PaymentTermsUpdateUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `PaymentTermsUpdateUserError`. */
export enum PaymentTermsUpdateUserErrorCode {
  /** An error occurred while updating payment terms. */
  PaymentTermsUpdateUnsuccessful = 'PAYMENT_TERMS_UPDATE_UNSUCCESSFUL',
}

/** Represents a valid PayPal Express subscriptions gateway status. */
export enum PaypalExpressSubscriptionsGatewayStatus {
  /** The status is disabled. */
  Disabled = 'DISABLED',
  /** The status is enabled. */
  Enabled = 'ENABLED',
  /** The status is pending. */
  Pending = 'PENDING',
}

/**
 * Represents a price list, including information about related prices and eligibility rules.
 * You can use price lists to specify either fixed prices or adjusted relative prices that
 * override initial product variant prices. Price lists are applied to customers
 * using context rules, which determine price list eligibility.
 *
 *   For more information on price lists, refer to
 *   [*Support different pricing models using the price list API*](https://shopify.dev/api/examples/product-price-lists#update-an-existing-price-list).
 *
 */
export type PriceList = Node & {
  __typename?: 'PriceList'
  /** A set of facts about the customer, used to determine price list eligibility. */
  contextRule?: Maybe<PriceListContextRule>
  /** The currency for fixed prices associated with this price list. */
  currency: CurrencyCode
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The unique name of the price list, used as a human-readable identifier. */
  name: Scalars['String']
  /** Relative adjustments to other prices. */
  parent?: Maybe<PriceListParent>
  /** A list of prices associated with the price list. */
  prices: PriceListPriceConnection
}

/**
 * Represents a price list, including information about related prices and eligibility rules.
 * You can use price lists to specify either fixed prices or adjusted relative prices that
 * override initial product variant prices. Price lists are applied to customers
 * using context rules, which determine price list eligibility.
 *
 *   For more information on price lists, refer to
 *   [*Support different pricing models using the price list API*](https://shopify.dev/api/examples/product-price-lists#update-an-existing-price-list).
 *
 */
export type PriceListPricesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  originType?: InputMaybe<PriceListPriceOriginType>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents the type and value of price list adjustments. */
export type PriceListAdjustment = {
  __typename?: 'PriceListAdjustment'
  /** The type of price adjustment, such as percentage increase or decrease. */
  type: PriceListAdjustmentType
  /**
   * The value of price adjustment, where positive numbers
   *           reduce the prices and negative numbers increase them.
   */
  value: Scalars['Float']
}

/** Provides the fields and values to use when updating a price list parent adjustment. */
export type PriceListAdjustmentInput = {
  /** The type of price adjustment, such as percentage increase or decrease. */
  type: PriceListAdjustmentType
  /**
   * The value of the price adjustment, where positive numbers reduce
   *                the prices and negative numbers increase them.
   */
  value: Scalars['Float']
}

/** Represents a percentage price adjustment type. */
export enum PriceListAdjustmentType {
  /** Percentage decrease type. Prices will have a lower value. */
  PercentageDecrease = 'PERCENTAGE_DECREASE',
  /** Percentage increase type. Prices will have a higher value. */
  PercentageIncrease = 'PERCENTAGE_INCREASE',
}

/**
 * An auto-generated type for paginating through multiple PriceLists.
 *
 */
export type PriceListConnection = {
  __typename?: 'PriceListConnection'
  /** A list of edges. */
  edges: Array<PriceListEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Represents a set of facts about the customer used to determine price list eligibility. For example, you can specify the country code so that the price list only applies to customers visiting from a specific country. */
export type PriceListContext = {
  /** The code for the country that the price list applies to. */
  country?: InputMaybe<CountryCode>
}

/** Represents a set of facts about the customer used to determine price list eligibility. */
export type PriceListContextRule = {
  __typename?: 'PriceListContextRule'
  /** A list of two letter country codes that determines price list eligibility. */
  countries: Array<CountryCode>
}

/** The context that the price list applies to. */
export type PriceListContextRuleInput = {
  /**
   * The code for the country that the price list applies to. You can only specify one country code.
   * Use `marketId` as of version 2022-04 instead.
   *
   */
  countries?: InputMaybe<Array<CountryCode>>
}

/** Provides the fields and values to use when creating a price list. */
export type PriceListCreateInput = {
  /** A set of facts about the customer used to determine price list eligibility. */
  contextRule?: InputMaybe<PriceListContextRuleInput>
  /** Three letter currency code for fixed prices associated with this price list. */
  currency: CurrencyCode
  /** The unique name of the price list, used as a human-readable identifier. */
  name: Scalars['String']
  /** Relative adjustments to other prices. */
  parent: PriceListParentCreateInput
}

/** Return type for `priceListCreate` mutation. */
export type PriceListCreatePayload = {
  __typename?: 'PriceListCreatePayload'
  /** The newly created price list. */
  priceList?: Maybe<PriceList>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<PriceListUserError>
}

/** Return type for `priceListDelete` mutation. */
export type PriceListDeletePayload = {
  __typename?: 'PriceListDeletePayload'
  /** The ID of the deleted price list. */
  deletedId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<PriceListUserError>
}

/**
 * An auto-generated type which holds one PriceList and a cursor during pagination.
 *
 */
export type PriceListEdge = {
  __typename?: 'PriceListEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of PriceListEdge. */
  node: PriceList
}

/** Return type for `priceListFixedPricesAdd` mutation. */
export type PriceListFixedPricesAddPayload = {
  __typename?: 'PriceListFixedPricesAddPayload'
  /** The list of fixed prices that were added to or updated in the price list. */
  prices?: Maybe<Array<PriceListPrice>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<PriceListPriceUserError>
}

/** Return type for `priceListFixedPricesDelete` mutation. */
export type PriceListFixedPricesDeletePayload = {
  __typename?: 'PriceListFixedPricesDeletePayload'
  /** A list of product variant IDs whose fixed prices were removed from the price list. */
  deletedFixedPriceVariantIds?: Maybe<Array<Scalars['ID']>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<PriceListPriceUserError>
}

/**
 * Represents relative adjustments from one price list to other prices.
 *   You can use a `PriceListParent` to specify an adjusted relative price using a percentage-based
 *   adjustment. Adjusted prices work in conjunction with exchange rules and rounding.
 *
 *   [Adjustment types](https://shopify.dev/api/admin-graphql/latest/enums/pricelistadjustmenttype)
 *   support both percentage increases and decreases.
 *
 */
export type PriceListParent = {
  __typename?: 'PriceListParent'
  /** A price list adjustment. */
  adjustment: PriceListAdjustment
}

/** Provides the fields and values to use when creating a price list parent adjustment. */
export type PriceListParentCreateInput = {
  /** Provides the fields and values to use when updating a price list parent adjustment. */
  adjustment: PriceListAdjustmentInput
}

/** Relative adjustments to other prices. */
export type PriceListParentUpdateInput = {
  /** Provides the fields and values to use when updating a price list parent adjustment. */
  adjustment: PriceListAdjustmentInput
}

/**
 * Represents information about pricing for a product variant
 *         as defined on a price list, such as the price, compare at price, and origin type. You can use a PriceListPrice to specify a fixed price for a specific product variant.
 */
export type PriceListPrice = {
  __typename?: 'PriceListPrice'
  /** The compare-at price of the product variant on this price list. */
  compareAtPrice?: Maybe<MoneyV2>
  /**
   * The origin of this price, either fixed (defined on the price list)
   *           or relative (calculated using an adjustment via a price list parent configuration).
   */
  originType: PriceListPriceOriginType
  /** The price of the product variant on this price list. */
  price: MoneyV2
  /** The product variant associated with this price. */
  variant: ProductVariant
}

/**
 * An auto-generated type for paginating through multiple PriceListPrices.
 *
 */
export type PriceListPriceConnection = {
  __typename?: 'PriceListPriceConnection'
  /** A list of edges. */
  edges: Array<PriceListPriceEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one PriceListPrice and a cursor during pagination.
 *
 */
export type PriceListPriceEdge = {
  __typename?: 'PriceListPriceEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of PriceListPriceEdge. */
  node: PriceListPrice
}

/** Provides the fields and values to use when creating or updating a fixed price list price. */
export type PriceListPriceInput = {
  /** The compare-at price of the product variant on this price list. */
  compareAtPrice?: InputMaybe<MoneyInput>
  /** The price of the product variant on this price list. */
  price: MoneyInput
  /** The product variant ID associated with the price list price. */
  variantId: Scalars['ID']
}

/**
 * Represents the origin of a price, either fixed (defined on the price list)
 *         or relative (calculated using an adjustment via a price list parent configuration).
 */
export enum PriceListPriceOriginType {
  /** The price is defined on the price list. */
  Fixed = 'FIXED',
  /** The price is relative to the parent price list. */
  Relative = 'RELATIVE',
}

/** An error for a failed price list price operation. */
export type PriceListPriceUserError = DisplayableError & {
  __typename?: 'PriceListPriceUserError'
  /** The error code. */
  code?: Maybe<PriceListPriceUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `PriceListPriceUserError`. */
export enum PriceListPriceUserErrorCode {
  /** The input value is blank. */
  Blank = 'BLANK',
  /** The specified currency doesn't match the price list's currency. */
  PriceListCurrencyMismatch = 'PRICE_LIST_CURRENCY_MISMATCH',
  /** The price list doesn't exist. */
  PriceListNotFound = 'PRICE_LIST_NOT_FOUND',
  /** Only fixed prices can be deleted. */
  PriceNotFixed = 'PRICE_NOT_FIXED',
  /** A fixed price for the specified product variant doesn't exist. */
  VariantNotFound = 'VARIANT_NOT_FOUND',
}

/** The set of valid sort keys for the PriceList query. */
export enum PriceListSortKeys {
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `name` value. */
  Name = 'NAME',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/** Provides the fields and values to use when updating a price list. */
export type PriceListUpdateInput = {
  /** A set of facts about buyer context used to determine price list eligibility. */
  contextRule?: InputMaybe<PriceListContextRuleInput>
  /** The three-letter code for fixed prices associated with this price list. */
  currency?: InputMaybe<CurrencyCode>
  /** The unique name of the price list, used as a human-readable identifier. */
  name?: InputMaybe<Scalars['String']>
  /** Relative adjustments to other prices. */
  parent?: InputMaybe<PriceListParentUpdateInput>
}

/** Return type for `priceListUpdate` mutation. */
export type PriceListUpdatePayload = {
  __typename?: 'PriceListUpdatePayload'
  /** The updated price list. */
  priceList?: Maybe<PriceList>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<PriceListUserError>
}

/** Error codes for failed contextual pricing operations. */
export type PriceListUserError = DisplayableError & {
  __typename?: 'PriceListUserError'
  /** The error code. */
  code?: Maybe<PriceListUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `PriceListUserError`. */
export enum PriceListUserErrorCode {
  /** A price list context rule cannot have more than one country. */
  ContextRuleCountriesLimit = 'CONTEXT_RULE_COUNTRIES_LIMIT',
  /** A price list for this country is already taken. */
  ContextRuleCountryTaken = 'CONTEXT_RULE_COUNTRY_TAKEN',
  /** Cannot save the price list with context rule because the limit of context rules per shop was reached. */
  ContextRuleLimitReached = 'CONTEXT_RULE_LIMIT_REACHED',
  /** A country in a context rule must use a valid currency. */
  CountryCurrencyMismatch = 'COUNTRY_CURRENCY_MISMATCH',
  /** A price list’s currency must be of the pricing rule’s country. */
  CurrencyCountryMismatch = 'CURRENCY_COUNTRY_MISMATCH',
  /** The adjustment value must be a positive value and not be greater than 100% for PERCENTAGE_DECREASE and not be greater than 1000% for PERCENTAGE_INCREASE. */
  InvalidAdjustmentValue = 'INVALID_ADJUSTMENT_VALUE',
  /** The PriceList specified does not exist. */
  PriceListNotFound = 'PRICE_LIST_NOT_FOUND',
  /** The input value is already taken. */
  Taken = 'TAKEN',
}

/** Price rules are a set of conditions, including entitlements and prerequisites, that must be met in order for a discount code to apply. We recommend using the [Discount types](https://shopify.dev/api/examples/discounts) available in the GraphQL Admin API, which are intended to replace the GraphQL `PriceRule` object and REST Admin `PriceRule` and `DiscountCode` resources. */
export type PriceRule = CommentEventSubject &
  HasEvents &
  LegacyInteroperability &
  Node & {
    __typename?: 'PriceRule'
    /** The maximum number of times that the price rule can be allocated onto an order. */
    allocationLimit?: Maybe<Scalars['Int']>
    /** The method by which the price rule's value is allocated to its entitled items. */
    allocationMethod: PriceRuleAllocationMethod
    /** The application that created the price rule. */
    app?: Maybe<App>
    /** The date and time when the price rule was created. */
    createdAt: Scalars['DateTime']
    /** The customers that can use this price rule. */
    customerSelection: PriceRuleCustomerSelection
    /** List of the price rule's discount codes. */
    discountCodes: PriceRuleDiscountCodeConnection
    /** How many discount codes associated with the price rule. */
    discountCodesCount: Scalars['Int']
    /** The date and time when the price rule ends. For open-ended price rules, use `null`. */
    endsAt?: Maybe<Scalars['DateTime']>
    /**
     * Quantity of prerequisite items required for the price rule to be applicable,  compared to quantity of entitled items.
     * @deprecated Use `prerequisiteToEntitlementQuantityRatio` instead
     */
    entitlementToPrerequisiteQuantityRatio?: Maybe<PriceRuleEntitlementToPrerequisiteQuantityRatio>
    /** The paginated list of events associated with the price rule. */
    events: EventConnection
    /** A list of the price rule's features. */
    features: Array<PriceRuleFeature>
    /** Indicates whether there are any timeline comments on the price rule. */
    hasTimelineComment: Scalars['Boolean']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The items to which the price rule applies. */
    itemEntitlements: PriceRuleItemEntitlements
    /** The items required for the price rule to be applicable. */
    itemPrerequisites: PriceRuleLineItemPrerequisites
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** Whether the price rule can be applied only once per customer. */
    oncePerCustomer: Scalars['Boolean']
    /** The number of the entitled items must fall within this range for the price rule to be applicable. */
    prerequisiteQuantityRange?: Maybe<PriceRuleQuantityRange>
    /** The shipping cost must fall within this range for the price rule to be applicable. */
    prerequisiteShippingPriceRange?: Maybe<PriceRuleMoneyRange>
    /** The sum of the entitled items subtotal prices must fall within this range for the price rule to be applicable. */
    prerequisiteSubtotalRange?: Maybe<PriceRuleMoneyRange>
    /** Quantity of prerequisite items required for the price rule to be applicable,  compared to quantity of entitled items. */
    prerequisiteToEntitlementQuantityRatio?: Maybe<PriceRulePrerequisiteToEntitlementQuantityRatio>
    /** URLs that can be used to share the discount. */
    shareableUrls: Array<PriceRuleShareableUrl>
    /** The shipping lines to which the price rule applies. */
    shippingEntitlements: PriceRuleShippingLineEntitlements
    /** The date and time when the price rule starts. */
    startsAt: Scalars['DateTime']
    /** The status of the price rule. */
    status: PriceRuleStatus
    /** A detailed summary of the price rule. */
    summary?: Maybe<Scalars['String']>
    /** The type of lines (line_item or shipping_line) to which the price rule applies. */
    target: PriceRuleTarget
    /** The title of the price rule. */
    title: Scalars['String']
    /** The total sales from orders where the price rule was used. */
    totalSales?: Maybe<MoneyV2>
    /**
     * A list of the price rule's features.
     * @deprecated Use `features` instead
     */
    traits: Array<PriceRuleTrait>
    /** The number of times that the price rule has been used. This value is updated asynchronously and can be different than the actual usage count. */
    usageCount: Scalars['Int']
    /** The maximum number of times that the price rule can be used in total. */
    usageLimit?: Maybe<Scalars['Int']>
    /** A time period during which a price rule is applicable. */
    validityPeriod: PriceRuleValidityPeriod
    /**
     * The value of the price rule.
     * @deprecated Use `valueV2` instead
     */
    value: PriceRuleValue
    /** The value of the price rule. */
    valueV2: PricingValue
  }

/** Price rules are a set of conditions, including entitlements and prerequisites, that must be met in order for a discount code to apply. We recommend using the [Discount types](https://shopify.dev/api/examples/discounts) available in the GraphQL Admin API, which are intended to replace the GraphQL `PriceRule` object and REST Admin `PriceRule` and `DiscountCode` resources. */
export type PriceRuleDiscountCodesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<DiscountCodeSortKeys>
}

/** Price rules are a set of conditions, including entitlements and prerequisites, that must be met in order for a discount code to apply. We recommend using the [Discount types](https://shopify.dev/api/examples/discounts) available in the GraphQL Admin API, which are intended to replace the GraphQL `PriceRule` object and REST Admin `PriceRule` and `DiscountCode` resources. */
export type PriceRuleEventsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<EventSortKeys>
}

/** Return type for `priceRuleActivate` mutation. */
export type PriceRuleActivatePayload = {
  __typename?: 'PriceRuleActivatePayload'
  /** The activated price rule. */
  priceRule?: Maybe<PriceRule>
  /** The list of errors that occurred from executing the mutation. */
  priceRuleUserErrors: Array<PriceRuleUserError>
  /**
   * The list of errors that occurred from executing the mutation.
   * @deprecated Use `priceRuleUserErrors` instead
   */
  userErrors: Array<UserError>
}

/** The method by which the price rule's value is allocated to its entitled items. */
export enum PriceRuleAllocationMethod {
  /** The value will be applied once across the entitled items. */
  Across = 'ACROSS',
  /** The value will be applied to each of the entitled items. */
  Each = 'EACH',
}

/**
 * An auto-generated type for paginating through multiple PriceRules.
 *
 */
export type PriceRuleConnection = {
  __typename?: 'PriceRuleConnection'
  /** A list of edges. */
  edges: Array<PriceRuleEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `priceRuleCreate` mutation. */
export type PriceRuleCreatePayload = {
  __typename?: 'PriceRuleCreatePayload'
  /** The newly created price rule. */
  priceRule?: Maybe<PriceRule>
  /** The newly created discount code. */
  priceRuleDiscountCode?: Maybe<PriceRuleDiscountCode>
  /** The list of errors that occurred from executing the mutation. */
  priceRuleUserErrors: Array<PriceRuleUserError>
  /**
   * The list of errors that occurred from executing the mutation.
   * @deprecated Use `priceRuleUserErrors` instead
   */
  userErrors: Array<UserError>
}

/** A selection of customers for whom the price rule applies. */
export type PriceRuleCustomerSelection = {
  __typename?: 'PriceRuleCustomerSelection'
  /** List of customers to whom the price rule applies. */
  customers: CustomerConnection
  /** Whether the price rule applies to all customers. */
  forAllCustomers: Scalars['Boolean']
  /**
   * A list of customer saved searches that contain the customers who can use the price rule.
   * @deprecated Use `customer_segments` instead.
   */
  savedSearches: Array<SavedSearch>
}

/** A selection of customers for whom the price rule applies. */
export type PriceRuleCustomerSelectionCustomersArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<CustomerSortKeys>
}

/** Specifies the input fields to update a price rule customer selection. */
export type PriceRuleCustomerSelectionInput = {
  /** List of customers to add to the current list of customers to whom the price rule applies. `savedSearchIds` must be empty. */
  customerIdsToAdd?: InputMaybe<Array<Scalars['ID']>>
  /** A list of customers to remove from the current list of customers to whom the price rule applies. */
  customerIdsToRemove?: InputMaybe<Array<Scalars['ID']>>
  /** Whether the price rule applies to all customers. */
  forAllCustomers?: InputMaybe<Scalars['Boolean']>
}

/** Return type for `priceRuleDeactivate` mutation. */
export type PriceRuleDeactivatePayload = {
  __typename?: 'PriceRuleDeactivatePayload'
  /** The deactivated price rule. */
  priceRule?: Maybe<PriceRule>
  /** The list of errors that occurred from executing the mutation. */
  priceRuleUserErrors: Array<PriceRuleUserError>
  /**
   * The list of errors that occurred from executing the mutation.
   * @deprecated Use `priceRuleUserErrors` instead
   */
  userErrors: Array<UserError>
}

/** Return type for `priceRuleDelete` mutation. */
export type PriceRuleDeletePayload = {
  __typename?: 'PriceRuleDeletePayload'
  /** The id price of the deleted price rule. */
  deletedPriceRuleId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  priceRuleUserErrors: Array<PriceRuleUserError>
  /** The shop of the deleted price rule. */
  shop: Shop
  /**
   * The list of errors that occurred from executing the mutation.
   * @deprecated Use `priceRuleUserErrors` instead
   */
  userErrors: Array<UserError>
}

/** A discount code of a price rule. */
export type PriceRuleDiscountCode = Node & {
  __typename?: 'PriceRuleDiscountCode'
  /** The application that created the discount code. */
  app?: Maybe<App>
  /** The code to use the discount. */
  code: Scalars['String']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The number of times that the price rule has been used. This value is updated asynchronously and can be different than the actual usage count. */
  usageCount: Scalars['Int']
}

/**
 * An auto-generated type for paginating through multiple PriceRuleDiscountCodes.
 *
 */
export type PriceRuleDiscountCodeConnection = {
  __typename?: 'PriceRuleDiscountCodeConnection'
  /** A list of edges. */
  edges: Array<PriceRuleDiscountCodeEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `priceRuleDiscountCodeCreate` mutation. */
export type PriceRuleDiscountCodeCreatePayload = {
  __typename?: 'PriceRuleDiscountCodeCreatePayload'
  /** The updated price rule. */
  priceRule?: Maybe<PriceRule>
  /** The newly created discount code. */
  priceRuleDiscountCode?: Maybe<PriceRuleDiscountCode>
  /** The list of errors that occurred from executing the mutation. */
  priceRuleUserErrors: Array<PriceRuleUserError>
  /**
   * The list of errors that occurred from executing the mutation.
   * @deprecated Use `priceRuleUserErrors` instead
   */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one PriceRuleDiscountCode and a cursor during pagination.
 *
 */
export type PriceRuleDiscountCodeEdge = {
  __typename?: 'PriceRuleDiscountCodeEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of PriceRuleDiscountCodeEdge. */
  node: PriceRuleDiscountCode
}

/** Specifies the input fields to manipulate a discount code. */
export type PriceRuleDiscountCodeInput = {
  /** The code to use the discount. */
  code?: InputMaybe<Scalars['String']>
}

/** Return type for `priceRuleDiscountCodeUpdate` mutation. */
export type PriceRuleDiscountCodeUpdatePayload = {
  __typename?: 'PriceRuleDiscountCodeUpdatePayload'
  /** The updated price rule. */
  priceRule?: Maybe<PriceRule>
  /** The updated discount code. */
  priceRuleDiscountCode?: Maybe<PriceRuleDiscountCode>
  /** The list of errors that occurred from executing the mutation. */
  priceRuleUserErrors: Array<PriceRuleUserError>
  /**
   * The list of errors that occurred from executing the mutation.
   * @deprecated Use `priceRuleUserErrors` instead
   */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one PriceRule and a cursor during pagination.
 *
 */
export type PriceRuleEdge = {
  __typename?: 'PriceRuleEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of PriceRuleEdge. */
  node: PriceRule
}

/** Quantity of prerequisite items required for the price rule to be applicable, compared to quantity of entitled items. */
export type PriceRuleEntitlementToPrerequisiteQuantityRatio = {
  __typename?: 'PriceRuleEntitlementToPrerequisiteQuantityRatio'
  /** The quantity of entitlements in the ratio. */
  entitlementQuantity: Scalars['Int']
  /** The quantity of prerequisites in the ratio. */
  prerequisiteQuantity: Scalars['Int']
}

/** Specifies the quantity of prerequisite items required for the price rule to be applicable, compared to quantity of entitled items. */
export type PriceRuleEntitlementToPrerequisiteQuantityRatioInput = {
  /** The quantity of entitlements in the ratio. */
  entitlementQuantity?: InputMaybe<Scalars['Int']>
  /** The quantity of prerequisites in the ratio. */
  prerequisiteQuantity?: InputMaybe<Scalars['Int']>
}

/** Possible error codes that could be returned by a price rule mutation. */
export enum PriceRuleErrorCode {
  /** The allocation method must be "across" for the provided target selection. */
  AllocationMethodMustBeAcrossForGivenTargetSelection = 'ALLOCATION_METHOD_MUST_BE_ACROSS_FOR_GIVEN_TARGET_SELECTION',
  /** The discount must apply on either one-time purchase or subscription items, or both. */
  AppliesOnNothing = 'APPLIES_ON_NOTHING',
  /** The input value is blank. */
  Blank = 'BLANK',
  BogoInvalidTargetSelection = 'BOGO_INVALID_TARGET_SELECTION',
  BogoInvalidTargetType = 'BOGO_INVALID_TARGET_TYPE',
  BogoInvalidValueType = 'BOGO_INVALID_VALUE_TYPE',
  BothCustomerAndSavedSearchPrerequisitesSelected = 'BOTH_CUSTOMER_AND_SAVED_SEARCH_PREREQUISITES_SELECTED',
  CannotEntitleCollectionsWithProductsOrVariants = 'CANNOT_ENTITLE_COLLECTIONS_WITH_PRODUCTS_OR_VARIANTS',
  CannotPrerequisiteCollectionWithProductOrVariants = 'CANNOT_PREREQUISITE_COLLECTION_WITH_PRODUCT_OR_VARIANTS',
  CustomerPrerequisitesExceededMax = 'CUSTOMER_PREREQUISITES_EXCEEDED_MAX',
  CustomerPrerequisitesInvalidSelection = 'CUSTOMER_PREREQUISITES_INVALID_SELECTION',
  CustomerPrerequisitesMissing = 'CUSTOMER_PREREQUISITES_MISSING',
  /** Duplicate customer prerequisite id present. */
  CustomerPrerequisiteDuplicate = 'CUSTOMER_PREREQUISITE_DUPLICATE',
  CustomerSavedSearchDuplicate = 'CUSTOMER_SAVED_SEARCH_DUPLICATE',
  CustomerSavedSearchExceededMax = 'CUSTOMER_SAVED_SEARCH_EXCEEDED_MAX',
  CustomerSavedSearchInvalid = 'CUSTOMER_SAVED_SEARCH_INVALID',
  DiscountCodeDuplicate = 'DISCOUNT_CODE_DUPLICATE',
  /** The discount end date must be after the start date. */
  EndDateBeforeStartDate = 'END_DATE_BEFORE_START_DATE',
  /** The input value should be equal to the value allowed. */
  EqualTo = 'EQUAL_TO',
  /** Exceeding the maximum number is allowed. */
  ExceededMax = 'EXCEEDED_MAX',
  /** The input value should be greater than the minimum allowed value. */
  GreaterThan = 'GREATER_THAN',
  /** The input value should be greater than or equal to the minimum value allowed. */
  GreaterThanOrEqualTo = 'GREATER_THAN_OR_EQUAL_TO',
  /** Unexpected internal error happened. */
  InternalError = 'INTERNAL_ERROR',
  /** The input value is invalid. */
  Invalid = 'INVALID',
  InvalidTargetTypePrerequisiteShippingPriceRange = 'INVALID_TARGET_TYPE_PREREQUISITE_SHIPPING_PRICE_RANGE',
  ItemEntitlementsDuplicateCollection = 'ITEM_ENTITLEMENTS_DUPLICATE_COLLECTION',
  ItemEntitlementsDuplicateProduct = 'ITEM_ENTITLEMENTS_DUPLICATE_PRODUCT',
  ItemEntitlementsDuplicateVariant = 'ITEM_ENTITLEMENTS_DUPLICATE_VARIANT',
  ItemEntitlementsExceededMaxCollection = 'ITEM_ENTITLEMENTS_EXCEEDED_MAX_COLLECTION',
  ItemEntitlementsExceededMaxProduct = 'ITEM_ENTITLEMENTS_EXCEEDED_MAX_PRODUCT',
  ItemEntitlementsExceededMaxVariant = 'ITEM_ENTITLEMENTS_EXCEEDED_MAX_VARIANT',
  ItemEntitlementsInvalidCollection = 'ITEM_ENTITLEMENTS_INVALID_COLLECTION',
  ItemEntitlementsInvalidProduct = 'ITEM_ENTITLEMENTS_INVALID_PRODUCT',
  ItemEntitlementsInvalidTargetTypeOrSelection = 'ITEM_ENTITLEMENTS_INVALID_TARGET_TYPE_OR_SELECTION',
  ItemEntitlementsInvalidVariant = 'ITEM_ENTITLEMENTS_INVALID_VARIANT',
  ItemEntitlementsMissing = 'ITEM_ENTITLEMENTS_MISSING',
  ItemEntitlementInvalidType = 'ITEM_ENTITLEMENT_INVALID_TYPE',
  ItemPrerequisitesDuplicateCollection = 'ITEM_PREREQUISITES_DUPLICATE_COLLECTION',
  ItemPrerequisitesDuplicateProduct = 'ITEM_PREREQUISITES_DUPLICATE_PRODUCT',
  ItemPrerequisitesDuplicateVariant = 'ITEM_PREREQUISITES_DUPLICATE_VARIANT',
  ItemPrerequisitesExceededMax = 'ITEM_PREREQUISITES_EXCEEDED_MAX',
  ItemPrerequisitesInvalidCollection = 'ITEM_PREREQUISITES_INVALID_COLLECTION',
  ItemPrerequisitesInvalidProduct = 'ITEM_PREREQUISITES_INVALID_PRODUCT',
  ItemPrerequisitesInvalidType = 'ITEM_PREREQUISITES_INVALID_TYPE',
  ItemPrerequisitesInvalidVariant = 'ITEM_PREREQUISITES_INVALID_VARIANT',
  ItemPrerequisitesMissing = 'ITEM_PREREQUISITES_MISSING',
  ItemPrerequisitesMustBeEmpty = 'ITEM_PREREQUISITES_MUST_BE_EMPTY',
  /** The input value should be less than the maximum value allowed. */
  LessThan = 'LESS_THAN',
  /** The input value should be less than or equal to the maximum value allowed. */
  LessThanOrEqualTo = 'LESS_THAN_OR_EQUAL_TO',
  /** Missing a required argument. */
  MissingArgument = 'MISSING_ARGUMENT',
  /** The recurring cycle limit must be 1 when a discount does not apply on subscription items. */
  MultipleRecurringCycleLimitForNonSubscriptionItems = 'MULTIPLE_RECURRING_CYCLE_LIMIT_FOR_NON_SUBSCRIPTION_ITEMS',
  /** Only one of the minimum subtotal or minimum quantity condition can be defined. */
  PrerequisiteSubtotalAndQuantityRangeBothPresent = 'PREREQUISITE_SUBTOTAL_AND_QUANTITY_RANGE_BOTH_PRESENT',
  /** The allocation limit must be a non-zero positive number. */
  PriceRuleAllocationLimitIsZero = 'PRICE_RULE_ALLOCATION_LIMIT_IS_ZERO',
  /** The allocation limit can only be set on buy-one-get-one type discounts. */
  PriceRuleAllocationLimitOnNonBogo = 'PRICE_RULE_ALLOCATION_LIMIT_ON_NON_BOGO',
  /** The number of discount codes in the shop has reached its limit. */
  PriceRuleExceededMaxDiscountCode = 'PRICE_RULE_EXCEEDED_MAX_DISCOUNT_CODE',
  /** The percentage value must be between 0 and -100. */
  PriceRulePercentageValueOutsideRange = 'PRICE_RULE_PERCENTAGE_VALUE_OUTSIDE_RANGE',
  ShippingEntitlementsDuplicateCountry = 'SHIPPING_ENTITLEMENTS_DUPLICATE_COUNTRY',
  ShippingEntitlementsExceededMax = 'SHIPPING_ENTITLEMENTS_EXCEEDED_MAX',
  ShippingEntitlementsInvalidCountry = 'SHIPPING_ENTITLEMENTS_INVALID_COUNTRY',
  ShippingEntitlementsInvalidTargetTypeOrSelection = 'SHIPPING_ENTITLEMENTS_INVALID_TARGET_TYPE_OR_SELECTION',
  ShippingEntitlementsMissing = 'SHIPPING_ENTITLEMENTS_MISSING',
  ShippingEntitlementsUnsupportedDestinationType = 'SHIPPING_ENTITLEMENTS_UNSUPPORTED_DESTINATION_TYPE',
  /** The number of discounts in the shop has reached its limit. */
  ShopExceededMaxPriceRules = 'SHOP_EXCEEDED_MAX_PRICE_RULES',
  /** The input value is already taken. */
  Taken = 'TAKEN',
  /** The input value is too long. */
  TooLong = 'TOO_LONG',
  /** Too many arguments provided. */
  TooManyArguments = 'TOO_MANY_ARGUMENTS',
  /** The input value is too short. */
  TooShort = 'TOO_SHORT',
  VariantAlreadyEntitledThroughProduct = 'VARIANT_ALREADY_ENTITLED_THROUGH_PRODUCT',
}

/** A list of features used by the price rule. */
export enum PriceRuleFeature {
  /** The price rule supports bulk discounts. */
  Bulk = 'BULK',
  /** The price rule supports quantity BXGY discounts. */
  BuyOneGetOne = 'BUY_ONE_GET_ONE',
  /** The price rule supports BXGY discounts using custom allocation limit. */
  BuyOneGetOneWithAllocationLimit = 'BUY_ONE_GET_ONE_WITH_ALLOCATION_LIMIT',
  /** The price rule supports quantity discounts. */
  QuantityDiscounts = 'QUANTITY_DISCOUNTS',
  /** The price rule supports specific customers. */
  SpecificCustomers = 'SPECIFIC_CUSTOMERS',
}

/** The value of a fixed amount price rule. */
export type PriceRuleFixedAmountValue = {
  __typename?: 'PriceRuleFixedAmountValue'
  /** The monetary value of the price rule. */
  amount: Scalars['Money']
}

/** Specifies the input fields to manipulate a price rule. */
export type PriceRuleInput = {
  /** The maximum number of times that the price rule can be allocated onto an order. */
  allocationLimit?: InputMaybe<Scalars['Int']>
  /** The method by which the price rule's value is allocated to its entitled items. */
  allocationMethod?: InputMaybe<PriceRuleAllocationMethod>
  /** The customers that can use this price rule. */
  customerSelection?: InputMaybe<PriceRuleCustomerSelectionInput>
  /** Quantity of prerequisite items required for the price rule to be applicable, compared to quantity of entitled items. This argument is deprecated: Use `prerequisiteToEntitlementQuantityRatio` instead. */
  entitlementToPrerequisiteQuantityRatio?: InputMaybe<PriceRuleEntitlementToPrerequisiteQuantityRatioInput>
  /** The items to which the price rule applies. */
  itemEntitlements?: InputMaybe<PriceRuleItemEntitlementsInput>
  /** The items required for the price rule to be applicable. */
  itemPrerequisites?: InputMaybe<PriceRuleItemPrerequisitesInput>
  /** Whether the price rule can be applied only once per customer. */
  oncePerCustomer?: InputMaybe<Scalars['Boolean']>
  /** The number of the entitled items must fall within this range for the price rule to be applicable. */
  prerequisiteQuantityRange?: InputMaybe<PriceRuleQuantityRangeInput>
  /** The shipping cost must fall within this range for the price rule to be applicable. */
  prerequisiteShippingPriceRange?: InputMaybe<PriceRuleMoneyRangeInput>
  /** The sum of the entitled items subtotal prices must fall within this range for the price rule to be applicable. */
  prerequisiteSubtotalRange?: InputMaybe<PriceRuleMoneyRangeInput>
  /** Quantity of prerequisite items required for the price rule to be applicable, compared to quantity of entitled items. */
  prerequisiteToEntitlementQuantityRatio?: InputMaybe<PriceRulePrerequisiteToEntitlementQuantityRatioInput>
  /** The shipping lines to which the price rule applies. */
  shippingEntitlements?: InputMaybe<PriceRuleShippingEntitlementsInput>
  /** The type of lines (line_item or shipping_line) to which the price rule applies. */
  target?: InputMaybe<PriceRuleTarget>
  /** Title of the price rule. */
  title?: InputMaybe<Scalars['String']>
  /** The maximum number of times that the price rule can be used in total. */
  usageLimit?: InputMaybe<Scalars['Int']>
  /** PriceRuleValidityPeriod for the price rule. */
  validityPeriod?: InputMaybe<PriceRuleValidityPeriodInput>
  /** The value of the price rule. */
  value?: InputMaybe<PriceRuleValueInput>
}

/** The items to which this price rule applies. This may be multiple products, product variants, collections or combinations of the aforementioned. */
export type PriceRuleItemEntitlements = {
  __typename?: 'PriceRuleItemEntitlements'
  /** The collections to which the price rule applies. */
  collections: CollectionConnection
  /** The product variants to which the price rule applies. */
  productVariants: ProductVariantConnection
  /** The products to which the price rule applies. */
  products: ProductConnection
  /** Whether the price rule applies to all line items. */
  targetAllLineItems: Scalars['Boolean']
}

/** The items to which this price rule applies. This may be multiple products, product variants, collections or combinations of the aforementioned. */
export type PriceRuleItemEntitlementsCollectionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The items to which this price rule applies. This may be multiple products, product variants, collections or combinations of the aforementioned. */
export type PriceRuleItemEntitlementsProductVariantsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The items to which this price rule applies. This may be multiple products, product variants, collections or combinations of the aforementioned. */
export type PriceRuleItemEntitlementsProductsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Specifies the input fields to update a price rule line item entitlement. */
export type PriceRuleItemEntitlementsInput = {
  /** The collections to which the price rule applies. */
  collectionIds?: InputMaybe<Array<Scalars['ID']>>
  /** The products to which the price rule applies. */
  productIds?: InputMaybe<Array<Scalars['ID']>>
  /** The product variants to which the price rule applies. */
  productVariantIds?: InputMaybe<Array<Scalars['ID']>>
  /** Whether the price rule applies to all items. */
  targetAllLineItems?: InputMaybe<Scalars['Boolean']>
}

/** Specifies the input fields to update a price rule's item prerequisites. */
export type PriceRuleItemPrerequisitesInput = {
  /** The collections needed for the price rule to be applied. */
  collectionIds?: InputMaybe<Array<Scalars['ID']>>
  /** The products needed for the price rule to be applied. */
  productIds?: InputMaybe<Array<Scalars['ID']>>
  /** The product variants needed for the price rule to be applied. */
  productVariantIds?: InputMaybe<Array<Scalars['ID']>>
}

/** Single or multiple line item products, product variants or collections required for the price rule to be applicable, can also be provided in combination. */
export type PriceRuleLineItemPrerequisites = {
  __typename?: 'PriceRuleLineItemPrerequisites'
  /** The collections required for the price rule to be applicable. */
  collections: CollectionConnection
  /** The product variants required for the price rule to be applicable. */
  productVariants: ProductVariantConnection
  /** The products required for the price rule to be applicable. */
  products: ProductConnection
}

/** Single or multiple line item products, product variants or collections required for the price rule to be applicable, can also be provided in combination. */
export type PriceRuleLineItemPrerequisitesCollectionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Single or multiple line item products, product variants or collections required for the price rule to be applicable, can also be provided in combination. */
export type PriceRuleLineItemPrerequisitesProductVariantsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Single or multiple line item products, product variants or collections required for the price rule to be applicable, can also be provided in combination. */
export type PriceRuleLineItemPrerequisitesProductsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** A money range within which the price rule is applicable. */
export type PriceRuleMoneyRange = {
  __typename?: 'PriceRuleMoneyRange'
  /** The lower bound of the money range. */
  greaterThan?: Maybe<Scalars['Money']>
  /** The lower bound or equal of the money range. */
  greaterThanOrEqualTo?: Maybe<Scalars['Money']>
  /** The upper bound of the money range. */
  lessThan?: Maybe<Scalars['Money']>
  /** The upper bound or equal of the money range. */
  lessThanOrEqualTo?: Maybe<Scalars['Money']>
}

/**
 * Specifies the input fields to update the money range within which the price rule is applicable.
 *
 */
export type PriceRuleMoneyRangeInput = {
  /** The lower bound of the money range. */
  greaterThan?: InputMaybe<Scalars['Money']>
  /** The lower or equal bound of the money range. */
  greaterThanOrEqualTo?: InputMaybe<Scalars['Money']>
  /** The upper bound of the money range. */
  lessThan?: InputMaybe<Scalars['Money']>
  /** The upper or equal bound of the money range. */
  lessThanOrEqualTo?: InputMaybe<Scalars['Money']>
}

/** The value of a percent price rule. */
export type PriceRulePercentValue = {
  __typename?: 'PriceRulePercentValue'
  /** The percent value of the price rule. */
  percentage: Scalars['Float']
}

/** Quantity of prerequisite items required for the price rule to be applicable, compared to quantity of entitled items. */
export type PriceRulePrerequisiteToEntitlementQuantityRatio = {
  __typename?: 'PriceRulePrerequisiteToEntitlementQuantityRatio'
  /** The quantity of entitlements in the ratio. */
  entitlementQuantity: Scalars['Int']
  /** The quantity of prerequisites in the ratio. */
  prerequisiteQuantity: Scalars['Int']
}

/** Specifies the quantity of prerequisite items required for the price rule to be applicable, compared to quantity of entitled items. */
export type PriceRulePrerequisiteToEntitlementQuantityRatioInput = {
  /** The quantity of entitlements in the ratio. */
  entitlementQuantity?: InputMaybe<Scalars['Int']>
  /** The quantity of prerequisites in the ratio. */
  prerequisiteQuantity?: InputMaybe<Scalars['Int']>
}

/** A quantity range within which the price rule is applicable. */
export type PriceRuleQuantityRange = {
  __typename?: 'PriceRuleQuantityRange'
  /** The lower bound of the quantity range. */
  greaterThan?: Maybe<Scalars['Int']>
  /** The lower bound or equal of the quantity range. */
  greaterThanOrEqualTo?: Maybe<Scalars['Int']>
  /** The upper bound of the quantity range. */
  lessThan?: Maybe<Scalars['Int']>
  /** The upper bound or equal of the quantity range. */
  lessThanOrEqualTo?: Maybe<Scalars['Int']>
}

/**
 * Specifies the input fields to update the quantity range within which the price rule is applicable.
 *
 */
export type PriceRuleQuantityRangeInput = {
  /** The lower bound of the quantity range. */
  greaterThan?: InputMaybe<Scalars['Int']>
  /** The lower or equal bound of the quantity range. */
  greaterThanOrEqualTo?: InputMaybe<Scalars['Int']>
  /** The upper bound of the quantity range. */
  lessThan?: InputMaybe<Scalars['Int']>
  /** The upper or equal bound of the quantity range. */
  lessThanOrEqualTo?: InputMaybe<Scalars['Int']>
}

/** Shareable URL for the discount code associated with the price rule. */
export type PriceRuleShareableUrl = {
  __typename?: 'PriceRuleShareableUrl'
  /** The image URL of the item (product or collection) to which the discount applies. */
  targetItemImage?: Maybe<Image>
  /** The type of page that's associated with the URL. */
  targetType: PriceRuleShareableUrlTargetType
  /** The title of the page that's associated with the URL. */
  title: Scalars['String']
  /** The URL for the discount code. */
  url: Scalars['URL']
}

/** Page type where shareable URL lands. */
export enum PriceRuleShareableUrlTargetType {
  Collection = 'COLLECTION',
  Home = 'HOME',
  Product = 'PRODUCT',
}

/** Specifies the input fields to update a price rule shipping entitlement. */
export type PriceRuleShippingEntitlementsInput = {
  /** The codes for the countries to which the price rule applies to. */
  countryCodes?: InputMaybe<Array<CountryCode>>
  /** Whether the price rule is applicable to countries that have not been defined in the shop's shipping zones. */
  includeRestOfWorld?: InputMaybe<Scalars['Boolean']>
  /** Whether the price rule applies to all shipping lines. */
  targetAllShippingLines?: InputMaybe<Scalars['Boolean']>
}

/** The shipping lines to which the price rule applies to. */
export type PriceRuleShippingLineEntitlements = {
  __typename?: 'PriceRuleShippingLineEntitlements'
  /** The codes for the countries to which the price rule applies to. */
  countryCodes: Array<CountryCode>
  /** Whether the price rule is applicable to countries that have not been defined in the shop's shipping zones. */
  includeRestOfWorld: Scalars['Boolean']
  /** Whether the price rule applies to all shipping lines. */
  targetAllShippingLines: Scalars['Boolean']
}

/** The set of valid sort keys for the PriceRule query. */
export enum PriceRuleSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `ends_at` value. */
  EndsAt = 'ENDS_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
  /** Sort by the `starts_at` value. */
  StartsAt = 'STARTS_AT',
  /** Sort by the `title` value. */
  Title = 'TITLE',
  /** Sort by the `updated_at` value. */
  UpdatedAt = 'UPDATED_AT',
}

/** The status of the price rule. */
export enum PriceRuleStatus {
  Active = 'ACTIVE',
  Expired = 'EXPIRED',
  Scheduled = 'SCHEDULED',
}

/** The type of lines (line_item or shipping_line) to which the price rule applies. */
export enum PriceRuleTarget {
  /** The price rule applies to line items. */
  LineItem = 'LINE_ITEM',
  /** The price rule applies to shipping lines. */
  ShippingLine = 'SHIPPING_LINE',
}

/** A list of features used by the price rule. */
export enum PriceRuleTrait {
  /** The price rule supports bulk discounts. */
  Bulk = 'BULK',
  /** The price rule supports quantity BXGY discounts. */
  BuyOneGetOne = 'BUY_ONE_GET_ONE',
  /** The price rule supports BXGY discounts using custom allocation limit. */
  BuyOneGetOneWithAllocationLimit = 'BUY_ONE_GET_ONE_WITH_ALLOCATION_LIMIT',
  /** The price rule supports quantity discounts. */
  QuantityDiscounts = 'QUANTITY_DISCOUNTS',
  /** The price rule supports specific customers. */
  SpecificCustomers = 'SPECIFIC_CUSTOMERS',
}

/** Return type for `priceRuleUpdate` mutation. */
export type PriceRuleUpdatePayload = {
  __typename?: 'PriceRuleUpdatePayload'
  /** The updated price rule. */
  priceRule?: Maybe<PriceRule>
  /** The updated discount code. */
  priceRuleDiscountCode?: Maybe<PriceRuleDiscountCode>
  /** The list of errors that occurred from executing the mutation. */
  priceRuleUserErrors: Array<PriceRuleUserError>
  /**
   * The list of errors that occurred from executing the mutation.
   * @deprecated Use `priceRuleUserErrors` instead
   */
  userErrors: Array<UserError>
}

/** Represents an error that happens during execution of a price rule mutation. */
export type PriceRuleUserError = DisplayableError & {
  __typename?: 'PriceRuleUserError'
  /** Error code to uniquely identify the error. */
  code?: Maybe<PriceRuleErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** A time period during which a price rule is applicable. */
export type PriceRuleValidityPeriod = {
  __typename?: 'PriceRuleValidityPeriod'
  /** The time after which the price rule becomes invalid. */
  end?: Maybe<Scalars['DateTime']>
  /** The time after which the price rule is valid. */
  start: Scalars['DateTime']
}

/** Specifies the input fields to update the validity period of a price rule. */
export type PriceRuleValidityPeriodInput = {
  /** The time after which the price rule becomes invalid. */
  end?: InputMaybe<Scalars['DateTime']>
  /** The time after which the price rule is valid. */
  start: Scalars['DateTime']
}

/** The value of the price rule. */
export type PriceRuleValue = PriceRuleFixedAmountValue | PriceRulePercentValue

/** Specifies the input fields to update a price rule. */
export type PriceRuleValueInput = {
  /** The fixed amount value of the price rule. */
  fixedAmountValue?: InputMaybe<Scalars['Money']>
  /** The percentage value of the price rule. */
  percentageValue?: InputMaybe<Scalars['Float']>
}

/** The value of the percentage pricing object. */
export type PricingPercentageValue = {
  __typename?: 'PricingPercentageValue'
  /** The percentage value of the object. */
  percentage: Scalars['Float']
}

/** The value of the pricing object. */
export type PricingValue = MoneyV2 | PricingPercentageValue

/**
 * Private metafields represent custom metadata that is attached to a resource.
 * Private metafields are accessible only by the application that created them and only from the GraphQL Admin API.
 *
 * An application can create a maximum of 10 private metafields per shop resource.
 *
 */
export type PrivateMetafield = Node & {
  __typename?: 'PrivateMetafield'
  /** The date and time when the private metafield was created. */
  createdAt: Scalars['DateTime']
  /** The id of the private metafield. */
  id: Scalars['ID']
  /** The key name of the private metafield. */
  key: Scalars['String']
  /** The namespace of the private metafield. */
  namespace: Scalars['String']
  /** The date and time when the private metafield was updated. */
  updatedAt: Scalars['DateTime']
  /** The value of a private metafield. */
  value: Scalars['String']
  /** Represents the private metafield value type. */
  valueType: PrivateMetafieldValueType
}

/**
 * An auto-generated type for paginating through multiple PrivateMetafields.
 *
 */
export type PrivateMetafieldConnection = {
  __typename?: 'PrivateMetafieldConnection'
  /** A list of edges. */
  edges: Array<PrivateMetafieldEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * The input fields for the private metafield to delete.
 *
 */
export type PrivateMetafieldDeleteInput = {
  /** The key of the private metafield. */
  key: Scalars['String']
  /** The namespace of the private metafield. */
  namespace: Scalars['String']
  /** The ID of the resource that owns the metafield. If the field is blank, then the `Shop` resource owns the metafield. */
  owner?: InputMaybe<Scalars['ID']>
}

/** Return type for `privateMetafieldDelete` mutation. */
export type PrivateMetafieldDeletePayload = {
  __typename?: 'PrivateMetafieldDeletePayload'
  /** The ID of private metafield that was deleted. */
  deletedPrivateMetafieldId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one PrivateMetafield and a cursor during pagination.
 *
 */
export type PrivateMetafieldEdge = {
  __typename?: 'PrivateMetafieldEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of PrivateMetafieldEdge. */
  node: PrivateMetafield
}

/**
 * The input fields for a private metafield.
 *
 */
export type PrivateMetafieldInput = {
  /** The key of the private metafield. */
  key: Scalars['String']
  /** The namespace of the private metafield. */
  namespace: Scalars['String']
  /** The resource that owns the metafield. If the field is blank, then the `Shop` resource owns the metafield. */
  owner?: InputMaybe<Scalars['ID']>
  /** The `value` and `valueType` of the private metafield, wrapped in a `ValueInput` object. */
  valueInput: PrivateMetafieldValueInput
}

/** Return type for `privateMetafieldUpsert` mutation. */
export type PrivateMetafieldUpsertPayload = {
  __typename?: 'PrivateMetafieldUpsertPayload'
  /** The private metafield that was created or updated. */
  privateMetafield?: Maybe<PrivateMetafield>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * The value input contains the value and value type of the private metafield.
 *
 */
export type PrivateMetafieldValueInput = {
  /** The value of a private metafield. */
  value: Scalars['String']
  /** Represents the private metafield value type. */
  valueType: PrivateMetafieldValueType
}

/** Supported private metafield value types. */
export enum PrivateMetafieldValueType {
  /** An integer metafield. */
  Integer = 'INTEGER',
  /** A JSON string metafield. */
  JsonString = 'JSON_STRING',
  /** A string metafield. */
  String = 'STRING',
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type Product = HasMetafieldDefinitions &
  HasMetafields &
  HasPublishedTranslations &
  LegacyInteroperability &
  Navigable &
  Node &
  OnlineStorePreviewable &
  Publishable & {
    __typename?: 'Product'
    /** The number of publications a resource is published to without feedback errors. */
    availablePublicationCount: Scalars['Int']
    /**
     * The description of the product, complete with HTML formatting.
     * @deprecated Use `descriptionHtml` instead
     */
    bodyHtml?: Maybe<Scalars['String']>
    /** A list of the collections that include the product. */
    collections: CollectionConnection
    /** The pricing that applies for a customer in a given context. */
    contextualPricing: ProductContextualPricing
    /**
     * The date and time ([ISO 8601 format](http://en.wikipedia.org/wiki/ISO_8601)) when the product was created.
     *
     */
    createdAt: Scalars['DateTime']
    /** The custom product type specified by the merchant. */
    customProductType?: Maybe<Scalars['String']>
    /**
     * A default cursor that returns the single next record, sorted ascending by ID.
     *
     */
    defaultCursor: Scalars['String']
    /** A stripped description of the product, single line with HTML tags removed. */
    description: Scalars['String']
    /** The description of the product, complete with HTML formatting. */
    descriptionHtml: Scalars['HTML']
    /**
     * Stripped description of the product, single line with HTML tags removed.
     * Truncated to 60 characters.
     *
     * @deprecated Use `description` instead
     */
    descriptionPlainSummary: Scalars['String']
    /** The featured image for the product. */
    featuredImage?: Maybe<Image>
    /** The featured media for the product. */
    featuredMedia?: Maybe<Media>
    /** Information about the product that's provided through resource feedback. */
    feedback?: Maybe<ResourceFeedback>
    /** The theme template used when viewing the gift card in a store. */
    giftCardTemplateSuffix?: Maybe<Scalars['String']>
    /** A unique human-friendly string of the product's title. */
    handle: Scalars['String']
    /** Whether the product has only a single variant with the default option and value. */
    hasOnlyDefaultVariant: Scalars['Boolean']
    /** Whether the product has out of stock variants. */
    hasOutOfStockVariants: Scalars['Boolean']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The images associated with the product. */
    images: ImageConnection
    /** Whether the product is in a given collection. */
    inCollection: Scalars['Boolean']
    /** Whether the product is a gift card. */
    isGiftCard: Scalars['Boolean']
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** The media associated with the product. This can include images, 3D models, or videos. */
    media: MediaConnection
    /** Total count of media belonging to a product. */
    mediaCount: Scalars['Int']
    /** Returns a metafield by namespace and key that belongs to the resource. */
    metafield?: Maybe<Metafield>
    /** List of metafield definitions. */
    metafieldDefinitions: MetafieldDefinitionConnection
    /** List of metafields that belong to the resource. */
    metafields: MetafieldConnection
    /** The online store preview URL. */
    onlineStorePreviewUrl?: Maybe<Scalars['URL']>
    /**
     * The online store URL for the product.
     * A value of `null` indicates that the product is not published to the Online Store sales channel.
     *
     */
    onlineStoreUrl?: Maybe<Scalars['URL']>
    /** A list of product options. The limit is specified by Shop.resourceLimits.maxProductOptions. */
    options: Array<ProductOption>
    /**
     * The price range of the product.
     * @deprecated Deprecated in API version 2020-10. Use `priceRangeV2` instead.
     */
    priceRange: ProductPriceRange
    /** The price range of the product with prices formatted as decimals. */
    priceRangeV2: ProductPriceRangeV2
    /** Returns a private metafield by namespace and key that belongs to the resource. */
    privateMetafield?: Maybe<PrivateMetafield>
    /** List of private metafields that belong to the resource. */
    privateMetafields: PrivateMetafieldConnection
    /**
     * A list of the channels where the product is published.
     * @deprecated Use `resourcePublications` instead
     */
    productPublications: ProductPublicationConnection
    /** The product type specified by the merchant. */
    productType: Scalars['String']
    /** The number of publications a resource is published on. */
    publicationCount: Scalars['Int']
    /**
     * A list of the channels where the product is published.
     * @deprecated Use `resourcePublications` instead
     */
    publications: ProductPublicationConnection
    /**
     * The date and time ([ISO 8601 format](http://en.wikipedia.org/wiki/ISO_8601)) when the product was published to the Online Store.
     *
     */
    publishedAt?: Maybe<Scalars['DateTime']>
    /**
     * Check to see whether the resource is published to a given channel.
     * @deprecated Use `publishedOnPublication` instead
     */
    publishedOnChannel: Scalars['Boolean']
    /**
     * Check to see whether the resource is published to the calling app's channel.
     * @deprecated Use `publishedOnCurrentPublication` instead
     */
    publishedOnCurrentChannel: Scalars['Boolean']
    /** Check to see whether the resource is published to the calling app's publication. */
    publishedOnCurrentPublication: Scalars['Boolean']
    /** Check to see whether the resource is published to a given publication. */
    publishedOnPublication: Scalars['Boolean']
    /** Whether the product can only be purchased with a selling plan (subscription). Products that are sold on subscription (`requiresSellingPlan: true`) can be updated only for online stores. If you update a product to be subscription only, then the product is unpublished from all channels except the online store. */
    requiresSellingPlan: Scalars['Boolean']
    /** The resource that is either published or staged to be published to the calling app's publication. Requires the `read_product_listings` scope. */
    resourcePublicationOnCurrentPublication?: Maybe<ResourcePublicationV2>
    /** The list of resources that are published to a publication. */
    resourcePublications: ResourcePublicationConnection
    /** The list of resources that are either published or staged to be published to a publication. */
    resourcePublicationsV2: ResourcePublicationV2Connection
    /** Count of selling plan groups associated with the product. */
    sellingPlanGroupCount: Scalars['Int']
    /** A list of all selling plan groups defined in the current shop associated with the product either directly or through any of its variants. */
    sellingPlanGroups: SellingPlanGroupConnection
    /** SEO information of the product. */
    seo: Seo
    /** The standardized product type in the Shopify product taxonomy. */
    standardizedProductType?: Maybe<StandardizedProductType>
    /** The product status. This controls visibility across all channels. */
    status: ProductStatus
    /**
     * The Storefront GraphQL API ID of the `Product`.
     *
     * As of the `2022-04` version release, the Storefront GraphQL API will no longer return Base64 encoded IDs to match the behavior of the Admin GraphQL API. Therefore, you can safely use the `id` field's value instead.
     *
     * @deprecated Use `id` instead
     */
    storefrontId: Scalars['StorefrontID']
    /**
     * A comma separated list of tags associated with the product. Updating `tags` overwrites
     * any existing tags that were previously added to the product. To add new tags without overwriting
     * existing tags, use the [tagsAdd](https://shopify.dev/api/admin-graphql/latest/mutations/tagsadd)
     * mutation.
     *
     */
    tags: Array<Scalars['String']>
    /** The theme template used when viewing the product in a store. */
    templateSuffix?: Maybe<Scalars['String']>
    /** The title of the product. */
    title: Scalars['String']
    /** The quantity of inventory in stock. */
    totalInventory: Scalars['Int']
    /** The number of variants that are associated with the product. */
    totalVariants: Scalars['Int']
    /** Whether inventory tracking has been enabled for the product. */
    tracksInventory: Scalars['Boolean']
    /** The translations associated with the resource. */
    translations: Array<PublishedTranslation>
    /**
     * The list of channels that the resource is not published to.
     * @deprecated Use `unpublishedPublications` instead
     */
    unpublishedChannels: ChannelConnection
    /** The list of publications that the resource is not published to. */
    unpublishedPublications: PublicationConnection
    /**
     * The date and time when the product was last modified.
     * A product's `updatedAt` value can change for different reasons. For example, if an order
     * is placed for a product that has inventory tracking set up, then the inventory adjustment
     * is counted as an update.
     *
     */
    updatedAt: Scalars['DateTime']
    /** A list of variants associated with the product. */
    variants: ProductVariantConnection
    /** The name of the product's vendor. */
    vendor: Scalars['String']
  }

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductCollectionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<CollectionSortKeys>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductContextualPricingArgs = {
  context: ContextualPricingContext
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductDescriptionArgs = {
  truncateAt?: InputMaybe<Scalars['Int']>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductImagesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  crop?: InputMaybe<CropRegion>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  maxHeight?: InputMaybe<Scalars['Int']>
  maxWidth?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  scale?: InputMaybe<Scalars['Int']>
  sortKey?: InputMaybe<ProductImageSortKeys>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductInCollectionArgs = {
  id: Scalars['ID']
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductMediaArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<ProductMediaSortKeys>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductMetafieldDefinitionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  pinnedStatus?: InputMaybe<MetafieldDefinitionPinnedStatus>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<MetafieldDefinitionSortKeys>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductOptionsArgs = {
  first?: InputMaybe<Scalars['Int']>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductPrivateMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductPrivateMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductProductPublicationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductPublicationCountArgs = {
  onlyPublished?: InputMaybe<Scalars['Boolean']>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductPublicationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  onlyPublished?: InputMaybe<Scalars['Boolean']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductPublishedOnChannelArgs = {
  channelId: Scalars['ID']
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductPublishedOnPublicationArgs = {
  publicationId: Scalars['ID']
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductResourcePublicationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  onlyPublished?: InputMaybe<Scalars['Boolean']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductResourcePublicationsV2Args = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  onlyPublished?: InputMaybe<Scalars['Boolean']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductSellingPlanGroupsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductTranslationsArgs = {
  locale: Scalars['String']
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductUnpublishedChannelsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductUnpublishedPublicationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The Product resource lets you manage products in a merchant’s store. You can use [ProductVariants](https://shopify.dev/api/admin-graphql/latest/objects/productvariant) to create or update different versions of the same product. You can also add or update product [Media](https://shopify.dev/api/admin-graphql/latest/interfaces/media). Products can be organized by grouping them into a [Collection](https://shopify.dev/api/admin-graphql/latest/objects/collection). */
export type ProductVariantsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<ProductVariantSortKeys>
}

/** Specifies product images to append. */
export type ProductAppendImagesInput = {
  /** The ID of the product. */
  id: Scalars['ID']
  /** The images to be appended to the product. */
  images: Array<ImageInput>
}

/** Return type for `productAppendImages` mutation. */
export type ProductAppendImagesPayload = {
  __typename?: 'ProductAppendImagesPayload'
  /** List of new images appended to the product. */
  newImages?: Maybe<Array<Image>>
  /** The product object. */
  product?: Maybe<Product>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `productAppendImages` mutation. */
export type ProductAppendImagesPayloadNewImagesArgs = {
  crop?: InputMaybe<CropRegion>
  maxHeight?: InputMaybe<Scalars['Int']>
  maxWidth?: InputMaybe<Scalars['Int']>
  scale?: InputMaybe<Scalars['Int']>
}

/** Return type for `productChangeStatus` mutation. */
export type ProductChangeStatusPayload = {
  __typename?: 'ProductChangeStatusPayload'
  /** The product object. */
  product?: Maybe<Product>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<ProductChangeStatusUserError>
}

/** An error that occurs during the execution of `ProductChangeStatus`. */
export type ProductChangeStatusUserError = DisplayableError & {
  __typename?: 'ProductChangeStatusUserError'
  /** The error code. */
  code?: Maybe<ProductChangeStatusUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `ProductChangeStatusUserError`. */
export enum ProductChangeStatusUserErrorCode {
  /** Product could not be found. */
  ProductNotFound = 'PRODUCT_NOT_FOUND',
}

/** The set of valid sort keys for the ProductCollection query. */
export enum ProductCollectionSortKeys {
  /** Sort by the `best-selling` value. */
  BestSelling = 'BEST_SELLING',
  /** Sort by the `collection-default` value. */
  CollectionDefault = 'COLLECTION_DEFAULT',
  /** Sort by the `created` value. */
  Created = 'CREATED',
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `manual` value. */
  Manual = 'MANUAL',
  /** Sort by the `price` value. */
  Price = 'PRICE',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
  /** Sort by the `title` value. */
  Title = 'TITLE',
}

/**
 * An auto-generated type for paginating through multiple Products.
 *
 */
export type ProductConnection = {
  __typename?: 'ProductConnection'
  /** A list of edges. */
  edges: Array<ProductEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** The pricing of a particular product in a given context. */
export type ProductContextualPricing = {
  __typename?: 'ProductContextualPricing'
  /** The pricing of the variant with the highest price in the given context. */
  maxVariantPricing?: Maybe<ProductVariantContextualPricing>
  /** The pricing of the variant with the lowest price in the given context. */
  minVariantPricing?: Maybe<ProductVariantContextualPricing>
  /** The price range of the product with prices formatted as decimals. */
  priceRange: ProductPriceRangeV2
}

/** Return type for `productCreateMedia` mutation. */
export type ProductCreateMediaPayload = {
  __typename?: 'ProductCreateMediaPayload'
  /** The newly created media. */
  media?: Maybe<Array<Media>>
  /** The list of errors that occurred from executing the mutation. */
  mediaUserErrors: Array<MediaUserError>
  /** The product associated with the media. */
  product?: Maybe<Product>
  /**
   * The list of errors that occurred from executing the mutation.
   * @deprecated Use `mediaUserErrors` instead
   */
  userErrors: Array<UserError>
}

/** Return type for `productCreate` mutation. */
export type ProductCreatePayload = {
  __typename?: 'ProductCreatePayload'
  /** The product object. */
  product?: Maybe<Product>
  /** The shop associated with the product. */
  shop: Shop
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `productDeleteImages` mutation. */
export type ProductDeleteImagesPayload = {
  __typename?: 'ProductDeleteImagesPayload'
  /** This is an array of IDs of images to delete. */
  deletedImageIds: Array<Scalars['ID']>
  /** This is the product object. */
  product?: Maybe<Product>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Specifies the product to delete. */
export type ProductDeleteInput = {
  /** The ID of the product. */
  id: Scalars['ID']
}

/** Return type for `productDeleteMedia` mutation. */
export type ProductDeleteMediaPayload = {
  __typename?: 'ProductDeleteMediaPayload'
  /** List of media IDs which were deleted. */
  deletedMediaIds?: Maybe<Array<Scalars['ID']>>
  /** List of product image IDs which were deleted. */
  deletedProductImageIds?: Maybe<Array<Scalars['ID']>>
  /** The list of errors that occurred from executing the mutation. */
  mediaUserErrors: Array<MediaUserError>
  /** The product which media was deleted from. */
  product?: Maybe<Product>
  /**
   * The list of errors that occurred from executing the mutation.
   * @deprecated Use `mediaUserErrors` instead
   */
  userErrors: Array<UserError>
}

/** Return type for `productDelete` mutation. */
export type ProductDeletePayload = {
  __typename?: 'ProductDeletePayload'
  /** The ID of the deleted product. */
  deletedProductId?: Maybe<Scalars['ID']>
  /** The shop associated with the product. */
  shop: Shop
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `productDuplicate` mutation. */
export type ProductDuplicatePayload = {
  __typename?: 'ProductDuplicatePayload'
  /** The asynchronous job duplicating the product images. */
  imageJob?: Maybe<Job>
  /** The duplicated product. */
  newProduct?: Maybe<Product>
  /** The user's shop. */
  shop: Shop
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one Product and a cursor during pagination.
 *
 */
export type ProductEdge = {
  __typename?: 'ProductEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of ProductEdge. */
  node: Product
}

/** The set of valid sort keys for the ProductImage query. */
export enum ProductImageSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `position` value. */
  Position = 'POSITION',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/** Return type for `productImageUpdate` mutation. */
export type ProductImageUpdatePayload = {
  __typename?: 'ProductImageUpdatePayload'
  /** Image updated. */
  image?: Maybe<Image>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `productImageUpdate` mutation. */
export type ProductImageUpdatePayloadImageArgs = {
  crop?: InputMaybe<CropRegion>
  maxHeight?: InputMaybe<Scalars['Int']>
  maxWidth?: InputMaybe<Scalars['Int']>
  scale?: InputMaybe<Scalars['Int']>
}

/** Specifies the input fields required to create a product. */
export type ProductInput = {
  /** A description of the product. Supports HTML formatting. This argument is deprecated: Use `descriptionHtml` instead. */
  bodyHtml?: InputMaybe<Scalars['String']>
  /** The IDs of the collections that this product will be added to. */
  collectionsToJoin?: InputMaybe<Array<Scalars['ID']>>
  /** The IDs of collections that will no longer include the product. */
  collectionsToLeave?: InputMaybe<Array<Scalars['ID']>>
  /** The custom product type specified by the merchant. */
  customProductType?: InputMaybe<Scalars['String']>
  /** The description of the product, complete with HTML formatting. */
  descriptionHtml?: InputMaybe<Scalars['String']>
  /** Whether the product is a gift card. */
  giftCard?: InputMaybe<Scalars['Boolean']>
  /** The theme template used when viewing the gift card in a store. */
  giftCardTemplateSuffix?: InputMaybe<Scalars['String']>
  /**
   * A unique human-friendly string for the product. Automatically generated from the product's title.
   *
   */
  handle?: InputMaybe<Scalars['String']>
  /** Specifies the product to update in productUpdate or creates a new product if absent in productCreate. */
  id?: InputMaybe<Scalars['ID']>
  /** The images to associate with the product. */
  images?: InputMaybe<Array<ImageInput>>
  /** The metafields to associate with this product. */
  metafields?: InputMaybe<Array<MetafieldInput>>
  /** List of custom product options (maximum of 3 per product). */
  options?: InputMaybe<Array<Scalars['String']>>
  /** The private metafields to associate with this product. */
  privateMetafields?: InputMaybe<Array<PrivateMetafieldInput>>
  /** A list of the channels where the product is published. This argument is deprecated: Use `PublishablePublish` instead. */
  productPublications?: InputMaybe<Array<ProductPublicationInput>>
  /** The product type specified by the merchant. */
  productType?: InputMaybe<Scalars['String']>
  /** A list of the channels where the product is published. This argument is deprecated: Use `PublishablePublish` instead. */
  publications?: InputMaybe<Array<ProductPublicationInput>>
  /** Only products with an active status can be published. This argument is deprecated: Use `PublishablePublish` instead. */
  publishDate?: InputMaybe<Scalars['DateTime']>
  /** Only products with an active status can be published. This argument is deprecated: Use `PublishablePublish` instead. */
  publishOn?: InputMaybe<Scalars['DateTime']>
  /** Only products with an active status can be published. This argument is deprecated: Use `PublishablePublish` instead. */
  published?: InputMaybe<Scalars['Boolean']>
  /** Only products with an active status can be published. This argument is deprecated: Use `PublishablePublish` instead. */
  publishedAt?: InputMaybe<Scalars['DateTime']>
  /**
   * Whether a redirect is required after a new handle has been provided.
   * If true, then the old handle is redirected to the new one automatically.
   *
   */
  redirectNewHandle?: InputMaybe<Scalars['Boolean']>
  /** Whether the product can only be purchased with a selling plan (subscription). Products that are sold exclusively on subscription can only be created on online stores. If set to `true` on an already existing product, then the product will be marked unavailable on channels that don't support subscriptions. */
  requiresSellingPlan?: InputMaybe<Scalars['Boolean']>
  /** The SEO information associated with the product. */
  seo?: InputMaybe<SeoInput>
  /** The standardized product type in the Shopify product taxonomy. */
  standardizedProductType?: InputMaybe<StandardizedProductTypeInput>
  /** The status of the product. */
  status?: InputMaybe<ProductStatus>
  /** A comma separated list tags that have been added to the product. */
  tags?: InputMaybe<Array<Scalars['String']>>
  /** The theme template used when viewing the product in a store. */
  templateSuffix?: InputMaybe<Scalars['String']>
  /** The title of the product. */
  title?: InputMaybe<Scalars['String']>
  /** A list of variants associated with the product. */
  variants?: InputMaybe<Array<ProductVariantInput>>
  /** The name of the product's vendor. */
  vendor?: InputMaybe<Scalars['String']>
}

/** Return type for `productJoinSellingPlanGroups` mutation. */
export type ProductJoinSellingPlanGroupsPayload = {
  __typename?: 'ProductJoinSellingPlanGroupsPayload'
  /** The product object. */
  product?: Maybe<Product>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SellingPlanGroupUserError>
}

/** Return type for `productLeaveSellingPlanGroups` mutation. */
export type ProductLeaveSellingPlanGroupsPayload = {
  __typename?: 'ProductLeaveSellingPlanGroupsPayload'
  /** The product object. */
  product?: Maybe<Product>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SellingPlanGroupUserError>
}

/** The set of valid sort keys for the ProductMedia query. */
export enum ProductMediaSortKeys {
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `position` value. */
  Position = 'POSITION',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/**
 * Product property names like "Size", "Color", and "Material".
 * Variants are selected based on permutations of these options.
 * 255 characters limit each.
 *
 */
export type ProductOption = HasPublishedTranslations &
  Node & {
    __typename?: 'ProductOption'
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The product option’s name. */
    name: Scalars['String']
    /** The product option's position. */
    position: Scalars['Int']
    /** The translations associated with the resource. */
    translations: Array<PublishedTranslation>
    /** The corresponding value to the product option name. */
    values: Array<Scalars['String']>
  }

/**
 * Product property names like "Size", "Color", and "Material".
 * Variants are selected based on permutations of these options.
 * 255 characters limit each.
 *
 */
export type ProductOptionTranslationsArgs = {
  locale: Scalars['String']
}

/** The price range of the product. */
export type ProductPriceRange = {
  __typename?: 'ProductPriceRange'
  /** The highest variant's price. */
  maxVariantPrice: MoneyV2
  /** The lowest variant's price. */
  minVariantPrice: MoneyV2
}

/** The price range of the product. */
export type ProductPriceRangeV2 = {
  __typename?: 'ProductPriceRangeV2'
  /** The highest variant's price. */
  maxVariantPrice: MoneyV2
  /** The lowest variant's price. */
  minVariantPrice: MoneyV2
}

/** Represents the channels where a product is published. */
export type ProductPublication = {
  __typename?: 'ProductPublication'
  /** The channel where the product was or is published. */
  channel: Channel
  /** Whether the publication is published or not. */
  isPublished: Scalars['Boolean']
  /** The product that was or is going to be published on the channel. */
  product: Product
  /** The date that the product was or is going to be published on the channel. */
  publishDate?: Maybe<Scalars['DateTime']>
}

/**
 * An auto-generated type for paginating through multiple ProductPublications.
 *
 */
export type ProductPublicationConnection = {
  __typename?: 'ProductPublicationConnection'
  /** A list of edges. */
  edges: Array<ProductPublicationEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one ProductPublication and a cursor during pagination.
 *
 */
export type ProductPublicationEdge = {
  __typename?: 'ProductPublicationEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of ProductPublicationEdge. */
  node: ProductPublication
}

/** Specifies a publication to which a product will be published. */
export type ProductPublicationInput = {
  /** This argument is deprecated: Use publicationId instead. */
  channelHandle?: InputMaybe<Scalars['String']>
  /** ID of the channel. This argument is deprecated: Use publicationId instead. */
  channelId?: InputMaybe<Scalars['ID']>
  /** ID of the publication. */
  publicationId?: InputMaybe<Scalars['ID']>
  /** The date and time that the product was (or will be) published. */
  publishDate?: InputMaybe<Scalars['DateTime']>
}

/** Specifies a product to publish and the channels to publish it to. */
export type ProductPublishInput = {
  /** The product to create or update publications for. */
  id: Scalars['ID']
  /** The publication that the product is published to. */
  productPublications: Array<ProductPublicationInput>
}

/** Return type for `productPublish` mutation. */
export type ProductPublishPayload = {
  __typename?: 'ProductPublishPayload'
  /** The product that has been published. */
  product?: Maybe<Product>
  /**
   * The channels where the product is published.
   * @deprecated Use Product.publications instead.
   */
  productPublications?: Maybe<Array<ProductPublication>>
  /** The user's shop. */
  shop: Shop
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `productReorderImages` mutation. */
export type ProductReorderImagesPayload = {
  __typename?: 'ProductReorderImagesPayload'
  /** The asynchronous job reordering the images. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `productReorderMedia` mutation. */
export type ProductReorderMediaPayload = {
  __typename?: 'ProductReorderMediaPayload'
  /** The asynchronous job reordering the media. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  mediaUserErrors: Array<MediaUserError>
  /**
   * The list of errors that occurred from executing the mutation.
   * @deprecated Use `mediaUserErrors` instead
   */
  userErrors: Array<UserError>
}

/**
 * Reports the status of product for a Sales Channel or Storefront API.
 * This might include why a product is not available in a Sales Channel
 * and how a merchant might fix this.
 *
 */
export type ProductResourceFeedback = {
  __typename?: 'ProductResourceFeedback'
  /**
   * The time when the feedback was generated. Used to help determine whether
   * incoming feedback is outdated compared to existing feedback.
   *
   */
  feedbackGeneratedAt: Scalars['DateTime']
  /** The feedback messages presented to the merchant. */
  messages: Array<Scalars['String']>
  /** The ID of the product associated with the feedback. */
  productId: Scalars['ID']
  /** The timestamp of the product associated with the feedback. */
  productUpdatedAt: Scalars['DateTime']
  /** Conveys the state of the feedback and whether it requires merchant action or not. */
  state: ResourceFeedbackState
}

/** The input fields used to create a product feedback. */
export type ProductResourceFeedbackInput = {
  /**
   * The date and time when the payload is constructed.
   * Used to help determine whether incoming feedback is outdated compared to feedback already received, and if it should be ignored upon arrival.
   *
   */
  feedbackGeneratedAt: Scalars['DateTime']
  /**
   * A concise set of copy strings to be displayed to merchants. Used to guide merchants in resolving problems that your app encounters when trying to make use of their products.
   * You can specify up to four messages. Each message is limited to 100 characters.
   *
   */
  messages?: InputMaybe<Array<Scalars['String']>>
  /** The ID of the product that the feedback was created on. */
  productId: Scalars['ID']
  /** The timestamp of the product associated with the feedback. */
  productUpdatedAt: Scalars['DateTime']
  /** Whether the merchant needs to take action on the product. */
  state: ResourceFeedbackState
}

/** A sale associated with a product. */
export type ProductSale = Sale & {
  __typename?: 'ProductSale'
  /** The type of order action that the sale represents. */
  actionType: SaleActionType
  /** The unique identifier for the sale. */
  id: Scalars['ID']
  /** The line item for the associated sale. */
  lineItem: LineItem
  /** The line type assocated with the sale. */
  lineType: SaleLineType
  /** The number of units either ordered or intended to be returned. */
  quantity?: Maybe<Scalars['Int']>
  /** All individual taxes associated with the sale. */
  taxes: Array<SaleTax>
  /** The total sale amount after taxes and discounts. */
  totalAmount: MoneyBag
  /** The total discounts allocated to the sale after taxes. */
  totalDiscountAmountAfterTaxes: MoneyBag
  /** The total discounts allocated to the sale before taxes. */
  totalDiscountAmountBeforeTaxes: MoneyBag
  /** The total amount of taxes for the sale. */
  totalTaxAmount: MoneyBag
}

/** The set of valid sort keys for the Product query. */
export enum ProductSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `inventory_total` value. */
  InventoryTotal = 'INVENTORY_TOTAL',
  /** Sort by the `product_type` value. */
  ProductType = 'PRODUCT_TYPE',
  /** Sort by the `published_at` value. */
  PublishedAt = 'PUBLISHED_AT',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
  /** Sort by the `title` value. */
  Title = 'TITLE',
  /** Sort by the `updated_at` value. */
  UpdatedAt = 'UPDATED_AT',
  /** Sort by the `vendor` value. */
  Vendor = 'VENDOR',
}

/** The possible product statuses. */
export enum ProductStatus {
  /** The product is ready to sell and is available to customers on the online store, sales channels, and apps. By default, existing products are set to active. */
  Active = 'ACTIVE',
  /** The product is no longer being sold and isn't available to customers on sales channels and apps. */
  Archived = 'ARCHIVED',
  /** The product isn't ready to sell and is unavailable to customers on sales channels and apps. By default, duplicated and unarchived products are set to draft. */
  Draft = 'DRAFT',
}

/** Represents a [Shopify product taxonomy](https://help.shopify.com/txt/product_taxonomy/en.txt) node. */
export type ProductTaxonomyNode = Node & {
  __typename?: 'ProductTaxonomyNode'
  /** The full name of the product taxonomy node. For example,  Animals & Pet Supplies > Pet Supplies > Dog Supplies > Dog Beds. */
  fullName: Scalars['String']
  /** The ID of the product taxonomy node. */
  id: Scalars['ID']
  /** Whether the node is a leaf node. */
  isLeaf: Scalars['Boolean']
  /** Whether the node is a root node. */
  isRoot: Scalars['Boolean']
  /** The name of the product taxonomy node. For example, Dog Beds. */
  name: Scalars['String']
}

/** Specifies a product to unpublish from a channel and the sales channels to unpublish it from. */
export type ProductUnpublishInput = {
  /** The ID of the product to create or update publications for. */
  id: Scalars['ID']
  /** The channels to unpublish the product from. */
  productPublications: Array<ProductPublicationInput>
}

/** Return type for `productUnpublish` mutation. */
export type ProductUnpublishPayload = {
  __typename?: 'ProductUnpublishPayload'
  /** The product that has been unpublished. */
  product?: Maybe<Product>
  /** The user's shop. */
  shop: Shop
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `productUpdateMedia` mutation. */
export type ProductUpdateMediaPayload = {
  __typename?: 'ProductUpdateMediaPayload'
  /** The updated media. */
  media?: Maybe<Array<Media>>
  /** The list of errors that occurred from executing the mutation. */
  mediaUserErrors: Array<MediaUserError>
  /** The product which media was updated on. */
  product?: Maybe<Product>
  /**
   * The list of errors that occurred from executing the mutation.
   * @deprecated Use `mediaUserErrors` instead
   */
  userErrors: Array<UserError>
}

/** Return type for `productUpdate` mutation. */
export type ProductUpdatePayload = {
  __typename?: 'ProductUpdatePayload'
  /** The updated product. */
  product?: Maybe<Product>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Represents a product variant. */
export type ProductVariant = HasMetafieldDefinitions &
  HasMetafields &
  HasPublishedTranslations &
  LegacyInteroperability &
  Navigable &
  Node & {
    __typename?: 'ProductVariant'
    /** Whether the product variant is available for sale. */
    availableForSale: Scalars['Boolean']
    /** The value of the barcode associated with the product. */
    barcode?: Maybe<Scalars['String']>
    /** The compare-at price of the variant in the default shop currency. */
    compareAtPrice?: Maybe<Scalars['Money']>
    /** The pricing that applies for a customer in a given context. */
    contextualPricing: ProductVariantContextualPricing
    /** The date and time when the variant was created. */
    createdAt: Scalars['DateTime']
    /**
     * A default cursor that returns the single next record, sorted ascending by ID.
     *
     */
    defaultCursor: Scalars['String']
    /** The delivery profile for the variant. */
    deliveryProfile?: Maybe<DeliveryProfile>
    /** Display name of the variant, based on product's title + variant's title. */
    displayName: Scalars['String']
    /** The fulfillment service associated with the product. */
    fulfillmentService?: Maybe<FulfillmentService>
    /** Whether changes to the fulfillment service for the product variant are allowed. */
    fulfillmentServiceEditable: EditableProperty
    /**
     * The Harmonized System Code (or HS Tariff Code) for the variant.
     * @deprecated Use `InventoryItem.harmonizedSystemCode` instead.
     */
    harmonizedSystemCode?: Maybe<Scalars['String']>
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The featured image for the variant. */
    image?: Maybe<Image>
    /** The inventory item, which is used to query for inventory information. */
    inventoryItem: InventoryItem
    /**
     * The fulfillment service that tracks the number of items in stock for the product variant.
     * @deprecated Use tracked attribute on `inventoryItem` instead.
     */
    inventoryManagement: ProductVariantInventoryManagement
    /** Whether customers are allowed to place an order for the product variant when it's out of stock. */
    inventoryPolicy: ProductVariantInventoryPolicy
    /** The total sellable quantity of the variant. */
    inventoryQuantity?: Maybe<Scalars['Int']>
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** The media associated with the product variant. */
    media: MediaConnection
    /** Returns a metafield by namespace and key that belongs to the resource. */
    metafield?: Maybe<Metafield>
    /** List of metafield definitions. */
    metafieldDefinitions: MetafieldDefinitionConnection
    /** List of metafields that belong to the resource. */
    metafields: MetafieldConnection
    /**
     * The order of the product variant in the list of product variants. The first position in the list is 1.
     *
     */
    position: Scalars['Int']
    /** List of prices and compare-at prices in the presentment currencies for this shop. */
    presentmentPrices: ProductVariantPricePairConnection
    /** The price of the product variant in the default shop currency. */
    price: Scalars['Money']
    /** Returns a private metafield by namespace and key that belongs to the resource. */
    privateMetafield?: Maybe<PrivateMetafield>
    /** List of private metafields that belong to the resource. */
    privateMetafields: PrivateMetafieldConnection
    /** The product that this variant belongs to. */
    product: Product
    /**
     * Whether a customer needs to provide a shipping address when placing an order for the product variant.
     *
     * @deprecated Use `InventoryItem.requiresShipping` instead.
     */
    requiresShipping: Scalars['Boolean']
    /** List of product options applied to the variant. */
    selectedOptions: Array<SelectedOption>
    /**
     * The total sellable quantity of the variant for online channels.
     * This doesn't represent the total available inventory or capture
     * [limitations based on customer location](https://help.shopify.com/manual/markets/inventory_and_fulfillment).
     *
     */
    sellableOnlineQuantity: Scalars['Int']
    /** Count of selling plan groups associated with the product variant. */
    sellingPlanGroupCount: Scalars['Int']
    /** A list of all selling plan groups defined in the current shop associated with the product variant. */
    sellingPlanGroups: SellingPlanGroupConnection
    /**
     * An identifier for the product variant in the shop. Required in order to connect to a fulfillment service.
     *
     */
    sku?: Maybe<Scalars['String']>
    /**
     * The Storefront GraphQL API ID of the `ProductVariant`.
     *
     * As of the `2022-04` version release, the Storefront GraphQL API will no longer return Base64 encoded IDs to match the behavior of the Admin GraphQL API. Therefore, you can safely use the `id` field's value instead.
     *
     * @deprecated Use `id` instead
     */
    storefrontId: Scalars['StorefrontID']
    /** The tax code for the product variant. */
    taxCode?: Maybe<Scalars['String']>
    /** Whether a tax is charged when the product variant is sold. */
    taxable: Scalars['Boolean']
    /** The title of the product variant. */
    title: Scalars['String']
    /** The translations associated with the resource. */
    translations: Array<PublishedTranslation>
    /**
     * The date and time (ISO 8601 format) when the product variant was last modified.
     *
     */
    updatedAt: Scalars['DateTime']
    /** The weight of the product variant in the unit system specified with weight_unit. */
    weight?: Maybe<Scalars['Float']>
    /**
     * The unit of measurement that applies to the product variant's weight. If you don't specify a value for weight_unit, then the shop's default unit of measurement is applied. Valid values: `g`, `kg`, `oz`, `lb`.
     *
     */
    weightUnit: WeightUnit
  }

/** Represents a product variant. */
export type ProductVariantContextualPricingArgs = {
  context: ContextualPricingContext
}

/** Represents a product variant. */
export type ProductVariantImageArgs = {
  crop?: InputMaybe<CropRegion>
  maxHeight?: InputMaybe<Scalars['Int']>
  maxWidth?: InputMaybe<Scalars['Int']>
  scale?: InputMaybe<Scalars['Int']>
}

/** Represents a product variant. */
export type ProductVariantMediaArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a product variant. */
export type ProductVariantMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/** Represents a product variant. */
export type ProductVariantMetafieldDefinitionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  pinnedStatus?: InputMaybe<MetafieldDefinitionPinnedStatus>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<MetafieldDefinitionSortKeys>
}

/** Represents a product variant. */
export type ProductVariantMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a product variant. */
export type ProductVariantPresentmentPricesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  presentmentCurrencies?: InputMaybe<Array<CurrencyCode>>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a product variant. */
export type ProductVariantPrivateMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/** Represents a product variant. */
export type ProductVariantPrivateMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a product variant. */
export type ProductVariantSellingPlanGroupsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a product variant. */
export type ProductVariantTranslationsArgs = {
  locale: Scalars['String']
}

/** Specifies the input fields required to append media to a single variant. */
export type ProductVariantAppendMediaInput = {
  /** Specifies the media to append to the variant. */
  mediaIds: Array<Scalars['ID']>
  /** Specifies the variant to which media will be appended. */
  variantId: Scalars['ID']
}

/** Return type for `productVariantAppendMedia` mutation. */
export type ProductVariantAppendMediaPayload = {
  __typename?: 'ProductVariantAppendMediaPayload'
  /** The product associated with the variants and media. */
  product?: Maybe<Product>
  /** The product variants that were updated. */
  productVariants?: Maybe<Array<ProductVariant>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<MediaUserError>
}

/**
 * An auto-generated type for paginating through multiple ProductVariants.
 *
 */
export type ProductVariantConnection = {
  __typename?: 'ProductVariantConnection'
  /** A list of edges. */
  edges: Array<ProductVariantEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** The pricing of a particular product variant in a given context. */
export type ProductVariantContextualPricing = {
  __typename?: 'ProductVariantContextualPricing'
  /** The final compare-at price after all adjustments are applied. */
  compareAtPrice?: Maybe<MoneyV2>
  /** The final price after all adjustments are applied. */
  price: MoneyV2
}

/** Return type for `productVariantCreate` mutation. */
export type ProductVariantCreatePayload = {
  __typename?: 'ProductVariantCreatePayload'
  /** The product associated with the variant. */
  product?: Maybe<Product>
  /** The successfully created variant. */
  productVariant?: Maybe<ProductVariant>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `productVariantDelete` mutation. */
export type ProductVariantDeletePayload = {
  __typename?: 'ProductVariantDeletePayload'
  /** ID of the deleted product variant. */
  deletedProductVariantId?: Maybe<Scalars['ID']>
  /** Product of the deleted product variant. */
  product?: Maybe<Product>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Specifies the input fields required to detach media from a single variant. */
export type ProductVariantDetachMediaInput = {
  /** Specifies the media to detach from the variant. */
  mediaIds: Array<Scalars['ID']>
  /** Specifies the variant from which media will be detached. */
  variantId: Scalars['ID']
}

/** Return type for `productVariantDetachMedia` mutation. */
export type ProductVariantDetachMediaPayload = {
  __typename?: 'ProductVariantDetachMediaPayload'
  /** The product associated with the variants and media. */
  product?: Maybe<Product>
  /** The product variants that were updated. */
  productVariants?: Maybe<Array<ProductVariant>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<MediaUserError>
}

/**
 * An auto-generated type which holds one ProductVariant and a cursor during pagination.
 *
 */
export type ProductVariantEdge = {
  __typename?: 'ProductVariantEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of ProductVariantEdge. */
  node: ProductVariant
}

/** Specifies a product variant to create or update. */
export type ProductVariantInput = {
  /** The value of the barcode associated with the product. */
  barcode?: InputMaybe<Scalars['String']>
  /** The compare-at price of the variant. */
  compareAtPrice?: InputMaybe<Scalars['Money']>
  /** The ID of the fulfillment service associated with the variant. */
  fulfillmentServiceId?: InputMaybe<Scalars['ID']>
  /** The Harmonized System Code (or HS Tariff Code) for the variant. */
  harmonizedSystemCode?: InputMaybe<Scalars['String']>
  /** Specifies the product variant to update or create a new variant if absent. */
  id?: InputMaybe<Scalars['ID']>
  /** The ID of the image that's associated with the variant. */
  imageId?: InputMaybe<Scalars['ID']>
  /**
   * The URL of an image to associate with the variant.  This field can only be used through mutations that create product images and must match one of the URLs being created on the product.
   *
   */
  imageSrc?: InputMaybe<Scalars['String']>
  /** Inventory Item associated with the variant, used for unit cost. */
  inventoryItem?: InputMaybe<InventoryItemInput>
  /**
   * The fulfillment service that tracks the number of items in stock for the product variant. If you track the inventory yourself using the admin, then set the value to `shopify`. Valid values: `shopify` or the handle of a fulfillment service that has inventory management enabled.
   *  This argument is deprecated: Use tracked attribute on `inventoryItem` instead.
   */
  inventoryManagement?: InputMaybe<ProductVariantInventoryManagement>
  /** Whether customers are allowed to place an order for the product variant when it's out of stock. */
  inventoryPolicy?: InputMaybe<ProductVariantInventoryPolicy>
  /** Create only field. The inventory quantities at each location where the variant is stocked. */
  inventoryQuantities?: InputMaybe<Array<InventoryLevelInput>>
  /** The URL of the media to associate with the variant. This field can only be used in mutations that create media images and must match one of the URLs being created on the product. This field only accepts one value. */
  mediaSrc?: InputMaybe<Array<Scalars['String']>>
  /** Additional customizable information about the product variant. */
  metafields?: InputMaybe<Array<MetafieldInput>>
  /** The custom properties that a shop owner uses to define product variants. */
  options?: InputMaybe<Array<Scalars['String']>>
  /**
   * The order of the product variant in the list of product variants. The first position in the list is 1.
   *
   */
  position?: InputMaybe<Scalars['Int']>
  /** The price of the variant. */
  price?: InputMaybe<Scalars['Money']>
  /** The private metafields to associated with this product. */
  privateMetafields?: InputMaybe<Array<PrivateMetafieldInput>>
  /** Create only required field. Specifies the product on which to create the variant. */
  productId?: InputMaybe<Scalars['ID']>
  /** Whether the variant requires shipping. */
  requiresShipping?: InputMaybe<Scalars['Boolean']>
  /** The SKU for the variant. */
  sku?: InputMaybe<Scalars['String']>
  /** The tax code associated with the variant. */
  taxCode?: InputMaybe<Scalars['String']>
  /** Whether the variant is taxable. */
  taxable?: InputMaybe<Scalars['Boolean']>
  /** This argument is deprecated: Variant title is not a writable field; it is generated from the selected variant options. */
  title?: InputMaybe<Scalars['String']>
  /** The weight of the variant. */
  weight?: InputMaybe<Scalars['Float']>
  /** The unit of weight that's used to measure the variant. */
  weightUnit?: InputMaybe<WeightUnit>
}

/** The valid values for the method of inventory tracking for a product variant. */
export enum ProductVariantInventoryManagement {
  /** This product variant's inventory is tracked by a third-party fulfillment service. */
  FulfillmentService = 'FULFILLMENT_SERVICE',
  /** This product variant's inventory is not tracked. */
  NotManaged = 'NOT_MANAGED',
  /** This product variant's inventory is tracked by Shopify. In the unstable API version, this product variant's inventory could also be tracked by both Shopify and a third-party fulfillment service. */
  Shopify = 'SHOPIFY',
}

/**
 * The valid values for the inventory policy of a product variant once it is out of stock.
 *
 */
export enum ProductVariantInventoryPolicy {
  /** Customers can buy this product variant after it's out of stock. */
  Continue = 'CONTINUE',
  /** Customers can't buy this product variant after it's out of stock. */
  Deny = 'DENY',
}

/** Return type for `productVariantJoinSellingPlanGroups` mutation. */
export type ProductVariantJoinSellingPlanGroupsPayload = {
  __typename?: 'ProductVariantJoinSellingPlanGroupsPayload'
  /** The product variant object. */
  productVariant?: Maybe<ProductVariant>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SellingPlanGroupUserError>
}

/** Return type for `productVariantLeaveSellingPlanGroups` mutation. */
export type ProductVariantLeaveSellingPlanGroupsPayload = {
  __typename?: 'ProductVariantLeaveSellingPlanGroupsPayload'
  /** The product variant object. */
  productVariant?: Maybe<ProductVariant>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SellingPlanGroupUserError>
}

/** Represents a product variant position. */
export type ProductVariantPositionInput = {
  /** Specifies the ID of the product variant to update. */
  id: Scalars['ID']
  /** The order of the product variant in the list of product variants. The first position in the list is 1. */
  position: Scalars['Int']
}

/**
 * The compare-at price and price of a variant sharing a currency.
 *
 */
export type ProductVariantPricePair = {
  __typename?: 'ProductVariantPricePair'
  /** The compare-at price of the variant with associated currency. */
  compareAtPrice?: Maybe<MoneyV2>
  /** The price of the variant with associated currency. */
  price: MoneyV2
}

/**
 * An auto-generated type for paginating through multiple ProductVariantPricePairs.
 *
 */
export type ProductVariantPricePairConnection = {
  __typename?: 'ProductVariantPricePairConnection'
  /** A list of edges. */
  edges: Array<ProductVariantPricePairEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one ProductVariantPricePair and a cursor during pagination.
 *
 */
export type ProductVariantPricePairEdge = {
  __typename?: 'ProductVariantPricePairEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of ProductVariantPricePairEdge. */
  node: ProductVariantPricePair
}

/** The set of valid sort keys for the ProductVariant query. */
export enum ProductVariantSortKeys {
  /** Sort by the `full_title` value. */
  FullTitle = 'FULL_TITLE',
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `inventory_levels.available` value. */
  InventoryLevelsAvailable = 'INVENTORY_LEVELS_AVAILABLE',
  /** Sort by the `inventory_management` value. */
  InventoryManagement = 'INVENTORY_MANAGEMENT',
  /** Sort by the `inventory_policy` value. */
  InventoryPolicy = 'INVENTORY_POLICY',
  /** Sort by the `inventory_quantity` value. */
  InventoryQuantity = 'INVENTORY_QUANTITY',
  /** Sort by the `name` value. */
  Name = 'NAME',
  /** Sort by the `popular` value. */
  Popular = 'POPULAR',
  /** Sort by the `position` value. */
  Position = 'POSITION',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
  /** Sort by the `sku` value. */
  Sku = 'SKU',
  /** Sort by the `title` value. */
  Title = 'TITLE',
}

/** Return type for `productVariantUpdate` mutation. */
export type ProductVariantUpdatePayload = {
  __typename?: 'ProductVariantUpdatePayload'
  /** The product associated with the variant. */
  product?: Maybe<Product>
  /** The updated variant. */
  productVariant?: Maybe<ProductVariant>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `productVariantsBulkCreate` mutation. */
export type ProductVariantsBulkCreatePayload = {
  __typename?: 'ProductVariantsBulkCreatePayload'
  /** The updated product object. */
  product?: Maybe<Product>
  /** The newly created variants. */
  productVariants?: Maybe<Array<ProductVariant>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<ProductVariantsBulkCreateUserError>
}

/** Error codes for failed product variant bulk create mutations. */
export type ProductVariantsBulkCreateUserError = DisplayableError & {
  __typename?: 'ProductVariantsBulkCreateUserError'
  /** The error code. */
  code?: Maybe<ProductVariantsBulkCreateUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `ProductVariantsBulkCreateUserError`. */
export enum ProductVariantsBulkCreateUserErrorCode {
  /** Variant price must be greater than or equal to zero. */
  GreaterThanOrEqualTo = 'GREATER_THAN_OR_EQUAL_TO',
  /** Invalid input detected. */
  Invalid = 'INVALID',
  /** Input must be for this product. */
  MustBeForThisProduct = 'MUST_BE_FOR_THIS_PRODUCT',
  /** Variant options are not enough. */
  NeedToAddOptionValues = 'NEED_TO_ADD_OPTION_VALUES',
  /** Price cannot take a negative value. */
  NegativePriceValue = 'NEGATIVE_PRICE_VALUE',
  /** Input is not defined for this shop. */
  NotDefinedForShop = 'NOT_DEFINED_FOR_SHOP',
  /** On create, this key cannot be used. */
  NoKeyOnCreate = 'NO_KEY_ON_CREATE',
  /** Variant options are more than the product options. */
  OptionValuesForNumberOfUnknownOptions = 'OPTION_VALUES_FOR_NUMBER_OF_UNKNOWN_OPTIONS',
  /** Product does not exist. */
  ProductDoesNotExist = 'PRODUCT_DOES_NOT_EXIST',
  /** You reached the limit of available SKUs in your current plan. */
  SubscriptionViolation = 'SUBSCRIPTION_VIOLATION',
  /** Inventory locations cannot exceed the allowed resource limit or 10. */
  TooManyInventoryLocations = 'TOO_MANY_INVENTORY_LOCATIONS',
  /** Quantity could not be set. The location was not found. */
  TrackedVariantLocationNotFound = 'TRACKED_VARIANT_LOCATION_NOT_FOUND',
  /** Variant already exists. */
  VariantAlreadyExists = 'VARIANT_ALREADY_EXISTS',
  /** Variant options already exist. Please change the variant option(s). */
  VariantAlreadyExistsChangeOptionValue = 'VARIANT_ALREADY_EXISTS_CHANGE_OPTION_VALUE',
}

/** Return type for `productVariantsBulkDelete` mutation. */
export type ProductVariantsBulkDeletePayload = {
  __typename?: 'ProductVariantsBulkDeletePayload'
  /** The updated product object. */
  product?: Maybe<Product>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<ProductVariantsBulkDeleteUserError>
}

/** Error codes for failed bulk variant delete mutations. */
export type ProductVariantsBulkDeleteUserError = DisplayableError & {
  __typename?: 'ProductVariantsBulkDeleteUserError'
  /** The error code. */
  code?: Maybe<ProductVariantsBulkDeleteUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `ProductVariantsBulkDeleteUserError`. */
export enum ProductVariantsBulkDeleteUserErrorCode {
  /** The variant does not exist. */
  AtLeastOneVariantDoesNotBelongToTheProduct = 'AT_LEAST_ONE_VARIANT_DOES_NOT_BELONG_TO_THE_PRODUCT',
  /** Cannot delete default variant. */
  CannotDeleteLastVariant = 'CANNOT_DELETE_LAST_VARIANT',
  /** Product does not exist. */
  ProductDoesNotExist = 'PRODUCT_DOES_NOT_EXIST',
}

/** Specifies a product variant to create as part of a variant bulk mutation. */
export type ProductVariantsBulkInput = {
  /** The value of the barcode associated with the product variant. */
  barcode?: InputMaybe<Scalars['String']>
  /** The compare-at price of the variant. */
  compareAtPrice?: InputMaybe<Scalars['Money']>
  /** The ID of the fulfillment service associated with the variant. */
  fulfillmentServiceId?: InputMaybe<Scalars['ID']>
  /** The Harmonized System Code (or HS Tariff Code) for the variant. */
  harmonizedSystemCode?: InputMaybe<Scalars['String']>
  /** Specifies the product variant to update or delete. */
  id?: InputMaybe<Scalars['ID']>
  /** The ID of the image that's associated with the variant. */
  imageId?: InputMaybe<Scalars['ID']>
  /**
   * The URL of an image to associate with the variant.  This field can only be used through mutations that create product images and must match one of the URLs being created on the product.
   *
   */
  imageSrc?: InputMaybe<Scalars['String']>
  /** The inventory item associated with the variant, used for unit cost. */
  inventoryItem?: InputMaybe<InventoryItemInput>
  /** Whether customers are allowed to place an order for the variant when it's out of stock. */
  inventoryPolicy?: InputMaybe<ProductVariantInventoryPolicy>
  /**
   * Create only field. The inventory quantities at each location where the variant is stocked. The number of elements
   * in the array of inventory quantities cannot exceed 10 and the amount specified for the plan.
   *
   */
  inventoryQuantities?: InputMaybe<Array<InventoryLevelInput>>
  /** The URL of the media to associate with the variant. */
  mediaSrc?: InputMaybe<Array<Scalars['String']>>
  /** The additional customizable information about the product variant. */
  metafields?: InputMaybe<Array<MetafieldInput>>
  /** The custom properties that a shop owner uses to define product variants. */
  options?: InputMaybe<Array<Scalars['String']>>
  /** The price of the variant. */
  price?: InputMaybe<Scalars['Money']>
  /** The private metafields to associated with this product. */
  privateMetafields?: InputMaybe<Array<PrivateMetafieldInput>>
  /** Whether the variant requires shipping. */
  requiresShipping?: InputMaybe<Scalars['Boolean']>
  /** The SKU for the variant. */
  sku?: InputMaybe<Scalars['String']>
  /** The tax code associated with the variant. */
  taxCode?: InputMaybe<Scalars['String']>
  /** Whether the variant is taxable. */
  taxable?: InputMaybe<Scalars['Boolean']>
  /** The weight of the variant. */
  weight?: InputMaybe<Scalars['Float']>
  /** The unit of weight that's used to measure the variant. */
  weightUnit?: InputMaybe<WeightUnit>
}

/** Return type for `productVariantsBulkReorder` mutation. */
export type ProductVariantsBulkReorderPayload = {
  __typename?: 'ProductVariantsBulkReorderPayload'
  /** The updated product. */
  product?: Maybe<Product>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<ProductVariantsBulkReorderUserError>
}

/** Error codes for failed bulk product variants reorder operation. */
export type ProductVariantsBulkReorderUserError = DisplayableError & {
  __typename?: 'ProductVariantsBulkReorderUserError'
  /** The error code. */
  code?: Maybe<ProductVariantsBulkReorderUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `ProductVariantsBulkReorderUserError`. */
export enum ProductVariantsBulkReorderUserErrorCode {
  /** Product Variant ids must be uniqe. */
  DuplicatedVariantId = 'DUPLICATED_VARIANT_ID',
  /** Product Variant position can not be zero or negative number. */
  InvalidPosition = 'INVALID_POSITION',
  /** Product Variant does not exist. */
  MissingVariant = 'MISSING_VARIANT',
  /** Product does not exist. */
  ProductDoesNotExist = 'PRODUCT_DOES_NOT_EXIST',
}

/** Return type for `productVariantsBulkUpdate` mutation. */
export type ProductVariantsBulkUpdatePayload = {
  __typename?: 'ProductVariantsBulkUpdatePayload'
  /** The updated product object. */
  product?: Maybe<Product>
  /** The updated variants. */
  productVariants?: Maybe<Array<ProductVariant>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<ProductVariantsBulkUpdateUserError>
}

/** Error codes for failed variant bulk update mutations. */
export type ProductVariantsBulkUpdateUserError = DisplayableError & {
  __typename?: 'ProductVariantsBulkUpdateUserError'
  /** The error code. */
  code?: Maybe<ProductVariantsBulkUpdateUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `ProductVariantsBulkUpdateUserError`. */
export enum ProductVariantsBulkUpdateUserErrorCode {
  /** The price of the variant must be greater than or equal to zero. */
  GreaterThanOrEqualTo = 'GREATER_THAN_OR_EQUAL_TO',
  /** Variant options are not enough. */
  NeedToAddOptionValues = 'NEED_TO_ADD_OPTION_VALUES',
  /** Price cannot take a negative value. */
  NegativePriceValue = 'NEGATIVE_PRICE_VALUE',
  /** Inventory_quanties cannot be provided during update. */
  NoInventoryQuantitesDuringUpdate = 'NO_INVENTORY_QUANTITES_DURING_UPDATE',
  /** Inventory quantities cannot be updated with variants API. */
  NoInventoryQuantitiesOnVariantsUpdate = 'NO_INVENTORY_QUANTITIES_ON_VARIANTS_UPDATE',
  /** Variant options are more than the product options. */
  OptionValuesForNumberOfUnknownOptions = 'OPTION_VALUES_FOR_NUMBER_OF_UNKNOWN_OPTIONS',
  /** Product does not exist. */
  ProductDoesNotExist = 'PRODUCT_DOES_NOT_EXIST',
  /** Product variant does not exist. */
  ProductVariantDoesNotExist = 'PRODUCT_VARIANT_DOES_NOT_EXIST',
  /** Product variant is missing ID attribute. */
  ProductVariantIdMissing = 'PRODUCT_VARIANT_ID_MISSING',
  /** You reached the limit of available SKUs in your current plan. */
  SubscriptionViolation = 'SUBSCRIPTION_VIOLATION',
  /** The variant already exists. */
  VariantAlreadyExists = 'VARIANT_ALREADY_EXISTS',
}

/** The set of valid sort keys for the ProfileItem query. */
export enum ProfileItemSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `inventory_total` value. */
  InventoryTotal = 'INVENTORY_TOTAL',
  /** Sort by the `product_type` value. */
  ProductType = 'PRODUCT_TYPE',
  /** Sort by the `published_at` value. */
  PublishedAt = 'PUBLISHED_AT',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
  /** Sort by the `title` value. */
  Title = 'TITLE',
  /** Sort by the `updated_at` value. */
  UpdatedAt = 'UPDATED_AT',
  /** Sort by the `vendor` value. */
  Vendor = 'VENDOR',
}

/** Return type for `pubSubWebhookSubscriptionCreate` mutation. */
export type PubSubWebhookSubscriptionCreatePayload = {
  __typename?: 'PubSubWebhookSubscriptionCreatePayload'
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<PubSubWebhookSubscriptionCreateUserError>
  /** The webhook subscription that was created. */
  webhookSubscription?: Maybe<WebhookSubscription>
}

/** An error that occurs during the execution of `PubSubWebhookSubscriptionCreate`. */
export type PubSubWebhookSubscriptionCreateUserError = DisplayableError & {
  __typename?: 'PubSubWebhookSubscriptionCreateUserError'
  /** The error code. */
  code?: Maybe<PubSubWebhookSubscriptionCreateUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `PubSubWebhookSubscriptionCreateUserError`. */
export enum PubSubWebhookSubscriptionCreateUserErrorCode {
  /** Invalid parameters provided. */
  InvalidParameters = 'INVALID_PARAMETERS',
}

/**
 * Specifies the input fields for a PubSub webhook subscription.
 *
 */
export type PubSubWebhookSubscriptionInput = {
  /** The format in which the webhook subscription should send the data. */
  format?: InputMaybe<WebhookSubscriptionFormat>
  /** The list of fields to be included in the webhook subscription. */
  includeFields?: InputMaybe<Array<Scalars['String']>>
  /** The list of namespaces for any metafields that should be included in the webhook subscription. */
  metafieldNamespaces?: InputMaybe<Array<Scalars['String']>>
  /** The Pub/Sub project ID. */
  pubSubProject: Scalars['String']
  /** The Pub/Sub topic ID. */
  pubSubTopic: Scalars['String']
}

/** Return type for `pubSubWebhookSubscriptionUpdate` mutation. */
export type PubSubWebhookSubscriptionUpdatePayload = {
  __typename?: 'PubSubWebhookSubscriptionUpdatePayload'
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<PubSubWebhookSubscriptionUpdateUserError>
  /** The webhook subscription that was updated. */
  webhookSubscription?: Maybe<WebhookSubscription>
}

/** An error that occurs during the execution of `PubSubWebhookSubscriptionUpdate`. */
export type PubSubWebhookSubscriptionUpdateUserError = DisplayableError & {
  __typename?: 'PubSubWebhookSubscriptionUpdateUserError'
  /** The error code. */
  code?: Maybe<PubSubWebhookSubscriptionUpdateUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `PubSubWebhookSubscriptionUpdateUserError`. */
export enum PubSubWebhookSubscriptionUpdateUserErrorCode {
  /** Invalid parameters provided. */
  InvalidParameters = 'INVALID_PARAMETERS',
}

/**
 * A publication is a group of products and collections that is published to an app.
 *
 */
export type Publication = Node & {
  __typename?: 'Publication'
  /** The app associated with the publication. */
  app: App
  /** The collection publications for the list of collections published to the publication. */
  collectionPublicationsV3: ResourcePublicationConnection
  /** The list of collections published to the publication. */
  collections: CollectionConnection
  /** Whether the collection is available to the publication. */
  hasCollection: Scalars['Boolean']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** Name of the publication. */
  name: Scalars['String']
  /** The product publications for the list of products published to the publication. */
  productPublicationsV3: ResourcePublicationConnection
  /** The list of products published to the publication. */
  products: ProductConnection
  /** Whether or not this publication supports future publishing. */
  supportsFuturePublishing: Scalars['Boolean']
}

/**
 * A publication is a group of products and collections that is published to an app.
 *
 */
export type PublicationCollectionPublicationsV3Args = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * A publication is a group of products and collections that is published to an app.
 *
 */
export type PublicationCollectionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * A publication is a group of products and collections that is published to an app.
 *
 */
export type PublicationHasCollectionArgs = {
  id: Scalars['ID']
}

/**
 * A publication is a group of products and collections that is published to an app.
 *
 */
export type PublicationProductPublicationsV3Args = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * A publication is a group of products and collections that is published to an app.
 *
 */
export type PublicationProductsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An auto-generated type for paginating through multiple Publications.
 *
 */
export type PublicationConnection = {
  __typename?: 'PublicationConnection'
  /** A list of edges. */
  edges: Array<PublicationEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one Publication and a cursor during pagination.
 *
 */
export type PublicationEdge = {
  __typename?: 'PublicationEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of PublicationEdge. */
  node: Publication
}

/** Specifies the input fields required to publish a resource. */
export type PublicationInput = {
  /** ID of the channel. This argument is deprecated: Use publicationId instead. */
  channelId?: InputMaybe<Scalars['ID']>
  /** ID of the publication. */
  publicationId?: InputMaybe<Scalars['ID']>
  /**
   * The date and time that the resource was published. Setting this to a date in the future will schedule
   * the resource to be published. Only online store channels support future publishing.
   *
   */
  publishDate?: InputMaybe<Scalars['DateTime']>
}

/**
 * Represents a resource that can be published to a channel.
 * A publishable resource can be either a Product or Collection.
 *
 */
export type Publishable = {
  /** The number of publications a resource is published to without feedback errors. */
  availablePublicationCount: Scalars['Int']
  /** The number of publications a resource is published on. */
  publicationCount: Scalars['Int']
  /**
   * Check to see whether the resource is published to a given channel.
   * @deprecated Use `publishedOnPublication` instead
   */
  publishedOnChannel: Scalars['Boolean']
  /**
   * Check to see whether the resource is published to the calling app's channel.
   * @deprecated Use `publishedOnCurrentPublication` instead
   */
  publishedOnCurrentChannel: Scalars['Boolean']
  /** Check to see whether the resource is published to the calling app's publication. */
  publishedOnCurrentPublication: Scalars['Boolean']
  /** Check to see whether the resource is published to a given publication. */
  publishedOnPublication: Scalars['Boolean']
  /** The list of resources that are published to a publication. */
  resourcePublications: ResourcePublicationConnection
  /** The list of resources that are either published or staged to be published to a publication. */
  resourcePublicationsV2: ResourcePublicationV2Connection
  /**
   * The list of channels that the resource is not published to.
   * @deprecated Use `unpublishedPublications` instead
   */
  unpublishedChannels: ChannelConnection
  /** The list of publications that the resource is not published to. */
  unpublishedPublications: PublicationConnection
}

/**
 * Represents a resource that can be published to a channel.
 * A publishable resource can be either a Product or Collection.
 *
 */
export type PublishablePublicationCountArgs = {
  onlyPublished?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a resource that can be published to a channel.
 * A publishable resource can be either a Product or Collection.
 *
 */
export type PublishablePublishedOnChannelArgs = {
  channelId: Scalars['ID']
}

/**
 * Represents a resource that can be published to a channel.
 * A publishable resource can be either a Product or Collection.
 *
 */
export type PublishablePublishedOnPublicationArgs = {
  publicationId: Scalars['ID']
}

/**
 * Represents a resource that can be published to a channel.
 * A publishable resource can be either a Product or Collection.
 *
 */
export type PublishableResourcePublicationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  onlyPublished?: InputMaybe<Scalars['Boolean']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a resource that can be published to a channel.
 * A publishable resource can be either a Product or Collection.
 *
 */
export type PublishableResourcePublicationsV2Args = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  onlyPublished?: InputMaybe<Scalars['Boolean']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a resource that can be published to a channel.
 * A publishable resource can be either a Product or Collection.
 *
 */
export type PublishableUnpublishedChannelsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a resource that can be published to a channel.
 * A publishable resource can be either a Product or Collection.
 *
 */
export type PublishableUnpublishedPublicationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Return type for `publishablePublish` mutation. */
export type PublishablePublishPayload = {
  __typename?: 'PublishablePublishPayload'
  /** Resource that has been published. */
  publishable?: Maybe<Publishable>
  /** The user's shop. */
  shop: Shop
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `publishablePublishToCurrentChannel` mutation. */
export type PublishablePublishToCurrentChannelPayload = {
  __typename?: 'PublishablePublishToCurrentChannelPayload'
  /** Resource that has been published. */
  publishable?: Maybe<Publishable>
  /** The user's shop. */
  shop: Shop
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `publishableUnpublish` mutation. */
export type PublishableUnpublishPayload = {
  __typename?: 'PublishableUnpublishPayload'
  /** Resource that has been unpublished. */
  publishable?: Maybe<Publishable>
  /** The user's shop. */
  shop: Shop
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `publishableUnpublishToCurrentChannel` mutation. */
export type PublishableUnpublishToCurrentChannelPayload = {
  __typename?: 'PublishableUnpublishToCurrentChannelPayload'
  /** Resource that has been unpublished. */
  publishable?: Maybe<Publishable>
  /** The user's shop. */
  shop: Shop
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Published translation of a field of a resource. */
export type PublishedTranslation = {
  __typename?: 'PublishedTranslation'
  /** The resource field that is being translated. */
  key: Scalars['String']
  /** The locale of this translation. */
  locale: Scalars['String']
  /** The translation value. */
  value?: Maybe<Scalars['String']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRoot = {
  __typename?: 'QueryRoot'
  /** Lookup an App by ID or return the currently authenticated App. */
  app?: Maybe<App>
  /**
   * Fetches app by handle.
   * Returns null if the app doesn't exist.
   *
   */
  appByHandle?: Maybe<App>
  /**
   * Fetches app by apiKey.
   * Returns null if the app doesn't exist.
   *
   */
  appByKey?: Maybe<App>
  /** Lookup an AppInstallation by ID or return the AppInstallation for the currently authenticated App. */
  appInstallation?: Maybe<AppInstallation>
  /** List of app installations. */
  appInstallations: AppInstallationConnection
  /**
   * Returns an automatic discount resource by ID.
   * @deprecated Use `automaticDiscountNode` instead
   */
  automaticDiscount?: Maybe<DiscountAutomatic>
  /** Returns an automatic discount resource by ID. */
  automaticDiscountNode?: Maybe<DiscountAutomaticNode>
  /** List of automatic discounts. */
  automaticDiscountNodes: DiscountAutomaticNodeConnection
  /** List of the shop's automatic discount saved searches. */
  automaticDiscountSavedSearches: SavedSearchConnection
  /**
   * List of automatic discounts.
   * @deprecated Use `automaticDiscountNodes` instead
   */
  automaticDiscounts: DiscountAutomaticConnection
  /** Returns a list of activated carrier services and associated shop locations that support them. */
  availableCarrierServices: Array<DeliveryCarrierServiceAndLocations>
  /** Returns a list of available locales. */
  availableLocales: Array<Locale>
  /** Returns a `DeliveryCarrierService` object by ID. */
  carrierService?: Maybe<DeliveryCarrierService>
  /**
   * Lookup a channel by ID.
   * @deprecated Use `publication` instead
   */
  channel?: Maybe<Channel>
  /**
   * List of the active sales channels.
   * @deprecated Use `publications` instead
   */
  channels: ChannelConnection
  /** Returns a code discount resource by ID. */
  codeDiscountNode?: Maybe<DiscountCodeNode>
  /** Returns a code discount identified by its code. */
  codeDiscountNodeByCode?: Maybe<DiscountCodeNode>
  /**
   * List of code discounts. Special fields for query params:
   *  * status: active, expired, scheduled
   *  * discount_type: bogo, fixed_amount, free_shipping, percentage.
   */
  codeDiscountNodes: DiscountCodeNodeConnection
  /** List of the shop's code discount saved searches. */
  codeDiscountSavedSearches: SavedSearchConnection
  /** Returns a Collection resource by ID. */
  collection?: Maybe<Collection>
  /** Return a collection by its handle. */
  collectionByHandle?: Maybe<Collection>
  /** A list of rule conditions to define how collections with rules can be created. */
  collectionRulesConditions: Array<CollectionRuleConditions>
  /** List of the shop's collection saved searches. */
  collectionSavedSearches: SavedSearchConnection
  /** List of collections. */
  collections: CollectionConnection
  /** Return the AppInstallation for the currently authenticated App. */
  currentAppInstallation: AppInstallation
  /** Returns the current app's most recent BulkOperation. Apps can run one bulk query and one bulk mutation operation at a time, by shop. */
  currentBulkOperation?: Maybe<BulkOperation>
  /** Returns a Customer resource by ID. */
  customer?: Maybe<Customer>
  /** Returns a CustomerPaymentMethod resource by ID. */
  customerPaymentMethod?: Maybe<CustomerPaymentMethod>
  /** List of the shop's customer saved searches. */
  customerSavedSearches: SavedSearchConnection
  /** List of customers. */
  customers: CustomerConnection
  /** The paginated list of deletion events. */
  deletionEvents: DeletionEventConnection
  /** Returns a Delivery Profile resource by ID. */
  deliveryProfile?: Maybe<DeliveryProfile>
  /** Returns a list of saved delivery profiles. */
  deliveryProfiles: DeliveryProfileConnection
  /** Returns the shop-wide shipping settings. */
  deliverySettings?: Maybe<DeliverySetting>
  /** The total number of discount codes for the shop. */
  discountCodeCount: Scalars['Int']
  /** Returns a bulk code creation resource by ID. */
  discountRedeemCodeBulkCreation?: Maybe<DiscountRedeemCodeBulkCreation>
  /** List of the shop's redeemed discount code saved searches. */
  discountRedeemCodeSavedSearches: SavedSearchConnection
  /** Lookup a Domain by ID. */
  domain?: Maybe<Domain>
  /** Returns a DraftOrder resource by ID. */
  draftOrder?: Maybe<DraftOrder>
  /** List of the shop's draft order saved searches. */
  draftOrderSavedSearches: SavedSearchConnection
  /** List of saved draft orders. */
  draftOrders: DraftOrderConnection
  /** A list of the shop's file saved searches. */
  fileSavedSearches: SavedSearchConnection
  /** A list of files. */
  files: FileConnection
  /** Returns a Fulfillment resource by ID. */
  fulfillment?: Maybe<Fulfillment>
  /** Returns a Fulfillment order resource by ID. */
  fulfillmentOrder?: Maybe<FulfillmentOrder>
  /** Returns a FulfillmentService resource by ID. */
  fulfillmentService?: Maybe<FulfillmentService>
  /** Returns a gift card resource by ID. */
  giftCard?: Maybe<GiftCard>
  /** Returns a list of gift cards. */
  giftCards: GiftCardConnection
  /** The total number of gift cards issued for the shop. */
  giftCardsCount: Scalars['UnsignedInt64']
  /** Returns an `InventoryItem` object by ID. */
  inventoryItem?: Maybe<InventoryItem>
  /** Returns a list of inventory items. */
  inventoryItems: InventoryItemConnection
  /** Returns an `InventoryLevel` object by ID. */
  inventoryLevel?: Maybe<InventoryLevel>
  /**
   * Returns a Job resource by ID. Used to check the status of internal jobs and any applicable changes.
   *
   */
  job?: Maybe<Job>
  /** Returns an inventory Location resource by ID. */
  location?: Maybe<Location>
  /** Returns a list of active inventory locations. */
  locations: LocationConnection
  /**
   * Returns a list of all origin locations available for a delivery profile.
   * @deprecated Use `locationsAvailableForDeliveryProfilesConnection` instead
   */
  locationsAvailableForDeliveryProfiles?: Maybe<Array<Location>>
  /** Returns a list of all origin locations available for a delivery profile. */
  locationsAvailableForDeliveryProfilesConnection: LocationConnection
  /** A list of marketing activities associated with the marketing app. */
  marketingActivities: MarketingActivityConnection
  /** Returns a MarketingActivity resource by ID. */
  marketingActivity?: Maybe<MarketingActivity>
  /** Returns a MarketingEvent resource by ID. */
  marketingEvent?: Maybe<MarketingEvent>
  /** A list of marketing events associated with the marketing app. */
  marketingEvents: MarketingEventConnection
  /** Returns a metafield by ID. */
  metafield?: Maybe<Metafield>
  /** Returns a metafield definition by ID. */
  metafieldDefinition?: Maybe<MetafieldDefinition>
  /**
   * Each metafield definition has a type, which defines the type of information that it can store.
   * This type is enforced across every instance of the resource that owns the metafield definition.
   *
   * Refer to the [list of supported metafield types](https://shopify.dev/apps/metafields/types).
   *
   */
  metafieldDefinitionTypes: Array<MetafieldDefinitionType>
  /** List of metafield definitions. */
  metafieldDefinitions: MetafieldDefinitionConnection
  /** List of the `MetafieldStorefrontVisibility` records. */
  metafieldStorefrontVisibilities: MetafieldStorefrontVisibilityConnection
  /**
   * Returns a `MetafieldStorefrontVisibility` record by ID. A `MetafieldStorefrontVisibility` record lists the
   * metafields to make visible in the Storefront API.
   *
   */
  metafieldStorefrontVisibility?: Maybe<MetafieldStorefrontVisibility>
  /**
   * Returns a specific node (any object that implements the
   * [Node](https://shopify.dev/api/admin-graphql/latest/interfaces/Node)
   * interface) by ID, in accordance with the
   * [Relay specification](https://relay.dev/docs/guides/graphql-server-specification/#object-identification).
   * This field is commonly used for refetching an object.
   *
   */
  node?: Maybe<Node>
  /**
   * Returns the list of nodes (any objects that implement the
   * [Node](https://shopify.dev/api/admin-graphql/latest/interfaces/Node)
   * interface) with the given IDs, in accordance with the
   * [Relay specification](https://relay.dev/docs/guides/graphql-server-specification/#object-identification).
   *
   */
  nodes: Array<Maybe<Node>>
  /** Returns an Order resource by ID. */
  order?: Maybe<Order>
  /** List of the shop's order saved searches. */
  orderSavedSearches: SavedSearchConnection
  /** Returns a list of orders placed. */
  orders: OrderConnection
  /** The list of payment terms templates eligible for all shops and users. */
  paymentTermsTemplates: Array<PaymentTermsTemplate>
  /** Returns a price list resource by ID. */
  priceList?: Maybe<PriceList>
  /** All price lists for a shop. */
  priceLists: PriceListConnection
  /** Lookup a price rule by ID. */
  priceRule?: Maybe<PriceRule>
  /** List of the shop's price rule saved searches. */
  priceRuleSavedSearches: SavedSearchConnection
  /** List of price rules. */
  priceRules: PriceRuleConnection
  /**
   * Returns a private metafield by ID.
   * Private metafields are accessible only by the application that created them.
   *
   */
  privateMetafield?: Maybe<PrivateMetafield>
  /**
   * Returns a list of private metafields associated to a resource.
   *
   */
  privateMetafields: PrivateMetafieldConnection
  /** Returns a Product resource by ID. */
  product?: Maybe<Product>
  /** Return a product by its handle. */
  productByHandle?: Maybe<Product>
  /** The product resource feedback for the currently authenticated app. */
  productResourceFeedback?: Maybe<ProductResourceFeedback>
  /** List of the shop's product saved searches. */
  productSavedSearches: SavedSearchConnection
  /** Returns a ProductVariant resource by ID. */
  productVariant?: Maybe<ProductVariant>
  /** List of the product variants. */
  productVariants: ProductVariantConnection
  /** List of products. */
  products: ProductConnection
  /** The list of publicly-accessible Admin API versions, including supported versions, the release candidate, and unstable versions. */
  publicApiVersions: Array<ApiVersion>
  /** Lookup a publication by ID. */
  publication?: Maybe<Publication>
  /** List of the active publications. */
  publications: PublicationConnection
  /** Returns a Refund resource by ID. */
  refund?: Maybe<Refund>
  /** Lookup a script tag resource by ID. */
  scriptTag?: Maybe<ScriptTag>
  /** A list of script tags. */
  scriptTags: ScriptTagConnection
  /** Returns a Selling Plan Group resource by ID. */
  sellingPlanGroup?: Maybe<SellingPlanGroup>
  /** List Selling Plan Groups. */
  sellingPlanGroups: SellingPlanGroupConnection
  /**
   * Returns the Shop resource corresponding to the access token used in the request. The Shop resource contains
   * business and store management settings for the shop.
   *
   */
  shop: Shop
  /** List of locales available on a shop. */
  shopLocales: Array<ShopLocale>
  /** Shopify Payments account information, including balances and payouts. */
  shopifyPaymentsAccount?: Maybe<ShopifyPaymentsAccount>
  /**
   * Standard metafield definitions are intended for specific, common use cases. Their namespace and keys reflect these use cases and are reserved.
   *
   * Refer to all available [`Standard Metafield Definition Templates`](https://shopify.dev/api/admin-graphql/latest/objects/StandardMetafieldDefinitionTemplate).
   *
   */
  standardMetafieldDefinitionTemplates: StandardMetafieldDefinitionTemplateConnection
  /** Returns a SubscriptionBillingAttempt by ID. */
  subscriptionBillingAttempt?: Maybe<SubscriptionBillingAttempt>
  /** Returns a Subscription Contract resource by ID. */
  subscriptionContract?: Maybe<SubscriptionContract>
  /** List Subscription Contracts. */
  subscriptionContracts: SubscriptionContractConnection
  /** Returns a Subscription Draft resource by ID. */
  subscriptionDraft?: Maybe<SubscriptionDraft>
  /** Returns a list of TenderTransactions associated with the shop. */
  tenderTransactions: TenderTransactionConnection
  /** Translatable resource. */
  translatableResource?: Maybe<TranslatableResource>
  /** List of translatable resources. */
  translatableResources: TranslatableResourceConnection
  /** A list of translatable resources by IDs. */
  translatableResourcesByIds: TranslatableResourceConnection
  /** Returns a redirect resource by ID. */
  urlRedirect?: Maybe<UrlRedirect>
  /** Returns a redirect import resource by ID. */
  urlRedirectImport?: Maybe<UrlRedirectImport>
  /** A list of the shop's URL redirect saved searches. */
  urlRedirectSavedSearches: SavedSearchConnection
  /** A list of redirects for a shop. */
  urlRedirects: UrlRedirectConnection
  /** Returns a webhook subscription by ID. */
  webhookSubscription?: Maybe<WebhookSubscription>
  /** Returns a list of webhook subscriptions. */
  webhookSubscriptions: WebhookSubscriptionConnection
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootAppArgs = {
  id?: InputMaybe<Scalars['ID']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootAppByHandleArgs = {
  handle: Scalars['String']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootAppByKeyArgs = {
  apiKey: Scalars['String']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootAppInstallationArgs = {
  id?: InputMaybe<Scalars['ID']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootAppInstallationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  category?: InputMaybe<AppInstallationCategory>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  privacy?: InputMaybe<AppInstallationPrivacy>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<AppInstallationSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootAutomaticDiscountArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootAutomaticDiscountNodeArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootAutomaticDiscountNodesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<AutomaticDiscountSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootAutomaticDiscountSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootAutomaticDiscountsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<AutomaticDiscountSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootCarrierServiceArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootChannelArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootChannelsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootCodeDiscountNodeArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootCodeDiscountNodeByCodeArgs = {
  code: Scalars['String']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootCodeDiscountNodesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<CodeDiscountSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootCodeDiscountSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootCollectionArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootCollectionByHandleArgs = {
  handle: Scalars['String']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootCollectionSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootCollectionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<CollectionSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootCurrentBulkOperationArgs = {
  type?: InputMaybe<BulkOperationType>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootCustomerArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootCustomerPaymentMethodArgs = {
  id: Scalars['ID']
  showRevoked?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootCustomerSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<CustomerSavedSearchSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootCustomersArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<CustomerSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootDeletionEventsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<DeletionEventSortKeys>
  subjectTypes?: InputMaybe<Array<DeletionEventSubjectType>>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootDeliveryProfileArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootDeliveryProfilesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  merchantOwnedOnly?: InputMaybe<Scalars['Boolean']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootDiscountCodeCountArgs = {
  query?: InputMaybe<Scalars['String']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootDiscountRedeemCodeBulkCreationArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootDiscountRedeemCodeSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<DiscountCodeSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootDomainArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootDraftOrderArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootDraftOrderSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootDraftOrdersArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<DraftOrderSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootFileSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootFilesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<FileSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootFulfillmentArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootFulfillmentOrderArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootFulfillmentServiceArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootGiftCardArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootGiftCardsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<GiftCardSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootGiftCardsCountArgs = {
  enabled?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootInventoryItemArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootInventoryItemsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootInventoryLevelArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootJobArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootLocationArgs = {
  id?: InputMaybe<Scalars['ID']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootLocationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  includeInactive?: InputMaybe<Scalars['Boolean']>
  includeLegacy?: InputMaybe<Scalars['Boolean']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<LocationSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootLocationsAvailableForDeliveryProfilesConnectionArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootMarketingActivitiesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<MarketingActivitySortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootMarketingActivityArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootMarketingEventArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootMarketingEventsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<MarketingEventSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootMetafieldArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootMetafieldDefinitionArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootMetafieldDefinitionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  key?: InputMaybe<Scalars['String']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  ownerType: MetafieldOwnerType
  pinnedStatus?: InputMaybe<MetafieldDefinitionPinnedStatus>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<MetafieldDefinitionSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootMetafieldStorefrontVisibilitiesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootMetafieldStorefrontVisibilityArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootNodeArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootNodesArgs = {
  ids: Array<Scalars['ID']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootOrderArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootOrderSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootOrdersArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<OrderSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootPaymentTermsTemplatesArgs = {
  paymentTermsType?: InputMaybe<PaymentTermsType>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootPriceListArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootPriceListsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  matchRule?: InputMaybe<PriceListContext>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<PriceListSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootPriceRuleArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootPriceRuleSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootPriceRulesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<PriceRuleSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootPrivateMetafieldArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootPrivateMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  owner: Scalars['ID']
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootProductArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootProductByHandleArgs = {
  handle: Scalars['String']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootProductResourceFeedbackArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootProductSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootProductVariantArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootProductVariantsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<ProductVariantSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootProductsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<ProductSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootPublicationArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootPublicationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootRefundArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootScriptTagArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootScriptTagsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  src?: InputMaybe<Scalars['URL']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootSellingPlanGroupArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootSellingPlanGroupsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<SellingPlanGroupSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootShopLocalesArgs = {
  published?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootStandardMetafieldDefinitionTemplatesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootSubscriptionBillingAttemptArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootSubscriptionContractArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootSubscriptionContractsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootSubscriptionDraftArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootTenderTransactionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootTranslatableResourceArgs = {
  resourceId: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootTranslatableResourcesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  resourceType: TranslatableResourceType
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootTranslatableResourcesByIdsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  resourceIds: Array<Scalars['ID']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootUrlRedirectArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootUrlRedirectImportArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootUrlRedirectSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootUrlRedirectsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<UrlRedirectSortKeys>
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootWebhookSubscriptionArgs = {
  id: Scalars['ID']
}

/** The schema's entry-point for queries. This acts as the public, top-level API from which all queries must start. */
export type QueryRootWebhookSubscriptionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  callbackUrl?: InputMaybe<Scalars['URL']>
  first?: InputMaybe<Scalars['Int']>
  format?: InputMaybe<WebhookSubscriptionFormat>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<WebhookSubscriptionSortKeys>
  topics?: InputMaybe<Array<WebhookSubscriptionTopic>>
}

/** The record of the line items and transactions that were refunded to a customer, along with restocking instructions for refunded line items. */
export type Refund = LegacyInteroperability &
  Node & {
    __typename?: 'Refund'
    /** The date and time when the refund was created. */
    createdAt?: Maybe<Scalars['DateTime']>
    /** A list of the refunded duties as part of this refund. */
    duties?: Maybe<Array<RefundDuty>>
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** The optional note associated with the refund. */
    note?: Maybe<Scalars['String']>
    /** The order associated with the refund. */
    order: Order
    /** The `RefundLineItem` resources attached to the refund. */
    refundLineItems: RefundLineItemConnection
    /**
     * The total amount across all transactions for the refund.
     * @deprecated Use `totalRefundedSet` instead
     */
    totalRefunded: MoneyV2
    /** The total amount across all transactions for the refund, in shop and presentment currencies. */
    totalRefundedSet: MoneyBag
    /** The transactions associated with the refund. */
    transactions: OrderTransactionConnection
    /** The date and time when the refund was updated. */
    updatedAt: Scalars['DateTime']
  }

/** The record of the line items and transactions that were refunded to a customer, along with restocking instructions for refunded line items. */
export type RefundRefundLineItemsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The record of the line items and transactions that were refunded to a customer, along with restocking instructions for refunded line items. */
export type RefundTransactionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** An agreement between the merchant and customer to refund all or a portion of the order. */
export type RefundAgreement = SalesAgreement & {
  __typename?: 'RefundAgreement'
  /** The application that created the agreement. */
  app?: Maybe<App>
  /** The date and time at which the agreement occured. */
  happenedAt: Scalars['DateTime']
  /** The unique identifier for the agreement. */
  id: Scalars['ID']
  /** The reason the agremeent was created. */
  reason: OrderActionType
  /** The refund associated with the agreement. */
  refund: Refund
  /** The sales associated with the agreement. */
  sales: SaleConnection
}

/** An agreement between the merchant and customer to refund all or a portion of the order. */
export type RefundAgreementSalesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Return type for `refundCreate` mutation. */
export type RefundCreatePayload = {
  __typename?: 'RefundCreatePayload'
  /** The order associated with the created refund. */
  order?: Maybe<Order>
  /** The created refund. */
  refund?: Maybe<Refund>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Represents a refunded duty. */
export type RefundDuty = {
  __typename?: 'RefundDuty'
  /** The amount of a refunded duty in shop and presentment currencies. */
  amountSet: MoneyBag
  /** The duty associated with this refunded duty. */
  originalDuty?: Maybe<Duty>
}

/** The fields required to reimburse duties on a refund. */
export type RefundDutyInput = {
  /** The ID of the duty in the refund. */
  dutyId: Scalars['ID']
  /** The type of refund for this duty. */
  refundType?: InputMaybe<RefundDutyRefundType>
}

/** The type of refund to perform for a particular refund duty. */
export enum RefundDutyRefundType {
  /** The duty is fully refunded. */
  Full = 'FULL',
  /** The duty is proportionally refunded based on the quantity of the refunded line item. */
  Proportional = 'PROPORTIONAL',
}

/** The input fields to create a refund. */
export type RefundInput = {
  /** The currency that is used to refund the order. This must be the presentment currency, which is the currency used by the customer. This is a required field for orders where the currency and presentment currency differ. */
  currency?: InputMaybe<CurrencyCode>
  /** An optional note that is attached to the refund. */
  note?: InputMaybe<Scalars['String']>
  /** Whether to send a refund notification to the customer. */
  notify?: InputMaybe<Scalars['Boolean']>
  /** The ID of the order that is being refunded. */
  orderId: Scalars['ID']
  /** A list of duties to refund. */
  refundDuties?: InputMaybe<Array<RefundDutyInput>>
  /** A list of line items to refund. */
  refundLineItems?: InputMaybe<Array<RefundLineItemInput>>
  /** The input fields that are required to reimburse shipping costs. */
  shipping?: InputMaybe<ShippingRefundInput>
  /** A list of transactions involved in the refund. */
  transactions?: InputMaybe<Array<OrderTransactionInput>>
}

/** A line item that's included in a refund. */
export type RefundLineItem = {
  __typename?: 'RefundLineItem'
  /** The `LineItem` resource associated to the refunded line item. */
  lineItem: LineItem
  /** The inventory restock location. */
  location?: Maybe<Location>
  /**
   * The price of a refunded line item.
   * @deprecated Use `priceSet` instead
   */
  price: Scalars['Money']
  /** The price of a refunded line item in shop and presentment currencies. */
  priceSet: MoneyBag
  /** The quantity of a refunded line item. */
  quantity: Scalars['Int']
  /** The type of restock for the refunded line item. */
  restockType: RefundLineItemRestockType
  /** Whether the refunded line item was restocked. Not applicable in the context of a SuggestedRefund. */
  restocked: Scalars['Boolean']
  /**
   * The subtotal price of a refunded line item.
   * @deprecated Use `subtotalSet` instead
   */
  subtotal: Scalars['Money']
  /** The subtotal price of a refunded line item in shop and presentment currencies. */
  subtotalSet: MoneyBag
  /**
   * The total tax charged on a refunded line item.
   * @deprecated Use `totalTaxSet` instead
   */
  totalTax: Scalars['Money']
  /** The total tax charged on a refunded line item in shop and presentment currencies. */
  totalTaxSet: MoneyBag
}

/**
 * An auto-generated type for paginating through multiple RefundLineItems.
 *
 */
export type RefundLineItemConnection = {
  __typename?: 'RefundLineItemConnection'
  /** A list of edges. */
  edges: Array<RefundLineItemEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one RefundLineItem and a cursor during pagination.
 *
 */
export type RefundLineItemEdge = {
  __typename?: 'RefundLineItemEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of RefundLineItemEdge. */
  node: RefundLineItem
}

/** The fields required to reimburse line items on a refund. */
export type RefundLineItemInput = {
  /** The ID of the line item in the refund. */
  lineItemId: Scalars['ID']
  /** The intended location for restocking. If the `restockType` is set to `NO_RESTOCK`, then this value is empty.` */
  locationId?: InputMaybe<Scalars['ID']>
  /** The quantity of the associated line item to be refunded. */
  quantity: Scalars['Int']
  /** The type of restock for this line item. */
  restockType?: InputMaybe<RefundLineItemRestockType>
}

/** The type of restock performed for a particular refund line item. */
export enum RefundLineItemRestockType {
  /** The refund line item was canceled. Use this when restocking unfulfilled line items. */
  Cancel = 'CANCEL',
  /** Deprecated. The refund line item was restocked, without specifically beingidentified as a return or cancelation. This value is not accepted when creating new refunds. */
  LegacyRestock = 'LEGACY_RESTOCK',
  /** Refund line item was not restocked. */
  NoRestock = 'NO_RESTOCK',
  /** The refund line item was returned. Use this when restocking line items that were fulfilled. */
  Return = 'RETURN',
}

/**
 * Input for a remote Authorize.net customer payment profile.
 *
 */
export type RemoteAuthorizeNetCustomerPaymentProfileInput = {
  /**
   * The customerPaymentProfileId value from the Authorize.net API.
   *
   */
  customerPaymentProfileId?: InputMaybe<Scalars['String']>
  /**
   * The customerProfileId value from the Authorize.net API.
   *
   */
  customerProfileId: Scalars['String']
}

/**
 * Input for a remote stripe payment method.
 *
 */
export type RemoteStripePaymentMethodInput = {
  /**
   * The customer_id value from the Stripe API.
   *
   */
  customerId: Scalars['String']
  /**
   * The payment_method_id value from the Stripe API.
   *
   */
  paymentMethodId?: InputMaybe<Scalars['String']>
}

/**
 * An alert message that appears in the Shopify admin about a problem with a store resource, with 1 or more actions to take. For example, you could use an alert to indicate that you're not charging taxes on some product variants.
 * They can optionally have a specific icon and be dismissed by merchants.
 *
 */
export type ResourceAlert = {
  __typename?: 'ResourceAlert'
  /**
   * Buttons in the alert that link to related information.
   * For example, _Edit variants_.
   *
   */
  actions: Array<ResourceAlertAction>
  /**
   * The secondary text in the alert that includes further information or instructions about how to solve a problem.
   *
   */
  content: Scalars['HTML']
  /**
   * Unique identifier that appears when an alert is manually closed by the merchant.
   * Most alerts cannot be manually closed.
   *
   */
  dismissibleHandle?: Maybe<Scalars['String']>
  /** An icon that is optionally displayed with the alert. */
  icon?: Maybe<ResourceAlertIcon>
  /** Indication of how important the alert is. */
  severity: ResourceAlertSeverity
  /** The primary text in the alert that includes information or describes the problem. */
  title: Scalars['String']
}

/** An action associated to a resource alert, such as editing variants. */
export type ResourceAlertAction = {
  __typename?: 'ResourceAlertAction'
  /** Whether the action appears as a button or as a link. */
  primary: Scalars['Boolean']
  /** Resource for the action to show. */
  show?: Maybe<Scalars['String']>
  /** The text for the button in the alert. For example, _Edit variants_. */
  title: Scalars['String']
  /** The target URL that the button links to. */
  url: Scalars['URL']
}

/** The available icons for resource alerts. */
export enum ResourceAlertIcon {
  /** A checkmark inside a circle. */
  CheckmarkCircle = 'CHECKMARK_CIRCLE',
  /** A lowercase `i` inside a circle. */
  InformationCircle = 'INFORMATION_CIRCLE',
}

/** The possible severity levels for a resource alert. */
export enum ResourceAlertSeverity {
  /** Indicates a critical alert. For example, a blocked app. */
  Critical = 'CRITICAL',
  /** Indicates a neutral alert. For example, an accepted dispute. */
  Default = 'DEFAULT',
  Error = 'ERROR',
  /** Indicates an informative alert. For example, an escalated dispute. */
  Info = 'INFO',
  /** Indicates a success alert. For example, a winning a dispute. */
  Success = 'SUCCESS',
  /** Indicates an informative alert. For example, a new dispute. */
  Warning = 'WARNING',
}

/**
 * Represents feedback from apps about a resource, and the steps required to set up the apps on the shop.
 *
 */
export type ResourceFeedback = {
  __typename?: 'ResourceFeedback'
  /**
   * Feedback from an app about the steps a merchant needs to take to set up the app on their store.
   * @deprecated Use `details` instead
   */
  appFeedback: Array<AppFeedback>
  /** List of AppFeedback detailing issues regarding a resource. */
  details: Array<AppFeedback>
  /** Summary of resource feedback pertaining to the resource. */
  summary: Scalars['String']
}

/** The state of the resource feedback. */
export enum ResourceFeedbackState {
  /** No action required from merchant. */
  Accepted = 'ACCEPTED',
  /** The merchant needs to resolve an issue with the resource. */
  RequiresAction = 'REQUIRES_ACTION',
}

/** A resource limit represents the limits that the resource has. */
export type ResourceLimit = {
  __typename?: 'ResourceLimit'
  /** Whether or not the resource is available. */
  available: Scalars['Boolean']
  /** Quantity available. If null the quantity available is unlimited. */
  quantityAvailable?: Maybe<Scalars['Int']>
  /** Quantity limit of the resource. If null the quantity is unlimited. */
  quantityLimit?: Maybe<Scalars['Int']>
  /** Quantity used of the resource. If null the quantity used cannot be retrieved. */
  quantityUsed?: Maybe<Scalars['Int']>
}

/** A resource publication represents that a resource has been published to a publication. */
export type ResourcePublication = {
  __typename?: 'ResourcePublication'
  /**
   * The channel the resource publication is published to.
   * @deprecated Use `publication` instead
   */
  channel: Channel
  /**
   * Whether the resource publication is published. Also returns true if the resource publication is scheduled to be published.
   * If false, then the resource publication is neither published nor scheduled to be published.
   *
   */
  isPublished: Scalars['Boolean']
  /** The publication the resource publication is published to. */
  publication: Publication
  /** The date that the resource publication was or is going to be published to the publication. */
  publishDate: Scalars['DateTime']
  /** The resource published to the publication. */
  publishable: Publishable
}

/**
 * An auto-generated type for paginating through multiple ResourcePublications.
 *
 */
export type ResourcePublicationConnection = {
  __typename?: 'ResourcePublicationConnection'
  /** A list of edges. */
  edges: Array<ResourcePublicationEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one ResourcePublication and a cursor during pagination.
 *
 */
export type ResourcePublicationEdge = {
  __typename?: 'ResourcePublicationEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of ResourcePublicationEdge. */
  node: ResourcePublication
}

/**
 * A resource publication represents that a resource either has been published or will be published to a publication.
 *
 */
export type ResourcePublicationV2 = {
  __typename?: 'ResourcePublicationV2'
  /**
   * Whether the resource publication is published. If true, then the resource publication is published to the publication.
   * If false, then the resource publication is staged to be published to the publication.
   *
   */
  isPublished: Scalars['Boolean']
  /** The publication the resource publication is published to. */
  publication: Publication
  /** The date that the resource publication was or is going to be published to the publication. */
  publishDate?: Maybe<Scalars['DateTime']>
  /** The resource published to the publication. */
  publishable: Publishable
}

/**
 * An auto-generated type for paginating through multiple ResourcePublicationV2s.
 *
 */
export type ResourcePublicationV2Connection = {
  __typename?: 'ResourcePublicationV2Connection'
  /** A list of edges. */
  edges: Array<ResourcePublicationV2Edge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one ResourcePublicationV2 and a cursor during pagination.
 *
 */
export type ResourcePublicationV2Edge = {
  __typename?: 'ResourcePublicationV2Edge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of ResourcePublicationV2Edge. */
  node: ResourcePublicationV2
}

/** SEO information. */
export type Seo = {
  __typename?: 'SEO'
  /** SEO Description. */
  description?: Maybe<Scalars['String']>
  /** SEO Title. */
  title?: Maybe<Scalars['String']>
}

/** SEO information. */
export type SeoInput = {
  /** SEO description of the product. */
  description?: InputMaybe<Scalars['String']>
  /** SEO title of the product. */
  title?: InputMaybe<Scalars['String']>
}

/** An individual sale record associated with a sales agreement. */
export type Sale = {
  /** The type of order action that the sale represents. */
  actionType: SaleActionType
  /** The unique identifier for the sale. */
  id: Scalars['ID']
  /** The line type assocated with the sale. */
  lineType: SaleLineType
  /** The number of units either ordered or intended to be returned. */
  quantity?: Maybe<Scalars['Int']>
  /** All individual taxes associated with the sale. */
  taxes: Array<SaleTax>
  /** The total sale amount after taxes and discounts. */
  totalAmount: MoneyBag
  /** The total discounts allocated to the sale after taxes. */
  totalDiscountAmountAfterTaxes: MoneyBag
  /** The total discounts allocated to the sale before taxes. */
  totalDiscountAmountBeforeTaxes: MoneyBag
  /** The total amount of taxes for the sale. */
  totalTaxAmount: MoneyBag
}

/** The possible order action types for a sale. */
export enum SaleActionType {
  /** A purchase or charge. */
  Order = 'ORDER',
  /** A removal or return. */
  Return = 'RETURN',
  /** An unknown order action. Represents new actions that may be added in future versions. */
  Unknown = 'UNKNOWN',
  /** A change to the price, taxes, or discounts for a prior purchase. */
  Update = 'UPDATE',
}

/**
 * An auto-generated type for paginating through multiple Sales.
 *
 */
export type SaleConnection = {
  __typename?: 'SaleConnection'
  /** A list of edges. */
  edges: Array<SaleEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one Sale and a cursor during pagination.
 *
 */
export type SaleEdge = {
  __typename?: 'SaleEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of SaleEdge. */
  node: Sale
}

/** The possible line types for a sale record. */
export enum SaleLineType {
  /** A sale adjustment. */
  Adjustment = 'ADJUSTMENT',
  /** A duty charge. */
  Duty = 'DUTY',
  /** A gift card. */
  GiftCard = 'GIFT_CARD',
  /** A product purchased, returned or exchanged. */
  Product = 'PRODUCT',
  /** A shipping cost. */
  Shipping = 'SHIPPING',
  /** A tip added by the customer. */
  Tip = 'TIP',
  /** An unknown sale line. Represents new types that may be added in future versions. */
  Unknown = 'UNKNOWN',
}

/** The tax allocated to a sale from a single tax line. */
export type SaleTax = {
  __typename?: 'SaleTax'
  /** The portion of the total tax amount on the related sale that comes from the associated tax line. */
  amount: MoneyBag
  /** The unique identifier for the sale tax. */
  id: Scalars['ID']
  /** The tax line associated with the sale. */
  taxLine: TaxLine
}

/** An addition, removal, modification, or other sale commitment associated with an order. */
export type SalesAgreement = {
  /** The application that created the agreement. */
  app?: Maybe<App>
  /** The date and time at which the agreement occured. */
  happenedAt: Scalars['DateTime']
  /** The unique identifier for the agreement. */
  id: Scalars['ID']
  /** The reason the agremeent was created. */
  reason: OrderActionType
  /** The sales associated with the agreement. */
  sales: SaleConnection
}

/** An addition, removal, modification, or other sale commitment associated with an order. */
export type SalesAgreementSalesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An auto-generated type for paginating through multiple SalesAgreements.
 *
 */
export type SalesAgreementConnection = {
  __typename?: 'SalesAgreementConnection'
  /** A list of edges. */
  edges: Array<SalesAgreementEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one SalesAgreement and a cursor during pagination.
 *
 */
export type SalesAgreementEdge = {
  __typename?: 'SalesAgreementEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of SalesAgreementEdge. */
  node: SalesAgreement
}

/** A saved search is a representation of a search query saved in the admin. */
export type SavedSearch = LegacyInteroperability &
  Node & {
    __typename?: 'SavedSearch'
    /** The filters of a saved search. */
    filters: Array<SearchFilter>
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** The name of a saved search. */
    name: Scalars['String']
    /** The query string of a saved search. This includes search terms and filters. */
    query: Scalars['String']
    /** The type of resource this saved search is searching in. */
    resourceType: SearchResultType
    /** The search terms of a saved search. */
    searchTerms: Scalars['String']
  }

/**
 * An auto-generated type for paginating through multiple SavedSearches.
 *
 */
export type SavedSearchConnection = {
  __typename?: 'SavedSearchConnection'
  /** A list of edges. */
  edges: Array<SavedSearchEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Specifies the fields required to create a saved search. */
export type SavedSearchCreateInput = {
  /** A descriptive name of the saved search. */
  name: Scalars['String']
  /** The query string of a saved search. This includes search terms and filters. */
  query: Scalars['String']
  /** The type of resource this saved search is searching in. */
  resourceType: SearchResultType
}

/** Return type for `savedSearchCreate` mutation. */
export type SavedSearchCreatePayload = {
  __typename?: 'SavedSearchCreatePayload'
  /** The saved search that was created. */
  savedSearch?: Maybe<SavedSearch>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Specifies the fields to delete a saved search. */
export type SavedSearchDeleteInput = {
  /** ID of the saved search to delete. */
  id: Scalars['ID']
}

/** Return type for `savedSearchDelete` mutation. */
export type SavedSearchDeletePayload = {
  __typename?: 'SavedSearchDeletePayload'
  /** The id of the saved search that was deleted. */
  deletedSavedSearchId?: Maybe<Scalars['ID']>
  /** The shop of the saved search that was deleted. */
  shop: Shop
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one SavedSearch and a cursor during pagination.
 *
 */
export type SavedSearchEdge = {
  __typename?: 'SavedSearchEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of SavedSearchEdge. */
  node: SavedSearch
}

/** Specifies the fields required to update a saved search. */
export type SavedSearchUpdateInput = {
  /** ID of the saved search to update. */
  id: Scalars['ID']
  /** A descriptive name of the saved search. */
  name?: InputMaybe<Scalars['String']>
  /** The query string of a saved search. This included search terms and filters. */
  query?: InputMaybe<Scalars['String']>
}

/** Return type for `savedSearchUpdate` mutation. */
export type SavedSearchUpdatePayload = {
  __typename?: 'SavedSearchUpdatePayload'
  /** The saved search that was updated. */
  savedSearch?: Maybe<SavedSearch>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * Script discount applications capture the intentions of a discount that
 * was created by a Shopify Script for an order's line item or shipping line.
 *
 */
export type ScriptDiscountApplication = DiscountApplication & {
  __typename?: 'ScriptDiscountApplication'
  /** The method by which the discount's value is allocated to its entitled items. */
  allocationMethod: DiscountApplicationAllocationMethod
  /**
   * The description of the application as defined by the Script.
   * @deprecated Use `title` instead
   */
  description: Scalars['String']
  /**
   * An ordered index that can be used to identify the discount application and indicate the precedence
   * of the discount application for calculations.
   *
   */
  index: Scalars['Int']
  /** How the discount amount is distributed on the discounted lines. */
  targetSelection: DiscountApplicationTargetSelection
  /** Whether the discount is applied on line items or shipping lines. */
  targetType: DiscountApplicationTargetType
  /** The title of the application as defined by the Script. */
  title: Scalars['String']
  /** The value of the discount application. */
  value: PricingValue
}

/**
 * A script tag represents remote JavaScript code that is loaded into the pages of a shop's storefront or the order status page of checkout.
 *
 */
export type ScriptTag = LegacyInteroperability &
  Node & {
    __typename?: 'ScriptTag'
    /**
     * Whether the Shopify CDN can cache and serve the script tag.
     * If `true`, then the script will be cached and served by the CDN.
     * The cache expires 15 minutes after the script tag is successfully returned.
     * If `false`, then the script will be served as is.
     *
     */
    cache: Scalars['Boolean']
    /** The date and time when the script tag was created. */
    createdAt: Scalars['DateTime']
    /** The page or pages on the online store that the script should be included. */
    displayScope: ScriptTagDisplayScope
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** The URL to the remote script. */
    src: Scalars['URL']
    /** The date and time when the script tag was last updated. */
    updatedAt: Scalars['DateTime']
  }

/**
 * An auto-generated type for paginating through multiple ScriptTags.
 *
 */
export type ScriptTagConnection = {
  __typename?: 'ScriptTagConnection'
  /** A list of edges. */
  edges: Array<ScriptTagEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `scriptTagCreate` mutation. */
export type ScriptTagCreatePayload = {
  __typename?: 'ScriptTagCreatePayload'
  /** The script tag that was created. */
  scriptTag?: Maybe<ScriptTag>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `scriptTagDelete` mutation. */
export type ScriptTagDeletePayload = {
  __typename?: 'ScriptTagDeletePayload'
  /** The ID of the deleted script tag. */
  deletedScriptTagId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * The page or pages on the online store where the script should be included.
 *
 */
export enum ScriptTagDisplayScope {
  /** Include the script on both the web storefront and the order status page. */
  All = 'ALL',
  /** Include the script only on the web storefront. */
  OnlineStore = 'ONLINE_STORE',
  /** Include the script only on the order status page. */
  OrderStatus = 'ORDER_STATUS',
}

/**
 * An auto-generated type which holds one ScriptTag and a cursor during pagination.
 *
 */
export type ScriptTagEdge = {
  __typename?: 'ScriptTagEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of ScriptTagEdge. */
  node: ScriptTag
}

/**
 * The input fields for a script tag. This input object is used when creating or updating
 * a script tag to specify its URL, where it should be included, and how it will be cached.
 *
 */
export type ScriptTagInput = {
  /**
   * Whether the Shopify CDN can cache and serve the script tag.
   * If `true`, then the script will be cached and served by the CDN.
   * The cache expires 15 minutes after the script tag is successfully returned.
   * If `false`, then the script is served as is.
   * The default value is `false`.
   *
   */
  cache?: InputMaybe<Scalars['Boolean']>
  /** The page or pages on the online store where the script should be included. */
  displayScope?: InputMaybe<ScriptTagDisplayScope>
  /** The URL of the remote script. For example: `https://example.com/path/to/script.js`. */
  src?: InputMaybe<Scalars['URL']>
}

/** Return type for `scriptTagUpdate` mutation. */
export type ScriptTagUpdatePayload = {
  __typename?: 'ScriptTagUpdatePayload'
  /** The script tag that was updated. */
  scriptTag?: Maybe<ScriptTag>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** A filter in a search query represented by a key value pair. */
export type SearchFilter = {
  __typename?: 'SearchFilter'
  /** The key of the search filter. */
  key: Scalars['String']
  /** The value of the search filter. */
  value: Scalars['String']
}

/** A list of search filters along with their specific options in value and label pair for filtering. */
export type SearchFilterOptions = {
  __typename?: 'SearchFilterOptions'
  /** A list of options that can be use to filter product availability. */
  productAvailability: Array<FilterOption>
}

/** Represents an individual result returned from a search. */
export type SearchResult = {
  __typename?: 'SearchResult'
  /** Returns the search result description text. */
  description?: Maybe<Scalars['String']>
  /** Returns the Image resource presented to accompany a search result. */
  image?: Maybe<Image>
  /** Returns the ID of the resource returned in the search result. */
  reference: Node
  /** Returns the resource title. */
  title: Scalars['String']
  /** Returns the absolute URL to the resource in the search result. */
  url: Scalars['URL']
}

/** The connection type for SearchResult. */
export type SearchResultConnection = {
  __typename?: 'SearchResultConnection'
  /** A list of edges. */
  edges: Array<SearchResultEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
  /**
   * Information to aid in pagination.
   * @deprecated The provided information is not accurate.
   */
  resultsAfterCount: Scalars['Int']
}

/**
 * An auto-generated type which holds one SearchResult and a cursor during pagination.
 *
 */
export type SearchResultEdge = {
  __typename?: 'SearchResultEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of SearchResultEdge. */
  node: SearchResult
}

/** Specifies the type of resources to be returned from a search. */
export enum SearchResultType {
  Collection = 'COLLECTION',
  Customer = 'CUSTOMER',
  /** A code discount redeem code. */
  DiscountRedeemCode = 'DISCOUNT_REDEEM_CODE',
  DraftOrder = 'DRAFT_ORDER',
  /** A file. */
  File = 'FILE',
  OnlineStoreArticle = 'ONLINE_STORE_ARTICLE',
  OnlineStoreBlog = 'ONLINE_STORE_BLOG',
  OnlineStorePage = 'ONLINE_STORE_PAGE',
  Order = 'ORDER',
  PriceRule = 'PRICE_RULE',
  Product = 'PRODUCT',
  /** A URL redirect. */
  UrlRedirect = 'URL_REDIRECT',
}

/**
 * Properties used by customers to select a product variant.
 * Products can have multiple options, like different sizes or colors.
 *
 */
export type SelectedOption = {
  __typename?: 'SelectedOption'
  /** The product option’s name. */
  name: Scalars['String']
  /** The product option’s value. */
  value: Scalars['String']
}

/**
 * Represents how a product can be sold and purchased. Selling plans and associated records (selling plan groups
 * and policies) are deleted 48 hours after a merchant uninstalls their subscriptions app. We recommend backing
 * up these records if you need to restore them later.
 *
 * For more information on selling plans, refer to
 * [*Creating and managing selling plans*](https://shopify.dev/apps/subscriptions/selling-plans).
 *
 */
export type SellingPlan = Node & {
  __typename?: 'SellingPlan'
  /** A selling plan policy which describes the recurring billing details. */
  billingPolicy: SellingPlanBillingPolicy
  /** The date and time when the selling plan was created. */
  createdAt: Scalars['DateTime']
  /** A selling plan policy which describes the delivery details. */
  deliveryPolicy: SellingPlanDeliveryPolicy
  /** Buyer facing string which describes the selling plan commitment. */
  description?: Maybe<Scalars['String']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /**
   * A customer-facing description of the selling plan.
   *
   * If your store supports multiple currencies, then don't include country-specific pricing content, such as "Buy monthly, get 10$ CAD off". This field won't be converted to reflect different currencies.
   *
   */
  name: Scalars['String']
  /** The values of all options available on the selling plan. Selling plans are grouped together in Liquid when they are created by the same app, and have the same `selling_plan_group.name` and `selling_plan_group.options` values. */
  options: Array<Scalars['String']>
  /** Relative position of the selling plan for display. A lower position will be displayed before a higher position. */
  position?: Maybe<Scalars['Int']>
  /** Selling plan pricing details. */
  pricingPolicies: Array<SellingPlanPricingPolicy>
}

/** Represents a selling plan policy anchor. */
export type SellingPlanAnchor = {
  __typename?: 'SellingPlanAnchor'
  /**
   * The day of the anchor.
   *
   * If `type` is WEEKDAY, then the value must be between 1-7. Shopify interprets
   * the days of the week according to ISO 8601, where 1 is Monday.
   *
   * If `type` is not WEEKDAY, then the value must be between 1-31.
   *
   */
  day: Scalars['Int']
  /**
   * The month of the anchor. If type is different than YEARDAY, this field must be null, otherwise it must be
   * between 1-12.
   *
   */
  month?: Maybe<Scalars['Int']>
  /**
   * Represents the anchor type, it can be one one of WEEKDAY, MONTHDAY, YEARDAY.
   *
   */
  type: SellingPlanAnchorType
}

/** Specifies the input fields required to create or update a selling plan anchor. */
export type SellingPlanAnchorInput = {
  /**
   * The day of the anchor.
   *
   * If `type` is WEEKDAY, then the value must be between 1-7. Shopify interprets
   * the days of the week according to ISO 8601, where 1 is Monday.
   *
   * If `type` is not WEEKDAY, then the value must be between 1-31.
   *
   */
  day?: InputMaybe<Scalars['Int']>
  /**
   * The month of the anchor. If type is different than YEARDAY, this field must be null, otherwise it must be
   * between 1-12.
   *
   */
  month?: InputMaybe<Scalars['Int']>
  /**
   * Represents the anchor type, must be one of WEEKDAY, MONTHDAY, YEARDAY.
   *
   */
  type?: InputMaybe<SellingPlanAnchorType>
}

/** Represents the anchor type. */
export enum SellingPlanAnchorType {
  /** Which day of the month, between 1-31. */
  Monthday = 'MONTHDAY',
  /** Which day of the week, between 1-7. */
  Weekday = 'WEEKDAY',
  /** Which days of the month and year, month between 1-12, and day between 1-31. */
  Yearday = 'YEARDAY',
}

/**
 * Represents the billing frequency associated to the selling plan (for example, bill every week, or bill every
 * three months). The selling plan billing policy and associated records (selling plan groups, selling plans, pricing
 * policies, and delivery policy) are deleted 48 hours after a merchant uninstalls their subscriptions app.
 * We recommend backing up these records if you need to restore them later.
 *
 */
export type SellingPlanBillingPolicy = SellingPlanRecurringBillingPolicy

/** Specifies the input fields required to create or update a billing policy type. */
export type SellingPlanBillingPolicyInput = {
  /** The recurring billing policy details. */
  recurring?: InputMaybe<SellingPlanRecurringBillingPolicyInput>
}

/**
 * An auto-generated type for paginating through multiple SellingPlans.
 *
 */
export type SellingPlanConnection = {
  __typename?: 'SellingPlanConnection'
  /** A list of edges. */
  edges: Array<SellingPlanEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * Represents the delivery frequency associated to the selling plan (for example, deliver every month, or deliver
 * every other week). The selling plan delivery policy and associated records (selling plan groups, selling plans,
 * pricing policies, and billing policy) are deleted 48 hours after a merchant uninstalls their subscriptions app.
 * We recommend backing up these records if you need to restore them later.
 *
 */
export type SellingPlanDeliveryPolicy = SellingPlanRecurringDeliveryPolicy

/** Specifies the input fields to create or update a delivery policy. */
export type SellingPlanDeliveryPolicyInput = {
  /** The recurring delivery policy details. */
  recurring?: InputMaybe<SellingPlanRecurringDeliveryPolicyInput>
}

/**
 * An auto-generated type which holds one SellingPlan and a cursor during pagination.
 *
 */
export type SellingPlanEdge = {
  __typename?: 'SellingPlanEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of SellingPlanEdge. */
  node: SellingPlan
}

/** Represents a fixed selling plan pricing policy. */
export type SellingPlanFixedPricingPolicy = SellingPlanPricingPolicyBase & {
  __typename?: 'SellingPlanFixedPricingPolicy'
  /** The price adjustment type. */
  adjustmentType: SellingPlanPricingPolicyAdjustmentType
  /** The price adjustment value. */
  adjustmentValue: SellingPlanPricingPolicyAdjustmentValue
  /** The date and time when the fixed selling plan pricing policy was created. */
  createdAt: Scalars['DateTime']
}

/** Specifies the input fields required to create or update a fixed selling plan pricing policy. */
export type SellingPlanFixedPricingPolicyInput = {
  /** Price adjustment type defined by the policy. */
  adjustmentType?: InputMaybe<SellingPlanPricingPolicyAdjustmentType>
  /** Price adjustment value defined by the policy. */
  adjustmentValue?: InputMaybe<SellingPlanPricingPolicyValueInput>
  /** ID of the pricing policy. */
  id?: InputMaybe<Scalars['ID']>
}

/**
 * Represents a selling method (for example, "Subscribe and save" or "Pre-paid"). Selling plan groups
 * and associated records (selling plans and policies) are deleted 48 hours after a merchant
 * uninstalls their subscriptions app. We recommend backing up these records if you need to restore them later.
 *
 */
export type SellingPlanGroup = Node & {
  __typename?: 'SellingPlanGroup'
  /** The identifier for app, exposed in Liquid and product JSON. */
  appId?: Maybe<Scalars['String']>
  /** Whether the given product is directly associated to the selling plan group. */
  appliesToProduct: Scalars['Boolean']
  /** Whether the given product variant is directly associated to the selling plan group. */
  appliesToProductVariant: Scalars['Boolean']
  /**
   * Whether any of the product variants of the given product are associated to the selling plan group.
   *
   */
  appliesToProductVariants: Scalars['Boolean']
  /** The date and time when the selling plan group was created. */
  createdAt: Scalars['DateTime']
  /** The merchant-facing description of the selling plan group. */
  description?: Maybe<Scalars['String']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The merchant-facing label of the selling plan group. */
  merchantCode: Scalars['String']
  /** The buyer-facing label of the selling plan group. */
  name: Scalars['String']
  /** The values of all options available on the selling plan group. Selling plans are grouped together in Liquid when they are created by the same app, and have the same `selling_plan_group.name` and `selling_plan_group.options` values. */
  options: Array<Scalars['String']>
  /** The relative position of the selling plan group for display. */
  position?: Maybe<Scalars['Int']>
  /** A count of products associated to the selling plan group. */
  productCount: Scalars['Int']
  /** A count of product variants associated to the selling plan group. */
  productVariantCount: Scalars['Int']
  /** Product variants associated to the selling plan group. */
  productVariants: ProductVariantConnection
  /** Products associated to the selling plan group. */
  products: ProductConnection
  /** Selling plans associated to the selling plan group. */
  sellingPlans: SellingPlanConnection
  /** A summary of the policies associated to the selling plan group. */
  summary?: Maybe<Scalars['String']>
}

/**
 * Represents a selling method (for example, "Subscribe and save" or "Pre-paid"). Selling plan groups
 * and associated records (selling plans and policies) are deleted 48 hours after a merchant
 * uninstalls their subscriptions app. We recommend backing up these records if you need to restore them later.
 *
 */
export type SellingPlanGroupAppliesToProductArgs = {
  productId: Scalars['ID']
}

/**
 * Represents a selling method (for example, "Subscribe and save" or "Pre-paid"). Selling plan groups
 * and associated records (selling plans and policies) are deleted 48 hours after a merchant
 * uninstalls their subscriptions app. We recommend backing up these records if you need to restore them later.
 *
 */
export type SellingPlanGroupAppliesToProductVariantArgs = {
  productVariantId: Scalars['ID']
}

/**
 * Represents a selling method (for example, "Subscribe and save" or "Pre-paid"). Selling plan groups
 * and associated records (selling plans and policies) are deleted 48 hours after a merchant
 * uninstalls their subscriptions app. We recommend backing up these records if you need to restore them later.
 *
 */
export type SellingPlanGroupAppliesToProductVariantsArgs = {
  productId: Scalars['ID']
}

/**
 * Represents a selling method (for example, "Subscribe and save" or "Pre-paid"). Selling plan groups
 * and associated records (selling plans and policies) are deleted 48 hours after a merchant
 * uninstalls their subscriptions app. We recommend backing up these records if you need to restore them later.
 *
 */
export type SellingPlanGroupProductVariantCountArgs = {
  productId?: InputMaybe<Scalars['ID']>
}

/**
 * Represents a selling method (for example, "Subscribe and save" or "Pre-paid"). Selling plan groups
 * and associated records (selling plans and policies) are deleted 48 hours after a merchant
 * uninstalls their subscriptions app. We recommend backing up these records if you need to restore them later.
 *
 */
export type SellingPlanGroupProductVariantsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  productId?: InputMaybe<Scalars['ID']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a selling method (for example, "Subscribe and save" or "Pre-paid"). Selling plan groups
 * and associated records (selling plans and policies) are deleted 48 hours after a merchant
 * uninstalls their subscriptions app. We recommend backing up these records if you need to restore them later.
 *
 */
export type SellingPlanGroupProductsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a selling method (for example, "Subscribe and save" or "Pre-paid"). Selling plan groups
 * and associated records (selling plans and policies) are deleted 48 hours after a merchant
 * uninstalls their subscriptions app. We recommend backing up these records if you need to restore them later.
 *
 */
export type SellingPlanGroupSellingPlansArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Return type for `sellingPlanGroupAddProductVariants` mutation. */
export type SellingPlanGroupAddProductVariantsPayload = {
  __typename?: 'SellingPlanGroupAddProductVariantsPayload'
  /** The updated selling plan group. */
  sellingPlanGroup?: Maybe<SellingPlanGroup>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SellingPlanGroupUserError>
}

/** Return type for `sellingPlanGroupAddProducts` mutation. */
export type SellingPlanGroupAddProductsPayload = {
  __typename?: 'SellingPlanGroupAddProductsPayload'
  /** The updated selling plan group. */
  sellingPlanGroup?: Maybe<SellingPlanGroup>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SellingPlanGroupUserError>
}

/**
 * An auto-generated type for paginating through multiple SellingPlanGroups.
 *
 */
export type SellingPlanGroupConnection = {
  __typename?: 'SellingPlanGroupConnection'
  /** A list of edges. */
  edges: Array<SellingPlanGroupEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `sellingPlanGroupCreate` mutation. */
export type SellingPlanGroupCreatePayload = {
  __typename?: 'SellingPlanGroupCreatePayload'
  /** The created selling plan group object. */
  sellingPlanGroup?: Maybe<SellingPlanGroup>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SellingPlanGroupUserError>
}

/** Return type for `sellingPlanGroupDelete` mutation. */
export type SellingPlanGroupDeletePayload = {
  __typename?: 'SellingPlanGroupDeletePayload'
  /** The id of the deleted selling plan group object. */
  deletedSellingPlanGroupId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SellingPlanGroupUserError>
}

/**
 * An auto-generated type which holds one SellingPlanGroup and a cursor during pagination.
 *
 */
export type SellingPlanGroupEdge = {
  __typename?: 'SellingPlanGroupEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of SellingPlanGroupEdge. */
  node: SellingPlanGroup
}

/** Specifies the input fields required to create or update a selling plan group. */
export type SellingPlanGroupInput = {
  /** Identifier for app, exposed in Liquid and product JSON. */
  appId?: InputMaybe<Scalars['String']>
  /** Merchant facing description of the selling plan group. */
  description?: InputMaybe<Scalars['String']>
  /** Merchant facing label of the selling plan group. */
  merchantCode?: InputMaybe<Scalars['String']>
  /** Buyer facing label of the selling plan group. */
  name?: InputMaybe<Scalars['String']>
  /** The values of all options available on the selling plan group. Selling plans are grouped together in Liquid when they are created by the same app, and have the same `selling_plan_group.name` and `selling_plan_group.options` values. */
  options?: InputMaybe<Array<Scalars['String']>>
  /** Relative value for display purposes of the selling plan group. A lower position will be displayed before a higher one. */
  position?: InputMaybe<Scalars['Int']>
  /** List of selling plans to create. */
  sellingPlansToCreate?: InputMaybe<Array<SellingPlanInput>>
  /** List of selling plans ids to delete. */
  sellingPlansToDelete?: InputMaybe<Array<Scalars['ID']>>
  /** List of selling plans to update. */
  sellingPlansToUpdate?: InputMaybe<Array<SellingPlanInput>>
}

/** Return type for `sellingPlanGroupRemoveProductVariants` mutation. */
export type SellingPlanGroupRemoveProductVariantsPayload = {
  __typename?: 'SellingPlanGroupRemoveProductVariantsPayload'
  /** The removed product variant ids. */
  removedProductVariantIds?: Maybe<Array<Scalars['ID']>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SellingPlanGroupUserError>
}

/** Return type for `sellingPlanGroupRemoveProducts` mutation. */
export type SellingPlanGroupRemoveProductsPayload = {
  __typename?: 'SellingPlanGroupRemoveProductsPayload'
  /** The removed product ids. */
  removedProductIds?: Maybe<Array<Scalars['ID']>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SellingPlanGroupUserError>
}

/** Specifies resource association with a Selling Plan Group. */
export type SellingPlanGroupResourceInput = {
  /** The IDs of the Products to add to the Selling Plan Group. */
  productIds?: InputMaybe<Array<Scalars['ID']>>
  /** The IDs of the Variants to add to the Selling Plan Group. */
  productVariantIds?: InputMaybe<Array<Scalars['ID']>>
}

/** The set of valid sort keys for the SellingPlanGroup query. */
export enum SellingPlanGroupSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `name` value. */
  Name = 'NAME',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
  /** Sort by the `updated_at` value. */
  UpdatedAt = 'UPDATED_AT',
}

/** Return type for `sellingPlanGroupUpdate` mutation. */
export type SellingPlanGroupUpdatePayload = {
  __typename?: 'SellingPlanGroupUpdatePayload'
  /** The IDs of the deleted Subscription Plans. */
  deletedSellingPlanIds?: Maybe<Array<Scalars['ID']>>
  /** The updated Selling Plan Group. */
  sellingPlanGroup?: Maybe<SellingPlanGroup>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SellingPlanGroupUserError>
}

/**
 * Represents a selling plan group custom error.
 *
 */
export type SellingPlanGroupUserError = DisplayableError & {
  __typename?: 'SellingPlanGroupUserError'
  /** The error code. */
  code?: Maybe<SellingPlanGroupUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `SellingPlanGroupUserError`. */
export enum SellingPlanGroupUserErrorCode {
  /** The input value is blank. */
  Blank = 'BLANK',
  /** Could not add the resource to the selling plan group. */
  ErrorAddingResourceToGroup = 'ERROR_ADDING_RESOURCE_TO_GROUP',
  /** The input value should be greater than the minimum allowed value. */
  GreaterThan = 'GREATER_THAN',
  /** The input value should be greater than or equal to the minimum value allowed. */
  GreaterThanOrEqualTo = 'GREATER_THAN_OR_EQUAL_TO',
  /** Selling plan group could not be deleted. */
  GroupCouldNotBeDeleted = 'GROUP_COULD_NOT_BE_DELETED',
  /** Selling plan group does not exist. */
  GroupDoesNotExist = 'GROUP_DOES_NOT_EXIST',
  /** The input value is invalid. */
  Invalid = 'INVALID',
  /** The input value should be less than the maximum value allowed. */
  LessThan = 'LESS_THAN',
  /** The input value should be less than or equal to the maximum value allowed. */
  LessThanOrEqualTo = 'LESS_THAN_OR_EQUAL_TO',
  /** The input value is not a number. */
  NotANumber = 'NOT_A_NUMBER',
  /** Only one pricing policy type can be defined. */
  OnlyNeedOnePricingPolicyType = 'ONLY_NEED_ONE_PRICING_POLICY_TYPE',
  /** Only one pricing policy adjustment value type can be defined. */
  OnlyNeedOnePricingPolicyValue = 'ONLY_NEED_ONE_PRICING_POLICY_VALUE',
  /** Selling plan does not exist. */
  PlanDoesNotExist = 'PLAN_DOES_NOT_EXIST',
  /** Selling plan ID must be specified to update. */
  PlanIdMustBeSpecifiedToUpdate = 'PLAN_ID_MUST_BE_SPECIFIED_TO_UPDATE',
  /** The input value needs to be blank. */
  Present = 'PRESENT',
  /** Pricing policy's adjustment value and adjustment type must match. */
  PricingPolicyAdjustmentValueAndTypeMustMatch = 'PRICING_POLICY_ADJUSTMENT_VALUE_AND_TYPE_MUST_MATCH',
  /** Product does not exist. */
  ProductDoesNotExist = 'PRODUCT_DOES_NOT_EXIST',
  /** Product variant does not exist. */
  ProductVariantDoesNotExist = 'PRODUCT_VARIANT_DOES_NOT_EXIST',
  /** The selling plan list provided contains 1 or more invalid IDs. */
  ResourceListContainsInvalidIds = 'RESOURCE_LIST_CONTAINS_INVALID_IDS',
  /** Selling plan's billing and delivery policies anchors must be equal. */
  SellingPlanBillingAndDeliveryPolicyAnchorsMustBeEqual = 'SELLING_PLAN_BILLING_AND_DELIVERY_POLICY_ANCHORS_MUST_BE_EQUAL',
  /** Selling plan's billing cycle must be a multiple of delivery cycle. */
  SellingPlanBillingCycleMustBeAMultipleOfDeliveryCycle = 'SELLING_PLAN_BILLING_CYCLE_MUST_BE_A_MULTIPLE_OF_DELIVERY_CYCLE',
  /** Missing billing policy. */
  SellingPlanBillingPolicyMissing = 'SELLING_PLAN_BILLING_POLICY_MISSING',
  /** Must include at least one selling plan. */
  SellingPlanCountLowerBound = 'SELLING_PLAN_COUNT_LOWER_BOUND',
  /** Exceeded the selling plan limit (20). */
  SellingPlanCountUpperBound = 'SELLING_PLAN_COUNT_UPPER_BOUND',
  /** Missing delivery policy. */
  SellingPlanDeliveryPolicyMissing = 'SELLING_PLAN_DELIVERY_POLICY_MISSING',
  /** Cannot have multiple selling plans with the same name. */
  SellingPlanDuplicateName = 'SELLING_PLAN_DUPLICATE_NAME',
  /** Cannot have multiple selling plans with the same options. */
  SellingPlanDuplicateOptions = 'SELLING_PLAN_DUPLICATE_OPTIONS',
  /** Selling plan's billing policy max cycles must be greater than min cycles. */
  SellingPlanMaxCyclesMustBeGreaterThanMinCycles = 'SELLING_PLAN_MAX_CYCLES_MUST_BE_GREATER_THAN_MIN_CYCLES',
  /** Cannot define option2 on this selling plan as there's no label on the parent selling plan group. */
  SellingPlanMissingOption2LabelOnParentGroup = 'SELLING_PLAN_MISSING_OPTION2_LABEL_ON_PARENT_GROUP',
  /** Cannot define option3 on this selling plan as there's no label on the parent selling plan group. */
  SellingPlanMissingOption3LabelOnParentGroup = 'SELLING_PLAN_MISSING_OPTION3_LABEL_ON_PARENT_GROUP',
  /** Selling plan's option2 is required because option2 exists. */
  SellingPlanOption2RequiredAsDefinedOnParentGroup = 'SELLING_PLAN_OPTION2_REQUIRED_AS_DEFINED_ON_PARENT_GROUP',
  /** Selling plan's option3 is required because option3 exists. */
  SellingPlanOption3RequiredAsDefinedOnParentGroup = 'SELLING_PLAN_OPTION3_REQUIRED_AS_DEFINED_ON_PARENT_GROUP',
  /** Selling plans can't have more than 2 pricing policies. */
  SellingPlanPricingPoliciesLimit = 'SELLING_PLAN_PRICING_POLICIES_LIMIT',
  /** Selling plan's pricing policies must contain one fixed pricing policy. */
  SellingPlanPricingPoliciesMustContainAFixedPricingPolicy = 'SELLING_PLAN_PRICING_POLICIES_MUST_CONTAIN_A_FIXED_PRICING_POLICY',
  /** The input value is already taken. */
  Taken = 'TAKEN',
  /** The input value is too long. */
  TooLong = 'TOO_LONG',
  /** The input value is too short. */
  TooShort = 'TOO_SHORT',
}

/** Specifies the input fields to create or update a selling plan. */
export type SellingPlanInput = {
  /** Selling plan policy which describes the billing details. */
  billingPolicy?: InputMaybe<SellingPlanBillingPolicyInput>
  /** A selling plan policy which describes the delivery details. */
  deliveryPolicy?: InputMaybe<SellingPlanDeliveryPolicyInput>
  /** Buyer facing string which describes the selling plan commitment. */
  description?: InputMaybe<Scalars['String']>
  /** ID of the selling plan. */
  id?: InputMaybe<Scalars['ID']>
  /** Buyer facing string which describes the selling plan content. */
  name?: InputMaybe<Scalars['String']>
  /** The values of all options available on the selling plan. Selling plans are grouped together in Liquid when they are created by the same app, and have the same `selling_plan_group.name` and `selling_plan_group.options` values. */
  options?: InputMaybe<Array<Scalars['String']>>
  /** Relative value for display purposes of this plan. A lower position will be displayed before a higher one. */
  position?: InputMaybe<Scalars['Int']>
  /**
   * The pricing policies which describe the pricing details. Each selling plan
   * can only contain a maximum of 2 pricing policies.
   *
   */
  pricingPolicies?: InputMaybe<Array<SellingPlanPricingPolicyInput>>
}

/** Represents valid selling plan interval. */
export enum SellingPlanInterval {
  /** Day interval. */
  Day = 'DAY',
  /** Month interval. */
  Month = 'MONTH',
  /** Week interval. */
  Week = 'WEEK',
  /** Year interval. */
  Year = 'YEAR',
}

/**
 * Represents the type of pricing associated to the selling plan (for example, a $10 or 20% discount that is set
 * for a limited period or that is fixed for the duration of the subscription). Selling plan pricing policies and
 * associated records (selling plan groups, selling plans, billing policy, and delivery policy) are deleted 48
 * hours after a merchant uninstalls their subscriptions app. We recommend backing up these records if you need
 * to restore them later.
 *
 */
export type SellingPlanPricingPolicy =
  | SellingPlanFixedPricingPolicy
  | SellingPlanRecurringPricingPolicy

/** Represents a selling plan pricing policy adjustment type. */
export enum SellingPlanPricingPolicyAdjustmentType {
  /** Fixed amount off adjustment. */
  FixedAmount = 'FIXED_AMOUNT',
  /** Percentage off adjustment. */
  Percentage = 'PERCENTAGE',
  /** Price of the policy. */
  Price = 'PRICE',
}

/** Represents a selling plan pricing policy adjustment value type. */
export type SellingPlanPricingPolicyAdjustmentValue =
  | MoneyV2
  | SellingPlanPricingPolicyPercentageValue

/** Represents selling plan pricing policy common fields. */
export type SellingPlanPricingPolicyBase = {
  /** The price adjustment type. */
  adjustmentType: SellingPlanPricingPolicyAdjustmentType
  /** The price adjustment value. */
  adjustmentValue: SellingPlanPricingPolicyAdjustmentValue
}

/** Specifies the input fields required to create or update a selling plan pricing policy. */
export type SellingPlanPricingPolicyInput = {
  /** Fixed pricing policy details. */
  fixed?: InputMaybe<SellingPlanFixedPricingPolicyInput>
  /** Recurring pricing policy details. */
  recurring?: InputMaybe<SellingPlanRecurringPricingPolicyInput>
}

/** Represents the percentage value of a selling plan pricing policy percentage type. */
export type SellingPlanPricingPolicyPercentageValue = {
  __typename?: 'SellingPlanPricingPolicyPercentageValue'
  /** The percentage value. */
  percentage: Scalars['Float']
}

/** Specifies the input fields required to create or update a pricing policy adjustment value. */
export type SellingPlanPricingPolicyValueInput = {
  /** Defines fixed value for an fixed amount off or a new policy price. */
  fixedValue?: InputMaybe<Scalars['Decimal']>
  /** Defines percentage value. */
  percentage?: InputMaybe<Scalars['Float']>
}

/** Represents a recurring selling plan billing policy. */
export type SellingPlanRecurringBillingPolicy = {
  __typename?: 'SellingPlanRecurringBillingPolicy'
  /** Specific anchor dates upon which the billing interval calculations should be made. */
  anchors: Array<SellingPlanAnchor>
  /** The date and time when the selling plan billing policy was created. */
  createdAt: Scalars['DateTime']
  /** The billing frequency, it can be either: day, week, month or year. */
  interval: SellingPlanInterval
  /** The number of intervals between billings. */
  intervalCount: Scalars['Int']
  /** Maximum number of billing iterations. */
  maxCycles?: Maybe<Scalars['Int']>
  /** Minimum number of billing iterations. */
  minCycles?: Maybe<Scalars['Int']>
}

/** Specifies the input fields required to create or update a recurring billing policy. */
export type SellingPlanRecurringBillingPolicyInput = {
  /** Specific anchor dates upon which the billing interval calculations should be made. */
  anchors?: InputMaybe<Array<SellingPlanAnchorInput>>
  /** The billing frequency, it can be either: day, week, month or year. */
  interval?: InputMaybe<SellingPlanInterval>
  /** The number of intervals between billings. */
  intervalCount?: InputMaybe<Scalars['Int']>
  /** Maximum number of billing iterations. */
  maxCycles?: InputMaybe<Scalars['Int']>
  /** Minimum number of billing iterations. */
  minCycles?: InputMaybe<Scalars['Int']>
}

/** Represents a recurring selling plan delivery policy. */
export type SellingPlanRecurringDeliveryPolicy = {
  __typename?: 'SellingPlanRecurringDeliveryPolicy'
  /** Specific anchor dates upon which the delivery interval calculations should be made. */
  anchors: Array<SellingPlanAnchor>
  /** The date and time when the selling plan delivery policy was created. */
  createdAt: Scalars['DateTime']
  /** A buffer period for orders to be included in a cycle. */
  cutoff?: Maybe<Scalars['Int']>
  /**
   * Specifies if the delivery policy is merchant or buyer-centric.
   * Buyer-centric delivery policies state the time when the buyer will receive the goods.
   * Merchant-centric delivery policies state the time when the fulfillment should be started.
   * Currently, only merchant-centric delivery policies are supported.
   *
   */
  intent: SellingPlanRecurringDeliveryPolicyIntent
  /** The delivery frequency, it can be either: day, week, month or year. */
  interval: SellingPlanInterval
  /** The number of intervals between deliveries. */
  intervalCount: Scalars['Int']
  /** Fulfillment or delivery behavior of the first fulfillment when the order is placed before the anchor. The default value for this field is `ASAP`. */
  preAnchorBehavior: SellingPlanRecurringDeliveryPolicyPreAnchorBehavior
}

/** Specifies the input fields to create or update a recurring delivery policy. */
export type SellingPlanRecurringDeliveryPolicyInput = {
  /** Specific anchor dates upon which the delivery interval calculations should be made. */
  anchors?: InputMaybe<Array<SellingPlanAnchorInput>>
  /** A buffer period for orders to be included in a cycle. */
  cutoff?: InputMaybe<Scalars['Int']>
  /** Intention of this delivery policy, it can be either: delivery or fulfillment. */
  intent?: InputMaybe<SellingPlanRecurringDeliveryPolicyIntent>
  /** The delivery frequency, it can be either: day, week, month or year. */
  interval?: InputMaybe<SellingPlanInterval>
  /** The number of intervals between deliveries. */
  intervalCount?: InputMaybe<Scalars['Int']>
  /** The pre anchor behavior. It can be either: asap or next. */
  preAnchorBehavior?: InputMaybe<SellingPlanRecurringDeliveryPolicyPreAnchorBehavior>
}

/** Possible intentions of a Delivery Policy. */
export enum SellingPlanRecurringDeliveryPolicyIntent {
  /**
   * A merchant-centric delivery policy. Mark this delivery policy to define when the merchant should start fulfillment.
   *
   */
  FulfillmentBegin = 'FULFILLMENT_BEGIN',
}

/** Possible fulfillment or delivery behaviors of the first fulfillment when the orderis placed before the anchor. */
export enum SellingPlanRecurringDeliveryPolicyPreAnchorBehavior {
  /**
   * Orders placed can be fulfilled / delivered immediately. Orders placed inside a cutoff can be fulfilled / delivered at the next anchor.
   *
   */
  Asap = 'ASAP',
  /**
   * Orders placed can be fulfilled / delivered at the next anchor date.
   * Orders placed inside a cutoff will skip the next anchor and can be fulfilled /
   * delivered at the following anchor.
   *
   */
  Next = 'NEXT',
}

/** Represents a recurring selling plan pricing policy. */
export type SellingPlanRecurringPricingPolicy = SellingPlanPricingPolicyBase & {
  __typename?: 'SellingPlanRecurringPricingPolicy'
  /** The price adjustment type. */
  adjustmentType: SellingPlanPricingPolicyAdjustmentType
  /** The price adjustment value. */
  adjustmentValue: SellingPlanPricingPolicyAdjustmentValue
  /** Cycle after which this pricing policy applies. */
  afterCycle?: Maybe<Scalars['Int']>
  /** The date and time when the recurring selling plan pricing policy was created. */
  createdAt: Scalars['DateTime']
}

/** Specifies the input fields required to create or update a recurring selling plan pricing policy. */
export type SellingPlanRecurringPricingPolicyInput = {
  /** Price adjustment type defined by the policy. */
  adjustmentType?: InputMaybe<SellingPlanPricingPolicyAdjustmentType>
  /** Price adjustment value defined by the policy. */
  adjustmentValue?: InputMaybe<SellingPlanPricingPolicyValueInput>
  /** Cycle after which the pricing policy applies. */
  afterCycle: Scalars['Int']
  /** ID of the pricing policy. */
  id?: InputMaybe<Scalars['ID']>
}

/** Represents the shipping details that the customer chose for their order. */
export type ShippingLine = {
  __typename?: 'ShippingLine'
  /**
   * A reference to the carrier service that provided the rate.
   * Present when the rate was computed by a third-party carrier service.
   *
   */
  carrierIdentifier?: Maybe<Scalars['String']>
  /** A reference to the shipping method. */
  code?: Maybe<Scalars['String']>
  /** Whether the shipping line is custom or not. */
  custom: Scalars['Boolean']
  /** The general classification of the delivery method. */
  deliveryCategory?: Maybe<Scalars['String']>
  /**
   * The discounts that have been allocated to the shipping line.
   *
   */
  discountAllocations: Array<DiscountAllocation>
  /**
   * The pre-tax shipping price with discounts applied.
   * @deprecated Use `discountedPriceSet` instead
   */
  discountedPrice: MoneyV2
  /** The pre-tax shipping price with discounts applied. */
  discountedPriceSet: MoneyBag
  /** A globally-unique identifier. */
  id?: Maybe<Scalars['ID']>
  /**
   * The pre-tax shipping price without any discounts applied.
   * @deprecated Use `originalPriceSet` instead
   */
  originalPrice: MoneyV2
  /** The pre-tax shipping price without any discounts applied. */
  originalPriceSet: MoneyBag
  /** The phone number at the shipping address. */
  phone?: Maybe<Scalars['String']>
  /**
   * Returns the price of the shipping line.
   * @deprecated Use `originalPriceSet` instead
   */
  price: Scalars['Money']
  /**
   * The fulfillment service requested for the shipping method.
   * Present if the shipping method requires processing by a third party fulfillment service.
   *
   */
  requestedFulfillmentService?: Maybe<FulfillmentService>
  /** A unique identifier for the shipping rate. The format can change without notice and is not meant to be shown to users. */
  shippingRateHandle?: Maybe<Scalars['String']>
  /** Returns the rate source for the shipping line. */
  source?: Maybe<Scalars['String']>
  /** The TaxLine objects connected to this shipping line. */
  taxLines: Array<TaxLine>
  /** Returns the title of the shipping line. */
  title: Scalars['String']
}

/**
 * An auto-generated type for paginating through multiple ShippingLines.
 *
 */
export type ShippingLineConnection = {
  __typename?: 'ShippingLineConnection'
  /** A list of edges. */
  edges: Array<ShippingLineEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one ShippingLine and a cursor during pagination.
 *
 */
export type ShippingLineEdge = {
  __typename?: 'ShippingLineEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of ShippingLineEdge. */
  node: ShippingLine
}

/** Specifies the shipping details for the order. */
export type ShippingLineInput = {
  /** Price of the shipping rate. */
  price?: InputMaybe<Scalars['Money']>
  /** A unique identifier for the shipping rate. */
  shippingRateHandle?: InputMaybe<Scalars['String']>
  /** Title of the shipping rate. */
  title?: InputMaybe<Scalars['String']>
}

/** A sale associated with a shipping charge. */
export type ShippingLineSale = Sale & {
  __typename?: 'ShippingLineSale'
  /** The type of order action that the sale represents. */
  actionType: SaleActionType
  /** The unique identifier for the sale. */
  id: Scalars['ID']
  /** The line type assocated with the sale. */
  lineType: SaleLineType
  /** The number of units either ordered or intended to be returned. */
  quantity?: Maybe<Scalars['Int']>
  /** The shipping line item for the associated sale. `shippingLine` is not available if the `SaleActionType` is a return. */
  shippingLine?: Maybe<ShippingLine>
  /** All individual taxes associated with the sale. */
  taxes: Array<SaleTax>
  /** The total sale amount after taxes and discounts. */
  totalAmount: MoneyBag
  /** The total discounts allocated to the sale after taxes. */
  totalDiscountAmountAfterTaxes: MoneyBag
  /** The total discounts allocated to the sale before taxes. */
  totalDiscountAmountBeforeTaxes: MoneyBag
  /** The total amount of taxes for the sale. */
  totalTaxAmount: MoneyBag
}

/**
 * The shipping method for the delivery. Customers will see applicable shipping methods in the shipping section of checkout.
 *
 */
export type ShippingMethod = {
  __typename?: 'ShippingMethod'
  /** A unique code associated with the rate. For example: `expedited_mail` */
  code: Scalars['String']
  /**
   * A description of the rate, which customers will see at checkout.
   * For example: `Local delivery`, `Free Express Worldwide`, `Includes tracking and insurance`.
   *
   */
  label: Scalars['String']
}

/** Return type for `shippingPackageDelete` mutation. */
export type ShippingPackageDeletePayload = {
  __typename?: 'ShippingPackageDeletePayload'
  /** The ID of the deleted shipping package. */
  deletedId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `shippingPackageMakeDefault` mutation. */
export type ShippingPackageMakeDefaultPayload = {
  __typename?: 'ShippingPackageMakeDefaultPayload'
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `shippingPackageUpdate` mutation. */
export type ShippingPackageUpdatePayload = {
  __typename?: 'ShippingPackageUpdatePayload'
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** A shipping rate is an additional cost added to the cost of the products that were ordered. */
export type ShippingRate = {
  __typename?: 'ShippingRate'
  /** Human-readable unique identifier for this shipping rate. */
  handle: Scalars['String']
  /** The cost associated with the shipping rate. */
  price: MoneyV2
  /** The name of the shipping rate. */
  title: Scalars['String']
}

/** Represents the shipping costs refunded on the Refund. */
export type ShippingRefund = {
  __typename?: 'ShippingRefund'
  /**
   * The monetary value of the shipping fees to be refunded.
   * @deprecated Use `amountSet` instead
   */
  amount: Scalars['Money']
  /** The monetary value of the shipping fees to be refunded in shop and presentment currencies. */
  amountSet: MoneyBag
  /**
   * The maximum amount of shipping fees currently refundable.
   * @deprecated Use `maximumRefundableSet` instead
   */
  maximumRefundable: Scalars['Money']
  /** The maximum amount of shipping fees currently refundable in shop and presentment currencies. */
  maximumRefundableSet: MoneyBag
  /**
   * The monetary value of the tax allocated to shipping fees to be refunded.
   * @deprecated Use `taxSet` instead
   */
  tax: Scalars['Money']
  /** The monetary value of the tax allocated to shipping fees to be refunded in shop and presentment currencies. */
  taxSet: MoneyBag
}

/** The input fields that are required to reimburse shipping costs. */
export type ShippingRefundInput = {
  /** The monetary value of the shipping fees to be reimbursed. */
  amount?: InputMaybe<Scalars['Money']>
  /** Whether a full refund is provided. */
  fullRefund?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type Shop = HasMetafields &
  HasPublishedTranslations &
  Node & {
    __typename?: 'Shop'
    /** A list of the shop's active alert messages that appear in the Shopify admin. */
    alerts: Array<ShopAlert>
    /**
     * The token required to query the shop's reports or dashboards.
     * @deprecated Not supported anymore.
     */
    analyticsToken: Scalars['String']
    /** The paginated list of fulfillment orders assigned to fulfillment services. */
    assignedFulfillmentOrders: FulfillmentOrderConnection
    /** The list of sales channels not currently installed on the shop. */
    availableChannelApps: AppConnection
    /** The shop's billing address information. */
    billingAddress: MailingAddress
    /**
     * Exposes the number of channels.
     * @deprecated Use `publicationCount` instead
     */
    channelCount: Scalars['Int']
    /**
     * List of the shop's active sales channels.
     * @deprecated Use `QueryRoot.channels` instead.
     */
    channels: ChannelConnection
    /** Specifies whether the shop supports checkouts via Checkout API. */
    checkoutApiSupported: Scalars['Boolean']
    /**
     * Return a collection by its handle.
     * @deprecated Use `QueryRoot.collectionByHandle` instead.
     */
    collectionByHandle?: Maybe<Collection>
    /**
     * List of the shop's collection saved searches.
     * @deprecated Use `QueryRoot.collectionSavedSearches` instead.
     */
    collectionSavedSearches: SavedSearchConnection
    /**
     * List of the shop's collections.
     * @deprecated Use `QueryRoot.collections` instead.
     */
    collections: CollectionConnection
    /**
     * The public-facing contact email address for the shop.
     * Customers will use this email to communicate with the shop owner.
     *
     */
    contactEmail: Scalars['String']
    /** Countries that have been defined in shipping zones for the shop. */
    countriesInShippingZones: CountriesInShippingZones
    /** The three letter code for the shop's currency. */
    currencyCode: CurrencyCode
    /** How currencies are displayed on your store. */
    currencyFormats: CurrencyFormats
    /** The presentment currency settings for the shop excluding the shop's own currency. */
    currencySettings: CurrencySettingConnection
    /** Whether customer accounts are required, optional, or disabled for the shop. */
    customerAccounts: ShopCustomerAccountsSetting
    /**
     * List of the shop's customer saved searches.
     * @deprecated Use `QueryRoot.customerSavedSearches` instead.
     */
    customerSavedSearches: SavedSearchConnection
    /** A list of tags that have been added to customer accounts. */
    customerTags: StringConnection
    /**
     * Customer accounts associated to the shop.
     * @deprecated Use `QueryRoot.customers` instead.
     */
    customers: CustomerConnection
    /** The shop's meta description used in search engine results. */
    description?: Maybe<Scalars['String']>
    /** The domains configured for the shop. */
    domains: Array<Domain>
    /**
     * List of the shop's draft order saved searches.
     * @deprecated Use `QueryRoot.draftOrderSavedSearches` instead.
     */
    draftOrderSavedSearches: SavedSearchConnection
    /** A list of tags that have been added to draft orders. */
    draftOrderTags: StringConnection
    /**
     * List of saved draft orders on the shop.
     * @deprecated Use `QueryRoot.draftOrders` instead.
     */
    draftOrders: DraftOrderConnection
    /**
     * The shop owner's email address.
     * Shopify will use this email address to communicate with the shop owner.
     *
     */
    email: Scalars['String']
    /** The presentment currencies enabled for the shop. */
    enabledPresentmentCurrencies: Array<CurrencyCode>
    /** The set of features enabled for the shop. */
    features: ShopFeatures
    /** The paginated list of merchant-managed and third-party fulfillment orders. */
    fulfillmentOrders: FulfillmentOrderConnection
    /** List of the shop's installed fulfillment services. */
    fulfillmentServices: Array<FulfillmentService>
    /** The shop's time zone as defined by the IANA. */
    ianaTimezone: Scalars['String']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /**
     * List of the shop's inventory items.
     * @deprecated Use `QueryRoot.inventoryItems` instead.
     */
    inventoryItems: InventoryItemConnection
    /**
     * The number of pendings orders on the shop.
     * Limited to a maximum of 10000.
     *
     */
    limitedPendingOrderCount: LimitedPendingOrderCount
    /**
     * List of active locations of the shop.
     * @deprecated Use `QueryRoot.locations` instead.
     */
    locations: LocationConnection
    /**
     * List of a shop's marketing events.
     * @deprecated Use `QueryRoot.marketingEvents` instead.
     */
    marketingEvents: MarketingEventConnection
    /** The approval signals for a shop to support onboarding to channel apps. */
    merchantApprovalSignals?: Maybe<MerchantApprovalSignals>
    /** Returns a metafield by namespace and key that belongs to the resource. */
    metafield?: Maybe<Metafield>
    /** List of metafields that belong to the resource. */
    metafields: MetafieldConnection
    /** The shop's .myshopify.com domain name. */
    myshopifyDomain: Scalars['String']
    /** The shop's name. */
    name: Scalars['String']
    /** The shop's settings related to navigation. */
    navigationSettings: Array<NavigationItem>
    /** The prefix that appears before order numbers. */
    orderNumberFormatPrefix: Scalars['String']
    /** The suffix that appears after order numbers. */
    orderNumberFormatSuffix: Scalars['String']
    /**
     * List of the shop's order saved searches.
     * @deprecated Use `QueryRoot.orderSavedSearches` instead.
     */
    orderSavedSearches: SavedSearchConnection
    /** A list of tags that have been added to orders. */
    orderTags: StringConnection
    /**
     * A list of the shop's orders.
     * @deprecated Use `QueryRoot.orders` instead.
     */
    orders: OrderConnection
    /** The shop's settings related to payments. */
    paymentSettings: PaymentSettings
    /**
     * Number of pending orders on the shop.
     * @deprecated Use `limitedPendingOrderCount` instead
     */
    pendingOrderCount: Scalars['Int']
    /** The shop's billing plan. */
    plan: ShopPlan
    /**
     * List of the shop's price rule saved searches.
     * @deprecated Use `QueryRoot.priceRuleSavedSearches` instead.
     */
    priceRuleSavedSearches: SavedSearchConnection
    /**
     * List of the shop’s price rules.
     * @deprecated Use `QueryRoot.priceRules` instead.
     */
    priceRules: PriceRuleConnection
    /** The shop's primary domain name. */
    primaryDomain: Domain
    /** Returns a private metafield by namespace and key that belongs to the resource. */
    privateMetafield?: Maybe<PrivateMetafield>
    /** List of private metafields that belong to the resource. */
    privateMetafields: PrivateMetafieldConnection
    /**
     * Return a product by its handle.
     * @deprecated Use `QueryRoot.productByHandle` instead.
     */
    productByHandle?: Maybe<Product>
    /** The list of all images of all products for the shop. */
    productImages: ImageConnection
    /**
     * List of the shop's product saved searches.
     * @deprecated Use `QueryRoot.productSavedSearches` instead.
     */
    productSavedSearches: SavedSearchConnection
    /** A list of tags that have been added to products. */
    productTags: StringConnection
    /** The list of types added to products. */
    productTypes: StringConnection
    /**
     * List of the shop's product variants.
     * @deprecated Use `QueryRoot.productVariants` instead.
     */
    productVariants: ProductVariantConnection
    /** The list of vendors added to products. */
    productVendors: StringConnection
    /**
     * List of the shop's products.
     * @deprecated Use `QueryRoot.products`.
     */
    products: ProductConnection
    /** The number of publications for the shop. */
    publicationCount: Scalars['Int']
    /** The shop's limits for specific resources. For example, the maximum number ofvariants allowed per product, or the maximum number of locations allowed. */
    resourceLimits: ShopResourceLimits
    /** The URL of the rich text editor that can be used for mobile devices. */
    richTextEditorUrl: Scalars['URL']
    /** Fetches a list of admin search results by a specified query. */
    search: SearchResultConnection
    /** The list of search filter options for the shop. These can be used to filter productvisibility for the shop. */
    searchFilters: SearchFilterOptions
    /** Whether the shop has outstanding setup steps. */
    setupRequired: Scalars['Boolean']
    /** The list of countries that the shop ships to. */
    shipsToCountries: Array<CountryCode>
    /** The list of all legal policies associated with a shop. */
    shopPolicies: Array<ShopPolicy>
    /**
     * Shopify Payments account information, including balances and payouts.
     * @deprecated Use `QueryRoot.shopifyPaymentsAccount` instead.
     */
    shopifyPaymentsAccount?: Maybe<ShopifyPaymentsAccount>
    /** The storefront access token of a private application. These are scoped per-application. */
    storefrontAccessTokens: StorefrontAccessTokenConnection
    /**
     * The URL of the shop's storefront.
     * @deprecated Use `url` instead
     */
    storefrontUrl: Scalars['URL']
    /** Whether the shop charges taxes for shipping. */
    taxShipping: Scalars['Boolean']
    /** Whether applicable taxes are included in the shop's product prices. */
    taxesIncluded: Scalars['Boolean']
    /** The shop's time zone abbreviation. */
    timezoneAbbreviation: Scalars['String']
    /** The shop's time zone offset. */
    timezoneOffset: Scalars['String']
    /** The shop's time zone offset expressed as a number of minutes. */
    timezoneOffsetMinutes: Scalars['Int']
    /** The translations associated with the resource. */
    translations: Array<PublishedTranslation>
    /** The shop's unit system for weights and measures. */
    unitSystem: UnitSystem
    /** Fetches a list of images uploaded to the shop by their IDs. */
    uploadedImagesByIds: Array<Image>
    /** The URL of the shop's online store. */
    url: Scalars['URL']
    /** The shop's primary unit of weight for products and shipping. */
    weightUnit: WeightUnit
  }

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopAssignedFulfillmentOrdersArgs = {
  after?: InputMaybe<Scalars['String']>
  assignmentStatus?: InputMaybe<FulfillmentOrderAssignmentStatus>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  locationIds?: InputMaybe<Array<Scalars['ID']>>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<FulfillmentOrderSortKeys>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopAvailableChannelAppsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopChannelsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopCollectionByHandleArgs = {
  handle: Scalars['String']
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopCollectionSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopCollectionsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<CollectionSortKeys>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopCurrencySettingsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopCustomerSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<CustomerSavedSearchSortKeys>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopCustomerTagsArgs = {
  first: Scalars['Int']
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopCustomersArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<CustomerSortKeys>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopDraftOrderSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopDraftOrderTagsArgs = {
  first: Scalars['Int']
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopDraftOrdersArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<DraftOrderSortKeys>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopFulfillmentOrdersArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  includeClosed?: InputMaybe<Scalars['Boolean']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<FulfillmentOrderSortKeys>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopInventoryItemsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopLocationsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  includeInactive?: InputMaybe<Scalars['Boolean']>
  includeLegacy?: InputMaybe<Scalars['Boolean']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<LocationSortKeys>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopMarketingEventsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<MarketingEventSortKeys>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopOrderSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopOrderTagsArgs = {
  first: Scalars['Int']
  sort?: InputMaybe<ShopTagSort>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopOrdersArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<OrderSortKeys>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopPriceRuleSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopPriceRulesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<PriceRuleSortKeys>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopPrivateMetafieldArgs = {
  key: Scalars['String']
  namespace: Scalars['String']
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopPrivateMetafieldsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  namespace?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopProductByHandleArgs = {
  handle: Scalars['String']
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopProductImagesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  crop?: InputMaybe<CropRegion>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  maxHeight?: InputMaybe<Scalars['Int']>
  maxWidth?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  scale?: InputMaybe<Scalars['Int']>
  sortKey?: InputMaybe<ProductImageSortKeys>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopProductSavedSearchesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopProductTagsArgs = {
  first: Scalars['Int']
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopProductTypesArgs = {
  first: Scalars['Int']
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopProductVariantsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  sortKey?: InputMaybe<ProductVariantSortKeys>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopProductVendorsArgs = {
  first: Scalars['Int']
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopProductsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
  savedSearchId?: InputMaybe<Scalars['ID']>
  sortKey?: InputMaybe<ProductSortKeys>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopSearchArgs = {
  after?: InputMaybe<Scalars['String']>
  first: Scalars['Int']
  query: Scalars['String']
  types?: InputMaybe<Array<SearchResultType>>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopStorefrontAccessTokensArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopTranslationsArgs = {
  locale: Scalars['String']
}

/**
 * Represents a collection of the general settings and information about the shop.
 *
 */
export type ShopUploadedImagesByIdsArgs = {
  imageIds: Array<Scalars['ID']>
}

/**
 * An alert message that appears in the Shopify admin about a problem with a store setting, with an action to take. For example, you could show an alert to ask the merchant to enter their billing information to activate Shopify Plus.
 *
 */
export type ShopAlert = {
  __typename?: 'ShopAlert'
  /**
   * The text for the button in the alert that links to related information. For example, _Add credit card_.
   *
   */
  action: ShopAlertAction
  /** A description of the alert and further information, such as whether the merchant will be charged. */
  description: Scalars['String']
}

/** An action associated to a shop alert, such as adding a credit card. */
export type ShopAlertAction = {
  __typename?: 'ShopAlertAction'
  /** The text for the button in the alert. For example, _Add credit card_. */
  title: Scalars['String']
  /** The target URL that the button links to. */
  url: Scalars['URL']
}

/**
 * Possible branding of a shop.
 * Branding can be used to define the look of a shop including its styling and logo in the Shopify Admin.
 *
 */
export enum ShopBranding {
  /** Shop has Rogers branding. */
  Rogers = 'ROGERS',
  /** Shop has Shopify branding. */
  Shopify = 'SHOPIFY',
  /** Shop has Shopify Gold branding. */
  ShopifyGold = 'SHOPIFY_GOLD',
  /** Shop has Shopify Plus branding. */
  ShopifyPlus = 'SHOPIFY_PLUS',
}

/**
 * Represents the shop's customer account requirement preference.
 *
 */
export enum ShopCustomerAccountsSetting {
  Disabled = 'DISABLED',
  Optional = 'OPTIONAL',
  Required = 'REQUIRED',
}

/**
 * Represents the feature set available to the shop.
 * Most fields specify whether a feature is enabled for a shop, and some fields return information
 * related to specific features.
 *
 */
export type ShopFeatures = {
  __typename?: 'ShopFeatures'
  /** Whether a shop has access to Avalara AvaTax. */
  avalaraAvatax: Scalars['Boolean']
  /** The branding of the shop, which influences its look and feel in the Shopify admin. */
  branding: ShopBranding
  /** Whether a shop's online store can have CAPTCHA protection. */
  captcha: Scalars['Boolean']
  /** Whether a shop's online store can have CAPTCHA protection for domains not managed by Shopify. */
  captchaExternalDomains: Scalars['Boolean']
  /**
   * Whether the delivery profiles functionality is enabled for this shop.
   * @deprecated Delivery profiles are now 100% enabled across Shopify.
   */
  deliveryProfiles: Scalars['Boolean']
  /** Whether a shop has access to the Google Analytics dynamic remarketing feature. */
  dynamicRemarketing: Scalars['Boolean']
  /** Whether a shop can be migrated to use Shopify subscriptions. */
  eligibleForSubscriptionMigration: Scalars['Boolean']
  /** Whether a shop is configured properly to sell subscriptions. */
  eligibleForSubscriptions: Scalars['Boolean']
  /** Whether a shop can create gift cards. */
  giftCards: Scalars['Boolean']
  /**
   * Whether a shop displays Harmonized System codes on products. This is used for customs when shipping
   * internationally.
   *
   */
  harmonizedSystemCode: Scalars['Boolean']
  /** Whether a shop can enable international domains. */
  internationalDomains: Scalars['Boolean']
  /** Whether a shop can enable international price overrides. */
  internationalPriceOverrides: Scalars['Boolean']
  /** Whether a shop can enable international price rules. */
  internationalPriceRules: Scalars['Boolean']
  /** Whether a shop has enabled a legacy subscription gateway to handle older subscriptions. */
  legacySubscriptionGatewayEnabled: Scalars['Boolean']
  /**
   * Whether to show the Live View metrics in the Shopify admin. Live view is hidden from merchants that are on a trial
   * or don't have a storefront.
   *
   */
  liveView: Scalars['Boolean']
  /**
   * Whether a shop has multi-location functionality.
   * @deprecated All shops support multi-location inventory. Use `QueryRoot.locations` to determine whether shop has more than one location.
   *
   */
  multiLocation: Scalars['Boolean']
  /** Whether a shop has access to the onboarding visual. */
  onboardingVisual: Scalars['Boolean']
  /** Whether a shop is configured to sell subscriptions with PayPal Express. */
  paypalExpressSubscriptionGatewayStatus: PaypalExpressSubscriptionsGatewayStatus
  /** Whether a shop has access to all reporting features. */
  reports: Scalars['Boolean']
  /** Whether a shop has ever had subscription products. */
  sellsSubscriptions: Scalars['Boolean']
  /**
   * Whether the shop has a Shopify Plus subscription.
   * @deprecated Use Shop.plan.shopifyPlus instead.
   */
  shopifyPlus: Scalars['Boolean']
  /**
   * Whether to show metrics in the Shopify admin. Metrics are hidden for new merchants until they become meaningful.
   *
   */
  showMetrics: Scalars['Boolean']
  /** Whether a shop has an online store. */
  storefront: Scalars['Boolean']
  /** Whether a shop is using Shopify Balance. */
  usingShopifyBalance: Scalars['Boolean']
}

/** Locale that has been enabled on a shop. */
export type ShopLocale = {
  __typename?: 'ShopLocale'
  /** Locale ISO code. */
  locale: Scalars['String']
  /** Human-readable locale name. */
  name: Scalars['String']
  /** Whether or not this is the default locale for the shop. */
  primary: Scalars['Boolean']
  /** Whether or not the locale is visible to buyers. */
  published: Scalars['Boolean']
}

/** Return type for `shopLocaleDisable` mutation. */
export type ShopLocaleDisablePayload = {
  __typename?: 'ShopLocaleDisablePayload'
  /** ISO code of the locale that was deleted. */
  locale?: Maybe<Scalars['String']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `shopLocaleEnable` mutation. */
export type ShopLocaleEnablePayload = {
  __typename?: 'ShopLocaleEnablePayload'
  /** ISO code of the locale that was enabled. */
  shopLocale?: Maybe<ShopLocale>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * Specifies the input fields for a shop locale.
 *
 */
export type ShopLocaleInput = {
  /** Specifies the published state of the locale. Only published locales are visible to the buyer. */
  published?: InputMaybe<Scalars['Boolean']>
}

/** Return type for `shopLocaleUpdate` mutation. */
export type ShopLocaleUpdatePayload = {
  __typename?: 'ShopLocaleUpdatePayload'
  /** The locale that was updated. */
  shopLocale?: Maybe<ShopLocale>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * Represents the billing plan of the shop.
 *
 */
export type ShopPlan = {
  __typename?: 'ShopPlan'
  /** The name of the shop's billing plan. */
  displayName: Scalars['String']
  /** Whether the shop is a partner development shop for testing purposes. */
  partnerDevelopment: Scalars['Boolean']
  /** Whether the shop has a Shopify Plus subscription. */
  shopifyPlus: Scalars['Boolean']
}

/** Policy that a merchant has configured for their store, such as their refund or privacy policy. */
export type ShopPolicy = HasPublishedTranslations &
  Node & {
    __typename?: 'ShopPolicy'
    /** The text of the policy. The maximum size is 512kb. */
    body: Scalars['HTML']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The translations associated with the resource. */
    translations: Array<PublishedTranslation>
    /** The shop policy type. */
    type: ShopPolicyType
    /** The public URL of the policy. */
    url: Scalars['URL']
  }

/** Policy that a merchant has configured for their store, such as their refund or privacy policy. */
export type ShopPolicyTranslationsArgs = {
  locale: Scalars['String']
}

/** Possible error codes that can be returned by `ShopPolicyUserError`. */
export enum ShopPolicyErrorCode {
  /** The input value is too big. */
  TooBig = 'TOO_BIG',
}

/** Specifies the input fields required to update a policy. */
export type ShopPolicyInput = {
  /** Policy text, maximum size of 512kb. */
  body: Scalars['String']
  /** The shop policy type. */
  type: ShopPolicyType
}

/** Available shop policy types. */
export enum ShopPolicyType {
  /** The legal notice. */
  LegalNotice = 'LEGAL_NOTICE',
  /** The privacy policy. */
  PrivacyPolicy = 'PRIVACY_POLICY',
  /** The refund policy. */
  RefundPolicy = 'REFUND_POLICY',
  /** The shipping policy. */
  ShippingPolicy = 'SHIPPING_POLICY',
  /** The subscription policy. */
  SubscriptionPolicy = 'SUBSCRIPTION_POLICY',
  /** The terms of sale. */
  TermsOfSale = 'TERMS_OF_SALE',
  /** The terms of service. */
  TermsOfService = 'TERMS_OF_SERVICE',
}

/** Return type for `shopPolicyUpdate` mutation. */
export type ShopPolicyUpdatePayload = {
  __typename?: 'ShopPolicyUpdatePayload'
  /** The shop policy that has been updated. */
  shopPolicy?: Maybe<ShopPolicy>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<ShopPolicyUserError>
}

/** An error that occurs during the execution of a shop policy mutation. */
export type ShopPolicyUserError = DisplayableError & {
  __typename?: 'ShopPolicyUserError'
  /** The error code. */
  code?: Maybe<ShopPolicyErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Resource limits of a shop. */
export type ShopResourceLimits = {
  __typename?: 'ShopResourceLimits'
  /** Maximum number of locations allowed. */
  locationLimit: Scalars['Int']
  /** Maximum number of product options allowed. */
  maxProductOptions: Scalars['Int']
  /** The maximum number of variants allowed per product. */
  maxProductVariants: Scalars['Int']
  /** Whether the shop has reached the limit of the number of URL redirects it can make for resources. */
  redirectLimitReached: Scalars['Boolean']
  /** The maximum number of variants allowed per shop. If the shop has unlimited SKUs, then the quantity used cannot be retrieved. */
  skuResourceLimits: ResourceLimit
}

/** Possible sort of tags. */
export enum ShopTagSort {
  /** Alphabetical sort. */
  Alphabetical = 'ALPHABETICAL',
  /** Popularity sort. */
  Popular = 'POPULAR',
}

/**
 * Balance and payout information for a
 * [Shopify Payments](https://help.shopify.com/manual/payments/shopify-payments/getting-paid-with-shopify-payments)
 * account. Balance includes all balances for the currencies supported by the shop.
 * You can also query for a list of payouts, where each payout includes the corresponding currencyCode field.
 *
 */
export type ShopifyPaymentsAccount = Node & {
  __typename?: 'ShopifyPaymentsAccount'
  /** Whether the Shopify Payments setup is completed. */
  activated: Scalars['Boolean']
  /** Current balances in all currencies for the account. */
  balance: Array<MoneyV2>
  /** All bank accounts configured for the Shopify Payments account. */
  bankAccounts: ShopifyPaymentsBankAccountConnection
  /**
   * Statement descriptor used for charges.
   *
   * This is what buyers will see on their credit card or bank statements when making a purchase.
   *
   * @deprecated Use `chargeStatementDescriptors` instead
   */
  chargeStatementDescriptor?: Maybe<Scalars['String']>
  /**
   * Statement descriptors used for charges.
   *
   * This is what buyers will see on their credit card or bank statements when making a purchase.
   *
   */
  chargeStatementDescriptors?: Maybe<ShopifyPaymentsChargeStatementDescriptor>
  /** The Shopify Payments account country. */
  country: Scalars['String']
  /** The default payout currency for the Shopify Payments account. */
  defaultCurrency: CurrencyCode
  /** All disputes related to the Shopify Payments account. */
  disputes: ShopifyPaymentsDisputeConnection
  /** The fraud settings of the Shopify Payments account. */
  fraudSettings: ShopifyPaymentsFraudSettings
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The notifications settings for the account. */
  notificationSettings: ShopifyPaymentsNotificationSettings
  /** Whether the Shopify Payments account can be onboarded. */
  onboardable: Scalars['Boolean']
  /** Payout schedule for the account. */
  payoutSchedule: ShopifyPaymentsPayoutSchedule
  /**
   * Descriptor used for payouts.
   *
   * This is what merchants will see on their bank statement when receiving a payout.
   *
   */
  payoutStatementDescriptor?: Maybe<Scalars['String']>
  /** All current and previous payouts made between the account and the bank account. */
  payouts: ShopifyPaymentsPayoutConnection
  /** The permitted documents for identity verification. */
  permittedVerificationDocuments: Array<ShopifyPaymentsVerificationDocument>
  /** The verifications necessary for this account. */
  verifications: Array<ShopifyPaymentsVerification>
}

/**
 * Balance and payout information for a
 * [Shopify Payments](https://help.shopify.com/manual/payments/shopify-payments/getting-paid-with-shopify-payments)
 * account. Balance includes all balances for the currencies supported by the shop.
 * You can also query for a list of payouts, where each payout includes the corresponding currencyCode field.
 *
 */
export type ShopifyPaymentsAccountBankAccountsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Balance and payout information for a
 * [Shopify Payments](https://help.shopify.com/manual/payments/shopify-payments/getting-paid-with-shopify-payments)
 * account. Balance includes all balances for the currencies supported by the shop.
 * You can also query for a list of payouts, where each payout includes the corresponding currencyCode field.
 *
 */
export type ShopifyPaymentsAccountDisputesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  query?: InputMaybe<Scalars['String']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * Balance and payout information for a
 * [Shopify Payments](https://help.shopify.com/manual/payments/shopify-payments/getting-paid-with-shopify-payments)
 * account. Balance includes all balances for the currencies supported by the shop.
 * You can also query for a list of payouts, where each payout includes the corresponding currencyCode field.
 *
 */
export type ShopifyPaymentsAccountPayoutsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  transactionType?: InputMaybe<ShopifyPaymentsPayoutTransactionType>
}

/**
 * A bank account that can receive payouts.
 *
 */
export type ShopifyPaymentsBankAccount = Node & {
  __typename?: 'ShopifyPaymentsBankAccount'
  /** The account number of the bank account. */
  accountNumber: Scalars['String']
  /** The last digits of the account number (the rest is redacted). */
  accountNumberLastDigits: Scalars['String']
  /**
   * The name of the bank.
   *
   */
  bankName?: Maybe<Scalars['String']>
  /**
   * The country of the bank.
   *
   */
  country: CountryCode
  /** The date that the bank account was created. */
  createdAt: Scalars['DateTime']
  /**
   * The currency of the bank account.
   *
   */
  currency: CurrencyCode
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** All current and previous payouts made between the account and the bank account. */
  payouts: ShopifyPaymentsPayoutConnection
  /**
   * The routing number of the bank account.
   *
   */
  routingNumber: Scalars['String']
  /**
   * The status of the bank account.
   *
   */
  status: ShopifyPaymentsBankAccountStatus
}

/**
 * A bank account that can receive payouts.
 *
 */
export type ShopifyPaymentsBankAccountPayoutsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
  transactionType?: InputMaybe<ShopifyPaymentsPayoutTransactionType>
}

/**
 * An auto-generated type for paginating through multiple ShopifyPaymentsBankAccounts.
 *
 */
export type ShopifyPaymentsBankAccountConnection = {
  __typename?: 'ShopifyPaymentsBankAccountConnection'
  /** A list of edges. */
  edges: Array<ShopifyPaymentsBankAccountEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one ShopifyPaymentsBankAccount and a cursor during pagination.
 *
 */
export type ShopifyPaymentsBankAccountEdge = {
  __typename?: 'ShopifyPaymentsBankAccountEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of ShopifyPaymentsBankAccountEdge. */
  node: ShopifyPaymentsBankAccount
}

/** The bank account status. */
export enum ShopifyPaymentsBankAccountStatus {
  /** A payout to the bank account failed. */
  Errored = 'ERRORED',
  /** A bank account that hasn't had any activity and that's not validated. */
  New = 'NEW',
  /** It was determined that the bank account exists. */
  Validated = 'VALIDATED',
  /** Bank account validation was successful. */
  Verified = 'VERIFIED',
}

/** The charge descriptors for a payments account. */
export type ShopifyPaymentsChargeStatementDescriptor = {
  /** The default charge statement descriptor. */
  default?: Maybe<Scalars['String']>
  /** The prefix of the statement descriptor. */
  prefix: Scalars['String']
}

/** The charge descriptors for a payments account. */
export type ShopifyPaymentsDefaultChargeStatementDescriptor =
  ShopifyPaymentsChargeStatementDescriptor & {
    __typename?: 'ShopifyPaymentsDefaultChargeStatementDescriptor'
    /** The default charge statement descriptor. */
    default?: Maybe<Scalars['String']>
    /** The prefix of the statement descriptor. */
    prefix: Scalars['String']
  }

/** A dispute occurs when a buyer questions the legitimacy of a charge with their financial institution. */
export type ShopifyPaymentsDispute = LegacyInteroperability &
  Node & {
    __typename?: 'ShopifyPaymentsDispute'
    /** The total amount disputed by the cardholder. */
    amount: MoneyV2
    /** The deadline for evidence submission. */
    evidenceDueBy?: Maybe<Scalars['Date']>
    /** The date when evidence was sent. Returns null if evidence has not yet been sent. */
    evidenceSentOn?: Maybe<Scalars['Date']>
    /** The date when this dispute was resolved. Returns null if the dispute is not yet resolved. */
    finalizedOn?: Maybe<Scalars['Date']>
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The date when this dispute was initiated. */
    initiatedAt: Scalars['DateTime']
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** The order that contains the charge that is under dispute. */
    order?: Maybe<Order>
    /** The reason of the dispute. */
    reasonDetails: ShopifyPaymentsDisputeReasonDetails
    /** The current state of the dispute. */
    status: DisputeStatus
    /** Indicates if this dispute is still in the inquiry phase or has turned into a chargeback. */
    type: DisputeType
  }

/**
 * An auto-generated type for paginating through multiple ShopifyPaymentsDisputes.
 *
 */
export type ShopifyPaymentsDisputeConnection = {
  __typename?: 'ShopifyPaymentsDisputeConnection'
  /** A list of edges. */
  edges: Array<ShopifyPaymentsDisputeEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one ShopifyPaymentsDispute and a cursor during pagination.
 *
 */
export type ShopifyPaymentsDisputeEdge = {
  __typename?: 'ShopifyPaymentsDisputeEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of ShopifyPaymentsDisputeEdge. */
  node: ShopifyPaymentsDispute
}

/** The reason for the dispute provided by the cardholder's bank. */
export enum ShopifyPaymentsDisputeReason {
  /** The customer's bank can't process the charge. */
  BankCannotProcess = 'BANK_CANNOT_PROCESS',
  /** The customer claims that the purchased product was returned or the transaction was otherwise canceled, but you haven't yet provided a refund or credit. */
  CreditNotProcessed = 'CREDIT_NOT_PROCESSED',
  /** The customer initiated the dispute. Contact the customer for additional details on why the payment was disputed. */
  CustomerInitiated = 'CUSTOMER_INITIATED',
  /** The customer's bank can't proceed with the debit since it hasn't been authorized. */
  DebitNotAuthorized = 'DEBIT_NOT_AUTHORIZED',
  /** The customer claims they were charged multiple times for the same product or service. */
  Duplicate = 'DUPLICATE',
  /** The cardholder claims that they didn’t authorize the payment. */
  Fraudulent = 'FRAUDULENT',
  /** The dispute is uncategorized, so you should contact the customer for additional details to find out why the payment was disputed. */
  General = 'GENERAL',
  /** The customer account associated with the purchase is incorrect. */
  IncorrectAccountDetails = 'INCORRECT_ACCOUNT_DETAILS',
  /** The customer's bank account has insufficient funds. */
  InsufficientFunds = 'INSUFFICIENT_FUNDS',
  /** The customer claims they did not receive the products or services purchased. */
  ProductNotReceived = 'PRODUCT_NOT_RECEIVED',
  /** The product or service was received but was defective, damaged, or not as described. */
  ProductUnacceptable = 'PRODUCT_UNACCEPTABLE',
  /** The customer claims that you continued to charge them after a subscription was canceled. */
  SubscriptionCancelled = 'SUBSCRIPTION_CANCELLED',
  /** The customer doesn’t recognize the payment appearing on their card statement. */
  Unrecognized = 'UNRECOGNIZED',
}

/** Details regarding a dispute reason. */
export type ShopifyPaymentsDisputeReasonDetails = {
  __typename?: 'ShopifyPaymentsDisputeReasonDetails'
  /** The raw code provided by the payment network. */
  networkReasonCode?: Maybe<Scalars['String']>
  /** The reason for the dispute provided by the cardholder's banks. */
  reason: ShopifyPaymentsDisputeReason
}

/** Presents all Shopify Payments information related to an extended authorization. */
export type ShopifyPaymentsExtendedAuthorization = {
  __typename?: 'ShopifyPaymentsExtendedAuthorization'
  /**
   * The time after which the extended authorization expires. After the expiry, the merchant is unable to capture the payment.
   *
   */
  extendedAuthorizationExpiresAt: Scalars['DateTime']
  /**
   * The time after which capture will incur an additional fee.
   *
   */
  standardAuthorizationExpiresAt: Scalars['DateTime']
}

/** The fraud settings of a payments account. */
export type ShopifyPaymentsFraudSettings = {
  __typename?: 'ShopifyPaymentsFraudSettings'
  /** Decline a charge if there is an AVS failure. */
  declineChargeOnAvsFailure: Scalars['Boolean']
  /** Decline a charge if there is an CVC failure. */
  declineChargeOnCvcFailure: Scalars['Boolean']
}

/** The charge descriptors for a Japanese payments account. */
export type ShopifyPaymentsJpChargeStatementDescriptor =
  ShopifyPaymentsChargeStatementDescriptor & {
    __typename?: 'ShopifyPaymentsJpChargeStatementDescriptor'
    /** The default charge statement descriptor. */
    default?: Maybe<Scalars['String']>
    /** The charge statement descriptor in kana. */
    kana?: Maybe<Scalars['String']>
    /** The charge statement descriptor in kanji. */
    kanji?: Maybe<Scalars['String']>
    /** The prefix of the statement descriptor. */
    prefix: Scalars['String']
  }

/** The notification settings for the account. */
export type ShopifyPaymentsNotificationSettings = {
  __typename?: 'ShopifyPaymentsNotificationSettings'
  /** Receive email notifications when new payouts are sent or payouts fail. */
  payouts: Scalars['Boolean']
}

/**
 * Payouts represent the movement of money between a merchant's Shopify
 * Payments balance and their bank account.
 *
 */
export type ShopifyPaymentsPayout = LegacyInteroperability &
  Node & {
    __typename?: 'ShopifyPaymentsPayout'
    /** The bank account for the payout. */
    bankAccount?: Maybe<ShopifyPaymentsBankAccount>
    /**
     * The total amount and currency of the payout.
     * @deprecated Use `net` instead
     */
    gross: MoneyV2
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /**
     * The exact time when the payout was issued. The payout only contains
     * balance transactions that were available at this time.
     *
     */
    issuedAt: Scalars['DateTime']
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** The total amount and currency of the payout. */
    net: MoneyV2
    /** The transfer status of the payout. */
    status: ShopifyPaymentsPayoutStatus
    /** The summary of the payout. */
    summary: ShopifyPaymentsPayoutSummary
    /** The direction of the payout. */
    transactionType: ShopifyPaymentsPayoutTransactionType
  }

/**
 * An auto-generated type for paginating through multiple ShopifyPaymentsPayouts.
 *
 */
export type ShopifyPaymentsPayoutConnection = {
  __typename?: 'ShopifyPaymentsPayoutConnection'
  /** A list of edges. */
  edges: Array<ShopifyPaymentsPayoutEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one ShopifyPaymentsPayout and a cursor during pagination.
 *
 */
export type ShopifyPaymentsPayoutEdge = {
  __typename?: 'ShopifyPaymentsPayoutEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of ShopifyPaymentsPayoutEdge. */
  node: ShopifyPaymentsPayout
}

/** The interval at which payouts are sent to the connected bank account. */
export enum ShopifyPaymentsPayoutInterval {
  /** Each business day. */
  Daily = 'DAILY',
  /** Payouts will not be automatically made. */
  Manual = 'MANUAL',
  /** Each month, on the day of month specified by monthlyAnchor. */
  Monthly = 'MONTHLY',
  /** Each week, on the day of week specified by weeklyAnchor. */
  Weekly = 'WEEKLY',
}

/** The payment schedule for a payments account. */
export type ShopifyPaymentsPayoutSchedule = {
  __typename?: 'ShopifyPaymentsPayoutSchedule'
  /** The interval at which payouts are sent to the connected bank account. */
  interval: ShopifyPaymentsPayoutInterval
  /**
   * The day of the month funds will be paid out.
   *
   * The value can be any day of the month from the 1st to the 31st.
   * If the payment interval is set to monthly, this value will be used.
   * Payouts scheduled between 29-31st of the month are sent on the last day of shorter months.
   *
   */
  monthlyAnchor?: Maybe<Scalars['Int']>
  /**
   * The day of the week funds will be paid out.
   *
   * The value can be any weekday from Monday to Friday.
   * If the payment interval is set to weekly, this value will be used.
   *
   */
  weeklyAnchor?: Maybe<DayOfTheWeek>
}

/** The transfer status of the payout. */
export enum ShopifyPaymentsPayoutStatus {
  /** The payout has been canceled by Shopify. */
  Canceled = 'CANCELED',
  /** The payout has been declined by the bank. */
  Failed = 'FAILED',
  /** The payout has been submitted to the bank. */
  InTransit = 'IN_TRANSIT',
  /** The payout has been successfully deposited into the bank. */
  Paid = 'PAID',
  /**
   * The payout has been created and had transactions assigned to it, but
   * it has not yet been submitted to the bank.
   *
   */
  Scheduled = 'SCHEDULED',
}

/**
 * Breakdown of the total fees and gross of each of the different types of transactions associated
 * with the payout.
 *
 */
export type ShopifyPaymentsPayoutSummary = {
  __typename?: 'ShopifyPaymentsPayoutSummary'
  /** Total fees for all adjustments including disputes. */
  adjustmentsFee: MoneyV2
  /** Total gross amount for all adjustments including disputes. */
  adjustmentsGross: MoneyV2
  /** Total fees for all charges. */
  chargesFee: MoneyV2
  /** Total gross amount for all charges. */
  chargesGross: MoneyV2
  /** Total fees for all refunds. */
  refundsFee: MoneyV2
  /** Total gross amount for all refunds. */
  refundsFeeGross: MoneyV2
  /** Total fees for all reserved funds. */
  reservedFundsFee: MoneyV2
  /** Total gross amount for all reserved funds. */
  reservedFundsGross: MoneyV2
  /** Total fees for all retried payouts. */
  retriedPayoutsFee: MoneyV2
  /** Total gross amount for all retried payouts. */
  retriedPayoutsGross: MoneyV2
}

/** The possible transaction types for a payout. */
export enum ShopifyPaymentsPayoutTransactionType {
  /** The payout is a deposit. */
  Deposit = 'DEPOSIT',
  /** The payout is a withdrawal. */
  Withdrawal = 'WITHDRAWAL',
}

/** Presents all Shopify Payments specific information related to an order refund. */
export type ShopifyPaymentsRefundSet = {
  __typename?: 'ShopifyPaymentsRefundSet'
  /**
   * The acquirer reference number (ARN) code generated for Visa/Mastercard transactions.
   *
   */
  acquirerReferenceNumber?: Maybe<Scalars['String']>
}

/** Presents all Shopify Payments specific information related to an order transaction. */
export type ShopifyPaymentsTransactionSet = {
  __typename?: 'ShopifyPaymentsTransactionSet'
  /**
   * Contains all fields related to an extended authorization.
   *
   */
  extendedAuthorizationSet?: Maybe<ShopifyPaymentsExtendedAuthorization>
  /**
   * Contains all fields related to a refund.
   *
   */
  refundSet?: Maybe<ShopifyPaymentsRefundSet>
}

/**
 * Each subject (individual) of an account has a verification object giving
 *  information about the verification state.
 *
 */
export type ShopifyPaymentsVerification = Node & {
  __typename?: 'ShopifyPaymentsVerification'
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The status of the verification. */
  status: ShopifyPaymentsVerificationStatus
  /** The subject/individual who has to be verified. */
  subject: ShopifyPaymentsVerificationSubject
}

/** A document which can be used to verify an individual. */
export type ShopifyPaymentsVerificationDocument = {
  __typename?: 'ShopifyPaymentsVerificationDocument'
  /** True if the back side of the document is required. */
  backRequired: Scalars['Boolean']
  /** True if the front side of the document is required. */
  frontRequired: Scalars['Boolean']
  /** The type of the document which can be used for verification. */
  type: ShopifyPaymentsVerificationDocumentType
}

/** The types of possible verification documents. */
export enum ShopifyPaymentsVerificationDocumentType {
  /** The subject's driver's license. */
  DriversLicense = 'DRIVERS_LICENSE',
  /** A government's identification document of the subject. */
  GovernmentIdentification = 'GOVERNMENT_IDENTIFICATION',
  /** The subject's passport. */
  Passport = 'PASSPORT',
}

/** The status of a verification. */
export enum ShopifyPaymentsVerificationStatus {
  /** The verification request has been submitted but a response has not yet been given. */
  Pending = 'PENDING',
  /** The verification has not yet been verified. */
  Unverified = 'UNVERIFIED',
  /** The verification has been verified. */
  Verified = 'VERIFIED',
}

/** The verification subject represents an individual that has to be verified. */
export type ShopifyPaymentsVerificationSubject = {
  __typename?: 'ShopifyPaymentsVerificationSubject'
  /** The family name of the individual to verify. */
  familyName: Scalars['String']
  /** The given name of the individual to verify. */
  givenName: Scalars['String']
}

/** Image to be uploaded. */
export type StageImageInput = {
  /** Image filename. */
  filename: Scalars['String']
  /** HTTP method to be used by the Staged Upload. */
  httpMethod?: InputMaybe<StagedUploadHttpMethodType>
  /** Image MIME type. */
  mimeType: Scalars['String']
  /** Image resource. */
  resource: StagedUploadTargetGenerateUploadResource
}

/** Staged media target information. */
export type StagedMediaUploadTarget = {
  __typename?: 'StagedMediaUploadTarget'
  /** Parameters of the media to be uploaded. */
  parameters: Array<StagedUploadParameter>
  /** The url to be passed as the original_source for the product create media mutation input. */
  resourceUrl?: Maybe<Scalars['URL']>
  /** Media URL. */
  url?: Maybe<Scalars['URL']>
}

/** Possible HTTP method of a staged upload target. */
export enum StagedUploadHttpMethodType {
  /** The POST HTTP method. */
  Post = 'POST',
  /** The PUT HTTP method. */
  Put = 'PUT',
}

/** Media to be uploaded. */
export type StagedUploadInput = {
  /** Size of the file to upload, in bytes. This is required for VIDEO and MODEL_3D resources. */
  fileSize?: InputMaybe<Scalars['UnsignedInt64']>
  /** Media filename. */
  filename: Scalars['String']
  /** HTTP method to be used by the Staged Upload. */
  httpMethod?: InputMaybe<StagedUploadHttpMethodType>
  /** Media MIME type. */
  mimeType: Scalars['String']
  /** Media resource. */
  resource: StagedUploadTargetGenerateUploadResource
}

/** Upload parameter of a Media. */
export type StagedUploadParameter = {
  __typename?: 'StagedUploadParameter'
  /** Parameter name. */
  name: Scalars['String']
  /** Parameter value. */
  value: Scalars['String']
}

/** Staged target information. */
export type StagedUploadTarget = {
  __typename?: 'StagedUploadTarget'
  /** Parameters of an image to be uploaded. */
  parameters: Array<ImageUploadParameter>
  /** Image URL. */
  url: Scalars['String']
}

/** Specifies the fields required to generate the URL and parameters needed to upload an asset to Shopify. */
export type StagedUploadTargetGenerateInput = {
  /** The size of the file to upload, in bytes. */
  fileSize?: InputMaybe<Scalars['UnsignedInt64']>
  /** The filename of the asset being uploaded. */
  filename: Scalars['String']
  /** The HTTP method to be used by the staged upload. */
  httpMethod?: InputMaybe<StagedUploadHttpMethodType>
  /** The MIME type of the asset being uploaded. */
  mimeType: Scalars['String']
  /** The resource type being uploaded. */
  resource: StagedUploadTargetGenerateUploadResource
}

/** Return type for `stagedUploadTargetGenerate` mutation. */
export type StagedUploadTargetGeneratePayload = {
  __typename?: 'StagedUploadTargetGeneratePayload'
  /** The signed parameters that can be used to upload the asset. */
  parameters: Array<MutationsStagedUploadTargetGenerateUploadParameter>
  /** The signed URL where the asset can be uploaded. */
  url: Scalars['String']
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** The resource type to receive. */
export enum StagedUploadTargetGenerateUploadResource {
  /** BulkOperation resource representation. */
  BulkMutationVariables = 'BULK_MUTATION_VARIABLES',
  /** A collection image. */
  CollectionImage = 'COLLECTION_IMAGE',
  /** Merchandising::GenericFile resource representation. */
  File = 'FILE',
  /** Merchandising::Image resource representation. */
  Image = 'IMAGE',
  /** Merchandising::Model3d resource representation. */
  Model_3D = 'MODEL_3D',
  /** A product image. */
  ProductImage = 'PRODUCT_IMAGE',
  /** A shop image. */
  ShopImage = 'SHOP_IMAGE',
  /** A timeline event. */
  Timeline = 'TIMELINE',
  /** RedirectImport resource representation. */
  UrlRedirectImport = 'URL_REDIRECT_IMPORT',
  /** Merchandising::Video resource representation. */
  Video = 'VIDEO',
}

/** Return type for `stagedUploadTargetsGenerate` mutation. */
export type StagedUploadTargetsGeneratePayload = {
  __typename?: 'StagedUploadTargetsGeneratePayload'
  /** The staged upload targets that were generated. */
  urls?: Maybe<Array<StagedUploadTarget>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `stagedUploadsCreate` mutation. */
export type StagedUploadsCreatePayload = {
  __typename?: 'StagedUploadsCreatePayload'
  /** The staged upload targets that were generated. */
  stagedTargets?: Maybe<Array<StagedMediaUploadTarget>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `standardMetafieldDefinitionEnable` mutation. */
export type StandardMetafieldDefinitionEnablePayload = {
  __typename?: 'StandardMetafieldDefinitionEnablePayload'
  /** The metafield definition that was created. */
  createdDefinition?: Maybe<MetafieldDefinition>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<StandardMetafieldDefinitionEnableUserError>
}

/** An error that occurs during the execution of `StandardMetafieldDefinitionEnable`. */
export type StandardMetafieldDefinitionEnableUserError = DisplayableError & {
  __typename?: 'StandardMetafieldDefinitionEnableUserError'
  /** The error code. */
  code?: Maybe<StandardMetafieldDefinitionEnableUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `StandardMetafieldDefinitionEnableUserError`. */
export enum StandardMetafieldDefinitionEnableUserErrorCode {
  /** The input value is invalid. */
  Invalid = 'INVALID',
  /** The maximum number of definitions per owner type has been exceeded. */
  LimitExceeded = 'LIMIT_EXCEEDED',
  /** The input value is already taken. */
  Taken = 'TAKEN',
  /** The standard metafield definition template was not found. */
  TemplateNotFound = 'TEMPLATE_NOT_FOUND',
  /** The namespace and key is already in use for a set of your metafields. */
  UnstructuredAlreadyExists = 'UNSTRUCTURED_ALREADY_EXISTS',
}

/**
 * Standard metafield definition templates provide preset configurations to create metafield definitions.
 * Each template has a specific namespace and key that we've reserved to have specific meanings for common use cases.
 *
 * Refer to the [list of standard metafield definitions](https://shopify.dev/apps/metafields/definitions/standard-definitions).
 *
 */
export type StandardMetafieldDefinitionTemplate = Node & {
  __typename?: 'StandardMetafieldDefinitionTemplate'
  /** The description of the standard metafield definition. */
  description?: Maybe<Scalars['String']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The key owned by the definition after the definition has been activated. */
  key: Scalars['String']
  /** The human-readable name for the standard metafield definition. */
  name: Scalars['String']
  /** The namespace owned by the definition after the definition has been activated. */
  namespace: Scalars['String']
  /** The list of resource types that the standard metafield definition can be applied to. */
  ownerTypes: Array<MetafieldOwnerType>
  /** The associated [metafield definition type](https://shopify.dev/apps/metafields/definitions/types) that the metafield stores. */
  type: MetafieldDefinitionType
  /** The configured validations for the standard metafield definition. */
  validations: Array<MetafieldDefinitionValidation>
}

/**
 * An auto-generated type for paginating through multiple StandardMetafieldDefinitionTemplates.
 *
 */
export type StandardMetafieldDefinitionTemplateConnection = {
  __typename?: 'StandardMetafieldDefinitionTemplateConnection'
  /** A list of edges. */
  edges: Array<StandardMetafieldDefinitionTemplateEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one StandardMetafieldDefinitionTemplate and a cursor during pagination.
 *
 */
export type StandardMetafieldDefinitionTemplateEdge = {
  __typename?: 'StandardMetafieldDefinitionTemplateEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of StandardMetafieldDefinitionTemplateEdge. */
  node: StandardMetafieldDefinitionTemplate
}

/** Represents the details of a specific type of product within the [Shopify product taxonomy](https://help.shopify.com/txt/product_taxonomy/en.txt). */
export type StandardizedProductType = {
  __typename?: 'StandardizedProductType'
  /** The product taxonomy node associated with the standardized product type. */
  productTaxonomyNode?: Maybe<ProductTaxonomyNode>
}

/** Provides the fields and values to use when adding a standard product type to a product. The [Shopify product taxonomy](https://help.shopify.com/txt/product_taxonomy/en.txt) contains the full list of available values. */
export type StandardizedProductTypeInput = {
  /** The id of the node in the Shopify taxonomy that represents the product type. */
  productTaxonomyNodeId: Scalars['ID']
}

/**
 * Token used to delegate unauthenticated access scopes to clients that need to access the unautheticated Storefront API.
 *
 */
export type StorefrontAccessToken = Node & {
  __typename?: 'StorefrontAccessToken'
  /** List of permissions associated with the token. */
  accessScopes: Array<AccessScope>
  /** The issued public access token. */
  accessToken: Scalars['String']
  /** The date and time when the public access token was created. */
  createdAt: Scalars['DateTime']
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** An arbitrary title for each token determined by the developer, used for reference         purposes. */
  title: Scalars['String']
  /** The date and time when the storefront access token was updated. */
  updatedAt: Scalars['DateTime']
}

/**
 * An auto-generated type for paginating through multiple StorefrontAccessTokens.
 *
 */
export type StorefrontAccessTokenConnection = {
  __typename?: 'StorefrontAccessTokenConnection'
  /** A list of edges. */
  edges: Array<StorefrontAccessTokenEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `storefrontAccessTokenCreate` mutation. */
export type StorefrontAccessTokenCreatePayload = {
  __typename?: 'StorefrontAccessTokenCreatePayload'
  /** The user's shop. */
  shop: Shop
  /** The storefront access token. */
  storefrontAccessToken?: Maybe<StorefrontAccessToken>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Specifies the input fields to delete a storefront access token. */
export type StorefrontAccessTokenDeleteInput = {
  /** The ID of the storefront access token to delete. */
  id: Scalars['ID']
}

/** Return type for `storefrontAccessTokenDelete` mutation. */
export type StorefrontAccessTokenDeletePayload = {
  __typename?: 'StorefrontAccessTokenDeletePayload'
  /** The ID of the deleted storefront access token. */
  deletedStorefrontAccessTokenId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one StorefrontAccessToken and a cursor during pagination.
 *
 */
export type StorefrontAccessTokenEdge = {
  __typename?: 'StorefrontAccessTokenEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of StorefrontAccessTokenEdge. */
  node: StorefrontAccessToken
}

/** Specifies the input fields for a storefront access token. */
export type StorefrontAccessTokenInput = {
  /** A title for the storefront access token. */
  title: Scalars['String']
}

/**
 * An auto-generated type for paginating through a list of Strings.
 *
 */
export type StringConnection = {
  __typename?: 'StringConnection'
  /** A list of edges. */
  edges: Array<StringEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one String and a cursor during pagination.
 *
 */
export type StringEdge = {
  __typename?: 'StringEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of StringEdge. */
  node: Scalars['String']
}

/** Represents an applied code discount. */
export type SubscriptionAppliedCodeDiscount = {
  __typename?: 'SubscriptionAppliedCodeDiscount'
  /** The unique identifier. */
  id: Scalars['ID']
  /** The redeem code of the discount that applies on the subscription. */
  redeemCode: Scalars['String']
  /** The reason that the discount on the subscription draft is rejected. */
  rejectionReason?: Maybe<SubscriptionDiscountRejectionReason>
}

/**
 * A record of an execution of the subscription billing process. Billing attempts use
 * idempotency keys to avoid duplicate order creation. A successful billing attempt
 * will create an order.
 *
 */
export type SubscriptionBillingAttempt = Node & {
  __typename?: 'SubscriptionBillingAttempt'
  /** The date and time when the billing attempt was completed. */
  completedAt?: Maybe<Scalars['DateTime']>
  /** The date and time when the billing attempt was created. */
  createdAt: Scalars['DateTime']
  /** A code corresponding to a payment error during processing. */
  errorCode?: Maybe<SubscriptionBillingAttemptErrorCode>
  /** A message describing a payment error during processing. */
  errorMessage?: Maybe<Scalars['String']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** A unique key generated by the client to avoid duplicate payments. */
  idempotencyKey: Scalars['String']
  /**
   * The URL where the customer needs to be redirected so they can complete the 3D Secure payment flow.
   *
   */
  nextActionUrl?: Maybe<Scalars['URL']>
  /** The result of this billing attempt if completed successfully. */
  order?: Maybe<Order>
  /** Whether or not the billing attempt is still processing. */
  ready: Scalars['Boolean']
  /** The subscription contract. */
  subscriptionContract: SubscriptionContract
}

/**
 * An auto-generated type for paginating through multiple SubscriptionBillingAttempts.
 *
 */
export type SubscriptionBillingAttemptConnection = {
  __typename?: 'SubscriptionBillingAttemptConnection'
  /** A list of edges. */
  edges: Array<SubscriptionBillingAttemptEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `subscriptionBillingAttemptCreate` mutation. */
export type SubscriptionBillingAttemptCreatePayload = {
  __typename?: 'SubscriptionBillingAttemptCreatePayload'
  /** The subscription billing attempt. */
  subscriptionBillingAttempt?: Maybe<SubscriptionBillingAttempt>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<BillingAttemptUserError>
}

/**
 * An auto-generated type which holds one SubscriptionBillingAttempt and a cursor during pagination.
 *
 */
export type SubscriptionBillingAttemptEdge = {
  __typename?: 'SubscriptionBillingAttemptEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of SubscriptionBillingAttemptEdge. */
  node: SubscriptionBillingAttempt
}

/**
 * The possible error codes associated with making billing attempts. The error codes supplement the
 * `error_message` to provide consistent results and help with dunning management.
 *
 */
export enum SubscriptionBillingAttemptErrorCode {
  /**
   * There was an error during the authentication.
   *
   */
  AuthenticationError = 'AUTHENTICATION_ERROR',
  /** Payment method was canceled by buyer. */
  BuyerCanceledPaymentMethod = 'BUYER_CANCELED_PAYMENT_METHOD',
  /** Customer is invalid. */
  CustomerInvalid = 'CUSTOMER_INVALID',
  /** Customer was not found. */
  CustomerNotFound = 'CUSTOMER_NOT_FOUND',
  /**
   * Payment method is expired.
   *
   */
  ExpiredPaymentMethod = 'EXPIRED_PAYMENT_METHOD',
  /**
   * Payment method is invalid. Please update or create a new payment method.
   *
   */
  InvalidPaymentMethod = 'INVALID_PAYMENT_METHOD',
  /** The shipping address is either missing or invalid. */
  InvalidShippingAddress = 'INVALID_SHIPPING_ADDRESS',
  /**
   * Payment method was declined by processor.
   *
   */
  PaymentMethodDeclined = 'PAYMENT_METHOD_DECLINED',
  /**
   * Payment method was not found.
   *
   */
  PaymentMethodNotFound = 'PAYMENT_METHOD_NOT_FOUND',
  /**
   * Payment provider is not enabled.
   *
   */
  PaymentProviderIsNotEnabled = 'PAYMENT_PROVIDER_IS_NOT_ENABLED',
  /**
   * Gateway is in test mode and attempted to bill a live payment method.
   *
   */
  TestMode = 'TEST_MODE',
  /**
   * There was an unexpected error during the billing attempt.
   *
   */
  UnexpectedError = 'UNEXPECTED_ERROR',
}

/** Specifies the fields required to complete a subscription billing attempt. */
export type SubscriptionBillingAttemptInput = {
  /** A unique key generated by the client to avoid duplicate payments. For more information, refer to [Idempotent requests](https://shopify.dev/api/usage/idempotent-requests). */
  idempotencyKey: Scalars['String']
}

/** Represents a Subscription Billing Policy. */
export type SubscriptionBillingPolicy = {
  __typename?: 'SubscriptionBillingPolicy'
  /** Specific anchor dates upon which the billing interval calculations should be made. */
  anchors: Array<SellingPlanAnchor>
  /** The kind of interval that is associated with this schedule (e.g. Monthly, Weekly, etc). */
  interval: SellingPlanInterval
  /** The number of billing intervals between invoices. */
  intervalCount: Scalars['Int']
  /** Maximum amount of cycles after which the subscription ends. */
  maxCycles?: Maybe<Scalars['Int']>
  /** Minimum amount of cycles required in the subscription. */
  minCycles?: Maybe<Scalars['Int']>
}

/** Specifies the input fields for a Subscription Billing Policy. */
export type SubscriptionBillingPolicyInput = {
  /** Specific anchor dates upon which the billing interval calculations should be made. */
  anchors?: InputMaybe<Array<SellingPlanAnchorInput>>
  /** The kind of interval that is associated with this schedule (e.g. Monthly, Weekly, etc). */
  interval: SellingPlanInterval
  /** The number of billing intervals between invoices. */
  intervalCount: Scalars['Int']
  /** Maximum amount of cycles required in the subscription. */
  maxCycles?: InputMaybe<Scalars['Int']>
  /** Minimum amount of cycles required in the subscription. */
  minCycles?: InputMaybe<Scalars['Int']>
}

/** Represents a Subscription Contract. */
export type SubscriptionContract = Node & {
  __typename?: 'SubscriptionContract'
  /** The subscription app that this subscription contract is registered to. */
  app?: Maybe<App>
  /** URL of the subscription contract page on the subscription app. */
  appAdminUrl?: Maybe<Scalars['URL']>
  /** The list of billing attempts associated with the subscription contract. */
  billingAttempts: SubscriptionBillingAttemptConnection
  /** The billing policy associated with the subscription contract. */
  billingPolicy: SubscriptionBillingPolicy
  /** The date and time when the subscription contract was created. */
  createdAt: Scalars['DateTime']
  /** The currency used for the subscription contract. */
  currencyCode: CurrencyCode
  /** The customer to whom the subscription contract belongs. */
  customer?: Maybe<Customer>
  /** The customer payment method used for the subscription contract. */
  customerPaymentMethod?: Maybe<CustomerPaymentMethod>
  /** The delivery method for each billing of the subscription contract. */
  deliveryMethod?: Maybe<SubscriptionDeliveryMethod>
  /** The delivery policy associated with the subscription contract. */
  deliveryPolicy: SubscriptionDeliveryPolicy
  /** The delivery price for each billing of the subscription contract. */
  deliveryPrice: MoneyV2
  /** The list of subscription discounts associated with the subscription contract. */
  discounts: SubscriptionManualDiscountConnection
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The current status of the last payment. */
  lastPaymentStatus?: Maybe<SubscriptionContractLastPaymentStatus>
  /** The number of lines associated with the subscription contract. */
  lineCount: Scalars['Int']
  /** The list of subscription lines associated with the subscription contract. */
  lines: SubscriptionLineConnection
  /** The next billing date for the subscription contract. */
  nextBillingDate?: Maybe<Scalars['DateTime']>
  /** The note field that will be applied to the generated orders. */
  note?: Maybe<Scalars['String']>
  /** A list of the subscription contract's orders. */
  orders: OrderConnection
  /** The order from which this contract originated. */
  originOrder?: Maybe<Order>
  /** The current status of the subscription contract. */
  status: SubscriptionContractSubscriptionStatus
  /** The date and time when the subscription contract was updated. */
  updatedAt: Scalars['DateTime']
}

/** Represents a Subscription Contract. */
export type SubscriptionContractBillingAttemptsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a Subscription Contract. */
export type SubscriptionContractCustomerPaymentMethodArgs = {
  showRevoked?: InputMaybe<Scalars['Boolean']>
}

/** Represents a Subscription Contract. */
export type SubscriptionContractDiscountsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a Subscription Contract. */
export type SubscriptionContractLinesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a Subscription Contract. */
export type SubscriptionContractOrdersArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/**
 * An auto-generated type for paginating through multiple SubscriptionContracts.
 *
 */
export type SubscriptionContractConnection = {
  __typename?: 'SubscriptionContractConnection'
  /** A list of edges. */
  edges: Array<SubscriptionContractEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Specifies the input fields required to create a Subscription Contract. */
export type SubscriptionContractCreateInput = {
  /** The attributes used as input for the Subscription Draft. */
  contract: SubscriptionDraftInput
  /** The currency used for the subscription contract. */
  currencyCode: CurrencyCode
  /** The ID of the customer to associate with the subscription contract. */
  customerId: Scalars['ID']
  /** The next billing date for the subscription contract. */
  nextBillingDate: Scalars['DateTime']
}

/** Return type for `subscriptionContractCreate` mutation. */
export type SubscriptionContractCreatePayload = {
  __typename?: 'SubscriptionContractCreatePayload'
  /** The Subscription Contract object. */
  draft?: Maybe<SubscriptionDraft>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SubscriptionDraftUserError>
}

/**
 * An auto-generated type which holds one SubscriptionContract and a cursor during pagination.
 *
 */
export type SubscriptionContractEdge = {
  __typename?: 'SubscriptionContractEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of SubscriptionContractEdge. */
  node: SubscriptionContract
}

/** Possible error codes that can be returned by `SubscriptionContractUserError`. */
export enum SubscriptionContractErrorCode {
  /** The input value is invalid. */
  Invalid = 'INVALID',
}

/** Possible status values of the last payment on a subscription contract. */
export enum SubscriptionContractLastPaymentStatus {
  /** Failed subscription billing attempt. */
  Failed = 'FAILED',
  /** Successful subscription billing attempt. */
  Succeeded = 'SUCCEEDED',
}

/** Return type for `subscriptionContractSetNextBillingDate` mutation. */
export type SubscriptionContractSetNextBillingDatePayload = {
  __typename?: 'SubscriptionContractSetNextBillingDatePayload'
  /** The updated Subscription Contract object. */
  contract?: Maybe<SubscriptionContract>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SubscriptionContractUserError>
}

/** Possible status values of a subscription. */
export enum SubscriptionContractSubscriptionStatus {
  /** Active subscription contract. */
  Active = 'ACTIVE',
  /** Cancelled subscription contract. */
  Cancelled = 'CANCELLED',
  /** Expired subscription contract. */
  Expired = 'EXPIRED',
  /** Failed subscription contract. */
  Failed = 'FAILED',
  /** Paused subscription contract. */
  Paused = 'PAUSED',
}

/** Return type for `subscriptionContractUpdate` mutation. */
export type SubscriptionContractUpdatePayload = {
  __typename?: 'SubscriptionContractUpdatePayload'
  /** The Subscription Contract object. */
  draft?: Maybe<SubscriptionDraft>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SubscriptionDraftUserError>
}

/** Represents a Subscription Contract error. */
export type SubscriptionContractUserError = DisplayableError & {
  __typename?: 'SubscriptionContractUserError'
  /** The error code. */
  code?: Maybe<SubscriptionContractErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Represents a Subscription Line Pricing Cycle Adjustment. */
export type SubscriptionCyclePriceAdjustment = {
  __typename?: 'SubscriptionCyclePriceAdjustment'
  /** Price adjustment type. */
  adjustmentType: SellingPlanPricingPolicyAdjustmentType
  /** Price adjustment value. */
  adjustmentValue: SellingPlanPricingPolicyAdjustmentValue
  /** The number of cycles required before this pricing policy applies. */
  afterCycle: Scalars['Int']
  /** The computed price after the adjustments applied. */
  computedPrice: MoneyV2
}

/** Describes the delivery method to use to get the physical goods to the customer. */
export type SubscriptionDeliveryMethod = SubscriptionDeliveryMethodShipping

/**
 * Specifies delivery method fields for a subscription draft.
 * This is an input union: one, and only one, field can be provided.
 * The field provided will determine which delivery method is to be used.
 *
 * Note: Only `shipping` is supported for now, but other inputs will be
 * added as they become supported in subscriptions.
 *
 */
export type SubscriptionDeliveryMethodInput = {
  /** Shipping delivery method input. */
  shipping?: InputMaybe<SubscriptionDeliveryMethodShippingInput>
}

/** Represents a shipping delivery method: a mailing address and a shipping option. */
export type SubscriptionDeliveryMethodShipping = {
  __typename?: 'SubscriptionDeliveryMethodShipping'
  /** The address to ship to. */
  address: SubscriptionMailingAddress
  /** The details of the shipping method to use. */
  shippingOption: SubscriptionDeliveryMethodShippingOption
}

/**
 * Specifies shipping delivery method fields.
 *
 * This input accepts partial input. When a field is not provided,
 * its prior value is left unchanged.
 *
 */
export type SubscriptionDeliveryMethodShippingInput = {
  /** The address to ship to. */
  address?: InputMaybe<MailingAddressInput>
  /** The details of the shipping method to use. */
  shippingOption?: InputMaybe<SubscriptionDeliveryMethodShippingOptionInput>
}

/** Represents the selected shipping option on a subscription contract. */
export type SubscriptionDeliveryMethodShippingOption = {
  __typename?: 'SubscriptionDeliveryMethodShippingOption'
  /** The carrier service of the shipping option. */
  carrierService?: Maybe<DeliveryCarrierService>
  /** The code of the shipping option. */
  code?: Maybe<Scalars['String']>
  /** The description of the shipping option. */
  description?: Maybe<Scalars['String']>
  /** The presentment title of the shipping option. */
  presentmentTitle?: Maybe<Scalars['String']>
  /** The title of the shipping option. */
  title?: Maybe<Scalars['String']>
}

/** Specifies shipping option fields. */
export type SubscriptionDeliveryMethodShippingOptionInput = {
  /** The carrier service ID of the shipping option. */
  carrierServiceId?: InputMaybe<Scalars['ID']>
  /** The code of the shipping option. */
  code?: InputMaybe<Scalars['String']>
  /** The description of the shipping option. */
  description?: InputMaybe<Scalars['String']>
  /** The presentment title of the shipping option. */
  presentmentTitle?: InputMaybe<Scalars['String']>
  /** The title of the shipping option. */
  title?: InputMaybe<Scalars['String']>
}

/** Represents a Subscription Delivery Policy. */
export type SubscriptionDeliveryPolicy = {
  __typename?: 'SubscriptionDeliveryPolicy'
  /** Specific anchor dates upon which the delivery interval calculations should be made. */
  anchors: Array<SellingPlanAnchor>
  /** The kind of interval that is associated with this schedule (e.g. Monthly, Weekly, etc). */
  interval: SellingPlanInterval
  /** The number of delivery intervals between deliveries. */
  intervalCount: Scalars['Int']
}

/** Specifies the input fields for a Subscription Delivery Policy. */
export type SubscriptionDeliveryPolicyInput = {
  /** Specific anchor dates upon which the delivery interval calculations should be made. */
  anchors?: InputMaybe<Array<SellingPlanAnchorInput>>
  /** The kind of interval that is associated with this schedule (e.g. Monthly, Weekly, etc). */
  interval: SellingPlanInterval
  /** The number of billing intervals between invoices. */
  intervalCount: Scalars['Int']
}

/** Subscription draft discount types. */
export type SubscriptionDiscount =
  | SubscriptionAppliedCodeDiscount
  | SubscriptionManualDiscount

/** Represents what a particular discount reduces from a line price. */
export type SubscriptionDiscountAllocation = {
  __typename?: 'SubscriptionDiscountAllocation'
  /** Allocation amount. */
  amount: MoneyV2
  /** Discount that created the allocation. */
  discount: SubscriptionDiscount
}

/**
 * An auto-generated type for paginating through multiple SubscriptionDiscounts.
 *
 */
export type SubscriptionDiscountConnection = {
  __typename?: 'SubscriptionDiscountConnection'
  /** A list of edges. */
  edges: Array<SubscriptionDiscountEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one SubscriptionDiscount and a cursor during pagination.
 *
 */
export type SubscriptionDiscountEdge = {
  __typename?: 'SubscriptionDiscountEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of SubscriptionDiscountEdge. */
  node: SubscriptionDiscount
}

/** Represents the subscription lines the discount applies on. */
export type SubscriptionDiscountEntitledLines = {
  __typename?: 'SubscriptionDiscountEntitledLines'
  /** Specify whether the subscription discount will apply on all subscription lines. */
  all: Scalars['Boolean']
  /** The list of subscription lines associated with the subscription discount. */
  lines: SubscriptionLineConnection
}

/** Represents the subscription lines the discount applies on. */
export type SubscriptionDiscountEntitledLinesLinesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** The value of the discount and how it will be applied. */
export type SubscriptionDiscountFixedAmountValue = {
  __typename?: 'SubscriptionDiscountFixedAmountValue'
  /** The fixed amount value of the discount. */
  amount: MoneyV2
  /** Whether the amount is applied per item. */
  appliesOnEachItem: Scalars['Boolean']
}

/** The percentage value of the discount. */
export type SubscriptionDiscountPercentageValue = {
  __typename?: 'SubscriptionDiscountPercentageValue'
  /** The percentage value of the discount. */
  percentage: Scalars['Int']
}

/** The reason a discount on a subscription draft was rejected. */
export enum SubscriptionDiscountRejectionReason {
  /** Discount is inactive. */
  CurrentlyInactive = 'CURRENTLY_INACTIVE',
  /** Given customer does not qualify for the discount. */
  CustomerNotEligible = 'CUSTOMER_NOT_ELIGIBLE',
  /** Customer usage limit has been reached. */
  CustomerUsageLimitReached = 'CUSTOMER_USAGE_LIMIT_REACHED',
  /** Purchase type does not qualify for the discount. */
  IncompatiblePurchaseType = 'INCOMPATIBLE_PURCHASE_TYPE',
  /** Internal error during discount code validation. */
  InternalError = 'INTERNAL_ERROR',
  /** Discount code is not found. */
  NotFound = 'NOT_FOUND',
  /** Discount does not apply to any of the given line items. */
  NoEntitledLineItems = 'NO_ENTITLED_LINE_ITEMS',
  /** No applicable shipping lines. */
  NoEntitledShippingLines = 'NO_ENTITLED_SHIPPING_LINES',
  /** Purchase amount of items does not qualify for the discount. */
  PurchaseNotInRange = 'PURCHASE_NOT_IN_RANGE',
  /** Quantity of items does not qualify for the discount. */
  QuantityNotInRange = 'QUANTITY_NOT_IN_RANGE',
  /** Discount usage limit has been reached. */
  UsageLimitReached = 'USAGE_LIMIT_REACHED',
}

/** The value of the discount and how it will be applied. */
export type SubscriptionDiscountValue =
  | SubscriptionDiscountFixedAmountValue
  | SubscriptionDiscountPercentageValue

/** Represents a Subscription Draft. */
export type SubscriptionDraft = Node & {
  __typename?: 'SubscriptionDraft'
  /** The billing policy for the subscription contract. */
  billingPolicy: SubscriptionBillingPolicy
  /** The currency used for the subscription contract. */
  currencyCode: CurrencyCode
  /** The customer to whom the subscription contract belongs. */
  customer: Customer
  /** The customer payment method used for the subscription contract. */
  customerPaymentMethod?: Maybe<CustomerPaymentMethod>
  /** The delivery method for each billing of the subscription contract. */
  deliveryMethod?: Maybe<SubscriptionDeliveryMethod>
  /** The delivery policy for the subscription contract. */
  deliveryPolicy: SubscriptionDeliveryPolicy
  /** The delivery price for each billing the subscription contract. */
  deliveryPrice?: Maybe<MoneyV2>
  /** The list of subscription discounts which will be associated with the subscription contract. */
  discounts: SubscriptionDiscountConnection
  /** The list of subscription discounts to be added to the subscription contract. */
  discountsAdded: SubscriptionDiscountConnection
  /** The list of subscription discounts to be removed from the subscription contract. */
  discountsRemoved: SubscriptionDiscountConnection
  /** The list of subscription discounts to be updated on the subscription contract. */
  discountsUpdated: SubscriptionDiscountConnection
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** The list of subscription lines which will be associated with the subscription contract. */
  lines: SubscriptionLineConnection
  /** The list of subscription lines to be added to the subscription contract. */
  linesAdded: SubscriptionLineConnection
  /** The list of subscription lines to be removed from the subscription contract. */
  linesRemoved: SubscriptionLineConnection
  /** The next billing date for the subscription contract. */
  nextBillingDate?: Maybe<Scalars['DateTime']>
  /** The note field that will be applied to the generated orders. */
  note?: Maybe<Scalars['String']>
  /** The original subscription contract. */
  originalContract?: Maybe<SubscriptionContract>
  /**
   * Available Shipping Options for a given delivery address. Returns NULL for pending requests.
   *
   */
  shippingOptions?: Maybe<SubscriptionShippingOptionResult>
  /** The current status of the subscription contract. */
  status?: Maybe<SubscriptionContractSubscriptionStatus>
}

/** Represents a Subscription Draft. */
export type SubscriptionDraftCustomerPaymentMethodArgs = {
  showRevoked?: InputMaybe<Scalars['Boolean']>
}

/** Represents a Subscription Draft. */
export type SubscriptionDraftDiscountsArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a Subscription Draft. */
export type SubscriptionDraftDiscountsAddedArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a Subscription Draft. */
export type SubscriptionDraftDiscountsRemovedArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a Subscription Draft. */
export type SubscriptionDraftDiscountsUpdatedArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a Subscription Draft. */
export type SubscriptionDraftLinesArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a Subscription Draft. */
export type SubscriptionDraftLinesAddedArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a Subscription Draft. */
export type SubscriptionDraftLinesRemovedArgs = {
  after?: InputMaybe<Scalars['String']>
  before?: InputMaybe<Scalars['String']>
  first?: InputMaybe<Scalars['Int']>
  last?: InputMaybe<Scalars['Int']>
  reverse?: InputMaybe<Scalars['Boolean']>
}

/** Represents a Subscription Draft. */
export type SubscriptionDraftShippingOptionsArgs = {
  deliveryAddress?: InputMaybe<MailingAddressInput>
}

/** Return type for `subscriptionDraftCommit` mutation. */
export type SubscriptionDraftCommitPayload = {
  __typename?: 'SubscriptionDraftCommitPayload'
  /** The updated Subscription Contract object. */
  contract?: Maybe<SubscriptionContract>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SubscriptionDraftUserError>
}

/** Return type for `subscriptionDraftDiscountAdd` mutation. */
export type SubscriptionDraftDiscountAddPayload = {
  __typename?: 'SubscriptionDraftDiscountAddPayload'
  /** The added Subscription Discount. */
  discountAdded?: Maybe<SubscriptionManualDiscount>
  /** The Subscription Contract draft object. */
  draft?: Maybe<SubscriptionDraft>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SubscriptionDraftUserError>
}

/** Return type for `subscriptionDraftDiscountCodeApply` mutation. */
export type SubscriptionDraftDiscountCodeApplyPayload = {
  __typename?: 'SubscriptionDraftDiscountCodeApplyPayload'
  /** The added subscription discount. */
  appliedDiscount?: Maybe<SubscriptionAppliedCodeDiscount>
  /** The subscription contract draft object. */
  draft?: Maybe<SubscriptionDraft>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SubscriptionDraftUserError>
}

/** Return type for `subscriptionDraftDiscountRemove` mutation. */
export type SubscriptionDraftDiscountRemovePayload = {
  __typename?: 'SubscriptionDraftDiscountRemovePayload'
  /** The removed subscription draft discount. */
  discountRemoved?: Maybe<SubscriptionDiscount>
  /** The subscription contract draft object. */
  draft?: Maybe<SubscriptionDraft>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SubscriptionDraftUserError>
}

/** Return type for `subscriptionDraftDiscountUpdate` mutation. */
export type SubscriptionDraftDiscountUpdatePayload = {
  __typename?: 'SubscriptionDraftDiscountUpdatePayload'
  /** The updated Subscription Discount. */
  discountUpdated?: Maybe<SubscriptionManualDiscount>
  /** The Subscription Contract draft object. */
  draft?: Maybe<SubscriptionDraft>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SubscriptionDraftUserError>
}

/** Possible error codes that can be returned by `SubscriptionDraftUserError`. */
export enum SubscriptionDraftErrorCode {
  /** This line has already been removed. */
  AlreadyRemoved = 'ALREADY_REMOVED',
  /** The input value is blank. */
  Blank = 'BLANK',
  /** Subscription draft has been already committed. */
  Committed = 'COMMITTED',
  /** Currency is not enabled. */
  CurrencyNotEnabled = 'CURRENCY_NOT_ENABLED',
  /** The customer doesn't exist. */
  CustomerDoesNotExist = 'CUSTOMER_DOES_NOT_EXIST',
  /** The payment method customer must be the same as the contract customer. */
  CustomerMismatch = 'CUSTOMER_MISMATCH',
  /** The after cycle attribute must be unique between cycle discounts. */
  CycleDiscountsUniqueAfterCycle = 'CYCLE_DISCOUNTS_UNIQUE_AFTER_CYCLE',
  /** The delivery method can't be blank if any lines require shipping. */
  DeliveryMethodRequired = 'DELIVERY_METHOD_REQUIRED',
  /** The delivery policy interval must be a multiple of the billing policy interval. */
  DeliveryMustBeMultipleOfBilling = 'DELIVERY_MUST_BE_MULTIPLE_OF_BILLING',
  /** The input value should be greater than the minimum allowed value. */
  GreaterThan = 'GREATER_THAN',
  /** The input value should be greater than or equal to the minimum value allowed. */
  GreaterThanOrEqualTo = 'GREATER_THAN_OR_EQUAL_TO',
  /** The input value is invalid. */
  Invalid = 'INVALID',
  /** The adjustment value must the same type as the adjustment type. */
  InvalidAdjustmentType = 'INVALID_ADJUSTMENT_TYPE',
  /** The adjustment value must be either fixed_value or percentage. */
  InvalidAdjustmentValue = 'INVALID_ADJUSTMENT_VALUE',
  /** Next billing date is invalid. */
  InvalidBillingDate = 'INVALID_BILLING_DATE',
  /** Must have at least one line. */
  InvalidLines = 'INVALID_LINES',
  /** Note length is too long. */
  InvalidNoteLength = 'INVALID_NOTE_LENGTH',
  /** The input value should be less than the maximum value allowed. */
  LessThan = 'LESS_THAN',
  /** The input value should be less than or equal to the maximum value allowed. */
  LessThanOrEqualTo = 'LESS_THAN_OR_EQUAL_TO',
  /** The value is not an integer. */
  NotAnInteger = 'NOT_AN_INTEGER',
  /** Value is not in range. */
  NotInRange = 'NOT_IN_RANGE',
  /** Discount must have at least one entitled line. */
  NoEntitledLines = 'NO_ENTITLED_LINES',
  /** Input value is not present. */
  Presence = 'PRESENCE',
  /** The maximum number of cycles must be greater than the minimum. */
  SellingPlanMaxCyclesMustBeGreaterThanMinCycles = 'SELLING_PLAN_MAX_CYCLES_MUST_BE_GREATER_THAN_MIN_CYCLES',
  /** Another operation updated the contract concurrently as the commit was in progress. */
  StaleContract = 'STALE_CONTRACT',
  /** The input value is too long. */
  TooLong = 'TOO_LONG',
  /** The input value is too short. */
  TooShort = 'TOO_SHORT',
}

/** Return type for `subscriptionDraftFreeShippingDiscountAdd` mutation. */
export type SubscriptionDraftFreeShippingDiscountAddPayload = {
  __typename?: 'SubscriptionDraftFreeShippingDiscountAddPayload'
  /** The added subscription free shipping discount. */
  discountAdded?: Maybe<SubscriptionManualDiscount>
  /** The subscription contract draft object. */
  draft?: Maybe<SubscriptionDraft>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SubscriptionDraftUserError>
}

/** Return type for `subscriptionDraftFreeShippingDiscountUpdate` mutation. */
export type SubscriptionDraftFreeShippingDiscountUpdatePayload = {
  __typename?: 'SubscriptionDraftFreeShippingDiscountUpdatePayload'
  /** The updated Subscription Discount. */
  discountUpdated?: Maybe<SubscriptionManualDiscount>
  /** The Subscription Contract draft object. */
  draft?: Maybe<SubscriptionDraft>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SubscriptionDraftUserError>
}

/** Specifies the input fields required to create a Subscription Draft. */
export type SubscriptionDraftInput = {
  /** The billing policy for the subscription contract. */
  billingPolicy?: InputMaybe<SubscriptionBillingPolicyInput>
  /** The delivery method for the subscription contract. */
  deliveryMethod?: InputMaybe<SubscriptionDeliveryMethodInput>
  /** The delivery policy for the subscription contract. */
  deliveryPolicy?: InputMaybe<SubscriptionDeliveryPolicyInput>
  /** The shipping price for each renewal the subscription contract. */
  deliveryPrice?: InputMaybe<Scalars['Decimal']>
  /** The next billing date for the subscription contract. */
  nextBillingDate?: InputMaybe<Scalars['DateTime']>
  /** The note field that will be applied to the generated orders. */
  note?: InputMaybe<Scalars['String']>
  /** The ID of the payment method to be used for the subscription contract. */
  paymentMethodId?: InputMaybe<Scalars['ID']>
  /** The current status of the subscription contract. */
  status?: InputMaybe<SubscriptionContractSubscriptionStatus>
}

/** Return type for `subscriptionDraftLineAdd` mutation. */
export type SubscriptionDraftLineAddPayload = {
  __typename?: 'SubscriptionDraftLineAddPayload'
  /** The Subscription Contract draft object. */
  draft?: Maybe<SubscriptionDraft>
  /** The added Subscription Line. */
  lineAdded?: Maybe<SubscriptionLine>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SubscriptionDraftUserError>
}

/** Return type for `subscriptionDraftLineRemove` mutation. */
export type SubscriptionDraftLineRemovePayload = {
  __typename?: 'SubscriptionDraftLineRemovePayload'
  /** The list of updated subscription discounts impacted by the removed line. */
  discountsUpdated?: Maybe<Array<SubscriptionManualDiscount>>
  /** The Subscription Contract draft object. */
  draft?: Maybe<SubscriptionDraft>
  /** The removed Subscription Line. */
  lineRemoved?: Maybe<SubscriptionLine>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SubscriptionDraftUserError>
}

/** Return type for `subscriptionDraftLineUpdate` mutation. */
export type SubscriptionDraftLineUpdatePayload = {
  __typename?: 'SubscriptionDraftLineUpdatePayload'
  /** The Subscription Contract draft object. */
  draft?: Maybe<SubscriptionDraft>
  /** The updated Subscription Line. */
  lineUpdated?: Maybe<SubscriptionLine>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SubscriptionDraftUserError>
}

/** Return type for `subscriptionDraftUpdate` mutation. */
export type SubscriptionDraftUpdatePayload = {
  __typename?: 'SubscriptionDraftUpdatePayload'
  /** The Subscription Draft object. */
  draft?: Maybe<SubscriptionDraft>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<SubscriptionDraftUserError>
}

/** Represents a Subscription Draft error. */
export type SubscriptionDraftUserError = DisplayableError & {
  __typename?: 'SubscriptionDraftUserError'
  /** The error code. */
  code?: Maybe<SubscriptionDraftErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Specifies the input fields of a subscription free shipping discount on a contract. */
export type SubscriptionFreeShippingDiscountInput = {
  /** The maximum number of times the subscription free shipping discount will be applied on orders. */
  recurringCycleLimit?: InputMaybe<Scalars['Int']>
  /** The title associated with the subscription free shipping discount. */
  title?: InputMaybe<Scalars['String']>
}

/** Represents a Subscription Line. */
export type SubscriptionLine = {
  __typename?: 'SubscriptionLine'
  /** The price per unit for the subscription line in the contract's currency. */
  currentPrice: MoneyV2
  /** List of custom attributes associated to the line item. */
  customAttributes: Array<Attribute>
  /** Discount allocations. */
  discountAllocations: Array<SubscriptionDiscountAllocation>
  /** The unique identifier. */
  id: Scalars['ID']
  /** Total line price including all discounts. */
  lineDiscountedPrice: MoneyV2
  /** Describe the price changes of the line over time. */
  pricingPolicy?: Maybe<SubscriptionPricingPolicy>
  /** The product id associated with the subscription line. */
  productId?: Maybe<Scalars['ID']>
  /** The quantity of the unit selected for the subscription line. */
  quantity: Scalars['Int']
  /** Whether physical shipping is required for the variant. */
  requiresShipping: Scalars['Boolean']
  /**
   * The selling plan ID associated to the line.
   *
   * Indicates which selling plan was used to create this
   * contract line initially. The selling plan ID is also used to
   * find the associated delivery profile.
   *
   * The subscription contract, subscription line, or selling plan might have
   * changed. As a result, the selling plan's attributes might not
   * match the information on the contract.
   *
   */
  sellingPlanId?: Maybe<Scalars['ID']>
  /**
   * The selling plan name associated to the line. This name describes
   * the order line items created from this subscription line
   * for both merchants and customers.
   *
   * The value can be different from the selling plan's name, because both
   * the selling plan's name and the subscription line's selling_plan_name
   * attribute can be updated independently.
   *
   */
  sellingPlanName?: Maybe<Scalars['String']>
  /** Variant SKU number of the item associated with the subscription line. */
  sku?: Maybe<Scalars['String']>
  /** Whether the variant is taxable. */
  taxable: Scalars['Boolean']
  /** Product title of the item associated with the subscription line. */
  title: Scalars['String']
  /** The product variant id associated with the subscription line. */
  variantId?: Maybe<Scalars['ID']>
  /** The image associated with the line item's variant or product. */
  variantImage?: Maybe<Image>
  /** Product variant title of the item associated with the subscription line. */
  variantTitle?: Maybe<Scalars['String']>
}

/**
 * An auto-generated type for paginating through multiple SubscriptionLines.
 *
 */
export type SubscriptionLineConnection = {
  __typename?: 'SubscriptionLineConnection'
  /** A list of edges. */
  edges: Array<SubscriptionLineEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one SubscriptionLine and a cursor during pagination.
 *
 */
export type SubscriptionLineEdge = {
  __typename?: 'SubscriptionLineEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of SubscriptionLineEdge. */
  node: SubscriptionLine
}

/** Specifies the input fields required to add a new subscription line to a contract. */
export type SubscriptionLineInput = {
  /** The price of the product. */
  currentPrice: Scalars['Decimal']
  /** The custom attributes for this subscription line. */
  customAttributes?: InputMaybe<Array<AttributeInput>>
  /** Describes expected price changes of the subscription line over time. */
  pricingPolicy?: InputMaybe<SubscriptionPricingPolicyInput>
  /** The ID of the product variant the subscription line refers to. */
  productVariantId: Scalars['ID']
  /** The quantity of the product. */
  quantity: Scalars['Int']
  /** The selling plan for the subscription line. */
  sellingPlanId?: InputMaybe<Scalars['ID']>
  /**
   * The selling plan name for the subscription line.
   *
   * Defaults to using the selling plan's current name when not specified.
   *
   */
  sellingPlanName?: InputMaybe<Scalars['String']>
}

/** Specifies the input fields required to update a subscription line on a contract. */
export type SubscriptionLineUpdateInput = {
  /** The price of the product. */
  currentPrice?: InputMaybe<Scalars['Decimal']>
  /** The custom attributes for this subscription line. */
  customAttributes?: InputMaybe<Array<AttributeInput>>
  /** Describes expected price changes of the subscription line over time. */
  pricingPolicy?: InputMaybe<SubscriptionPricingPolicyInput>
  /** The ID of the product variant the subscription line refers to. */
  productVariantId?: InputMaybe<Scalars['ID']>
  /** The quantity of the product. */
  quantity?: InputMaybe<Scalars['Int']>
  /** The selling plan for the subscription line. */
  sellingPlanId?: InputMaybe<Scalars['ID']>
  /** The selling plan name for the subscription line. */
  sellingPlanName?: InputMaybe<Scalars['String']>
}

/** Represents a Mailing Address on a Subscription. */
export type SubscriptionMailingAddress = {
  __typename?: 'SubscriptionMailingAddress'
  /** The first line of the address. Typically the street address or PO Box number. */
  address1?: Maybe<Scalars['String']>
  /** The second line of the address. Typically the number of the apartment, suite, or unit. */
  address2?: Maybe<Scalars['String']>
  /** The name of the city, district, village, or town. */
  city?: Maybe<Scalars['String']>
  /** The name of the customer's company or organization. */
  company?: Maybe<Scalars['String']>
  /** The name of the country. */
  country?: Maybe<Scalars['String']>
  /**
   * The two-letter code for the country of the address.
   *
   * For example, US.
   *
   */
  countryCode?: Maybe<CountryCode>
  /** The first name of the customer. */
  firstName?: Maybe<Scalars['String']>
  /** The last name of the customer. */
  lastName?: Maybe<Scalars['String']>
  /** The full name of the customer, based on firstName and lastName. */
  name?: Maybe<Scalars['String']>
  /** A unique phone number for the customer. Formatted using E.164 standard. For example, _+16135551111_. */
  phone?: Maybe<Scalars['String']>
  /** The region of the address, such as the province, state, or district. */
  province?: Maybe<Scalars['String']>
  /**
   * The two-letter code for the region.
   *
   * For example, ON.
   *
   */
  provinceCode?: Maybe<Scalars['String']>
  /** The zip or postal code of the address. */
  zip?: Maybe<Scalars['String']>
}

/** Custom subscription discount. */
export type SubscriptionManualDiscount = {
  __typename?: 'SubscriptionManualDiscount'
  /** Entitled line items used to apply the subscription discount on. */
  entitledLines: SubscriptionDiscountEntitledLines
  /** The unique identifier. */
  id: Scalars['ID']
  /** The maximum number of times the subscription discount will be applied on orders. */
  recurringCycleLimit?: Maybe<Scalars['Int']>
  /** The reason that the discount on the subscription draft is rejected. */
  rejectionReason?: Maybe<SubscriptionDiscountRejectionReason>
  /** Type of line the discount applies on. */
  targetType: DiscountTargetType
  /** The title associated with the subscription discount. */
  title?: Maybe<Scalars['String']>
  /** The type of the subscription discount. */
  type: DiscountType
  /** The number of times the discount was applied. */
  usageCount: Scalars['Int']
  /** The value of the subscription discount. */
  value: SubscriptionDiscountValue
}

/**
 * An auto-generated type for paginating through multiple SubscriptionManualDiscounts.
 *
 */
export type SubscriptionManualDiscountConnection = {
  __typename?: 'SubscriptionManualDiscountConnection'
  /** A list of edges. */
  edges: Array<SubscriptionManualDiscountEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one SubscriptionManualDiscount and a cursor during pagination.
 *
 */
export type SubscriptionManualDiscountEdge = {
  __typename?: 'SubscriptionManualDiscountEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of SubscriptionManualDiscountEdge. */
  node: SubscriptionManualDiscount
}

/** Represents the subscription lines the discount applies on. */
export type SubscriptionManualDiscountEntitledLinesInput = {
  /** Specify whether the subscription discount will apply on all subscription lines. */
  all?: InputMaybe<Scalars['Boolean']>
  /** The ID of the lines to add to or remove from the subscription discount. */
  lines?: InputMaybe<SubscriptionManualDiscountLinesInput>
}

/** Specifies the fixed amount value of the discount and distribution on the lines. */
export type SubscriptionManualDiscountFixedAmountInput = {
  /** Fixed amount value. */
  amount?: InputMaybe<Scalars['Float']>
  /** Whether the amount is intended per line item or once per subscription. */
  appliesOnEachItem?: InputMaybe<Scalars['Boolean']>
}

/** Specifies the input fields of a subscription discount on a contract. */
export type SubscriptionManualDiscountInput = {
  /** Entitled line items used to apply the subscription discount on. */
  entitledLines?: InputMaybe<SubscriptionManualDiscountEntitledLinesInput>
  /** The maximum number of times the subscription discount will be applied on orders. */
  recurringCycleLimit?: InputMaybe<Scalars['Int']>
  /** The title associated with the subscription discount. */
  title?: InputMaybe<Scalars['String']>
  /** Percentage or fixed amount value of the discount. */
  value?: InputMaybe<SubscriptionManualDiscountValueInput>
}

/** Line items that a the discount refers to. */
export type SubscriptionManualDiscountLinesInput = {
  /** The ID of the lines to add to the subscription discount. */
  add?: InputMaybe<Array<Scalars['ID']>>
  /** The ID of the lines to remove from the subscription discount. */
  remove?: InputMaybe<Array<Scalars['ID']>>
}

/** Specifies the discount value and its distribution. */
export type SubscriptionManualDiscountValueInput = {
  /** Fixed amount input in the currency defined by the subscription. */
  fixedAmount?: InputMaybe<SubscriptionManualDiscountFixedAmountInput>
  /** The percentage value of the discount. Value must be between 0 - 100. */
  percentage?: InputMaybe<Scalars['Int']>
}

/** Represents a Subscription Line Pricing Policy. */
export type SubscriptionPricingPolicy = {
  __typename?: 'SubscriptionPricingPolicy'
  /** The base price per unit for the subscription line in the contract's currency. */
  basePrice: MoneyV2
  /** The adjustments per cycle for the subscription line. */
  cycleDiscounts: Array<SubscriptionCyclePriceAdjustment>
}

/** An array containing all pricing changes for each billing cycle. */
export type SubscriptionPricingPolicyCycleDiscountsInput = {
  /** The price adjustment type. */
  adjustmentType: SellingPlanPricingPolicyAdjustmentType
  /** The price adjustment value. */
  adjustmentValue: SellingPlanPricingPolicyValueInput
  /** The cycle after which the pricing policy applies. */
  afterCycle: Scalars['Int']
  /** The computed price after the adjustments are applied. */
  computedPrice: Scalars['Decimal']
}

/** Describes expected price changes of the subscription line over time. */
export type SubscriptionPricingPolicyInput = {
  /** The base price per unit for the subscription line in the contract's currency. */
  basePrice: Scalars['Decimal']
  /** An array containing all pricing changes for each billing cycle. */
  cycleDiscounts: Array<SubscriptionPricingPolicyCycleDiscountsInput>
}

/** A shipping option to deliver a subscription contract. */
export type SubscriptionShippingOption = {
  __typename?: 'SubscriptionShippingOption'
  /**
   * The carrier service that is providing this shipping option.
   * This field isn't currently supported and returns null.
   *
   */
  carrierService?: Maybe<DeliveryCarrierService>
  /** The code of the shipping option. */
  code: Scalars['String']
  /** The description of the shipping option. */
  description?: Maybe<Scalars['String']>
  /** If a phone number is required for the shipping option. */
  phoneRequired?: Maybe<Scalars['Boolean']>
  /** The presentment title of the shipping option. */
  presentmentTitle?: Maybe<Scalars['String']>
  /** The price of the shipping option. */
  price?: Maybe<MoneyV2>
  /** The title of the shipping option. */
  title: Scalars['String']
}

/** The result of the query to fetch shipping options for the subscription contract. */
export type SubscriptionShippingOptionResult =
  | SubscriptionShippingOptionResultFailure
  | SubscriptionShippingOptionResultSuccess

/** Failure determining available shipping options for delivery of a subscription contract. */
export type SubscriptionShippingOptionResultFailure = {
  __typename?: 'SubscriptionShippingOptionResultFailure'
  /** Failure reason. */
  message?: Maybe<Scalars['String']>
}

/** A shipping option for delivery of a subscription contract. */
export type SubscriptionShippingOptionResultSuccess = {
  __typename?: 'SubscriptionShippingOptionResultSuccess'
  /** Available shipping options. */
  shippingOptions: Array<SubscriptionShippingOption>
}

/**
 * A suggested transaction. Suggested transaction are usually used in the context of refunds
 * and exchanges.
 *
 */
export type SuggestedOrderTransaction = {
  __typename?: 'SuggestedOrderTransaction'
  /** The masked account number associated with the payment method. */
  accountNumber?: Maybe<Scalars['String']>
  /**
   * The amount of the transaction.
   * @deprecated Use `amountSet` instead
   */
  amount: Scalars['Money']
  /** The amount and currency of the suggested order transaction in shop and presentment currencies. */
  amountSet: MoneyBag
  /** The human-readable payment gateway name suggested to process the transaction. */
  formattedGateway?: Maybe<Scalars['String']>
  /** The suggested payment gateway used to process the transaction. */
  gateway?: Maybe<Scalars['String']>
  /** Specifies the kind of the suggested order transaction. */
  kind: SuggestedOrderTransactionKind
  /**
   * Specifies the available amount to refund on the gateway. Only available within SuggestedRefund.
   * @deprecated Use `maximumRefundableSet` instead
   */
  maximumRefundable?: Maybe<Scalars['Money']>
  /** Specifies the available amount to refund on the gateway in shop and presentment currencies. Only available within SuggestedRefund. */
  maximumRefundableSet?: Maybe<MoneyBag>
  /** The associated parent transaction, for example the authorization of a capture. */
  parentTransaction?: Maybe<OrderTransaction>
}

/** Specifies the kind of the suggested order transaction. */
export enum SuggestedOrderTransactionKind {
  /** A suggested refund transaction for an order. */
  SuggestedRefund = 'SUGGESTED_REFUND',
}

/** Represents a refund suggested by Shopify based on the items being reimbursed. You can then use the suggested refund object to generate an actual refund. */
export type SuggestedRefund = {
  __typename?: 'SuggestedRefund'
  /**
   * The total monetary value to be refunded.
   * @deprecated Use `amountSet` instead
   */
  amount: Scalars['Money']
  /** The total monetary value to be refunded in shop and presentment currencies. */
  amountSet: MoneyBag
  /** The sum of all the discounted prices of the line items being refunded. */
  discountedSubtotalSet: MoneyBag
  /**
   * The total monetary value available to refund.
   * @deprecated Use `maximumRefundableSet` instead
   */
  maximumRefundable: Scalars['Money']
  /** The total monetary value available to refund in shop and presentment currencies. */
  maximumRefundableSet: MoneyBag
  /** A list of duties to be refunded from the order. */
  refundDuties: Array<RefundDuty>
  /** A list of line items to be refunded, along with restock instructions. */
  refundLineItems: Array<RefundLineItem>
  /** The shipping costs to be refunded from the order. */
  shipping: ShippingRefund
  /**
   * The sum of all the prices of the line items being refunded.
   * @deprecated Use `subtotalSet` instead
   */
  subtotal: Scalars['Money']
  /** The sum of all the prices of the line items being refunded in shop and presentment currencies. */
  subtotalSet: MoneyBag
  /** A list of suggested order transactions. */
  suggestedTransactions: Array<SuggestedOrderTransaction>
  /** The total cart discount amount that was applied to all line items in this refund. */
  totalCartDiscountAmountSet: MoneyBag
  /** The sum of all the duties being refunded from the order in shop and presentment currencies. The value must be positive. */
  totalDutiesSet: MoneyBag
  /** The sum of the taxes being refunded from the order in shop and presentment currencies. The value must be positive. */
  totalTaxSet: MoneyBag
  /**
   * The sum of the taxes being refunded from the order. The value must be positive.
   * @deprecated Use `totalTaxSet` instead
   */
  totalTaxes: Scalars['Money']
}

/** Return type for `tagsAdd` mutation. */
export type TagsAddPayload = {
  __typename?: 'TagsAddPayload'
  /** The object that was updated. */
  node?: Maybe<Node>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `tagsRemove` mutation. */
export type TagsRemovePayload = {
  __typename?: 'TagsRemovePayload'
  /** The object that was updated. */
  node?: Maybe<Node>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Available customer tax exemptions. */
export enum TaxExemption {
  /** This customer is exempt from specific taxes for holding a valid COMMERCIAL_FISHERY_EXEMPTION in British Columbia. */
  CaBcCommercialFisheryExemption = 'CA_BC_COMMERCIAL_FISHERY_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid CONTRACTOR_EXEMPTION in British Columbia. */
  CaBcContractorExemption = 'CA_BC_CONTRACTOR_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid PRODUCTION_AND_MACHINERY_EXEMPTION in British Columbia. */
  CaBcProductionAndMachineryExemption = 'CA_BC_PRODUCTION_AND_MACHINERY_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid RESELLER_EXEMPTION in British Columbia. */
  CaBcResellerExemption = 'CA_BC_RESELLER_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid SUB_CONTRACTOR_EXEMPTION in British Columbia. */
  CaBcSubContractorExemption = 'CA_BC_SUB_CONTRACTOR_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid DIPLOMAT_EXEMPTION in Canada. */
  CaDiplomatExemption = 'CA_DIPLOMAT_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid COMMERCIAL_FISHERY_EXEMPTION in Manitoba. */
  CaMbCommercialFisheryExemption = 'CA_MB_COMMERCIAL_FISHERY_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid FARMER_EXEMPTION in Manitoba. */
  CaMbFarmerExemption = 'CA_MB_FARMER_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid RESELLER_EXEMPTION in Manitoba. */
  CaMbResellerExemption = 'CA_MB_RESELLER_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid COMMERCIAL_FISHERY_EXEMPTION in Nova Scotia. */
  CaNsCommercialFisheryExemption = 'CA_NS_COMMERCIAL_FISHERY_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid FARMER_EXEMPTION in Nova Scotia. */
  CaNsFarmerExemption = 'CA_NS_FARMER_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid PURCHASE_EXEMPTION in Ontario. */
  CaOnPurchaseExemption = 'CA_ON_PURCHASE_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid COMMERCIAL_FISHERY_EXEMPTION in Prince Edward Island. */
  CaPeCommercialFisheryExemption = 'CA_PE_COMMERCIAL_FISHERY_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid COMMERCIAL_FISHERY_EXEMPTION in Saskatchewan. */
  CaSkCommercialFisheryExemption = 'CA_SK_COMMERCIAL_FISHERY_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid CONTRACTOR_EXEMPTION in Saskatchewan. */
  CaSkContractorExemption = 'CA_SK_CONTRACTOR_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid FARMER_EXEMPTION in Saskatchewan. */
  CaSkFarmerExemption = 'CA_SK_FARMER_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid PRODUCTION_AND_MACHINERY_EXEMPTION in Saskatchewan. */
  CaSkProductionAndMachineryExemption = 'CA_SK_PRODUCTION_AND_MACHINERY_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid RESELLER_EXEMPTION in Saskatchewan. */
  CaSkResellerExemption = 'CA_SK_RESELLER_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid SUB_CONTRACTOR_EXEMPTION in Saskatchewan. */
  CaSkSubContractorExemption = 'CA_SK_SUB_CONTRACTOR_EXEMPTION',
  /** This customer is exempt from specific taxes for holding a valid STATUS_CARD_EXEMPTION in Canada. */
  CaStatusCardExemption = 'CA_STATUS_CARD_EXEMPTION',
}

/** Represents a single tax applied to the associated line item. */
export type TaxLine = {
  __typename?: 'TaxLine'
  /** Whether the channel that submitted the tax line is liable for remitting. A value of null indicates unknown liability for this tax line. */
  channelLiable?: Maybe<Scalars['Boolean']>
  /**
   * The amount of tax, in shop currency, after discounts and before returns.
   * @deprecated Use `priceSet` instead
   */
  price: Scalars['Money']
  /** The amount of tax, in shop and presentment currencies, after discounts and before returns. */
  priceSet: MoneyBag
  /** The proportion of the line item price that the tax represents as a decimal. */
  rate?: Maybe<Scalars['Float']>
  /** The proportion of the line item price that the tax represents as a percentage. */
  ratePercentage?: Maybe<Scalars['Float']>
  /** The name of the tax. */
  title: Scalars['String']
}

/**
 * A TenderTransaction represents a transaction with financial impact on a shop's balance sheet. A tender transaction always
 * represents actual money movement between a buyer and a shop. TenderTransactions can be used instead of OrderTransactions
 * for reconciling a shop's cash flow. A TenderTransaction is immutable once created.
 *
 */
export type TenderTransaction = Node & {
  __typename?: 'TenderTransaction'
  /** The amount and currency of the tender transaction. */
  amount: MoneyV2
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** Information about the payment method used for the transaction. */
  paymentMethod?: Maybe<Scalars['String']>
  /** Date and time when the transaction was processed. */
  processedAt?: Maybe<Scalars['DateTime']>
  /** The remote gateway reference associated with the tender transaction. */
  remoteReference?: Maybe<Scalars['String']>
  /** Whether the transaction is a test transaction. */
  test: Scalars['Boolean']
  /** Information about the payment instrument used for the transaction. */
  transactionDetails?: Maybe<TenderTransactionDetails>
}

/**
 * An auto-generated type for paginating through multiple TenderTransactions.
 *
 */
export type TenderTransactionConnection = {
  __typename?: 'TenderTransactionConnection'
  /** A list of edges. */
  edges: Array<TenderTransactionEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Information about the credit card used for this transaction. */
export type TenderTransactionCreditCardDetails = {
  __typename?: 'TenderTransactionCreditCardDetails'
  /** The name of the company that issued the customer's credit card. Example: `Visa`. */
  creditCardCompany?: Maybe<Scalars['String']>
  /**
   * The customer's credit card number, with all digits except the last 4 redacted. Example: `•••• •••• •••• 1234`
   *
   */
  creditCardNumber?: Maybe<Scalars['String']>
}

/** Information about the payment instrument used for this transaction. */
export type TenderTransactionDetails = TenderTransactionCreditCardDetails

/**
 * An auto-generated type which holds one TenderTransaction and a cursor during pagination.
 *
 */
export type TenderTransactionEdge = {
  __typename?: 'TenderTransactionEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of TenderTransactionEdge. */
  node: TenderTransaction
}

/** A sale associated with a tip. */
export type TipSale = Sale & {
  __typename?: 'TipSale'
  /** The type of order action that the sale represents. */
  actionType: SaleActionType
  /** The unique identifier for the sale. */
  id: Scalars['ID']
  /** The line item for the associated sale. */
  lineItem: LineItem
  /** The line type assocated with the sale. */
  lineType: SaleLineType
  /** The number of units either ordered or intended to be returned. */
  quantity?: Maybe<Scalars['Int']>
  /** All individual taxes associated with the sale. */
  taxes: Array<SaleTax>
  /** The total sale amount after taxes and discounts. */
  totalAmount: MoneyBag
  /** The total discounts allocated to the sale after taxes. */
  totalDiscountAmountAfterTaxes: MoneyBag
  /** The total discounts allocated to the sale before taxes. */
  totalDiscountAmountBeforeTaxes: MoneyBag
  /** The total amount of taxes for the sale. */
  totalTaxAmount: MoneyBag
}

/** Specifies the fields for tracking information. */
export type TrackingInfoInput = {
  /** The tracking number of the fulfillment. */
  number?: InputMaybe<Scalars['String']>
  /** The URL to track the fulfillment. */
  url?: InputMaybe<Scalars['String']>
}

/** The input fields that specify all the possible fields for updating tracking information. */
export type TrackingInfoUpdateInput = {
  /**
   * Whether the customer will be notified of this update and future updates for the fulfillment.
   * If the field is left blank, then notifications won't be sent to the customer when the fulfillment is updated.
   *
   */
  notifyCustomer?: InputMaybe<Scalars['Boolean']>
  /** The name of the tracking company. */
  trackingCompany?: InputMaybe<Scalars['String']>
  /**
   * Tracking information consisting of one or more tracking URLs and numbers associated with the fulfillment.
   *
   */
  trackingDetails?: InputMaybe<Array<TrackingInfoInput>>
}

/** Transaction fee related to an order transaction. */
export type TransactionFee = Node & {
  __typename?: 'TransactionFee'
  /** Amount of the fee. */
  amount: MoneyV2
  /** Flat rate charge for a transaction. */
  flatFee: MoneyV2
  /** Name of the credit card flat fee. */
  flatFeeName?: Maybe<Scalars['String']>
  /** A globally-unique identifier. */
  id: Scalars['ID']
  /** Percentage charge. */
  rate: Scalars['Decimal']
  /** Name of the credit card rate. */
  rateName?: Maybe<Scalars['String']>
  /** Tax amount charged on the fee. */
  taxAmount: MoneyV2
  /** Name of the type of fee. */
  type: Scalars['String']
}

/** Translatable content of a resource's field. */
export type TranslatableContent = {
  __typename?: 'TranslatableContent'
  /** Hash digest representation of the content value. */
  digest?: Maybe<Scalars['String']>
  /** The resource field that is being translated. */
  key: Scalars['String']
  /** Locale of the content. */
  locale: Scalars['String']
  /** Content value. */
  value?: Maybe<Scalars['String']>
}

/** A resource that has translatable fields. */
export type TranslatableResource = {
  __typename?: 'TranslatableResource'
  /** GID of the resource. */
  resourceId: Scalars['ID']
  /** Translatable content. */
  translatableContent: Array<TranslatableContent>
  /** Translatable content translations. */
  translations: Array<Translation>
}

/** A resource that has translatable fields. */
export type TranslatableResourceTranslationsArgs = {
  locale: Scalars['String']
  outdated?: InputMaybe<Scalars['Boolean']>
}

/**
 * An auto-generated type for paginating through multiple TranslatableResources.
 *
 */
export type TranslatableResourceConnection = {
  __typename?: 'TranslatableResourceConnection'
  /** A list of edges. */
  edges: Array<TranslatableResourceEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/**
 * An auto-generated type which holds one TranslatableResource and a cursor during pagination.
 *
 */
export type TranslatableResourceEdge = {
  __typename?: 'TranslatableResourceEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of TranslatableResourceEdge. */
  node: TranslatableResource
}

/** Specifies the type of resources that are translatable. */
export enum TranslatableResourceType {
  /** A product collection. Translatable fields: `title`, `body_html`, `meta_title`, `meta_description`. */
  Collection = 'COLLECTION',
  /**
   * The delivery method definition. For example, "Standard", or "Expedited".
   *         Translatable fields: `name`.
   */
  DeliveryMethodDefinition = 'DELIVERY_METHOD_DEFINITION',
  /** An email template. Translatable fields: `title`, `body_html`. */
  EmailTemplate = 'EMAIL_TEMPLATE',
  /** A link to direct users. Translatable fields: `title`. */
  Link = 'LINK',
  /** A Metafield. Translatable fields: `value`. */
  Metafield = 'METAFIELD',
  /** An online store article. Translatable fields: `title`, `body_html`, `summary_html`, `meta_title`, `meta_description`. */
  OnlineStoreArticle = 'ONLINE_STORE_ARTICLE',
  /** An online store blog. Translatable fields: `title`, `meta_title`, `meta_description`. */
  OnlineStoreBlog = 'ONLINE_STORE_BLOG',
  /** A category of links. Translatable fields: `title`. */
  OnlineStoreMenu = 'ONLINE_STORE_MENU',
  /** An online store page. Translatable fields: `title`, `body_html`, `meta_title`, `meta_description`. */
  OnlineStorePage = 'ONLINE_STORE_PAGE',
  /** An online store theme. Translatable fields: `dynamic keys based on theme data`. */
  OnlineStoreTheme = 'ONLINE_STORE_THEME',
  /** A packing slip template. Translatable fields: `body`. */
  PackingSlipTemplate = 'PACKING_SLIP_TEMPLATE',
  /** A payment gateway. Translatable fields: `name`. */
  PaymentGateway = 'PAYMENT_GATEWAY',
  /** An online store product. Translatable fields: `title`, `body_html`, `meta_title`, `meta_description`. */
  Product = 'PRODUCT',
  /**
   * An online store custom product property name. For example, "Size", "Color", or "Material".
   *         Translatable fields: `name`.
   */
  ProductOption = 'PRODUCT_OPTION',
  /** An online store product variant. Translatable fields: `title`, `option1`, `option2`, `option3`. */
  ProductVariant = 'PRODUCT_VARIANT',
  /** A shop. Translatable fields: `meta_title`, `meta_description`. */
  Shop = 'SHOP',
  /** A shop policy. Translatable fields: `body`. */
  ShopPolicy = 'SHOP_POLICY',
  /** An SMS template. Translatable fields: `body`. */
  SmsTemplate = 'SMS_TEMPLATE',
}

/** Translation of a field of a resource. */
export type Translation = {
  __typename?: 'Translation'
  /** On the resource that this translation belongs to, the reference to the value being translated. */
  key: Scalars['String']
  /** ISO code of the translation locale. */
  locale: Scalars['String']
  /** Whether the original content has changed since this translation was updated. */
  outdated: Scalars['Boolean']
  /** Translation value. */
  value?: Maybe<Scalars['String']>
}

/** Possible error codes that can be returned by `TranslationUserError`. */
export enum TranslationErrorCode {
  /** The input value is blank. */
  Blank = 'BLANK',
  /** Translation value is invalid. */
  FailsResourceValidation = 'FAILS_RESOURCE_VALIDATION',
  /** The input value is invalid. */
  Invalid = 'INVALID',
  /** Locale language code is invalid. */
  InvalidCode = 'INVALID_CODE',
  /** Locale code format is invalid. */
  InvalidFormat = 'INVALID_FORMAT',
  /** Translation key is invalid. */
  InvalidKeyForModel = 'INVALID_KEY_FOR_MODEL',
  /** Locale is invalid for the shop. */
  InvalidLocaleForShop = 'INVALID_LOCALE_FOR_SHOP',
  /** Translatable content is invalid. */
  InvalidTranslatableContent = 'INVALID_TRANSLATABLE_CONTENT',
  /** Resource does not exist. */
  ResourceNotFound = 'RESOURCE_NOT_FOUND',
  /** Too many translation keys for the resource. */
  TooManyKeysForResource = 'TOO_MANY_KEYS_FOR_RESOURCE',
}

/** Provides the fields and values to use when creating or updating a translation. */
export type TranslationInput = {
  /** On the resource that this translation belongs to,         the reference to the value being translated. */
  key: Scalars['String']
  /** ISO code of the locale being translated into. */
  locale: Scalars['String']
  /** Hash digest representation         of the content being translated. */
  translatableContentDigest: Scalars['String']
  /** The value of the translation. */
  value: Scalars['String']
}

/** Represents an error that happens during the execution of a translation mutation. */
export type TranslationUserError = DisplayableError & {
  __typename?: 'TranslationUserError'
  /** The error code. */
  code?: Maybe<TranslationErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Return type for `translationsRegister` mutation. */
export type TranslationsRegisterPayload = {
  __typename?: 'TranslationsRegisterPayload'
  /** The translations that were created or updated. */
  translations?: Maybe<Array<Translation>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<TranslationUserError>
}

/** Return type for `translationsRemove` mutation. */
export type TranslationsRemovePayload = {
  __typename?: 'TranslationsRemovePayload'
  /** The translations that were deleted. */
  translations?: Maybe<Array<Translation>>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<TranslationUserError>
}

/**
 * Specifies the
 * [Urchin Traffic Module (UTM) parameters](https://en.wikipedia.org/wiki/UTM_parameters)
 * that are associated with a related marketing campaign.
 *
 */
export type UtmInput = {
  /** The name of the UTM campaign. */
  campaign: Scalars['String']
  /** The UTM campaign medium. */
  medium: Scalars['String']
  /** The name of the website or application where the referral link exists. */
  source: Scalars['String']
}

/** Represents a set of UTM parameters. */
export type UtmParameters = {
  __typename?: 'UTMParameters'
  /** The name of a marketing campaign. */
  campaign?: Maybe<Scalars['String']>
  /** Identifies specific content in a marketing campaign. Used to differentiate between similar content or links in a marketing campaign to determine which is the most effective. */
  content?: Maybe<Scalars['String']>
  /** The medium of a marketing campaign, such as a banner or email newsletter. */
  medium?: Maybe<Scalars['String']>
  /** The source of traffic to the merchant's store, such as Google or an email newsletter. */
  source?: Maybe<Scalars['String']>
  /** Paid search terms used by a marketing campaign. */
  term?: Maybe<Scalars['String']>
}

/** Systems of weights and measures. */
export enum UnitSystem {
  /** Imperial system of weights and measures. */
  ImperialSystem = 'IMPERIAL_SYSTEM',
  /** Metric system of weights and measures. */
  MetricSystem = 'METRIC_SYSTEM',
}

/** Specifies the input fields required to update a media object. */
export type UpdateMediaInput = {
  /** The alt text associated to the media. */
  alt?: InputMaybe<Scalars['String']>
  /** Specifies the media to update. */
  id: Scalars['ID']
  /** The source from which to update the media preview image. May be an external URL or signed upload URL. */
  previewImageSource?: InputMaybe<Scalars['String']>
}

/** The URL redirect for the online store. */
export type UrlRedirect = Node & {
  __typename?: 'UrlRedirect'
  /** The ID of the URL redirect. */
  id: Scalars['ID']
  /** The old path to be redirected from. When the user visits this path, they will be redirected to the target location. */
  path: Scalars['String']
  /** The target location where the user will be redirected to. */
  target: Scalars['String']
}

/** Return type for `urlRedirectBulkDeleteAll` mutation. */
export type UrlRedirectBulkDeleteAllPayload = {
  __typename?: 'UrlRedirectBulkDeleteAllPayload'
  /** The asynchronous job removing the redirects. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `urlRedirectBulkDeleteByIds` mutation. */
export type UrlRedirectBulkDeleteByIdsPayload = {
  __typename?: 'UrlRedirectBulkDeleteByIdsPayload'
  /** The asynchronous job removing the redirects. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UrlRedirectBulkDeleteByIdsUserError>
}

/** An error that occurs during the execution of `UrlRedirectBulkDeleteByIds`. */
export type UrlRedirectBulkDeleteByIdsUserError = DisplayableError & {
  __typename?: 'UrlRedirectBulkDeleteByIdsUserError'
  /** The error code. */
  code?: Maybe<UrlRedirectBulkDeleteByIdsUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `UrlRedirectBulkDeleteByIdsUserError`. */
export enum UrlRedirectBulkDeleteByIdsUserErrorCode {
  /**
   * You must pass one or more [`URLRedirect`](
   *             https://help.shopify.com/en/manual/online-store/menus-and-links/url-redirect
   *           ) object IDs.
   */
  IdsEmpty = 'IDS_EMPTY',
}

/** Return type for `urlRedirectBulkDeleteBySavedSearch` mutation. */
export type UrlRedirectBulkDeleteBySavedSearchPayload = {
  __typename?: 'UrlRedirectBulkDeleteBySavedSearchPayload'
  /** The asynchronous job removing the redirects. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UrlRedirectBulkDeleteBySavedSearchUserError>
}

/** An error that occurs during the execution of `UrlRedirectBulkDeleteBySavedSearch`. */
export type UrlRedirectBulkDeleteBySavedSearchUserError = DisplayableError & {
  __typename?: 'UrlRedirectBulkDeleteBySavedSearchUserError'
  /** The error code. */
  code?: Maybe<UrlRedirectBulkDeleteBySavedSearchUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `UrlRedirectBulkDeleteBySavedSearchUserError`. */
export enum UrlRedirectBulkDeleteBySavedSearchUserErrorCode {
  /** The saved search's query cannot match all entries or be empty. */
  InvalidSavedSearchQuery = 'INVALID_SAVED_SEARCH_QUERY',
  /** Saved search not found. */
  SavedSearchNotFound = 'SAVED_SEARCH_NOT_FOUND',
}

/** Return type for `urlRedirectBulkDeleteBySearch` mutation. */
export type UrlRedirectBulkDeleteBySearchPayload = {
  __typename?: 'UrlRedirectBulkDeleteBySearchPayload'
  /** The asynchronous job removing the redirects. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UrlRedirectBulkDeleteBySearchUserError>
}

/** An error that occurs during the execution of `UrlRedirectBulkDeleteBySearch`. */
export type UrlRedirectBulkDeleteBySearchUserError = DisplayableError & {
  __typename?: 'UrlRedirectBulkDeleteBySearchUserError'
  /** The error code. */
  code?: Maybe<UrlRedirectBulkDeleteBySearchUserErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Possible error codes that can be returned by `UrlRedirectBulkDeleteBySearchUserError`. */
export enum UrlRedirectBulkDeleteBySearchUserErrorCode {
  /** Invalid search string. */
  InvalidSearchArgument = 'INVALID_SEARCH_ARGUMENT',
}

/**
 * An auto-generated type for paginating through multiple UrlRedirects.
 *
 */
export type UrlRedirectConnection = {
  __typename?: 'UrlRedirectConnection'
  /** A list of edges. */
  edges: Array<UrlRedirectEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `urlRedirectCreate` mutation. */
export type UrlRedirectCreatePayload = {
  __typename?: 'UrlRedirectCreatePayload'
  /** The created redirect. */
  urlRedirect?: Maybe<UrlRedirect>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UrlRedirectUserError>
}

/** Return type for `urlRedirectDelete` mutation. */
export type UrlRedirectDeletePayload = {
  __typename?: 'UrlRedirectDeletePayload'
  /** The ID of the deleted redirect. */
  deletedUrlRedirectId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UrlRedirectUserError>
}

/**
 * An auto-generated type which holds one UrlRedirect and a cursor during pagination.
 *
 */
export type UrlRedirectEdge = {
  __typename?: 'UrlRedirectEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of UrlRedirectEdge. */
  node: UrlRedirect
}

/** Possible error codes that can be returned by `UrlRedirectUserError`. */
export enum UrlRedirectErrorCode {
  /** Redirect could not be created. */
  CreateFailed = 'CREATE_FAILED',
  /** Redirect could not be deleted. */
  DeleteFailed = 'DELETE_FAILED',
  /** Redirect does not exist. */
  DoesNotExist = 'DOES_NOT_EXIST',
  /** Redirect could not be updated. */
  UpdateFailed = 'UPDATE_FAILED',
}

/**
 * A request to import a [`URLRedirect`](https://shopify.dev/api/admin-graphql/latest/objects/UrlRedirect) object
 * into the Online Store channel. Apps can use this to query the state of an `UrlRedirectImport` request.
 *
 * For more information, see [`url-redirect`](https://help.shopify.com/en/manual/online-store/menus-and-links/url-redirect)s.
 *
 */
export type UrlRedirectImport = Node & {
  __typename?: 'UrlRedirectImport'
  /** The number of rows in the file. */
  count?: Maybe<Scalars['Int']>
  /** The number of redirects created from the import. */
  createdCount?: Maybe<Scalars['Int']>
  /** The number of redirects that failed to be imported. */
  failedCount?: Maybe<Scalars['Int']>
  /** Whether the import is finished. */
  finished: Scalars['Boolean']
  /** The date and time when the import finished. */
  finishedAt?: Maybe<Scalars['DateTime']>
  /** The ID of the `UrlRedirectImport` object. */
  id: Scalars['ID']
  /** A list of up to three previews of the URL redirects to be imported. */
  previewRedirects: Array<UrlRedirectImportPreview>
  /** The number of redirects updated during the import. */
  updatedCount?: Maybe<Scalars['Int']>
}

/** Return type for `urlRedirectImportCreate` mutation. */
export type UrlRedirectImportCreatePayload = {
  __typename?: 'UrlRedirectImportCreatePayload'
  /** The created `URLRedirectImport` object. */
  urlRedirectImport?: Maybe<UrlRedirectImport>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UrlRedirectImportUserError>
}

/** Possible error codes that can be returned by `UrlRedirectImportUserError`. */
export enum UrlRedirectImportErrorCode {
  /** The import has already completed. */
  AlreadyImported = 'ALREADY_IMPORTED',
  /** CSV file does not exist at given URL. */
  FileDoesNotExist = 'FILE_DOES_NOT_EXIST',
  /** The import is already in progress. */
  InProgress = 'IN_PROGRESS',
  /** URL redirect import not found. */
  NotFound = 'NOT_FOUND',
}

/** A preview of a URL redirect import row. */
export type UrlRedirectImportPreview = {
  __typename?: 'UrlRedirectImportPreview'
  /** The old path to be redirected from. When the user visits this path, they will be redirected to the target location. */
  path: Scalars['String']
  /** The target location where the user will be redirected to. */
  target: Scalars['String']
}

/** Return type for `urlRedirectImportSubmit` mutation. */
export type UrlRedirectImportSubmitPayload = {
  __typename?: 'UrlRedirectImportSubmitPayload'
  /** The asynchronous job importing the redirects. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UrlRedirectImportUserError>
}

/** Represents an error that happens during execution of a redirect import mutation. */
export type UrlRedirectImportUserError = DisplayableError & {
  __typename?: 'UrlRedirectImportUserError'
  /** The error code. */
  code?: Maybe<UrlRedirectImportErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** The input fields to create or update a URL redirect. */
export type UrlRedirectInput = {
  /** The old path to be redirected from. When the user visits this path, they will be redirected to the target location. */
  path?: InputMaybe<Scalars['String']>
  /** The target location where the user will be redirected to. */
  target?: InputMaybe<Scalars['String']>
}

/** The set of valid sort keys for the UrlRedirect query. */
export enum UrlRedirectSortKeys {
  /** Sort by the `id` value. */
  Id = 'ID',
  /** Sort by the `path` value. */
  Path = 'PATH',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/** Return type for `urlRedirectUpdate` mutation. */
export type UrlRedirectUpdatePayload = {
  __typename?: 'UrlRedirectUpdatePayload'
  /** Returns the updated URL redirect. */
  urlRedirect?: Maybe<UrlRedirect>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UrlRedirectUserError>
}

/** Represents an error that happens during execution of a redirect mutation. */
export type UrlRedirectUserError = DisplayableError & {
  __typename?: 'UrlRedirectUserError'
  /** The error code. */
  code?: Maybe<UrlRedirectErrorCode>
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/** Represents an error in the input of a mutation. */
export type UserError = DisplayableError & {
  __typename?: 'UserError'
  /** The path to the input field that caused the error. */
  field?: Maybe<Array<Scalars['String']>>
  /** The error message. */
  message: Scalars['String']
}

/**
 * Representation of 3d vectors and points. It can represent
 * either the coordinates of a point in space, a direction, or
 * size. Presented as an object with three floating-point values.
 *
 */
export type Vector3 = {
  __typename?: 'Vector3'
  /** The x coordinate of Vector3. */
  x: Scalars['Float']
  /** The y coordinate of Vector3. */
  y: Scalars['Float']
  /** The z coordinate of Vector3. */
  z: Scalars['Float']
}

/**
 * Represents a Shopify hosted video.
 *
 */
export type Video = Media &
  Node & {
    __typename?: 'Video'
    /** A word or phrase to share the nature or contents of a media. */
    alt?: Maybe<Scalars['String']>
    /** The filename of the video. */
    filename: Scalars['String']
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** The media content type. */
    mediaContentType: MediaContentType
    /** Any errors which have occurred on the media. */
    mediaErrors: Array<MediaError>
    /** The warnings attached to the media. */
    mediaWarnings: Array<MediaWarning>
    /** The original source for a video. Value is `null` when `status` is PROCESSING. */
    originalSource?: Maybe<VideoSource>
    /** The preview image for the media. */
    preview?: Maybe<MediaPreviewImage>
    /** The sources for a video. Sources are only available when `status` is READY. */
    sources: Array<VideoSource>
    /** Current status of the media. */
    status: MediaStatus
  }

/**
 * Represents a source for a Shopify hosted video.
 *
 */
export type VideoSource = {
  __typename?: 'VideoSource'
  /** The format of the video source. */
  format: Scalars['String']
  /** The height of the video. */
  height: Scalars['Int']
  /** The video MIME type. */
  mimeType: Scalars['String']
  /** The URL of the video. */
  url: Scalars['String']
  /** The width of the video. */
  width: Scalars['Int']
}

/** An Amazon EventBridge partner event source to which webhook subscriptions publish events. */
export type WebhookEventBridgeEndpoint = {
  __typename?: 'WebhookEventBridgeEndpoint'
  /** The ARN of this EventBridge partner event source. */
  arn: Scalars['ARN']
}

/** An HTTPS endpoint to which webhook subscriptions send POST requests. */
export type WebhookHttpEndpoint = {
  __typename?: 'WebhookHttpEndpoint'
  /** The URL to which the webhooks events are sent. */
  callbackUrl: Scalars['URL']
}

/** A Google Cloud Pub/Sub topic to which webhook subscriptions publish events. */
export type WebhookPubSubEndpoint = {
  __typename?: 'WebhookPubSubEndpoint'
  /** The Google Cloud Pub/Sub project ID. */
  pubSubProject: Scalars['String']
  /** The Google Cloud Pub/Sub topic ID. */
  pubSubTopic: Scalars['String']
}

/**
 * A webhook subscription is a persisted data object created by an app using the REST Admin API or GraphQL Admin API.
 * It describes the topic that the app wants to receive, and a destination where Shopify should send webhooks of the specified topic.
 * When an event for a given topic occurs, the webhook subscription sends a relevant payload to the destination.
 * Learn more about the [webhooks system](https://shopify.dev/apps/webhooks).
 *
 */
export type WebhookSubscription = LegacyInteroperability &
  Node & {
    __typename?: 'WebhookSubscription'
    /**
     * The destination URI to which the webhook subscription will send a message when an event occurs.
     * @deprecated Use `endpoint` instead
     */
    callbackUrl: Scalars['URL']
    /** The date and time when the webhook subscription was created. */
    createdAt: Scalars['DateTime']
    /** The endpoint to which the webhook subscription will send events. */
    endpoint: WebhookSubscriptionEndpoint
    /** The format in which the webhook subscription should send the data. */
    format: WebhookSubscriptionFormat
    /** A globally-unique identifier. */
    id: Scalars['ID']
    /** An optional array of top-level resource fields that should be serialized and sent in the webhook message. If null, then all fields will be sent. */
    includeFields: Array<Scalars['String']>
    /** The ID of the corresponding resource in the REST Admin API. */
    legacyResourceId: Scalars['UnsignedInt64']
    /** The list of namespaces for any metafields that should be included in the webhook subscription. */
    metafieldNamespaces: Array<Scalars['String']>
    /** The list of namespaces for private metafields that should be included in the webhook subscription. */
    privateMetafieldNamespaces: Array<Scalars['String']>
    /** The type of event that triggers the webhook. The topic determines when the webhook subscription sends a webhook, as well as what class of data object that webhook contains. */
    topic: WebhookSubscriptionTopic
    /** The date and time when the webhook subscription was updated. */
    updatedAt: Scalars['DateTime']
  }

/**
 * An auto-generated type for paginating through multiple WebhookSubscriptions.
 *
 */
export type WebhookSubscriptionConnection = {
  __typename?: 'WebhookSubscriptionConnection'
  /** A list of edges. */
  edges: Array<WebhookSubscriptionEdge>
  /** Information to aid in pagination. */
  pageInfo: PageInfo
}

/** Return type for `webhookSubscriptionCreate` mutation. */
export type WebhookSubscriptionCreatePayload = {
  __typename?: 'WebhookSubscriptionCreatePayload'
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
  /** The webhook subscription that was created. */
  webhookSubscription?: Maybe<WebhookSubscription>
}

/** Return type for `webhookSubscriptionDelete` mutation. */
export type WebhookSubscriptionDeletePayload = {
  __typename?: 'WebhookSubscriptionDeletePayload'
  /** The ID of the deleted webhook subscription. */
  deletedWebhookSubscriptionId?: Maybe<Scalars['ID']>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/**
 * An auto-generated type which holds one WebhookSubscription and a cursor during pagination.
 *
 */
export type WebhookSubscriptionEdge = {
  __typename?: 'WebhookSubscriptionEdge'
  /** A cursor for use in pagination. */
  cursor: Scalars['String']
  /** The item at the end of WebhookSubscriptionEdge. */
  node: WebhookSubscription
}

/** An endpoint to which webhook subscriptions send webhooks events. */
export type WebhookSubscriptionEndpoint =
  | WebhookEventBridgeEndpoint
  | WebhookHttpEndpoint
  | WebhookPubSubEndpoint

/** The supported formats for webhook subscriptions. */
export enum WebhookSubscriptionFormat {
  Json = 'JSON',
  Xml = 'XML',
}

/**
 * Specifies the input fields for a webhook subscription.
 *
 */
export type WebhookSubscriptionInput = {
  /** URL where the webhook subscription should send the POST request when the event occurs. */
  callbackUrl?: InputMaybe<Scalars['URL']>
  /** The format in which the webhook subscription should send the data. */
  format?: InputMaybe<WebhookSubscriptionFormat>
  /** The list of fields to be included in the webhook subscription. */
  includeFields?: InputMaybe<Array<Scalars['String']>>
  /** The list of namespaces for any metafields that should be included in the webhook subscription. */
  metafieldNamespaces?: InputMaybe<Array<Scalars['String']>>
  /** The list of namespaces for private metafields that should be included inthe webhook subscription. */
  privateMetafieldNamespaces?: InputMaybe<Array<Scalars['String']>>
}

/** The set of valid sort keys for the WebhookSubscription query. */
export enum WebhookSubscriptionSortKeys {
  /** Sort by the `created_at` value. */
  CreatedAt = 'CREATED_AT',
  /** Sort by the `id` value. */
  Id = 'ID',
  /**
   * Sort by relevance to the search terms when the `query` parameter is specified on the connection.
   * Don't use this sort key when no search query is specified.
   *
   */
  Relevance = 'RELEVANCE',
}

/**
 * The supported topics for webhook subscriptions. You can use webhook subscriptions to receive
 * notifications about particular events in a shop.
 *
 * You don't create webhook subscriptions to
 * [mandatory webhooks](https://shopify.dev/apps/webhooks/configuration/mandatory-webhooks).
 * Instead, you configure mandatory webhooks in your Partner Dashboard as part of your app setup.
 *
 */
export enum WebhookSubscriptionTopic {
  /** The webhook topic for `app_purchases_one_time/update` events. Occurs whenever a one-time app charge is updated. */
  AppPurchasesOneTimeUpdate = 'APP_PURCHASES_ONE_TIME_UPDATE',
  /** The webhook topic for `app_subscriptions/update` events. Occurs whenever an app subscription is updated. */
  AppSubscriptionsUpdate = 'APP_SUBSCRIPTIONS_UPDATE',
  /** The webhook topic for `app/uninstalled` events. Occurs whenever a shop has uninstalled the app. */
  AppUninstalled = 'APP_UNINSTALLED',
  /** The webhook topic for `attributed_sessions/first` events. Occurs whenever an order with a "first" attributed session is attributed. Requires the `read_marketing_events` scope. */
  AttributedSessionsFirst = 'ATTRIBUTED_SESSIONS_FIRST',
  /** The webhook topic for `attributed_sessions/last` events. Occurs whenever an order with a "last" attributed session is attributed. Requires the `read_marketing_events` scope. */
  AttributedSessionsLast = 'ATTRIBUTED_SESSIONS_LAST',
  /** The webhook topic for `bulk_operations/finish` events. Notifies when a Bulk Operation finishes. */
  BulkOperationsFinish = 'BULK_OPERATIONS_FINISH',
  /** The webhook topic for `carts/create` events. Occurs when a cart is created in the online store. Other types of carts aren't supported. For example, the webhook doesn't support carts that are created in a custom storefront. Requires the `read_orders` scope. */
  CartsCreate = 'CARTS_CREATE',
  /** The webhook topic for `carts/update` events. Occurs when a cart is updated in the online store. Other types of carts aren't supported. For example, the webhook doesn't support carts that are updated in a custom storefront. Requires the `read_orders` scope. */
  CartsUpdate = 'CARTS_UPDATE',
  /** The webhook topic for `channels/delete` events. Occurs whenever a channel is deleted. Requires the `read_publications` scope. */
  ChannelsDelete = 'CHANNELS_DELETE',
  /** The webhook topic for `checkouts/create` events. Occurs whenever a checkout is created. Requires the `read_orders` scope. */
  CheckoutsCreate = 'CHECKOUTS_CREATE',
  /** The webhook topic for `checkouts/delete` events. Occurs whenever a checkout is deleted. Requires the `read_orders` scope. */
  CheckoutsDelete = 'CHECKOUTS_DELETE',
  /** The webhook topic for `checkouts/update` events. Occurs whenever a checkout is updated. Requires the `read_orders` scope. */
  CheckoutsUpdate = 'CHECKOUTS_UPDATE',
  /** The webhook topic for `collections/create` events. Occurs whenever a collection is created. Requires the `read_products` scope. */
  CollectionsCreate = 'COLLECTIONS_CREATE',
  /** The webhook topic for `collections/delete` events. Occurs whenever a collection is deleted. Requires the `read_products` scope. */
  CollectionsDelete = 'COLLECTIONS_DELETE',
  /** The webhook topic for `collections/update` events. Occurs whenever a collection is updated, including whenever products are added or removed from the collection. Occurs once if multiple products are added or removed from a collection at the same time. Requires the `read_products` scope. */
  CollectionsUpdate = 'COLLECTIONS_UPDATE',
  /** The webhook topic for `collection_listings/add` events. Occurs whenever a collection listing is added. Requires the `read_product_listings` scope. */
  CollectionListingsAdd = 'COLLECTION_LISTINGS_ADD',
  /** The webhook topic for `collection_listings/remove` events. Occurs whenever a collection listing is removed. Requires the `read_product_listings` scope. */
  CollectionListingsRemove = 'COLLECTION_LISTINGS_REMOVE',
  /** The webhook topic for `collection_listings/update` events. Occurs whenever a collection listing is updated. Requires the `read_product_listings` scope. */
  CollectionListingsUpdate = 'COLLECTION_LISTINGS_UPDATE',
  /** The webhook topic for `collection_publications/create` events. Occurs whenever a collection publication listing is created. Requires the `read_publications` scope. */
  CollectionPublicationsCreate = 'COLLECTION_PUBLICATIONS_CREATE',
  /** The webhook topic for `collection_publications/delete` events. Occurs whenever a collection publication listing is deleted. Requires the `read_publications` scope. */
  CollectionPublicationsDelete = 'COLLECTION_PUBLICATIONS_DELETE',
  /** The webhook topic for `collection_publications/update` events. Occurs whenever a collection publication listing is updated. Requires the `read_publications` scope. */
  CollectionPublicationsUpdate = 'COLLECTION_PUBLICATIONS_UPDATE',
  /** The webhook topic for `customers/create` events. Occurs whenever a customer is created. Requires the `read_customers` scope. */
  CustomersCreate = 'CUSTOMERS_CREATE',
  /** The webhook topic for `customers/delete` events. Occurs whenever a customer is deleted. Requires the `read_customers` scope. */
  CustomersDelete = 'CUSTOMERS_DELETE',
  /** The webhook topic for `customers/disable` events. Occurs whenever a customer account is disabled. Requires the `read_customers` scope. */
  CustomersDisable = 'CUSTOMERS_DISABLE',
  /** The webhook topic for `customers/enable` events. Occurs whenever a customer account is enabled. Requires the `read_customers` scope. */
  CustomersEnable = 'CUSTOMERS_ENABLE',
  /** The webhook topic for `customers_marketing_consent/update` events. Occurs whenever a customer's marketing consent is updated. Requires the `read_customers` scope. */
  CustomersMarketingConsentUpdate = 'CUSTOMERS_MARKETING_CONSENT_UPDATE',
  /** The webhook topic for `customers/update` events. Occurs whenever a customer is updated. Requires the `read_customers` scope. */
  CustomersUpdate = 'CUSTOMERS_UPDATE',
  /** The webhook topic for `customer_groups/create` events. Occurs whenever a customer saved search is created. Requires the `read_customers` scope. */
  CustomerGroupsCreate = 'CUSTOMER_GROUPS_CREATE',
  /** The webhook topic for `customer_groups/delete` events. Occurs whenever a customer saved search is deleted. Requires the `read_customers` scope. */
  CustomerGroupsDelete = 'CUSTOMER_GROUPS_DELETE',
  /** The webhook topic for `customer_groups/update` events. Occurs whenever a customer saved search is updated. Requires the `read_customers` scope. */
  CustomerGroupsUpdate = 'CUSTOMER_GROUPS_UPDATE',
  /** The webhook topic for `customer_payment_methods/create` events. Occurs whenever a customer payment method is created. Requires the `read_customer_payment_methods` scope. */
  CustomerPaymentMethodsCreate = 'CUSTOMER_PAYMENT_METHODS_CREATE',
  /** The webhook topic for `customer_payment_methods/revoke` events. Occurs whenever a customer payment method is revoked. Requires the `read_customer_payment_methods` scope. */
  CustomerPaymentMethodsRevoke = 'CUSTOMER_PAYMENT_METHODS_REVOKE',
  /** The webhook topic for `customer_payment_methods/update` events. Occurs whenever a customer payment method is updated. Requires the `read_customer_payment_methods` scope. */
  CustomerPaymentMethodsUpdate = 'CUSTOMER_PAYMENT_METHODS_UPDATE',
  /** The webhook topic for `disputes/create` events. Occurs whenever a dispute is created. Requires the `read_shopify_payments_disputes` scope. */
  DisputesCreate = 'DISPUTES_CREATE',
  /** The webhook topic for `disputes/update` events. Occurs whenever a dispute is updated. Requires the `read_shopify_payments_disputes` scope. */
  DisputesUpdate = 'DISPUTES_UPDATE',
  /** The webhook topic for `domains/create` events. Occurs whenever a domain is created. */
  DomainsCreate = 'DOMAINS_CREATE',
  /** The webhook topic for `domains/destroy` events. Occurs whenever a domain is destroyed. */
  DomainsDestroy = 'DOMAINS_DESTROY',
  /** The webhook topic for `domains/update` events. Occurs whenever a domain is updated. */
  DomainsUpdate = 'DOMAINS_UPDATE',
  /** The webhook topic for `draft_orders/create` events. Occurs whenever a draft order is created. Requires the `read_draft_orders` scope. */
  DraftOrdersCreate = 'DRAFT_ORDERS_CREATE',
  /** The webhook topic for `draft_orders/delete` events. Occurs whenever a draft order is deleted. Requires the `read_draft_orders` scope. */
  DraftOrdersDelete = 'DRAFT_ORDERS_DELETE',
  /** The webhook topic for `draft_orders/update` events. Occurs whenever a draft order is updated. Requires the `read_draft_orders` scope. */
  DraftOrdersUpdate = 'DRAFT_ORDERS_UPDATE',
  /** The webhook topic for `fulfillments/create` events. Occurs whenever a fulfillment is created. Requires at least one of the following scopes: read_fulfillments, read_marketplace_orders. */
  FulfillmentsCreate = 'FULFILLMENTS_CREATE',
  /** The webhook topic for `fulfillments/update` events. Occurs whenever a fulfillment is updated. Requires at least one of the following scopes: read_fulfillments, read_marketplace_orders. */
  FulfillmentsUpdate = 'FULFILLMENTS_UPDATE',
  /** The webhook topic for `fulfillment_events/create` events. Occurs whenever a fulfillment event is created. Requires the `read_fulfillments` scope. */
  FulfillmentEventsCreate = 'FULFILLMENT_EVENTS_CREATE',
  /** The webhook topic for `fulfillment_events/delete` events. Occurs whenever a fulfillment event is deleted. Requires the `read_fulfillments` scope. */
  FulfillmentEventsDelete = 'FULFILLMENT_EVENTS_DELETE',
  /** The webhook topic for `inventory_items/create` events. Occurs whenever an inventory item is created. Requires the `read_inventory` scope. */
  InventoryItemsCreate = 'INVENTORY_ITEMS_CREATE',
  /** The webhook topic for `inventory_items/delete` events. Occurs whenever an inventory item is deleted. Requires the `read_inventory` scope. */
  InventoryItemsDelete = 'INVENTORY_ITEMS_DELETE',
  /** The webhook topic for `inventory_items/update` events. Occurs whenever an inventory item is updated. Requires the `read_inventory` scope. */
  InventoryItemsUpdate = 'INVENTORY_ITEMS_UPDATE',
  /** The webhook topic for `inventory_levels/connect` events. Occurs whenever an inventory level is connected. Requires the `read_inventory` scope. */
  InventoryLevelsConnect = 'INVENTORY_LEVELS_CONNECT',
  /** The webhook topic for `inventory_levels/disconnect` events. Occurs whenever an inventory level is disconnected. Requires the `read_inventory` scope. */
  InventoryLevelsDisconnect = 'INVENTORY_LEVELS_DISCONNECT',
  /** The webhook topic for `inventory_levels/update` events. Occurs whenever an inventory level is updated. Requires the `read_inventory` scope. */
  InventoryLevelsUpdate = 'INVENTORY_LEVELS_UPDATE',
  /** The webhook topic for `locales/create` events. Occurs whenever a shop locale is created Requires the `read_locales` scope. */
  LocalesCreate = 'LOCALES_CREATE',
  /** The webhook topic for `locales/update` events. Occurs whenever a shop locale is updated, such as published or unpublished Requires the `read_locales` scope. */
  LocalesUpdate = 'LOCALES_UPDATE',
  /** The webhook topic for `locations/create` events. Occurs whenever a location is created. Requires the `read_locations` scope. */
  LocationsCreate = 'LOCATIONS_CREATE',
  /** The webhook topic for `locations/delete` events. Occurs whenever a location is deleted. Requires the `read_locations` scope. */
  LocationsDelete = 'LOCATIONS_DELETE',
  /** The webhook topic for `locations/update` events. Occurs whenever a location is updated. Requires the `read_locations` scope. */
  LocationsUpdate = 'LOCATIONS_UPDATE',
  /** The webhook topic for `orders/cancelled` events. Occurs whenever an order is cancelled. Requires at least one of the following scopes: read_orders, read_marketplace_orders. */
  OrdersCancelled = 'ORDERS_CANCELLED',
  /** The webhook topic for `orders/create` events. Occurs whenever an order is created. Requires at least one of the following scopes: read_orders, read_marketplace_orders. */
  OrdersCreate = 'ORDERS_CREATE',
  /** The webhook topic for `orders/delete` events. Occurs whenever an order is deleted. Requires the `read_orders` scope. */
  OrdersDelete = 'ORDERS_DELETE',
  /** The webhook topic for `orders/edited` events. Occurs whenever an order is edited. Requires the `read_orders` scope. */
  OrdersEdited = 'ORDERS_EDITED',
  /** The webhook topic for `orders/fulfilled` events. Occurs whenever an order is fulfilled. Requires at least one of the following scopes: read_orders, read_marketplace_orders. */
  OrdersFulfilled = 'ORDERS_FULFILLED',
  /** The webhook topic for `orders/paid` events. Occurs whenever an order is paid. Requires at least one of the following scopes: read_orders, read_marketplace_orders. */
  OrdersPaid = 'ORDERS_PAID',
  /** The webhook topic for `orders/partially_fulfilled` events. Occurs whenever an order is partially fulfilled. Requires the `read_orders` scope. */
  OrdersPartiallyFulfilled = 'ORDERS_PARTIALLY_FULFILLED',
  /** The webhook topic for `orders/updated` events. Occurs whenever an order is updated. Requires at least one of the following scopes: read_orders, read_marketplace_orders. */
  OrdersUpdated = 'ORDERS_UPDATED',
  /** The webhook topic for `order_transactions/create` events. Occurs when a order transaction is created or when it's status is updated. Only occurs for transactions with a status of success, failure or error. Requires at least one of the following scopes: read_orders, read_marketplace_orders. */
  OrderTransactionsCreate = 'ORDER_TRANSACTIONS_CREATE',
  /** The webhook topic for `payment_terms/create` events. Occurs whenever payment terms are created. Requires the `read_payment_terms` scope. */
  PaymentTermsCreate = 'PAYMENT_TERMS_CREATE',
  /** The webhook topic for `payment_terms/delete` events. Occurs whenever payment terms are deleted. Requires the `read_payment_terms` scope. */
  PaymentTermsDelete = 'PAYMENT_TERMS_DELETE',
  /** The webhook topic for `payment_terms/update` events. Occurs whenever payment terms are updated. Requires the `read_payment_terms` scope. */
  PaymentTermsUpdate = 'PAYMENT_TERMS_UPDATE',
  /** The webhook topic for `products/create` events. Occurs whenever a product is created. Requires the `read_products` scope. */
  ProductsCreate = 'PRODUCTS_CREATE',
  /** The webhook topic for `products/delete` events. Occurs whenever a product publication is deleted. Requires the `read_products` scope. */
  ProductsDelete = 'PRODUCTS_DELETE',
  /** The webhook topic for `products/update` events. Occurs whenever a product is updated, or whenever a product is ordered, or whenever a variant is added, removed, or updated. Requires the `read_products` scope. */
  ProductsUpdate = 'PRODUCTS_UPDATE',
  /** The webhook topic for `product_listings/add` events. Occurs whenever an active product is listed on a channel. Requires the `read_product_listings` scope. */
  ProductListingsAdd = 'PRODUCT_LISTINGS_ADD',
  /** The webhook topic for `product_listings/remove` events. Occurs whenever a product listing is removed from the channel. Requires the `read_product_listings` scope. */
  ProductListingsRemove = 'PRODUCT_LISTINGS_REMOVE',
  /** The webhook topic for `product_listings/update` events. Occurs whenever a product publication is updated. Requires the `read_product_listings` scope. */
  ProductListingsUpdate = 'PRODUCT_LISTINGS_UPDATE',
  /** The webhook topic for `product_publications/create` events. Occurs whenever a product publication for an active product is created, or whenever an existing product publication is published. Requires the `read_publications` scope. */
  ProductPublicationsCreate = 'PRODUCT_PUBLICATIONS_CREATE',
  /** The webhook topic for `product_publications/delete` events. Occurs whenever a product publication for an active product is removed, or whenever an existing product publication is unpublished. Requires the `read_publications` scope. */
  ProductPublicationsDelete = 'PRODUCT_PUBLICATIONS_DELETE',
  /** The webhook topic for `product_publications/update` events. Occurs whenever a product publication is updated. Requires the `read_publications` scope. */
  ProductPublicationsUpdate = 'PRODUCT_PUBLICATIONS_UPDATE',
  /** The webhook topic for `profiles/create` events. Occurs whenever a delivery profile is created Requires the `read_shipping` scope. */
  ProfilesCreate = 'PROFILES_CREATE',
  /** The webhook topic for `profiles/delete` events. Occurs whenever a delivery profile is deleted Requires the `read_shipping` scope. */
  ProfilesDelete = 'PROFILES_DELETE',
  /** The webhook topic for `profiles/update` events. Occurs whenever a delivery profile is updated Requires the `read_shipping` scope. */
  ProfilesUpdate = 'PROFILES_UPDATE',
  /** The webhook topic for `refunds/create` events. Occurs whenever a new refund is created without errors on an order, independent from the movement of money. Requires at least one of the following scopes: read_orders, read_marketplace_orders. */
  RefundsCreate = 'REFUNDS_CREATE',
  /** The webhook topic for `scheduled_product_listings/add` events. Occurs whenever a product is scheduled to be published. Requires the `read_product_listings` scope. */
  ScheduledProductListingsAdd = 'SCHEDULED_PRODUCT_LISTINGS_ADD',
  /** The webhook topic for `scheduled_product_listings/remove` events. Occurs whenever a product is no longer scheduled to be published. Requires the `read_product_listings` scope. */
  ScheduledProductListingsRemove = 'SCHEDULED_PRODUCT_LISTINGS_REMOVE',
  /** The webhook topic for `scheduled_product_listings/update` events. Occurs whenever a product's scheduled availability date changes. Requires the `read_product_listings` scope. */
  ScheduledProductListingsUpdate = 'SCHEDULED_PRODUCT_LISTINGS_UPDATE',
  /** The webhook topic for `selling_plan_groups/create` events. Notifies when a SellingPlanGroup is created. Requires the `read_products` scope. */
  SellingPlanGroupsCreate = 'SELLING_PLAN_GROUPS_CREATE',
  /** The webhook topic for `selling_plan_groups/delete` events. Notifies when a SellingPlanGroup is deleted. Requires the `read_products` scope. */
  SellingPlanGroupsDelete = 'SELLING_PLAN_GROUPS_DELETE',
  /** The webhook topic for `selling_plan_groups/update` events. Notifies when a SellingPlanGroup is updated. Requires the `read_products` scope. */
  SellingPlanGroupsUpdate = 'SELLING_PLAN_GROUPS_UPDATE',
  /** The webhook topic for `shipping_addresses/create` events. Occurs whenever a shipping address is created. Requires the `read_shipping` scope. */
  ShippingAddressesCreate = 'SHIPPING_ADDRESSES_CREATE',
  /** The webhook topic for `shipping_addresses/update` events. Occurs whenever a shipping address is updated. Requires the `read_shipping` scope. */
  ShippingAddressesUpdate = 'SHIPPING_ADDRESSES_UPDATE',
  /** The webhook topic for `shop/update` events. Occurs whenever a shop is updated. */
  ShopUpdate = 'SHOP_UPDATE',
  /** The webhook topic for `subscription_billing_attempts/challenged` events. Occurs when the financial instutition challenges the subscripttion billing attempt charge as per 3D Secure. Requires the `read_own_subscription_contracts` scope. */
  SubscriptionBillingAttemptsChallenged = 'SUBSCRIPTION_BILLING_ATTEMPTS_CHALLENGED',
  /** The webhook topic for `subscription_billing_attempts/failure` events. Occurs whenever a subscription billing attempt fails. Requires the `read_own_subscription_contracts` scope. */
  SubscriptionBillingAttemptsFailure = 'SUBSCRIPTION_BILLING_ATTEMPTS_FAILURE',
  /** The webhook topic for `subscription_billing_attempts/success` events. Occurs whenever a subscription billing attempt succeeds. Requires the `read_own_subscription_contracts` scope. */
  SubscriptionBillingAttemptsSuccess = 'SUBSCRIPTION_BILLING_ATTEMPTS_SUCCESS',
  /** The webhook topic for `subscription_contracts/create` events. Occurs whenever a subscription contract is created. Requires the `read_own_subscription_contracts` scope. */
  SubscriptionContractsCreate = 'SUBSCRIPTION_CONTRACTS_CREATE',
  /** The webhook topic for `subscription_contracts/update` events. Occurs whenever a subscription contract is updated. Requires the `read_own_subscription_contracts` scope. */
  SubscriptionContractsUpdate = 'SUBSCRIPTION_CONTRACTS_UPDATE',
  /** The webhook topic for `tax_services/create` events. Occurs whenever a tax service is created. Requires the `read_taxes` scope. */
  TaxServicesCreate = 'TAX_SERVICES_CREATE',
  /** The webhook topic for `tax_services/update` events. Occurs whenver a tax service is updated. Requires the `read_taxes` scope. */
  TaxServicesUpdate = 'TAX_SERVICES_UPDATE',
  /** The webhook topic for `tender_transactions/create` events. Occurs when a tender transaction is created. Requires the `read_orders` scope. */
  TenderTransactionsCreate = 'TENDER_TRANSACTIONS_CREATE',
  /** The webhook topic for `themes/create` events. Occurs whenever a theme is created. Does not occur when theme files are created. Requires the `read_themes` scope. */
  ThemesCreate = 'THEMES_CREATE',
  /** The webhook topic for `themes/delete` events. Occurs whenever a theme is deleted. Does not occur when theme files are deleted. Requires the `read_themes` scope. */
  ThemesDelete = 'THEMES_DELETE',
  /** The webhook topic for `themes/publish` events. Occurs whenever a theme with the main or mobile (deprecated) role is published. Requires the `read_themes` scope. */
  ThemesPublish = 'THEMES_PUBLISH',
  /** The webhook topic for `themes/update` events. Occurs whenever a theme is updated. Does not occur when theme files are updated. Requires the `read_themes` scope. */
  ThemesUpdate = 'THEMES_UPDATE',
  /** The webhook topic for `variants/in_stock` events. Occurs whenever a variant becomes in stock. Requires the `read_products` scope. */
  VariantsInStock = 'VARIANTS_IN_STOCK',
  /** The webhook topic for `variants/out_of_stock` events. Occurs whenever a variant becomes out of stock. Requires the `read_products` scope. */
  VariantsOutOfStock = 'VARIANTS_OUT_OF_STOCK',
}

/** Return type for `webhookSubscriptionUpdate` mutation. */
export type WebhookSubscriptionUpdatePayload = {
  __typename?: 'WebhookSubscriptionUpdatePayload'
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
  /** The webhook subscription that was updated. */
  webhookSubscription?: Maybe<WebhookSubscription>
}

/** A weight, which includes a numeric value and a unit of measurement. */
export type Weight = {
  __typename?: 'Weight'
  /** The unit of measurement for `value`. */
  unit: WeightUnit
  /** The weight value using the unit system specified with `unit`. */
  value: Scalars['Float']
}

/**
 * Specifies the weight unit and value inputs.
 *
 */
export type WeightInput = {
  /** Unit of measurement for `value`. */
  unit: WeightUnit
  /** The weight value using the unit system specified with `weight_unit`. */
  value: Scalars['Float']
}

/** Units of measurement for weight. */
export enum WeightUnit {
  /** Metric system unit of mass. */
  Grams = 'GRAMS',
  /** 1 kilogram equals 1000 grams. */
  Kilograms = 'KILOGRAMS',
  /** Imperial system unit of mass. */
  Ounces = 'OUNCES',
  /** 1 pound equals 16 ounces. */
  Pounds = 'POUNDS',
}

/** Return type for `deliveryProfileCreate` mutation. */
export type DeliveryProfileCreatePayload = {
  __typename?: 'deliveryProfileCreatePayload'
  /** The delivery profile that was created. */
  profile?: Maybe<DeliveryProfile>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `deliveryProfileRemove` mutation. */
export type DeliveryProfileRemovePayload = {
  __typename?: 'deliveryProfileRemovePayload'
  /** The delivery profile deletion job triggered by the mutation. */
  job?: Maybe<Job>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}

/** Return type for `deliveryProfileUpdate` mutation. */
export type DeliveryProfileUpdatePayload = {
  __typename?: 'deliveryProfileUpdatePayload'
  /** The delivery profile that was updated. */
  profile?: Maybe<DeliveryProfile>
  /** The list of errors that occurred from executing the mutation. */
  userErrors: Array<UserError>
}
